# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if getattr(kaitaistruct, 'API_VERSION', (0, 9)) < (0, 9):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Salsat(KaitaiStruct):
    """:field fsync: salsat_frame.fsync
    :field crc: salsat_frame.crc
    :field fcid_major: salsat_frame.fcid_major
    :field fcid_sub: salsat_frame.fcid_sub
    :field urgent_flag: salsat_frame.urgent_flag
    :field future_use: salsat_frame.future_use
    :field crc_check: salsat_frame.crc_check
    :field multiframe: salsat_frame.multiframe
    :field time_tagged_setting: salsat_frame.time_tagged_setting
    :field time_tagged: salsat_frame.time_tagged
    :field data_length: salsat_frame.data_length
    :field time_tag: salsat_frame.time_tag
    :field fdir_pget_obc_red_num: salsat_frame.user_data_obc_info.fdir_pget_obc_red_num
    :field fdir_pget_rodoserrorcounter: salsat_frame.user_data_obc_info.fdir_pget_rodoserrorcounter
    :field fdir_pget_gitversion: salsat_frame.user_data_obc_info.fdir_pget_gitversion
    :field fdir_pget_compiletimeinsec: salsat_frame.user_data_obc_info.fdir_pget_compiletimeinsec
    :field fdir_pget_ismodifiedversion: salsat_frame.user_data_obc_info.fdir_pget_ismodifiedversion
    :field fdir_pget_runtime: salsat_frame.user_data_fdir_thread_info.fdir_pget_runtime
    :field fdir_pget_buffertime: salsat_frame.user_data_fdir_thread_info.fdir_pget_buffertime
    :field fdir_pget_imalivecounter: salsat_frame.user_data_fdir_thread_info.fdir_pget_imalivecounter
    :field fdir_pget_periodcounter: salsat_frame.user_data_fdir_thread_info.fdir_pget_periodcounter
    :field fdir_pget_realalgotime: salsat_frame.user_data_fdir_thread_info.fdir_pget_realalgotime
    :field link_pget_link_mode: salsat_frame.user_data_link_std_tm.link_pget_link_mode
    :field link_pget_link_mode_last_error: salsat_frame.user_data_link_std_tm.link_pget_link_mode_last_error
    :field link_pdhctrl_pget_state: salsat_frame.user_data_link_std_tm.link_pdhctrl_pget_state
    :field link_stncctrl_pget_state: salsat_frame.user_data_link_std_tm.link_stncctrl_pget_state
    :field link_pget_tnc0recvframecnt: salsat_frame.user_data_link_std_tm.link_pget_tnc0recvframecnt
    :field link_pget_tnc1recvframecnt: salsat_frame.user_data_link_std_tm.link_pget_tnc1recvframecnt
    :field link_pget_activetnc: salsat_frame.user_data_link_std_tm.link_pget_activetnc
    :field link_pdhctrl_pget_activepdh: salsat_frame.user_data_link_std_tm.link_pdhctrl_pget_activepdh
    :field link_pget_tnc0_useflag: salsat_frame.user_data_link_std_tm.link_pget_tnc0_useflag
    :field link_pget_tnc0_useflaglock: salsat_frame.user_data_link_std_tm.link_pget_tnc0_useflaglock
    :field link_pget_tnc0_powerflag: salsat_frame.user_data_link_std_tm.link_pget_tnc0_powerflag
    :field link_pget_tnc0_powerflaglock: salsat_frame.user_data_link_std_tm.link_pget_tnc0_powerflaglock
    :field link_pget_tnc0_healthflag: salsat_frame.user_data_link_std_tm.link_pget_tnc0_healthflag
    :field link_pget_tnc1_useflag: salsat_frame.user_data_link_std_tm.link_pget_tnc1_useflag
    :field link_pget_tnc1_useflaglock: salsat_frame.user_data_link_std_tm.link_pget_tnc1_useflaglock
    :field link_pget_tnc1_powerflag: salsat_frame.user_data_link_std_tm.link_pget_tnc1_powerflag
    :field link_pget_tnc1_powerflaglock: salsat_frame.user_data_link_std_tm.link_pget_tnc1_powerflaglock
    :field link_pget_tnc1_healthflag: salsat_frame.user_data_link_std_tm.link_pget_tnc1_healthflag
    :field link_pget_pdh_payloads_pwr_flag: salsat_frame.user_data_link_std_tm.link_pget_pdh_payloads_pwr_flag
    :field link_pget_pdh0_useflag: salsat_frame.user_data_link_std_tm.link_pget_pdh0_useflag
    :field link_pget_pdh0_useflaglock: salsat_frame.user_data_link_std_tm.link_pget_pdh0_useflaglock
    :field link_pget_pdh0_powerflag: salsat_frame.user_data_link_std_tm.link_pget_pdh0_powerflag
    :field link_pget_pdh0_powerflaglock: salsat_frame.user_data_link_std_tm.link_pget_pdh0_powerflaglock
    :field link_pget_pdh0_healthflag: salsat_frame.user_data_link_std_tm.link_pget_pdh0_healthflag
    :field link_pget_pdh1_useflag: salsat_frame.user_data_link_std_tm.link_pget_pdh1_useflag
    :field link_pget_pdh1_useflaglock: salsat_frame.user_data_link_std_tm.link_pget_pdh1_useflaglock
    :field link_pget_pdh1_powerflag: salsat_frame.user_data_link_std_tm.link_pget_pdh1_powerflag
    :field link_pget_pdh1_powerflaglock: salsat_frame.user_data_link_std_tm.link_pget_pdh1_powerflaglock
    :field link_pget_pdh1_healthflag: salsat_frame.user_data_link_std_tm.link_pget_pdh1_healthflag
    :field link_stncctrl_stnc0_pget_useflag: salsat_frame.user_data_link_std_tm.link_stncctrl_stnc0_pget_useflag
    :field link_stncctrl_stnc0_pget_useflaglocked: salsat_frame.user_data_link_std_tm.link_stncctrl_stnc0_pget_useflaglocked
    :field link_stncctrl_stnc0_pget_powerflag: salsat_frame.user_data_link_std_tm.link_stncctrl_stnc0_pget_powerflag
    :field link_stncctrl_stnc0_pget_powerflaglocked: salsat_frame.user_data_link_std_tm.link_stncctrl_stnc0_pget_powerflaglocked
    :field link_stncctrl_stnc0_pget_healthflag: salsat_frame.user_data_link_std_tm.link_stncctrl_stnc0_pget_healthflag
    :field link_pdhctrl_pget_configuredbaudrate: salsat_frame.user_data_link_pdhctrl_std_tm.link_pdhctrl_pget_configuredbaudrate
    :field link_pdhctrl_pget_receivedframes: salsat_frame.user_data_link_pdhctrl_std_tm.link_pdhctrl_pget_receivedframes
    :field link_pdhctrl_pget_parsedbytecount: salsat_frame.user_data_link_pdhctrl_std_tm.link_pdhctrl_pget_parsedbytecount
    :field user_data_link_pdhctrl_std_tm_link_pdhctrl_pget_activepdh: salsat_frame.user_data_link_pdhctrl_std_tm.link_pdhctrl_pget_activepdh
    :field link_pget_pdh0fwdflag: salsat_frame.user_data_link_pdhctrl_std_tm.link_pget_pdh0fwdflag
    :field link_pdhctrl_pget_syncreceived: salsat_frame.user_data_link_pdhctrl_std_tm.link_pdhctrl_pget_syncreceived
    :field link_pdhctrl_pget_recvtcupstream: salsat_frame.user_data_link_pdhctrl_std_tm.link_pdhctrl_pget_recvtcupstream
    :field link_pdhctrl_pget_fwdtmdownstream: salsat_frame.user_data_link_pdhctrl_std_tm.link_pdhctrl_pget_fwdtmdownstream
    :field link_pget_pdh0runtime: salsat_frame.user_data_link_pdhctrl_std_tm.link_pget_pdh0runtime
    :field link_pget_pdh1runtime: salsat_frame.user_data_link_pdhctrl_std_tm.link_pget_pdh1runtime
    :field link_pget_pdh0runtimethreshold: salsat_frame.user_data_link_pdhctrl_std_tm.link_pget_pdh0runtimethreshold
    :field link_pget_pdh1runtimethreshold: salsat_frame.user_data_link_pdhctrl_std_tm.link_pget_pdh1runtimethreshold
    :field user_data_link_pdhctrl_ext_tm_link_pdhctrl_pget_configuredbaudrate: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_configuredbaudrate
    :field link_pdhctrl_pget_pdhswitchcounter: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_pdhswitchcounter
    :field link_pdhctrl_pget_parsererrorcounter: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_parsererrorcounter
    :field user_data_link_pdhctrl_ext_tm_link_pdhctrl_pget_receivedframes: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_receivedframes
    :field link_pdhctrl_pget_receivedpdhhkframes: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_receivedpdhhkframes
    :field link_pdhctrl_pget_receivedpdhfdirframes: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_receivedpdhfdirframes
    :field link_pdhctrl_pget_receivedsciframes: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_receivedsciframes
    :field user_data_link_pdhctrl_ext_tm_link_pdhctrl_pget_parsedbytecount: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_parsedbytecount
    :field user_data_link_pdhctrl_ext_tm_link_pget_pdh0fwdflag: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pget_pdh0fwdflag
    :field user_data_link_pdhctrl_ext_tm_link_pdhctrl_pget_syncreceived: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_syncreceived
    :field user_data_link_pdhctrl_ext_tm_link_pdhctrl_pget_recvtcupstream: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_recvtcupstream
    :field user_data_link_pdhctrl_ext_tm_link_pdhctrl_pget_fwdtmdownstream: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_fwdtmdownstream
    :field link_pdhctrl_pget_recvpdhtm: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_recvpdhtm
    :field link_pdhctrl_pget_recvscitm: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_recvscitm
    :field link_pdhctrl_pget_recvpdhfdir: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_recvpdhfdir
    :field user_data_link_pdhctrl_ext_tm_link_pdhctrl_pget_activepdh: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pget_activepdh
    :field link_pdhctrl_pdhx_pget_useflag: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pdhx_pget_useflag
    :field link_pdhctrl_pdhx_pget_useflaglocked: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pdhx_pget_useflaglocked
    :field link_pdhctrl_pdhx_pget_powerflag: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pdhx_pget_powerflag
    :field link_pdhctrl_pdhx_pget_powerflaglocked: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pdhx_pget_powerflaglocked
    :field link_pdhctrl_pdhx_pget_healthflag: salsat_frame.user_data_link_pdhctrl_ext_tm.link_pdhctrl_pdhx_pget_healthflag
    :field user_data_link_tnc0_info_link_pget_tnc0_useflag: salsat_frame.user_data_link_tnc0_info.link_pget_tnc0_useflag
    :field user_data_link_tnc0_info_link_pget_tnc0_useflaglock: salsat_frame.user_data_link_tnc0_info.link_pget_tnc0_useflaglock
    :field user_data_link_tnc0_info_link_pget_tnc0_powerflag: salsat_frame.user_data_link_tnc0_info.link_pget_tnc0_powerflag
    :field user_data_link_tnc0_info_link_pget_tnc0_powerflaglock: salsat_frame.user_data_link_tnc0_info.link_pget_tnc0_powerflaglock
    :field user_data_link_tnc0_info_link_pget_tnc0_healthflag: salsat_frame.user_data_link_tnc0_info.link_pget_tnc0_healthflag
    :field link_pget_tnc0_validflag: salsat_frame.user_data_link_tnc0_info.link_pget_tnc0_validflag
    :field user_data_link_tnc1_info_link_pget_tnc1_useflag: salsat_frame.user_data_link_tnc1_info.link_pget_tnc1_useflag
    :field user_data_link_tnc1_info_link_pget_tnc1_useflaglock: salsat_frame.user_data_link_tnc1_info.link_pget_tnc1_useflaglock
    :field user_data_link_tnc1_info_link_pget_tnc1_powerflag: salsat_frame.user_data_link_tnc1_info.link_pget_tnc1_powerflag
    :field user_data_link_tnc1_info_link_pget_tnc1_powerflaglock: salsat_frame.user_data_link_tnc1_info.link_pget_tnc1_powerflaglock
    :field user_data_link_tnc1_info_link_pget_tnc1_healthflag: salsat_frame.user_data_link_tnc1_info.link_pget_tnc1_healthflag
    :field link_pget_tnc1_validflag: salsat_frame.user_data_link_tnc1_info.link_pget_tnc1_validflag
    :field user_data_link_pdh0_info_link_pget_pdh0_useflag: salsat_frame.user_data_link_pdh0_info.link_pget_pdh0_useflag
    :field user_data_link_pdh0_info_link_pget_pdh0_useflaglock: salsat_frame.user_data_link_pdh0_info.link_pget_pdh0_useflaglock
    :field user_data_link_pdh0_info_link_pget_pdh0_powerflag: salsat_frame.user_data_link_pdh0_info.link_pget_pdh0_powerflag
    :field user_data_link_pdh0_info_link_pget_pdh0_powerflaglock: salsat_frame.user_data_link_pdh0_info.link_pget_pdh0_powerflaglock
    :field user_data_link_pdh0_info_link_pget_pdh0_healthflag: salsat_frame.user_data_link_pdh0_info.link_pget_pdh0_healthflag
    :field link_pget_pdh0_validflag: salsat_frame.user_data_link_pdh0_info.link_pget_pdh0_validflag
    :field user_data_link_pdh1_info_link_pget_pdh1_useflag: salsat_frame.user_data_link_pdh1_info.link_pget_pdh1_useflag
    :field user_data_link_pdh1_info_link_pget_pdh1_useflaglock: salsat_frame.user_data_link_pdh1_info.link_pget_pdh1_useflaglock
    :field user_data_link_pdh1_info_link_pget_pdh1_powerflag: salsat_frame.user_data_link_pdh1_info.link_pget_pdh1_powerflag
    :field user_data_link_pdh1_info_link_pget_pdh1_powerflaglock: salsat_frame.user_data_link_pdh1_info.link_pget_pdh1_powerflaglock
    :field user_data_link_pdh1_info_link_pget_pdh1_healthflag: salsat_frame.user_data_link_pdh1_info.link_pget_pdh1_healthflag
    :field link_pget_pdh1_validflag: salsat_frame.user_data_link_pdh1_info.link_pget_pdh1_validflag
    :field user_data_link_stncctrl_std_tm_link_pdhctrl_pget_configuredbaudrate: salsat_frame.user_data_link_stncctrl_std_tm.link_pdhctrl_pget_configuredbaudrate
    :field user_data_link_stncctrl_std_tm_link_pdhctrl_pget_receivedframes: salsat_frame.user_data_link_stncctrl_std_tm.link_pdhctrl_pget_receivedframes
    :field user_data_link_stncctrl_std_tm_link_pdhctrl_pget_parsedbytecount: salsat_frame.user_data_link_stncctrl_std_tm.link_pdhctrl_pget_parsedbytecount
    :field user_data_link_stncctrl_std_tm_link_pdhctrl_pget_syncreceived: salsat_frame.user_data_link_stncctrl_std_tm.link_pdhctrl_pget_syncreceived
    :field user_data_link_stncctrl_std_tm_link_pdhctrl_pget_recvtcupstream: salsat_frame.user_data_link_stncctrl_std_tm.link_pdhctrl_pget_recvtcupstream
    :field user_data_link_stncctrl_std_tm_link_pdhctrl_pget_fwdtmdownstream: salsat_frame.user_data_link_stncctrl_std_tm.link_pdhctrl_pget_fwdtmdownstream
    :field user_data_link_stncctrl_std_tm_link_pget_pdh0runtime: salsat_frame.user_data_link_stncctrl_std_tm.link_pget_pdh0runtime
    :field user_data_link_stncctrl_std_tm_link_pget_pdh0runtimethreshold: salsat_frame.user_data_link_stncctrl_std_tm.link_pget_pdh0runtimethreshold
    :field link_pget_predictedfifosize256: salsat_frame.user_data_link_stncctrl_std_tm.link_pget_predictedfifosize256
    :field link_pget_predictedfifosize64: salsat_frame.user_data_link_stncctrl_std_tm.link_pget_predictedfifosize64
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_configuredbaudrate: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_configuredbaudrate
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_parsererrorcounter: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_parsererrorcounter
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_receivedframes: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_receivedframes
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_receivedpdhhkframes: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_receivedpdhhkframes
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_receivedpdhfdirframes: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_receivedpdhfdirframes
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_receivedsciframes: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_receivedsciframes
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_parsedbytecount: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_parsedbytecount
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_syncreceived: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_syncreceived
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_recvtcupstream: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_recvtcupstream
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_fwdtmdownstream: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_fwdtmdownstream
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_recvpdhtm: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_recvpdhtm
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_recvscitm: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_recvscitm
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pget_recvpdhfdir: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pget_recvpdhfdir
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pdhx_pget_useflag: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pdhx_pget_useflag
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pdhx_pget_useflaglocked: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pdhx_pget_useflaglocked
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pdhx_pget_powerflag: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pdhx_pget_powerflag
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pdhx_pget_powerflaglocked: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pdhx_pget_powerflaglocked
    :field user_data_link_stncctrl_ext_tm_link_pdhctrl_pdhx_pget_healthflag: salsat_frame.user_data_link_stncctrl_ext_tm.link_pdhctrl_pdhx_pget_healthflag
    :field user_data_link_stnc_info_link_pget_pdh0_useflag: salsat_frame.user_data_link_stnc_info.link_pget_pdh0_useflag
    :field user_data_link_stnc_info_link_pget_pdh0_useflaglock: salsat_frame.user_data_link_stnc_info.link_pget_pdh0_useflaglock
    :field user_data_link_stnc_info_link_pget_pdh0_powerflag: salsat_frame.user_data_link_stnc_info.link_pget_pdh0_powerflag
    :field user_data_link_stnc_info_link_pget_pdh0_powerflaglock: salsat_frame.user_data_link_stnc_info.link_pget_pdh0_powerflaglock
    :field user_data_link_stnc_info_link_pget_pdh0_healthflag: salsat_frame.user_data_link_stnc_info.link_pget_pdh0_healthflag
    :field user_data_link_stnc_info_link_pget_pdh0_validflag: salsat_frame.user_data_link_stnc_info.link_pget_pdh0_validflag
    :field link_pget_linksessionopened: salsat_frame.user_data_link_stnc_slink_com_info.link_pget_linksessionopened
    :field pdh_pget_sessionopened: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_sessionopened
    :field pdh_pget_arquplinkack: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_arquplinkack
    :field pdh_pget_comtxon: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_comtxon
    :field pdh_pget_comrxon: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_comrxon
    :field pdh_pget_comautotm: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_comautotm
    :field pdh_pget_txrepeatmode: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_txrepeatmode
    :field pdh_pget_fifonumfreesdutxa: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_fifonumfreesdutxa
    :field pdh_pget_fifonumfreesdutxb: salsat_frame.user_data_link_stnc_slink_com_info.pdh_pget_fifonumfreesdutxb
    :field user_data_link_com_mode_link_pget_link_mode: salsat_frame.user_data_link_com_mode.link_pget_link_mode
    :field user_data_link_com_mode_link_pget_link_mode_last_error: salsat_frame.user_data_link_com_mode.link_pget_link_mode_last_error
    :field link_pget_max_mode_time: salsat_frame.user_data_link_com_mode.link_pget_max_mode_time
    :field link_pget_max_transition_time: salsat_frame.user_data_link_com_mode.link_pget_max_transition_time
    :field link_pget_max_stnchktmwaittime: salsat_frame.user_data_link_com_mode.link_pget_max_stnchktmwaittime
    :field link_pget_max_stnccomtmwaittime: salsat_frame.user_data_link_com_mode.link_pget_max_stnccomtmwaittime
    :field pdh_pget_slkprognum: salsat_frame.user_data_link_com_mode.pdh_pget_slkprognum
    :field user_data_link_com_mode_pdh_pget_txrepeatmode: salsat_frame.user_data_link_com_mode.pdh_pget_txrepeatmode
    :field pdh_pget_arqonuplink: salsat_frame.user_data_link_com_mode.pdh_pget_arqonuplink
    :field user_data_link_com_mode_pdh_pget_comtxon: salsat_frame.user_data_link_com_mode.pdh_pget_comtxon
    :field user_data_link_com_mode_pdh_pget_comrxon: salsat_frame.user_data_link_com_mode.pdh_pget_comrxon
    :field user_data_link_com_mode_pdh_pget_comautotm: salsat_frame.user_data_link_com_mode.pdh_pget_comautotm
    :field link_pget_uhfmode_allow_slink_on: salsat_frame.user_data_link_com_mode.link_pget_uhfmode_allow_slink_on
    :field pdh_pget_pleps_link_frames_received: salsat_frame.user_data_pdh_pleps_link_rq_std_tm.pdh_pget_pleps_link_frames_received
    :field pdh_pget_pleps_link_frames_sent: salsat_frame.user_data_pdh_pleps_link_rq_std_tm.pdh_pget_pleps_link_frames_sent
    :field pdh_pget_pleps_ctrl_pwr_fda: salsat_frame.user_data_pdh_pleps_rq_fda_pwr.pdh_pget_pleps_ctrl_pwr_fda
    :field user_data_pdh_pleps_link_thread_info_fdir_pget_runtime: salsat_frame.user_data_pdh_pleps_link_thread_info.fdir_pget_runtime
    :field user_data_pdh_pleps_link_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_pdh_pleps_link_thread_info.fdir_pget_imalivecounter
    :field user_data_pdh_pleps_link_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_pdh_pleps_link_thread_info.fdir_pget_realalgotime
    :field sat_pget_obc_act: salsat_frame.user_data_pdh_pleps_sat_std_tm.sat_pget_obc_act
    :field sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_pdh_pleps_sat_std_tm.sat_pget_fw_updater_activeslotnum
    :field sat_pget_selectedslotnum: salsat_frame.user_data_pdh_pleps_sat_std_tm.sat_pget_selectedslotnum
    :field sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_pdh_pleps_sat_std_tm.sat_pget_currentlyrunningsoftwareslot
    :field sat_pget_realalgotime: salsat_frame.user_data_pdh_pleps_sat_std_tm.sat_pget_realalgotime
    :field sat_pget_obt_utc_cddayofmonth: salsat_frame.user_data_pdh_pleps_sat_obt_utc.sat_pget_obt_utc_cddayofmonth
    :field sat_pget_obt_utc_cdmonth: salsat_frame.user_data_pdh_pleps_sat_obt_utc.sat_pget_obt_utc_cdmonth
    :field sat_pget_obt_utc_cdyear: salsat_frame.user_data_pdh_pleps_sat_obt_utc.sat_pget_obt_utc_cdyear
    :field sat_pget_obt_utc_cdhour: salsat_frame.user_data_pdh_pleps_sat_obt_utc.sat_pget_obt_utc_cdhour
    :field sat_pget_obt_utc_cdminute: salsat_frame.user_data_pdh_pleps_sat_obt_utc.sat_pget_obt_utc_cdminute
    :field sat_pget_obt_utc_second: salsat_frame.user_data_pdh_pleps_sat_obt_utc.sat_pget_obt_utc_second
    :field sat_pget_obt_utc_ns: salsat_frame.user_data_pdh_pleps_sat_obt_utc_ns.sat_pget_obt_utc_ns
    :field user_data_pdh_pleps_fw_update_tm_sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_currentlyrunningsoftwareslot
    :field sat_pget_fw_updater_state: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_state
    :field user_data_pdh_pleps_fw_update_tm_sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_activeslotnum
    :field sat_pget_fw_updater_tmpimgaddr: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_tmpimgaddr
    :field user_data_pdh_pleps_fw_update_tm_sat_pget_selectedslotnum: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_selectedslotnum
    :field sat_pget_fw_updater_slotnumundererase: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slotnumundererase
    :field sat_pget_fw_updater_slotnumundercrc: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slotnumundercrc
    :field sat_pget_fw_updater_activeimagelength: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_activeimagelength
    :field sat_pget_fw_updater_numwrittensequences: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_numwrittensequences
    :field sat_pget_fw_updater_nextexpectedsequence: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_nextexpectedsequence
    :field sat_pget_fw_updater_totalmissingsequences: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_totalmissingsequences
    :field sat_pget_fw_updater_missingsequenceswriteidx: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_missingsequenceswriteidx
    :field sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slot0_isfree
    :field sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slot1_isfree
    :field sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_pdh_pleps_fw_update_tm.sat_pget_fw_updater_slot2_isfree
    :field user_data_pdh_pleps_fw_update_slot_tm_sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field user_data_pdh_pleps_fw_update_slot_tm_sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field user_data_pdh_pleps_fw_update_slot_tm_sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field user_data_pdh_pleps_fw_update_slot_tm_sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot0_isfree
    :field user_data_pdh_pleps_fw_update_slot_tm_sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot1_isfree
    :field user_data_pdh_pleps_fw_update_slot_tm_sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot2_isfree
    :field sat_pget_fw_updater_slot0_isundererase: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot0_isundererase
    :field sat_pget_fw_updater_slot1_isundererase: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot1_isundererase
    :field sat_pget_fw_updater_slot2_isundererase: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot2_isundererase
    :field sat_pget_fw_updater_slot0_ishealthy: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot0_ishealthy
    :field sat_pget_fw_updater_slot1_ishealthy: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot1_ishealthy
    :field sat_pget_fw_updater_slot2_ishealthy: salsat_frame.user_data_pdh_pleps_fw_update_slot_tm.sat_pget_fw_updater_slot2_ishealthy
    :field sat_pget_fw_updater_missingsequencestartarray: salsat_frame.user_data_pdh_pleps_fw_update_missingintervalls.sat_pget_fw_updater_missingsequencestartarray
    :field sat_pget_fw_updater_missingsequenceendarray: salsat_frame.user_data_pdh_pleps_fw_update_missingintervalls.sat_pget_fw_updater_missingsequenceendarray
    :field user_data_pdh_pleps_info_fdir_pget_rodoserrorcounter: salsat_frame.user_data_pdh_pleps_info.fdir_pget_rodoserrorcounter
    :field user_data_pdh_pleps_info_fdir_pget_gitversion: salsat_frame.user_data_pdh_pleps_info.fdir_pget_gitversion
    :field user_data_pdh_pleps_info_fdir_pget_compiletimeinsec: salsat_frame.user_data_pdh_pleps_info.fdir_pget_compiletimeinsec
    :field shared_reset_counter: salsat_frame.user_data_pdh_pleps_info.shared_reset_counter
    :field user_data_pdh_pleps_info_fdir_pget_ismodifiedversion: salsat_frame.user_data_pdh_pleps_info.fdir_pget_ismodifiedversion
    :field user_data_pdh_pleps_sat_thread_info_fdir_pget_runtime: salsat_frame.user_data_pdh_pleps_sat_thread_info.fdir_pget_runtime
    :field user_data_pdh_pleps_sat_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_pdh_pleps_sat_thread_info.fdir_pget_imalivecounter
    :field user_data_pdh_pleps_sat_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_pdh_pleps_sat_thread_info.fdir_pget_realalgotime
    :field pdh_pleps_pget_v_salsa: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_salsa
    :field pdh_pleps_pget_i_salsa: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_salsa
    :field pdh_pleps_pget_v_fu: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_fu
    :field pdh_pleps_pget_i_fu: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_fu
    :field pdh_pleps_pget_v_fda_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_fda_3v3
    :field pdh_pleps_pget_i_fda_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_fda_3v3
    :field pdh_pleps_pget_v_fda_unreg: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_fda_unreg
    :field pdh_pleps_pget_i_fda_unreg: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_fda_unreg
    :field pdh_pleps_pget_v_gyro_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_gyro_3v3
    :field pdh_pleps_pget_i_gyro_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_gyro_3v3
    :field pdh_pleps_pget_v_gyro_unreg: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_gyro_unreg
    :field pdh_pleps_pget_i_gyro_unreg: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_gyro_unreg
    :field pdh_pleps_pget_v_pdh0_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_pdh0_3v3
    :field pdh_pleps_pget_i_pdh0_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_pdh0_3v3
    :field pdh_pleps_pget_v_pdh1_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_v_pdh1_3v3
    :field pdh_pleps_pget_i_pdh1_3v3: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_i_pdh1_3v3
    :field pdh_pleps_pget_t_myc_int: salsat_frame.user_data_pdh_pleps_hk_rq_std_tm.pdh_pleps_pget_t_myc_int
    :field pdh_pleps_pget_max_v_salsa: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_salsa
    :field pdh_pleps_pget_max_v_fu: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_fu
    :field pdh_pleps_pget_max_v_fda_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_fda_3v3
    :field pdh_pleps_pget_max_v_fda_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_fda_unreg
    :field pdh_pleps_pget_max_v_gyro_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_gyro_3v3
    :field pdh_pleps_pget_max_v_gyro_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_gyro_unreg
    :field pdh_pleps_pget_max_v_pdh0_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_pdh0_3v3
    :field pdh_pleps_pget_max_v_pdh1_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm.pdh_pleps_pget_max_v_pdh1_3v3
    :field pdh_pleps_pget_max_i_salsa: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_salsa
    :field pdh_pleps_pget_max_i_fu: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_fu
    :field pdh_pleps_pget_max_i_fda_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_fda_3v3
    :field pdh_pleps_pget_max_i_fda_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_fda_unreg
    :field pdh_pleps_pget_max_i_gyro_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_gyro_3v3
    :field pdh_pleps_pget_max_i_gyro_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_gyro_unreg
    :field pdh_pleps_pget_max_i_pdh0_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_pdh0_3v3
    :field pdh_pleps_pget_max_i_pdh1_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm.pdh_pleps_pget_max_i_pdh1_3v3
    :field pdh_pleps_pget_min_v_salsa: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_salsa
    :field pdh_pleps_pget_min_v_fu: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_fu
    :field pdh_pleps_pget_min_v_fda_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_fda_3v3
    :field pdh_pleps_pget_min_v_fda_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_fda_unreg
    :field pdh_pleps_pget_min_v_gyro_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_gyro_3v3
    :field pdh_pleps_pget_min_v_gyro_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_gyro_unreg
    :field pdh_pleps_pget_min_v_pdh0_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_pdh0_3v3
    :field pdh_pleps_pget_min_v_pdh1_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm.pdh_pleps_pget_min_v_pdh1_3v3
    :field pdh_pleps_pget_min_i_salsa: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_salsa
    :field pdh_pleps_pget_min_i_fu: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_fu
    :field pdh_pleps_pget_min_i_fda_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_fda_3v3
    :field pdh_pleps_pget_min_i_fda_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_fda_unreg
    :field pdh_pleps_pget_min_i_gyro_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_gyro_3v3
    :field pdh_pleps_pget_min_i_gyro_unreg: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_gyro_unreg
    :field pdh_pleps_pget_min_i_pdh0_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_pdh0_3v3
    :field pdh_pleps_pget_min_i_pdh1_3v3: salsat_frame.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm.pdh_pleps_pget_min_i_pdh1_3v3
    :field pdh_pget_pleps_ctrl_pwr_salsa: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_salsa
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_salsa: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_salsa
    :field pdh_pget_pleps_ctrl_pwr_fu: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_fu
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_fu: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_fu
    :field pdh_pget_pleps_ctrl_pwr_fda_3v3: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_fda_3v3
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_fda_3v3: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_fda_3v3
    :field pdh_pget_pleps_ctrl_pwr_fda_unreg: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_fda_unreg
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_fda_unreg: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_fda_unreg
    :field pdh_pget_pleps_ctrl_pwr_gyro_3v3: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_gyro_3v3
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_gyro_3v3: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_gyro_3v3
    :field pdh_pget_pleps_ctrl_pwr_gyro_unreg: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_gyro_unreg
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_gyro_unreg: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_gyro_unreg
    :field pdh_pget_pleps_ctrl_pwr_pdh0: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_pdh0
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_pdh0_3v3: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_pdh0_3v3
    :field pdh_pget_pleps_ctrl_pwr_pdh1: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pget_pleps_ctrl_pwr_pdh1
    :field user_data_pdh_pleps_switch_state_pdh_pleps_pget_i_pdh1_3v3: salsat_frame.user_data_pdh_pleps_switch_state.pdh_pleps_pget_i_pdh1_3v3
    :field pget_memt_type: salsat_frame.user_data_pdh_pleps_sram_check_res.pget_memt_type
    :field pget_memt_int_min: salsat_frame.user_data_pdh_pleps_sram_check_res.pget_memt_int_min
    :field pget_memt_dur_min: salsat_frame.user_data_pdh_pleps_sram_check_res.pget_memt_dur_min
    :field pget_memt_res: salsat_frame.user_data_pdh_pleps_sram_check_res.pget_memt_res
    :field pget_memt_state: salsat_frame.user_data_pdh_pleps_sram_check_res.pget_memt_state
    :field pget_memt_err_cnt: salsat_frame.user_data_pdh_pleps_sram_check_res.pget_memt_err_cnt
    :field user_data_pdh_pleps_norf_check_res_pget_memt_type: salsat_frame.user_data_pdh_pleps_norf_check_res.pget_memt_type
    :field user_data_pdh_pleps_norf_check_res_pget_memt_int_min: salsat_frame.user_data_pdh_pleps_norf_check_res.pget_memt_int_min
    :field user_data_pdh_pleps_norf_check_res_pget_memt_dur_min: salsat_frame.user_data_pdh_pleps_norf_check_res.pget_memt_dur_min
    :field user_data_pdh_pleps_norf_check_res_pget_memt_res: salsat_frame.user_data_pdh_pleps_norf_check_res.pget_memt_res
    :field user_data_pdh_pleps_norf_check_res_pget_memt_state: salsat_frame.user_data_pdh_pleps_norf_check_res.pget_memt_state
    :field user_data_pdh_pleps_norf_check_res_pget_memt_err_cnt: salsat_frame.user_data_pdh_pleps_norf_check_res.pget_memt_err_cnt
    :field user_data_pdh_pleps_hk_thread_info_fdir_pget_runtime: salsat_frame.user_data_pdh_pleps_hk_thread_info.fdir_pget_runtime
    :field user_data_pdh_pleps_hk_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_pdh_pleps_hk_thread_info.fdir_pget_imalivecounter
    :field user_data_pdh_pleps_hk_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_pdh_pleps_hk_thread_info.fdir_pget_realalgotime
    :field user_data_pdh_pleps_sctrl_rq_std_tm_pdh_pget_pleps_ctrl_pwr_salsa: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pget_pleps_ctrl_pwr_salsa
    :field pdh_pget_pleps_ctrl_pwr_state: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pget_pleps_ctrl_pwr_state
    :field pdh_pleps_pget_rf_switch: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pleps_pget_rf_switch
    :field pdh_pleps_pget_rf_block_utrx: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pleps_pget_rf_block_utrx
    :field pdh_pleps_pget_utrx0_ptt: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pleps_pget_utrx0_ptt
    :field pdh_pleps_pget_utrx1_ptt: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pleps_pget_utrx1_ptt
    :field pdh_pset_pget_rf_switch_time: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pset_pget_rf_switch_time
    :field pdh_pleps_pget_salsa_ctrl_reset_counter: salsat_frame.user_data_pdh_pleps_sctrl_rq_std_tm.pdh_pleps_pget_salsa_ctrl_reset_counter
    :field pdh_pleps_pget_scrtl_status_check_interval: salsat_frame.user_data_pdh_pleps_sctrl_config_status.pdh_pleps_pget_scrtl_status_check_interval
    :field pdh_pleps_pget_scrtl_auto_tm_interval: salsat_frame.user_data_pdh_pleps_sctrl_config_status.pdh_pleps_pget_scrtl_auto_tm_interval
    :field pdh_pleps_pget_scrtl_auto_tm_flag: salsat_frame.user_data_pdh_pleps_sctrl_config_status.pdh_pleps_pget_scrtl_auto_tm_flag
    :field pdh_pleps_pget_salsa_auto_reset_flag: salsat_frame.user_data_pdh_pleps_sctrl_config_status.pdh_pleps_pget_salsa_auto_reset_flag
    :field pdh_pget_pleps_sctrl_frames_received: salsat_frame.user_data_pdh_pleps_sctrl_frame_counter.pdh_pget_pleps_sctrl_frames_received
    :field pdh_pget_pleps_sctrl_frames_sent: salsat_frame.user_data_pdh_pleps_sctrl_frame_counter.pdh_pget_pleps_sctrl_frames_sent
    :field pdh_pget_sctrl_fwd_mode: salsat_frame.user_data_pdh_pleps_sctrl_get_fwd_mode.pdh_pget_sctrl_fwd_mode
    :field user_data_pdh_pleps_salsa_ctrl_thread_info_fdir_pget_runtime: salsat_frame.user_data_pdh_pleps_salsa_ctrl_thread_info.fdir_pget_runtime
    :field user_data_pdh_pleps_salsa_ctrl_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_pdh_pleps_salsa_ctrl_thread_info.fdir_pget_imalivecounter
    :field user_data_pdh_pleps_salsa_ctrl_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_pdh_pleps_salsa_ctrl_thread_info.fdir_pget_realalgotime
    :field pdh_pget_pleps_ctrl_fda_state: salsat_frame.user_data_pdh_pleps_fda_ctrl_rq_std_tm.pdh_pget_pleps_ctrl_fda_state
    :field pdh_pget_pleps_ctrl_gyro_state: salsat_frame.user_data_pdh_pleps_fda_ctrl_rq_std_tm.pdh_pget_pleps_ctrl_gyro_state
    :field pdh_pget_pleps_ctrl_pwr_3v3_fda: salsat_frame.user_data_pdh_pleps_fda_ctrl_rq_std_tm.pdh_pget_pleps_ctrl_pwr_3v3_fda
    :field pdh_pget_pleps_ctrl_pwr_3v3_gyro: salsat_frame.user_data_pdh_pleps_fda_ctrl_rq_std_tm.pdh_pget_pleps_ctrl_pwr_3v3_gyro
    :field pdh_pget_pleps_ctrl_pwr_unreg_fda: salsat_frame.user_data_pdh_pleps_fda_ctrl_rq_std_tm.pdh_pget_pleps_ctrl_pwr_unreg_fda
    :field pdh_pget_pleps_ctrl_pwr_unreg_gyro: salsat_frame.user_data_pdh_pleps_fda_ctrl_rq_std_tm.pdh_pget_pleps_ctrl_pwr_unreg_gyro
    :field pdh_pget_pleps_ctrl_fda_uart_switch_enable: salsat_frame.user_data_pdh_pleps_fda_ctrl_rq_std_tm.pdh_pget_pleps_ctrl_fda_uart_switch_enable
    :field user_data_pdh_pleps_fda_ctrl_thread_info_fdir_pget_runtime: salsat_frame.user_data_pdh_pleps_fda_ctrl_thread_info.fdir_pget_runtime
    :field user_data_pdh_pleps_fda_ctrl_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_pdh_pleps_fda_ctrl_thread_info.fdir_pget_imalivecounter
    :field user_data_pdh_pleps_fda_ctrl_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_pdh_pleps_fda_ctrl_thread_info.fdir_pget_realalgotime
    :field pdh_pget_pleps_ipu_ctrl_state: salsat_frame.user_data_pdh_pleps_ipu_ctrl_status.pdh_pget_pleps_ipu_ctrl_state
    :field pdh_pleps_pget_ipu_status_check_interval: salsat_frame.user_data_pdh_pleps_ipu_ctrl_status.pdh_pleps_pget_ipu_status_check_interval
    :field pdh_pget_pleps_ipu_frames_received: salsat_frame.user_data_pdh_pleps_ipu_frame_counter.pdh_pget_pleps_ipu_frames_received
    :field pdh_pget_pleps_ipu_frames_sent: salsat_frame.user_data_pdh_pleps_ipu_frame_counter.pdh_pget_pleps_ipu_frames_sent
    :field user_data_pdh_pleps_ipu_ctrl_thread_info_fdir_pget_runtime: salsat_frame.user_data_pdh_pleps_ipu_ctrl_thread_info.fdir_pget_runtime
    :field user_data_pdh_pleps_ipu_ctrl_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_pdh_pleps_ipu_ctrl_thread_info.fdir_pget_imalivecounter
    :field user_data_pdh_pleps_ipu_ctrl_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_pdh_pleps_ipu_ctrl_thread_info.fdir_pget_realalgotime
    :field sat_pget_rtc_centiseconds: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_centiseconds
    :field sat_pget_rtc_seconds: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_seconds
    :field sat_pget_rtc_minutes: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_minutes
    :field sat_pget_rtc_hours: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_hours
    :field sat_pget_rtc_dayofweek: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_dayofweek
    :field sat_pget_rtc_dayofmonth: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_dayofmonth
    :field sat_pget_rtc_monthandcentury: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_monthandcentury
    :field sat_pget_rtc_year: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_year
    :field sat_pget_rtc_alarmcentiseconds: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_alarmcentiseconds
    :field sat_pget_rtc_alarmseconds: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_alarmseconds
    :field sat_pget_rtc_alarmminutes: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_alarmminutes
    :field sat_pget_rtc_alarmhours: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_alarmhours
    :field sat_pget_rtc_alarmdayordate: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_alarmdayordate
    :field sat_pget_rtc_controlreg: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_controlreg
    :field sat_pget_rtc_statusreg: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_statusreg
    :field sat_pget_rtc_tricklecharger: salsat_frame.user_data_sat_rtc_registerraw.sat_pget_rtc_tricklecharger
    :field sat_pget_rtc_useflag: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_useflag
    :field sat_pget_rtc_useflaglock: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_useflaglock
    :field sat_pget_rtc_powerflag: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_powerflag
    :field sat_pget_rtc_powerflaglock: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_powerflaglock
    :field sat_pget_rtc_healthflag: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_healthflag
    :field sat_pget_rtc_validflag: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_validflag
    :field sat_pget_rtc_alarminterruptflag: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_alarminterruptflag
    :field sat_pget_rtc_rtcwassetatwakeup: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_rtcwassetatwakeup
    :field sat_pget_rtc_oscstopflagatwakeup: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_oscstopflagatwakeup
    :field sat_pget_rtc_alarmflagatwakeup: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_alarmflagatwakeup
    :field sat_pget_rtc_state: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_state
    :field sat_pget_rtc_errorcounter: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_errorcounter
    :field sat_pget_rtc_configuredbaudrate: salsat_frame.user_data_sat_rtc_info.sat_pget_rtc_configuredbaudrate
    :field user_data_sat_std_tm_sat_pget_obc_act: salsat_frame.user_data_sat_std_tm.sat_pget_obc_act
    :field user_data_sat_std_tm_sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_sat_std_tm.sat_pget_fw_updater_activeslotnum
    :field user_data_sat_std_tm_sat_pget_selectedslotnum: salsat_frame.user_data_sat_std_tm.sat_pget_selectedslotnum
    :field user_data_sat_std_tm_sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_sat_std_tm.sat_pget_currentlyrunningsoftwareslot
    :field sat_pget_leop_doleop: salsat_frame.user_data_sat_std_tm.sat_pget_leop_doleop
    :field sat_pget_leop_isstarted: salsat_frame.user_data_sat_std_tm.sat_pget_leop_isstarted
    :field user_data_sat_std_tm_sat_pget_realalgotime: salsat_frame.user_data_sat_std_tm.sat_pget_realalgotime
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot0_isfree
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot1_isfree
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot2_isfree
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot0_isundererase: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot0_isundererase
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot1_isundererase: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot1_isundererase
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot2_isundererase: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot2_isundererase
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot0_ishealthy: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot0_ishealthy
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot1_ishealthy: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot1_ishealthy
    :field user_data_sat_fw_update_slot_tm_sat_pget_fw_updater_slot2_ishealthy: salsat_frame.user_data_sat_fw_update_slot_tm.sat_pget_fw_updater_slot2_ishealthy
    :field user_data_sat_obt_utc_sat_pget_obt_utc_cddayofmonth: salsat_frame.user_data_sat_obt_utc.sat_pget_obt_utc_cddayofmonth
    :field user_data_sat_obt_utc_sat_pget_obt_utc_cdmonth: salsat_frame.user_data_sat_obt_utc.sat_pget_obt_utc_cdmonth
    :field user_data_sat_obt_utc_sat_pget_obt_utc_cdyear: salsat_frame.user_data_sat_obt_utc.sat_pget_obt_utc_cdyear
    :field user_data_sat_obt_utc_sat_pget_obt_utc_cdhour: salsat_frame.user_data_sat_obt_utc.sat_pget_obt_utc_cdhour
    :field user_data_sat_obt_utc_sat_pget_obt_utc_cdminute: salsat_frame.user_data_sat_obt_utc.sat_pget_obt_utc_cdminute
    :field user_data_sat_obt_utc_sat_pget_obt_utc_second: salsat_frame.user_data_sat_obt_utc.sat_pget_obt_utc_second
    :field sat_pget_rtc_cddayofmonth: salsat_frame.user_data_sat_rtc_time.sat_pget_rtc_cddayofmonth
    :field sat_pget_rtc_cdmonth: salsat_frame.user_data_sat_rtc_time.sat_pget_rtc_cdmonth
    :field sat_pget_rtc_cdyear: salsat_frame.user_data_sat_rtc_time.sat_pget_rtc_cdyear
    :field sat_pget_rtc_cdhour: salsat_frame.user_data_sat_rtc_time.sat_pget_rtc_cdhour
    :field sat_pget_rtc_cdminute: salsat_frame.user_data_sat_rtc_time.sat_pget_rtc_cdminute
    :field sat_pget_rtc_cdsecond: salsat_frame.user_data_sat_rtc_time.sat_pget_rtc_cdsecond
    :field user_data_sat_obt_utc_ns_sat_pget_obt_utc_ns: salsat_frame.user_data_sat_obt_utc_ns.sat_pget_obt_utc_ns
    :field sat_pget_heater0_useflag: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_useflag
    :field sat_pget_heater0_useflaglock: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_useflaglock
    :field sat_pget_heater0_powerflag: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_powerflag
    :field sat_pget_heater0_powerflaglock: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_powerflaglock
    :field sat_pget_heater0_healthflag: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_healthflag
    :field sat_pget_heater0_validflag: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_validflag
    :field sat_pget_heater0_togglecounter: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_togglecounter
    :field sat_pget_heater0_totalglowtime: salsat_frame.user_data_sat_heater0_info.sat_pget_heater0_totalglowtime
    :field sat_pget_heater1_useflag: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_useflag
    :field sat_pget_heater1_useflaglock: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_useflaglock
    :field sat_pget_heater1_powerflag: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_powerflag
    :field sat_pget_heater1_powerflaglock: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_powerflaglock
    :field sat_pget_heater1_healthflag: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_healthflag
    :field sat_pget_heater1_validflag: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_validflag
    :field sat_pget_heater1_togglecounter: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_togglecounter
    :field sat_pget_heater1_totalglowtime: salsat_frame.user_data_sat_heater1_info.sat_pget_heater1_totalglowtime
    :field user_data_sat_leop_info_sat_pget_leop_doleop: salsat_frame.user_data_sat_leop_info.sat_pget_leop_doleop
    :field user_data_sat_leop_info_sat_pget_leop_isstarted: salsat_frame.user_data_sat_leop_info.sat_pget_leop_isstarted
    :field sat_pget_leop_isfinished: salsat_frame.user_data_sat_leop_info.sat_pget_leop_isfinished
    :field sat_pget_leop_substate: salsat_frame.user_data_sat_leop_info.sat_pget_leop_substate
    :field sat_pget_leop_runtime: salsat_frame.user_data_sat_leop_info.sat_pget_leop_runtime
    :field user_data_sat_fw_update_missingintervalls_sat_pget_fw_updater_missingsequencestartarray: salsat_frame.user_data_sat_fw_update_missingintervalls.sat_pget_fw_updater_missingsequencestartarray
    :field user_data_sat_fw_update_missingintervalls_sat_pget_fw_updater_missingsequenceendarray: salsat_frame.user_data_sat_fw_update_missingintervalls.sat_pget_fw_updater_missingsequenceendarray
    :field user_data_sat_fw_update_tm_sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_sat_fw_update_tm.sat_pget_currentlyrunningsoftwareslot
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_state: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_state
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_activeslotnum
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_tmpimgaddr: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_tmpimgaddr
    :field user_data_sat_fw_update_tm_sat_pget_selectedslotnum: salsat_frame.user_data_sat_fw_update_tm.sat_pget_selectedslotnum
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slotnumundererase: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slotnumundererase
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slotnumundercrc: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slotnumundercrc
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_activeimagelength: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_activeimagelength
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_numwrittensequences: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_numwrittensequences
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_nextexpectedsequence: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_nextexpectedsequence
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_totalmissingsequences: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_totalmissingsequences
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_missingsequenceswriteidx: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_missingsequenceswriteidx
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slot0_isfree
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slot1_isfree
    :field user_data_sat_fw_update_tm_sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_sat_fw_update_tm.sat_pget_fw_updater_slot2_isfree
    :field fda_pget_device: salsat_frame.user_data_fda_tm_std.fda_pget_device
    :field fda_pget_mode: salsat_frame.user_data_fda_tm_std.fda_pget_mode
    :field fda_pget_power_mode: salsat_frame.user_data_fda_tm_std.fda_pget_power_mode
    :field fda_pget_rot_dir: salsat_frame.user_data_fda_tm_std.fda_pget_rot_dir
    :field fda_pget_flag_fu: salsat_frame.user_data_fda_tm_std.fda_pget_flag_fu
    :field fda_pget_sys_time: salsat_frame.user_data_fda_tm_std.fda_pget_sys_time
    :field fda_pget_turn_on_counter: salsat_frame.user_data_fda_tm_std.fda_pget_turn_on_counter
    :field fda_pget_temp_fda_x: salsat_frame.user_data_fda_tm_std.fda_pget_temp_fda_x
    :field fda_pget_temp_fda_y: salsat_frame.user_data_fda_tm_std.fda_pget_temp_fda_y
    :field fda_pget_temp_fda_z: salsat_frame.user_data_fda_tm_std.fda_pget_temp_fda_z
    :field fda_pget_temp_gyro: salsat_frame.user_data_fda_tm_std.fda_pget_temp_gyro
    :field fda_pget_dac_x: salsat_frame.user_data_fda_tm_std.fda_pget_dac_x
    :field fda_pget_dac_y: salsat_frame.user_data_fda_tm_std.fda_pget_dac_y
    :field fda_pget_dac_z: salsat_frame.user_data_fda_tm_std.fda_pget_dac_z
    :field fda_pget_int_gyr_omega_x: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyr_omega_x
    :field fda_pget_int_gyr_omega_y: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyr_omega_y
    :field fda_pget_int_gyr_omega_z: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyr_omega_z
    :field fda_pget_int_gyr_omega_abs: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyr_omega_abs
    :field fda_pget_int_gyr_phi_x: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyr_phi_x
    :field fda_pget_int_gyr_phi_y: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyr_phi_y
    :field fda_pget_int_gyr_phi_z: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyr_phi_z
    :field fda_pget_sat_mag_x: salsat_frame.user_data_fda_tm_std.fda_pget_sat_mag_x
    :field fda_pget_sat_mag_y: salsat_frame.user_data_fda_tm_std.fda_pget_sat_mag_y
    :field fda_pget_sat_mag_z: salsat_frame.user_data_fda_tm_std.fda_pget_sat_mag_z
    :field fda_pget_u_bx: salsat_frame.user_data_fda_tm_std.fda_pget_u_bx
    :field fda_pget_u_by: salsat_frame.user_data_fda_tm_std.fda_pget_u_by
    :field fda_pget_u_bz: salsat_frame.user_data_fda_tm_std.fda_pget_u_bz
    :field fda_pget_k_p: salsat_frame.user_data_fda_tm_std.fda_pget_k_p
    :field fda_pget_k_d: salsat_frame.user_data_fda_tm_std.fda_pget_k_d
    :field fda_pget_k_i: salsat_frame.user_data_fda_tm_std.fda_pget_k_i
    :field fda_pget_gyro_def: salsat_frame.user_data_fda_tm_std.fda_pget_gyro_def
    :field fda_pget_int_gyro_val: salsat_frame.user_data_fda_tm_std.fda_pget_int_gyro_val
    :field user_data_fda_tm_imu_rot_rate_fda_pget_device: salsat_frame.user_data_fda_tm_imu_rot_rate.fda_pget_device
    :field fda_pget_imu_omega_x: salsat_frame.user_data_fda_tm_imu_rot_rate.fda_pget_imu_omega_x
    :field fda_pget_imu_omega_y: salsat_frame.user_data_fda_tm_imu_rot_rate.fda_pget_imu_omega_y
    :field fda_pget_imu_omega_z: salsat_frame.user_data_fda_tm_imu_rot_rate.fda_pget_imu_omega_z
    :field fda_pget_int_imu_omega_abs: salsat_frame.user_data_fda_tm_imu_rot_rate.fda_pget_int_imu_omega_abs
    :field user_data_fda_tm_imu_incr_phi_fda_pget_device: salsat_frame.user_data_fda_tm_imu_incr_phi.fda_pget_device
    :field fda_pget_imu_incr_phi_x: salsat_frame.user_data_fda_tm_imu_incr_phi.fda_pget_imu_incr_phi_x
    :field fda_pget_imu_incr_phi_y: salsat_frame.user_data_fda_tm_imu_incr_phi.fda_pget_imu_incr_phi_y
    :field fda_pget_imu_incr_phi_z: salsat_frame.user_data_fda_tm_imu_incr_phi.fda_pget_imu_incr_phi_z
    :field user_data_fda_tm_imu_phi_fda_pget_device: salsat_frame.user_data_fda_tm_imu_phi.fda_pget_device
    :field fda_pget_imu_phi_x: salsat_frame.user_data_fda_tm_imu_phi.fda_pget_imu_phi_x
    :field fda_pget_imu_phi_y: salsat_frame.user_data_fda_tm_imu_phi.fda_pget_imu_phi_y
    :field fda_pget_imu_phi_z: salsat_frame.user_data_fda_tm_imu_phi.fda_pget_imu_phi_z
    :field user_data_fda_tm_debug_fda_pget_device: salsat_frame.user_data_fda_tm_debug.fda_pget_device
    :field user_data_fda_tm_longterm_mag_x_fda_pget_device: salsat_frame.user_data_fda_tm_longterm_mag_x.fda_pget_device
    :field fda_pget_longterm_mag_x: salsat_frame.user_data_fda_tm_longterm_mag_x.fda_pget_longterm_mag_x
    :field user_data_fda_tm_longterm_mag_y_fda_pget_device: salsat_frame.user_data_fda_tm_longterm_mag_y.fda_pget_device
    :field fda_pget_longterm_mag_y: salsat_frame.user_data_fda_tm_longterm_mag_y.fda_pget_longterm_mag_y
    :field user_data_fda_tm_longterm_mag_z_fda_pget_device: salsat_frame.user_data_fda_tm_longterm_mag_z.fda_pget_device
    :field fda_pget_longterm_mag_z: salsat_frame.user_data_fda_tm_longterm_mag_z.fda_pget_longterm_mag_z
    :field user_data_fda_tm_longterm_phi_x_fda_pget_device: salsat_frame.user_data_fda_tm_longterm_phi_x.fda_pget_device
    :field fda_pget_longterm_phi_x: salsat_frame.user_data_fda_tm_longterm_phi_x.fda_pget_longterm_phi_x
    :field user_data_fda_tm_longterm_phi_y_fda_pget_device: salsat_frame.user_data_fda_tm_longterm_phi_y.fda_pget_device
    :field fda_pget_longterm_phi_y: salsat_frame.user_data_fda_tm_longterm_phi_y.fda_pget_longterm_phi_y
    :field user_data_fda_tm_longterm_phi_z_fda_pget_device: salsat_frame.user_data_fda_tm_longterm_phi_z.fda_pget_device
    :field fda_pget_longterm_phi_z: salsat_frame.user_data_fda_tm_longterm_phi_z.fda_pget_longterm_phi_z
    :field user_data_fda_tm_longterm_temps_fda_pget_device: salsat_frame.user_data_fda_tm_longterm_temps.fda_pget_device
    :field fda_pget_longterm_temp_x: salsat_frame.user_data_fda_tm_longterm_temps.fda_pget_longterm_temp_x
    :field fda_pget_longterm_temp_y: salsat_frame.user_data_fda_tm_longterm_temps.fda_pget_longterm_temp_y
    :field fda_pget_longterm_temp_z: salsat_frame.user_data_fda_tm_longterm_temps.fda_pget_longterm_temp_z
    :field fda_pget_longterm_temp_imu: salsat_frame.user_data_fda_tm_longterm_temps.fda_pget_longterm_temp_imu
    :field pdh_pget_systime: salsat_frame.user_data_pdh_tm_std.pdh_pget_systime
    :field pdh_pget_resetcnt: salsat_frame.user_data_pdh_tm_std.pdh_pget_resetcnt
    :field pdh_pget_fsmmainstate: salsat_frame.user_data_pdh_tm_std.pdh_pget_fsmmainstate
    :field pdh_pget_fsmanalogstate: salsat_frame.user_data_pdh_tm_std.pdh_pget_fsmanalogstate
    :field pdh_pget_fsmspcdbgstate: salsat_frame.user_data_pdh_tm_std.pdh_pget_fsmspcdbgstate
    :field pdh_pget_fsmspcmainstate: salsat_frame.user_data_pdh_tm_std.pdh_pget_fsmspcmainstate
    :field pdh_pget_fsmsapstate: salsat_frame.user_data_pdh_tm_std.pdh_pget_fsmsapstate
    :field pdh_pget_fsmslkstate: salsat_frame.user_data_pdh_tm_std.pdh_pget_fsmslkstate
    :field pdh_pget_invrxframe: salsat_frame.user_data_pdh_tm_std.pdh_pget_invrxframe
    :field pdh_pget_comtimeout: salsat_frame.user_data_pdh_tm_std.pdh_pget_comtimeout
    :field pdh_pget_anomalyenvir: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalyenvir
    :field pdh_pget_anomalypwr: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalypwr
    :field pdh_pget_initeepromparcompl: salsat_frame.user_data_pdh_tm_std.pdh_pget_initeepromparcompl
    :field pdh_pget_swspccmdtosband: salsat_frame.user_data_pdh_tm_std.pdh_pget_swspccmdtosband
    :field pdh_pget_unsecured: salsat_frame.user_data_pdh_tm_std.pdh_pget_unsecured
    :field pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu2
    :field pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu3
    :field pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu4
    :field pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu5
    :field pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu6
    :field pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu7
    :field pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu8
    :field pdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu9
    :field pdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu10
    :field pdh_pget_anomalycur3v3ext: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalycur3v3ext
    :field pdh_pget_anomalycur3v3int: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalycur3v3int
    :field pdh_pget_anomalycurtrx: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalycurtrx
    :field pdh_pget_anomalyvlt3v3ext: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalyvlt3v3ext
    :field pdh_pget_anomalyvlt3v3int: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalyvlt3v3int
    :field pdh_pget_anomalyvlttrx: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalyvlttrx
    :field pdh_pget_anomalytmpext: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalytmpext
    :field pdh_pget_anomalytmpint: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalytmpint
    :field pdh_pget_anomalypwrtrx: salsat_frame.user_data_pdh_tm_std.pdh_pget_anomalypwrtrx
    :field pdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu11
    :field pdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu12
    :field pdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu13
    :field pdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu14
    :field pdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu15
    :field pdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu16
    :field pdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu17
    :field pdh_pget_spcdbgcomtimeout: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcdbgcomtimeout
    :field pdh_pget_spcdbgtxactive: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcdbgtxactive
    :field pdh_pget_spcdbgrxactive: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcdbgrxactive
    :field pdh_pget_boolrfu28: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu28
    :field pdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu18
    :field pdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu19
    :field pdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu20
    :field pdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu21
    :field pdh_pget_spcmaincomtimeout: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcmaincomtimeout
    :field pdh_pget_spcmainspiactive: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcmainspiactive
    :field pdh_pget_spcmainwait: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcmainwait
    :field pdh_pget_spcmaincierrfrsync: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcmaincierrfrsync
    :field pdh_pget_spcmaincierrfrlength: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcmaincierrfrlength
    :field pdh_pget_spcmainfdirrdy: salsat_frame.user_data_pdh_tm_std.pdh_pget_spcmainfdirrdy
    :field pdh_pget_boolrfu26: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu26
    :field pdh_pget_boolrfu27: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu27
    :field pdh_pget_sapspiactive: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspiactive
    :field pdh_pget_sapadcconfigured: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapadcconfigured
    :field pdh_pget_sapspiinvstartsync: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspiinvstartsync
    :field pdh_pget_sapspinotready: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspinotready
    :field pdh_pget_sapspiinvfrom: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspiinvfrom
    :field pdh_pget_sapspiinvendsync: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspiinvendsync
    :field pdh_pget_sapspiinvlength: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspiinvlength
    :field pdh_pget_sapspiinvid: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspiinvid
    :field pdh_pget_sapspimissedendhdr: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspimissedendhdr
    :field pdh_pget_sappltuinvportid: salsat_frame.user_data_pdh_tm_std.pdh_pget_sappltuinvportid
    :field pdh_pget_sapinvpltuversno: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapinvpltuversno
    :field pdh_pget_sapinvpltuscid: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapinvpltuscid
    :field pdh_pget_sapinvpltucrc32: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapinvpltucrc32
    :field pdh_pget_sappltuinvasm: salsat_frame.user_data_pdh_tm_std.pdh_pget_sappltuinvasm
    :field pdh_pget_sappltuinvfrmlen: salsat_frame.user_data_pdh_tm_std.pdh_pget_sappltuinvfrmlen
    :field pdh_pget_sapspiopactive: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapspiopactive
    :field pdh_pget_progrmodesat2satmain: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodesat2satmain
    :field pdh_pget_progrmodesat2satredund: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodesat2satredund
    :field pdh_pget_progrmodesatmain: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodesatmain
    :field pdh_pget_progrmodesatredund: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodesatredund
    :field pdh_pget_progrmodesatwopa: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodesatwopa
    :field pdh_pget_progrmodefree0: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodefree0
    :field pdh_pget_progrmodefree1: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodefree1
    :field pdh_pget_progrmodeboot: salsat_frame.user_data_pdh_tm_std.pdh_pget_progrmodeboot
    :field pdh_pget_sapactive: salsat_frame.user_data_pdh_tm_std.pdh_pget_sapactive
    :field pdh_pget_boolrfu29: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu29
    :field pdh_pget_boolrfu30: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu30
    :field pdh_pget_boolrfu31: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu31
    :field pdh_pget_boolrfu32: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu32
    :field pdh_pget_boolrfu33: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu33
    :field pdh_pget_boolrfu34: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu34
    :field pdh_pget_boolrfu35: salsat_frame.user_data_pdh_tm_std.pdh_pget_boolrfu35
    :field pdh_pget_cur3v3ext: salsat_frame.user_data_pdh_tm_std.pdh_pget_cur3v3ext
    :field pdh_pget_cur3v3int: salsat_frame.user_data_pdh_tm_std.pdh_pget_cur3v3int
    :field pdh_pget_curtrx: salsat_frame.user_data_pdh_tm_std.pdh_pget_curtrx
    :field pdh_pget_vlt3v3ext: salsat_frame.user_data_pdh_tm_std.pdh_pget_vlt3v3ext
    :field pdh_pget_vlt3v3int: salsat_frame.user_data_pdh_tm_std.pdh_pget_vlt3v3int
    :field pdh_pget_vlttrx: salsat_frame.user_data_pdh_tm_std.pdh_pget_vlttrx
    :field thm_pdh_pget_tmpext: salsat_frame.user_data_pdh_tm_std.thm_pdh_pget_tmpext
    :field thm_pdh_pget_tmpint: salsat_frame.user_data_pdh_tm_std.thm_pdh_pget_tmpint
    :field user_data_pdh_tm_memextser_8_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_systime
    :field pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialspiactive
    :field pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialrdeepromactive
    :field pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialrdflash0active
    :field pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialrdflash1active
    :field pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialwractive
    :field pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialreleaseactive
    :field pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialspiaccesserror
    :field pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu0
    :field pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_8_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_8_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_8_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_8_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_8_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_8_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_8_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_boolrfu8
    :field pdh_pget_memextserialrdaddr: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialrdaddr
    :field pdh_pget_memextserialdata8: salsat_frame.user_data_pdh_tm_memextser_8.pdh_pget_memextserialdata8
    :field user_data_pdh_tm_memextser_16_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_systime
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialspiactive
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialrdeepromactive
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialrdflash0active
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialrdflash1active
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialwractive
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialreleaseactive
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialspiaccesserror
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu0
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_16_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_boolrfu8
    :field user_data_pdh_tm_memextser_16_pdh_pget_memextserialrdaddr: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialrdaddr
    :field pdh_pget_memextserialdata16: salsat_frame.user_data_pdh_tm_memextser_16.pdh_pget_memextserialdata16
    :field user_data_pdh_tm_memextser_32_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_systime
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialspiactive
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialrdeepromactive
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialrdflash0active
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialrdflash1active
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialwractive
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialreleaseactive
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialspiaccesserror
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu0
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_32_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_boolrfu8
    :field user_data_pdh_tm_memextser_32_pdh_pget_memextserialrdaddr: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialrdaddr
    :field pdh_pget_memextserialdata32: salsat_frame.user_data_pdh_tm_memextser_32.pdh_pget_memextserialdata32
    :field user_data_pdh_tm_memextser_64_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_systime
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialspiactive
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialrdeepromactive
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialrdflash0active
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialrdflash1active
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialwractive
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialreleaseactive
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialspiaccesserror
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu0
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_64_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_boolrfu8
    :field user_data_pdh_tm_memextser_64_pdh_pget_memextserialrdaddr: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialrdaddr
    :field pdh_pget_memextserialdata64: salsat_frame.user_data_pdh_tm_memextser_64.pdh_pget_memextserialdata64
    :field user_data_pdh_tm_memextser_128_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_systime
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialspiactive
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialrdeepromactive
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialrdflash0active
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialrdflash1active
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialwractive
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialreleaseactive
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialspiaccesserror
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu0
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_128_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_boolrfu8
    :field user_data_pdh_tm_memextser_128_pdh_pget_memextserialrdaddr: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialrdaddr
    :field pdh_pget_memextserialdata128: salsat_frame.user_data_pdh_tm_memextser_128.pdh_pget_memextserialdata128
    :field user_data_pdh_tm_memextser_256_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_systime
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialspiactive
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialrdeepromactive
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialrdflash0active
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialrdflash1active
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialwractive
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialreleaseactive
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialspiaccesserror
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu0
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_256_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_boolrfu8
    :field user_data_pdh_tm_memextser_256_pdh_pget_memextserialrdaddr: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialrdaddr
    :field pdh_pget_memextserialdata256: salsat_frame.user_data_pdh_tm_memextser_256.pdh_pget_memextserialdata256
    :field user_data_pdh_tm_memextser_512_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_systime
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialspiactive
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialrdeepromactive
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialrdflash0active
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialrdflash1active
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialwractive
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialreleaseactive
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialspiaccesserror
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu0
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_512_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_boolrfu8
    :field user_data_pdh_tm_memextser_512_pdh_pget_memextserialrdaddr: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialrdaddr
    :field pdh_pget_memextserialdata512: salsat_frame.user_data_pdh_tm_memextser_512.pdh_pget_memextserialdata512
    :field user_data_pdh_tm_swvers_pdh_pget_systime: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_systime
    :field pdh_pget_swversmajor: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swversmajor
    :field pdh_pget_swversminor: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swversminor
    :field pdh_pget_swbuildyear: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swbuildyear
    :field pdh_pget_swbuildmonth: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swbuildmonth
    :field pdh_pget_swbuildday: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swbuildday
    :field pdh_pget_swbuildhour: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swbuildhour
    :field pdh_pget_swbuildmin: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swbuildmin
    :field pdh_pget_swbuildsec: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_swbuildsec
    :field pdh_pget_serialnum: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_serialnum
    :field pdh_pget_devid: salsat_frame.user_data_pdh_tm_swvers.pdh_pget_devid
    :field user_data_pdh_tm_memextser_std_pdh_pget_systime: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_systime
    :field pdh_pget_fsmmemextserialstate: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_fsmmemextserialstate
    :field user_data_pdh_tm_memextser_std_pdh_pget_memextserialspiactive: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialspiactive
    :field user_data_pdh_tm_memextser_std_pdh_pget_memextserialrdeepromactive: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialrdeepromactive
    :field user_data_pdh_tm_memextser_std_pdh_pget_memextserialrdflash0active: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialrdflash0active
    :field user_data_pdh_tm_memextser_std_pdh_pget_memextserialrdflash1active: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialrdflash1active
    :field user_data_pdh_tm_memextser_std_pdh_pget_memextserialwractive: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialwractive
    :field user_data_pdh_tm_memextser_std_pdh_pget_memextserialreleaseactive: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialreleaseactive
    :field user_data_pdh_tm_memextser_std_pdh_pget_memextserialspiaccesserror: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialspiaccesserror
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu0
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu1
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu2
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu3
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu4
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu5
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu6
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu7
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu8
    :field pdh_pget_fsmmemextserialeepromstate: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_fsmmemextserialeepromstate
    :field pdh_pget_memextserialeepromconfigured: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromconfigured
    :field pdh_pget_memextserialeeprompdhparloaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeeprompdhparloaded
    :field pdh_pget_memextserialeepromdataloaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromdataloaded
    :field pdh_pget_memextserialeeprompdhparsaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeeprompdhparsaved
    :field pdh_pget_memextserialeepromsapsatparsaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromsapsatparsaved
    :field pdh_pget_memextserialeepromsapsat2satparsaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromsapsat2satparsaved
    :field pdh_pget_memextserialeepromdatasaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromdatasaved
    :field pdh_pget_memextserialeeprominvsr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeeprominvsr
    :field pdh_pget_memextserialeepromexploaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromexploaded
    :field pdh_pget_memextserialeepromnetworktleparsaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromnetworktleparsaved
    :field pdh_pget_memextserialeepromsapparloaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromsapparloaded
    :field pdh_pget_memextserialeepromnetworktleparloaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromnetworktleparloaded
    :field pdh_pget_memextserialeepromnetworkparsaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromnetworkparsaved
    :field pdh_pget_memextserialeepromnetworkparloaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialeepromnetworkparloaded
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu9
    :field user_data_pdh_tm_memextser_std_pdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_boolrfu10
    :field pdh_pget_fsmmemextserialflashstate: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_fsmmemextserialflashstate
    :field pdh_pget_memextserialflash0configured: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0configured
    :field pdh_pget_memextserialflash0dataloaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0dataloaded
    :field pdh_pget_memextserialflash0datasaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0datasaved
    :field pdh_pget_memextserialflash0dataerased: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0dataerased
    :field pdh_pget_memextserialflash0invidcfi: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invidcfi
    :field pdh_pget_memextserialflash0invsr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invsr
    :field pdh_pget_memextserialflash0invcr1: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invcr1
    :field pdh_pget_memextserialflash0invbar: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invbar
    :field pdh_pget_memextserialflash0invaspr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invaspr
    :field pdh_pget_memextserialflash0invppbl: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invppbl
    :field pdh_pget_memextserialflash0invppbar: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invppbar
    :field pdh_pget_memextserialflash0invdybar: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invdybar
    :field pdh_pget_memextserialflash0inveccsr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0inveccsr
    :field pdh_pget_memextserialflash0invvdlr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invvdlr
    :field pdh_pget_memextserialflash0invabr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invabr
    :field pdh_pget_memextserialflash0invpasswd: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash0invpasswd
    :field pdh_pget_memextserialflash1configured: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1configured
    :field pdh_pget_memextserialflash1dataloaded: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1dataloaded
    :field pdh_pget_memextserialflash1datasaved: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1datasaved
    :field pdh_pget_memextserialflash1dataerased: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1dataerased
    :field pdh_pget_memextserialflash1invidcfi: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invidcfi
    :field pdh_pget_memextserialflash1invsr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invsr
    :field pdh_pget_memextserialflash1invcr1: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invcr1
    :field pdh_pget_memextserialflash1invbar: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invbar
    :field pdh_pget_memextserialflash1invaspr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invaspr
    :field pdh_pget_memextserialflash1invppbl: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invppbl
    :field pdh_pget_memextserialflash1invppbar: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invppbar
    :field pdh_pget_memextserialflash1invdybar: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invdybar
    :field pdh_pget_memextserialflash1inveccsr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1inveccsr
    :field pdh_pget_memextserialflash1invvdlr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invvdlr
    :field pdh_pget_memextserialflash1invabr: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invabr
    :field pdh_pget_memextserialflash1invpasswd: salsat_frame.user_data_pdh_tm_memextser_std.pdh_pget_memextserialflash1invpasswd
    :field user_data_pdh_tm_fifo_pdh_pget_systime: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_systime
    :field pdh_pget_fifonumspcmaintxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcmaintxsf
    :field pdh_pget_fifonumspcmaintxsf64: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcmaintxsf64
    :field pdh_pget_fifonumspcmaintxmf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcmaintxmf
    :field pdh_pget_fifonumspcrxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcrxsf
    :field pdh_pget_fifonumspcrxsf16: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcrxsf16
    :field pdh_pget_fifonumspcrxsf32: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcrxsf32
    :field pdh_pget_fifonumspcrxmf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcrxmf
    :field pdh_pget_fifonumexprxsf16: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumexprxsf16
    :field pdh_pget_fifonumexprxsf32: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumexprxsf32
    :field pdh_pget_fifonumsdutxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumsdutxsf
    :field pdh_pget_fifonumsdutxsf64: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumsdutxsf64
    :field pdh_pget_fifonumsdurxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumsdurxsf
    :field pdh_pget_fifonumsdurxsf64: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumsdurxsf64
    :field pdh_pget_fifonumexprxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumexprxsf
    :field pdh_pget_fifonumspcdbgtxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcdbgtxsf
    :field pdh_pget_fifonumspcdbgtxsf64: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcdbgtxsf64
    :field pdh_pget_fifonumspcdbgtxmf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcdbgtxmf
    :field pdh_pget_fifonumsbandtxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumsbandtxsf
    :field pdh_pget_fifonumsbandtxsf64: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumsbandtxsf64
    :field pdh_pget_fifonumsbandtxmf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumsbandtxmf
    :field pdh_pget_fifonummemtxsf: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonummemtxsf
    :field pdh_pget_fifonummemtxsf64: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonummemtxsf64
    :field pdh_pget_fifonumspcrxsf64: salsat_frame.user_data_pdh_tm_fifo.pdh_pget_fifonumspcrxsf64
    :field user_data_pdh_tm_std_add_pdh_pget_systime: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_systime
    :field user_data_pdh_tm_std_add_pdh_pget_resetcnt: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_resetcnt
    :field user_data_pdh_tm_std_add_pdh_pget_fsmmainstate: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_fsmmainstate
    :field user_data_pdh_tm_std_add_pdh_pget_fsmanalogstate: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_fsmanalogstate
    :field user_data_pdh_tm_std_add_pdh_pget_fsmspcdbgstate: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_fsmspcdbgstate
    :field user_data_pdh_tm_std_add_pdh_pget_fsmspcmainstate: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_fsmspcmainstate
    :field user_data_pdh_tm_std_add_pdh_pget_fsmsapstate: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_fsmsapstate
    :field user_data_pdh_tm_std_add_pdh_pget_fsmslkstate: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_fsmslkstate
    :field user_data_pdh_tm_std_add_pdh_pget_invrxframe: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_invrxframe
    :field user_data_pdh_tm_std_add_pdh_pget_comtimeout: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_comtimeout
    :field user_data_pdh_tm_std_add_pdh_pget_anomalyenvir: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalyenvir
    :field user_data_pdh_tm_std_add_pdh_pget_anomalypwr: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalypwr
    :field user_data_pdh_tm_std_add_pdh_pget_initeepromparcompl: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_initeepromparcompl
    :field user_data_pdh_tm_std_add_pdh_pget_swspccmdtosband: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_swspccmdtosband
    :field user_data_pdh_tm_std_add_pdh_pget_unsecured: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_unsecured
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu2
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu3
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu4
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu5
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu6
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu7
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu8
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu9
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu10
    :field user_data_pdh_tm_std_add_pdh_pget_anomalycur3v3ext: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalycur3v3ext
    :field user_data_pdh_tm_std_add_pdh_pget_anomalycur3v3int: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalycur3v3int
    :field user_data_pdh_tm_std_add_pdh_pget_anomalycurtrx: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalycurtrx
    :field user_data_pdh_tm_std_add_pdh_pget_anomalyvlt3v3ext: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalyvlt3v3ext
    :field user_data_pdh_tm_std_add_pdh_pget_anomalyvlt3v3int: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalyvlt3v3int
    :field user_data_pdh_tm_std_add_pdh_pget_anomalyvlttrx: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalyvlttrx
    :field user_data_pdh_tm_std_add_pdh_pget_anomalytmpext: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalytmpext
    :field user_data_pdh_tm_std_add_pdh_pget_anomalytmpint: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalytmpint
    :field user_data_pdh_tm_std_add_pdh_pget_anomalypwrtrx: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_anomalypwrtrx
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu11
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu12
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu13
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu14
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu15
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu16
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu17
    :field user_data_pdh_tm_std_add_pdh_pget_spcdbgcomtimeout: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcdbgcomtimeout
    :field user_data_pdh_tm_std_add_pdh_pget_spcdbgtxactive: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcdbgtxactive
    :field user_data_pdh_tm_std_add_pdh_pget_spcdbgrxactive: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcdbgrxactive
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu28: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu28
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu18
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu19
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu20
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu21
    :field user_data_pdh_tm_std_add_pdh_pget_spcmaincomtimeout: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcmaincomtimeout
    :field user_data_pdh_tm_std_add_pdh_pget_spcmainspiactive: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcmainspiactive
    :field user_data_pdh_tm_std_add_pdh_pget_spcmainwait: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcmainwait
    :field user_data_pdh_tm_std_add_pdh_pget_spcmaincierrfrsync: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcmaincierrfrsync
    :field user_data_pdh_tm_std_add_pdh_pget_spcmaincierrfrlength: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcmaincierrfrlength
    :field user_data_pdh_tm_std_add_pdh_pget_spcmainfdirrdy: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_spcmainfdirrdy
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu26: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu26
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu27: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu27
    :field user_data_pdh_tm_std_add_pdh_pget_sapspiactive: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspiactive
    :field user_data_pdh_tm_std_add_pdh_pget_sapadcconfigured: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapadcconfigured
    :field user_data_pdh_tm_std_add_pdh_pget_sapspiinvstartsync: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspiinvstartsync
    :field user_data_pdh_tm_std_add_pdh_pget_sapspinotready: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspinotready
    :field user_data_pdh_tm_std_add_pdh_pget_sapspiinvfrom: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspiinvfrom
    :field user_data_pdh_tm_std_add_pdh_pget_sapspiinvendsync: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspiinvendsync
    :field user_data_pdh_tm_std_add_pdh_pget_sapspiinvlength: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspiinvlength
    :field user_data_pdh_tm_std_add_pdh_pget_sapspiinvid: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspiinvid
    :field user_data_pdh_tm_std_add_pdh_pget_sapspimissedendhdr: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspimissedendhdr
    :field user_data_pdh_tm_std_add_pdh_pget_sappltuinvportid: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sappltuinvportid
    :field user_data_pdh_tm_std_add_pdh_pget_sapinvpltuversno: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapinvpltuversno
    :field user_data_pdh_tm_std_add_pdh_pget_sapinvpltuscid: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapinvpltuscid
    :field user_data_pdh_tm_std_add_pdh_pget_sapinvpltucrc32: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapinvpltucrc32
    :field user_data_pdh_tm_std_add_pdh_pget_sappltuinvasm: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sappltuinvasm
    :field user_data_pdh_tm_std_add_pdh_pget_sappltuinvfrmlen: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sappltuinvfrmlen
    :field user_data_pdh_tm_std_add_pdh_pget_sapspiopactive: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapspiopactive
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodesat2satmain: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodesat2satmain
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodesat2satredund: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodesat2satredund
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodesatmain: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodesatmain
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodesatredund: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodesatredund
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodesatwopa: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodesatwopa
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodefree0: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodefree0
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodefree1: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodefree1
    :field user_data_pdh_tm_std_add_pdh_pget_progrmodeboot: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_progrmodeboot
    :field user_data_pdh_tm_std_add_pdh_pget_sapactive: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_sapactive
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu29: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu29
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu30: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu30
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu31: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu31
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu32: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu32
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu33: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu33
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu34: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu34
    :field user_data_pdh_tm_std_add_pdh_pget_boolrfu35: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_boolrfu35
    :field user_data_pdh_tm_std_add_pdh_pget_cur3v3ext: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_cur3v3ext
    :field user_data_pdh_tm_std_add_pdh_pget_cur3v3int: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_cur3v3int
    :field user_data_pdh_tm_std_add_pdh_pget_curtrx: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_curtrx
    :field user_data_pdh_tm_std_add_pdh_pget_vlt3v3ext: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_vlt3v3ext
    :field user_data_pdh_tm_std_add_pdh_pget_vlt3v3int: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_vlt3v3int
    :field user_data_pdh_tm_std_add_pdh_pget_vlttrx: salsat_frame.user_data_pdh_tm_std_add.pdh_pget_vlttrx
    :field user_data_pdh_tm_std_add_thm_pdh_pget_tmpext: salsat_frame.user_data_pdh_tm_std_add.thm_pdh_pget_tmpext
    :field user_data_pdh_tm_std_add_thm_pdh_pget_tmpint: salsat_frame.user_data_pdh_tm_std_add.thm_pdh_pget_tmpint
    :field user_data_pdh_tm_extd_pdh_pget_systime: salsat_frame.user_data_pdh_tm_extd.pdh_pget_systime
    :field pdh_pget_tmoutl1sync: salsat_frame.user_data_pdh_tm_extd.pdh_pget_tmoutl1sync
    :field pdh_pget_tmoutl2sync: salsat_frame.user_data_pdh_tm_extd.pdh_pget_tmoutl2sync
    :field pdh_pget_tmoutl2connect: salsat_frame.user_data_pdh_tm_extd.pdh_pget_tmoutl2connect
    :field slkpdh_pget_sesbasetrmcaller: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasetrmcaller
    :field slkpdh_pget_sesbasetrmcallersendbcst: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasetrmcallersendbcst
    :field slkpdh_pget_sesbasetrmresponder: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasetrmresponder
    :field slkpdh_pget_sesbasetrmsesest: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasetrmsesest
    :field slkpdh_pget_sesbasetrmseslost: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasetrmseslost
    :field slkpdh_pget_sesbasetrmwaitforaiandtrmt: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasetrmwaitforaiandtrmt
    :field slkpdh_pget_sesbasercvsesest: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasercvsesest
    :field slkpdh_pget_sesbasercvseslost: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasercvseslost
    :field slkpdh_pget_sesbasercvwaitforaiandtrmt: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesbasercvwaitforaiandtrmt
    :field slkpdh_pget_traitrnrcvcpt: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_traitrnrcvcpt
    :field slkpdh_pget_trabasetrmnak: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_trabasetrmnak
    :field slkpdh_pget_trabasetrmcpt: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_trabasetrmcpt
    :field slkpdh_pget_trabasercvnak: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_trabasercvnak
    :field slkpdh_pget_trabasercvcpt: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_trabasercvcpt
    :field slkpdh_pget_appitrnallpktgen: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_appitrnallpktgen
    :field slkpdh_pget_appbasetrmpktloss: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_appbasetrmpktloss
    :field slkpdh_pget_appbasetrmcrcerr: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_appbasetrmcrcerr
    :field slkpdh_pget_appbasetrmpkthdrerr: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_appbasetrmpkthdrerr
    :field slkpdh_pget_appbasercvpktloss: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_appbasercvpktloss
    :field slkpdh_pget_appbasercvcrcerr: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_appbasercvcrcerr
    :field slkpdh_pget_appbasercvpkthdrerr: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_appbasercvpkthdrerr
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu0
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu1
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu2
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu3
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu4
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu5
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu6
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu7
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu8
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu9
    :field user_data_pdh_tm_extd_pdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_extd.pdh_pget_boolrfu10
    :field slkpdh_pget_sesspec0trmtxallbytenum: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesspec0trmtxallbytenum
    :field slkpdh_pget_sesspec0trmrxallbytenum: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesspec0trmrxallbytenum
    :field slkpdh_pget_sesspec0trmtxdatabytenum: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesspec0trmtxdatabytenum
    :field slkpdh_pget_sesspec0trmrxdatabytenum: salsat_frame.user_data_pdh_tm_extd.slkpdh_pget_sesspec0trmrxdatabytenum
    :field pdh_pget_arrayrfu0: salsat_frame.user_data_pdh_tm_extd.pdh_pget_arrayrfu0
    :field user_data_pdh_tm_std_a_pdh_pget_systime: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_systime
    :field user_data_pdh_tm_std_a_pdh_pget_resetcnt: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_resetcnt
    :field user_data_pdh_tm_std_a_pdh_pget_fsmmainstate: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_fsmmainstate
    :field user_data_pdh_tm_std_a_pdh_pget_fsmspcdbgstate: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_fsmspcdbgstate
    :field user_data_pdh_tm_std_a_pdh_pget_fsmsapstate: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_fsmsapstate
    :field user_data_pdh_tm_std_a_pdh_pget_fsmslkstate: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_fsmslkstate
    :field user_data_pdh_tm_std_a_pdh_pget_invrxframe: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_invrxframe
    :field user_data_pdh_tm_std_a_pdh_pget_comtimeout: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_comtimeout
    :field user_data_pdh_tm_std_a_pdh_pget_anomalyenvir: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalyenvir
    :field user_data_pdh_tm_std_a_pdh_pget_anomalypwr: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalypwr
    :field user_data_pdh_tm_std_a_pdh_pget_initeepromparcompl: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_initeepromparcompl
    :field user_data_pdh_tm_std_a_pdh_pget_swspccmdtosband: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_swspccmdtosband
    :field user_data_pdh_tm_std_a_pdh_pget_unsecured: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_unsecured
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu2
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu3
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu4
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu5
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu6
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu7
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu8
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu9
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu10
    :field user_data_pdh_tm_std_a_pdh_pget_anomalycur3v3ext: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalycur3v3ext
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu11
    :field user_data_pdh_tm_std_a_pdh_pget_anomalycurtrx: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalycurtrx
    :field user_data_pdh_tm_std_a_pdh_pget_anomalyvlt3v3ext: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalyvlt3v3ext
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu12
    :field user_data_pdh_tm_std_a_pdh_pget_anomalyvlttrx: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalyvlttrx
    :field user_data_pdh_tm_std_a_pdh_pget_anomalytmpext: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalytmpext
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu13
    :field user_data_pdh_tm_std_a_pdh_pget_anomalypwrtrx: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalypwrtrx
    :field pdh_pget_anomalycuripu: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalycuripu
    :field pdh_pget_anomalycurcam: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_anomalycurcam
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu14
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu15
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu16
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu17
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu18
    :field user_data_pdh_tm_std_a_pdh_pget_spcdbgcomtimeout: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_spcdbgcomtimeout
    :field user_data_pdh_tm_std_a_pdh_pget_spcdbgtxactive: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_spcdbgtxactive
    :field user_data_pdh_tm_std_a_pdh_pget_spcdbgrxactive: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_spcdbgrxactive
    :field pdh_pget_spctxlock: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_spctxlock
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu19
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu20
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu21
    :field pdh_pget_boolrfu22: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu22
    :field user_data_pdh_tm_std_a_pdh_pget_sapspiactive: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspiactive
    :field user_data_pdh_tm_std_a_pdh_pget_sapadcconfigured: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapadcconfigured
    :field user_data_pdh_tm_std_a_pdh_pget_sapspiinvstartsync: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspiinvstartsync
    :field user_data_pdh_tm_std_a_pdh_pget_sapspinotready: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspinotready
    :field user_data_pdh_tm_std_a_pdh_pget_sapspiinvfrom: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspiinvfrom
    :field user_data_pdh_tm_std_a_pdh_pget_sapspiinvendsync: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspiinvendsync
    :field user_data_pdh_tm_std_a_pdh_pget_sapspiinvlength: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspiinvlength
    :field user_data_pdh_tm_std_a_pdh_pget_sapspiinvid: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspiinvid
    :field user_data_pdh_tm_std_a_pdh_pget_sapspimissedendhdr: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspimissedendhdr
    :field user_data_pdh_tm_std_a_pdh_pget_sappltuinvportid: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sappltuinvportid
    :field user_data_pdh_tm_std_a_pdh_pget_sapinvpltuversno: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapinvpltuversno
    :field user_data_pdh_tm_std_a_pdh_pget_sapinvpltuscid: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapinvpltuscid
    :field user_data_pdh_tm_std_a_pdh_pget_sapinvpltucrc32: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapinvpltucrc32
    :field user_data_pdh_tm_std_a_pdh_pget_sappltuinvasm: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sappltuinvasm
    :field user_data_pdh_tm_std_a_pdh_pget_sappltuinvfrmlen: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sappltuinvfrmlen
    :field user_data_pdh_tm_std_a_pdh_pget_sapspiopactive: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapspiopactive
    :field pdh_pget_boolrfu23: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu23
    :field pdh_pget_boolrfu24: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu24
    :field user_data_pdh_tm_std_a_pdh_pget_progrmodesatmain: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodesatmain
    :field user_data_pdh_tm_std_a_pdh_pget_progrmodesatredund: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodesatredund
    :field pdh_pget_boolrfu25: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu25
    :field user_data_pdh_tm_std_a_pdh_pget_progrmodefree0: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodefree0
    :field user_data_pdh_tm_std_a_pdh_pget_progrmodefree1: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodefree1
    :field user_data_pdh_tm_std_a_pdh_pget_progrmodeboot: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodeboot
    :field user_data_pdh_tm_std_a_pdh_pget_sapactive: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_sapactive
    :field pdh_pget_progrmodesatmain1: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodesatmain1
    :field pdh_pget_progrmodesatredund1: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodesatredund1
    :field pdh_pget_progrmodeboot1: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_progrmodeboot1
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu26: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu26
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu27: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu27
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu28: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu28
    :field user_data_pdh_tm_std_a_pdh_pget_boolrfu29: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_boolrfu29
    :field user_data_pdh_tm_std_a_pdh_pget_cur3v3ext: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_cur3v3ext
    :field pdh_pget_curipu: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_curipu
    :field pdh_pget_curtrxa: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_curtrxa
    :field user_data_pdh_tm_std_a_pdh_pget_vlt3v3ext: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_vlt3v3ext
    :field pdh_pget_curcam: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_curcam
    :field user_data_pdh_tm_std_a_pdh_pget_vlttrx: salsat_frame.user_data_pdh_tm_std_a.pdh_pget_vlttrx
    :field user_data_pdh_tm_std_a_thm_pdh_pget_tmpext: salsat_frame.user_data_pdh_tm_std_a.thm_pdh_pget_tmpext
    :field user_data_pdh_tm_std_add_a_pdh_pget_systime: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_systime
    :field user_data_pdh_tm_std_add_a_pdh_pget_resetcnt: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_resetcnt
    :field user_data_pdh_tm_std_add_a_pdh_pget_fsmmainstate: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_fsmmainstate
    :field user_data_pdh_tm_std_add_a_pdh_pget_fsmspcdbgstate: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_fsmspcdbgstate
    :field user_data_pdh_tm_std_add_a_pdh_pget_fsmsapstate: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_fsmsapstate
    :field user_data_pdh_tm_std_add_a_pdh_pget_fsmslkstate: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_fsmslkstate
    :field user_data_pdh_tm_std_add_a_pdh_pget_invrxframe: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_invrxframe
    :field user_data_pdh_tm_std_add_a_pdh_pget_comtimeout: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_comtimeout
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalyenvir: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalyenvir
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalypwr: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalypwr
    :field user_data_pdh_tm_std_add_a_pdh_pget_initeepromparcompl: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_initeepromparcompl
    :field user_data_pdh_tm_std_add_a_pdh_pget_swspccmdtosband: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_swspccmdtosband
    :field user_data_pdh_tm_std_add_a_pdh_pget_unsecured: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_unsecured
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu2
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu3
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu4
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu5
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu6
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu7
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu8
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu9
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu10
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalycur3v3ext: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalycur3v3ext
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu11
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalycurtrx: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalycurtrx
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalyvlt3v3ext: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalyvlt3v3ext
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu12
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalyvlttrx: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalyvlttrx
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalytmpext: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalytmpext
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu13
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalypwrtrx: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalypwrtrx
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalycuripu: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalycuripu
    :field user_data_pdh_tm_std_add_a_pdh_pget_anomalycurcam: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_anomalycurcam
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu14
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu15
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu16
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu17
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu18
    :field user_data_pdh_tm_std_add_a_pdh_pget_spcdbgcomtimeout: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_spcdbgcomtimeout
    :field user_data_pdh_tm_std_add_a_pdh_pget_spcdbgtxactive: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_spcdbgtxactive
    :field user_data_pdh_tm_std_add_a_pdh_pget_spcdbgrxactive: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_spcdbgrxactive
    :field user_data_pdh_tm_std_add_a_pdh_pget_spctxlock: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_spctxlock
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu19
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu20
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu21
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu22: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu22
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspiactive: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspiactive
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapadcconfigured: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapadcconfigured
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspiinvstartsync: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspiinvstartsync
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspinotready: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspinotready
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspiinvfrom: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspiinvfrom
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspiinvendsync: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspiinvendsync
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspiinvlength: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspiinvlength
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspiinvid: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspiinvid
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspimissedendhdr: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspimissedendhdr
    :field user_data_pdh_tm_std_add_a_pdh_pget_sappltuinvportid: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sappltuinvportid
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapinvpltuversno: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapinvpltuversno
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapinvpltuscid: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapinvpltuscid
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapinvpltucrc32: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapinvpltucrc32
    :field user_data_pdh_tm_std_add_a_pdh_pget_sappltuinvasm: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sappltuinvasm
    :field user_data_pdh_tm_std_add_a_pdh_pget_sappltuinvfrmlen: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sappltuinvfrmlen
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapspiopactive: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapspiopactive
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu23: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu23
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu24: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu24
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodesatmain: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodesatmain
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodesatredund: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodesatredund
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu25: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu25
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodefree0: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodefree0
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodefree1: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodefree1
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodeboot: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodeboot
    :field user_data_pdh_tm_std_add_a_pdh_pget_sapactive: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_sapactive
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodesatmain1: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodesatmain1
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodesatredund1: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodesatredund1
    :field user_data_pdh_tm_std_add_a_pdh_pget_progrmodeboot1: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_progrmodeboot1
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu26: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu26
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu27: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu27
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu28: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu28
    :field user_data_pdh_tm_std_add_a_pdh_pget_boolrfu29: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_boolrfu29
    :field user_data_pdh_tm_std_add_a_pdh_pget_cur3v3ext: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_cur3v3ext
    :field user_data_pdh_tm_std_add_a_pdh_pget_curipu: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_curipu
    :field user_data_pdh_tm_std_add_a_pdh_pget_curtrxa: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_curtrxa
    :field user_data_pdh_tm_std_add_a_pdh_pget_vlt3v3ext: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_vlt3v3ext
    :field user_data_pdh_tm_std_add_a_pdh_pget_curcam: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_curcam
    :field user_data_pdh_tm_std_add_a_pdh_pget_vlttrx: salsat_frame.user_data_pdh_tm_std_add_a.pdh_pget_vlttrx
    :field user_data_pdh_tm_std_add_a_thm_pdh_pget_tmpext: salsat_frame.user_data_pdh_tm_std_add_a.thm_pdh_pget_tmpext
    :field user_data_pdh_tm_rtc_pdh_pget_systime: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_systime
    :field pdh_pget_rtcinitcomplete: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcinitcomplete
    :field pdh_pget_rtcinvreg: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcinvreg
    :field pdh_pget_rtcspiactive: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcspiactive
    :field pdh_pget_rtcspirelease: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcspirelease
    :field pdh_pget_rtcconfcomplete: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcconfcomplete
    :field pdh_pget_rtcwrtime: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcwrtime
    :field pdh_pget_rtcttavailable: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcttavailable
    :field user_data_pdh_tm_rtc_pdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_boolrfu1
    :field pdh_pget_rtcsec01: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec01
    :field pdh_pget_rtcsec001: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec001
    :field pdh_pget_rtcsec10: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec10
    :field pdh_pget_rtcsec1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec1
    :field pdh_pget_rtcsec01alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec01alarm
    :field pdh_pget_rtcsec001alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec001alarm
    :field pdh_pget_rtcsec10alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec10alarm
    :field pdh_pget_rtcsec1alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec1alarm
    :field pdh_pget_rtcmin10: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmin10
    :field pdh_pget_rtcmin1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmin1
    :field pdh_pget_rtcmin10alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmin10alarm
    :field pdh_pget_rtcmin1alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmin1alarm
    :field pdh_pget_rtchour10: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtchour10
    :field pdh_pget_rtchour1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtchour1
    :field pdh_pget_rtchour10alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtchour10alarm
    :field pdh_pget_rtchour1alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtchour1alarm
    :field pdh_pget_rtcday: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcday
    :field pdh_pget_rtcdayalarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdayalarm
    :field pdh_pget_rtcdate10: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdate10
    :field pdh_pget_rtcdate1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdate1
    :field pdh_pget_rtcdate10alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdate10alarm
    :field pdh_pget_rtcdate1alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdate1alarm
    :field pdh_pget_rtcmonth10: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmonth10
    :field pdh_pget_rtcmonth1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmonth1
    :field pdh_pget_rtcyear10: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcyear10
    :field pdh_pget_rtcyear1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcyear1
    :field pdh_pget_rtcregcontrol: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcregcontrol
    :field pdh_pget_rtcregstatus: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcregstatus
    :field pdh_pget_rtcregtricklecharger: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcregtricklecharger
    :field pdh_pget_rtc12: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtc12
    :field pdh_pget_rtcpm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcpm
    :field pdh_pget_rtccentury: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtccentury
    :field pdh_pget_rtc12alarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtc12alarm
    :field pdh_pget_rtcpmalarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcpmalarm
    :field pdh_pget_rtcdyalarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdyalarm
    :field pdh_pget_rtcam1: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcam1
    :field pdh_pget_rtcam2: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcam2
    :field pdh_pget_rtcam3: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcam3
    :field pdh_pget_rtcam4: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcam4
    :field user_data_pdh_tm_rtc_pdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_boolrfu2
    :field user_data_pdh_tm_rtc_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_boolrfu3
    :field user_data_pdh_tm_rtc_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_boolrfu4
    :field user_data_pdh_tm_rtc_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_boolrfu5
    :field user_data_pdh_tm_rtc_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_boolrfu6
    :field user_data_pdh_tm_rtc_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_boolrfu7
    :field pdh_pget_rtcyear: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcyear
    :field pdh_pget_rtcmonth: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmonth
    :field pdh_pget_rtcmin: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcmin
    :field pdh_pget_rtcminalarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcminalarm
    :field pdh_pget_rtchour: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtchour
    :field pdh_pget_rtchouralarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtchouralarm
    :field pdh_pget_rtcdate: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdate
    :field pdh_pget_rtcdatealarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcdatealarm
    :field pdh_pget_rtcsec: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsec
    :field pdh_pget_rtcsecalarm: salsat_frame.user_data_pdh_tm_rtc.pdh_pget_rtcsecalarm
    :field user_data_pdh_tm_com_pdh_pget_fsmmainstate: salsat_frame.user_data_pdh_tm_com.pdh_pget_fsmmainstate
    :field user_data_pdh_tm_com_pdh_pget_fsmsapstate: salsat_frame.user_data_pdh_tm_com.pdh_pget_fsmsapstate
    :field user_data_pdh_tm_com_pdh_pget_fsmslkstate: salsat_frame.user_data_pdh_tm_com.pdh_pget_fsmslkstate
    :field pdh_pget_sapmuxstate: salsat_frame.user_data_pdh_tm_com.pdh_pget_sapmuxstate
    :field pdh_pget_ipumode: salsat_frame.user_data_pdh_tm_com.pdh_pget_ipumode
    :field pdh_pget_cammode: salsat_frame.user_data_pdh_tm_com.pdh_pget_cammode
    :field user_data_pdh_tm_com_pdh_pget_fifonumfreesdutxa: salsat_frame.user_data_pdh_tm_com.pdh_pget_fifonumfreesdutxa
    :field user_data_pdh_tm_com_pdh_pget_fifonumfreesdutxb: salsat_frame.user_data_pdh_tm_com.pdh_pget_fifonumfreesdutxb
    :field pdh_pget_fifonumfreesbandtxa: salsat_frame.user_data_pdh_tm_com.pdh_pget_fifonumfreesbandtxa
    :field pdh_pget_fifonumfreesbandtxb: salsat_frame.user_data_pdh_tm_com.pdh_pget_fifonumfreesbandtxb
    :field pdh_pget_fifonumfreesbandtxc: salsat_frame.user_data_pdh_tm_com.pdh_pget_fifonumfreesbandtxc
    :field pdh_pget_satxmtmode: salsat_frame.user_data_pdh_tm_com.pdh_pget_satxmtmode
    :field pdh_pget_satctrmaxaitype: salsat_frame.user_data_pdh_tm_com.pdh_pget_satctrmaxaitype
    :field pdh_pget_satrcvstate: salsat_frame.user_data_pdh_tm_com.pdh_pget_satrcvstate
    :field pdh_pget_satfrc: salsat_frame.user_data_pdh_tm_com.pdh_pget_satfrc
    :field pdh_pget_satmaxsir: salsat_frame.user_data_pdh_tm_com.pdh_pget_satmaxsir
    :field pdh_pget_satminsir: salsat_frame.user_data_pdh_tm_com.pdh_pget_satminsir
    :field pdh_pget_satdopplerfreq: salsat_frame.user_data_pdh_tm_com.pdh_pget_satdopplerfreq
    :field pdh_pget_satdistance: salsat_frame.user_data_pdh_tm_com.pdh_pget_satdistance
    :field user_data_pdh_tm_com_pdh_pget_arqonuplink: salsat_frame.user_data_pdh_tm_com.pdh_pget_arqonuplink
    :field pdh_pget_arqondownlink: salsat_frame.user_data_pdh_tm_com.pdh_pget_arqondownlink
    :field pdh_pget_sessionest: salsat_frame.user_data_pdh_tm_com.pdh_pget_sessionest
    :field user_data_pdh_tm_com_pdh_pget_sessionopened: salsat_frame.user_data_pdh_tm_com.pdh_pget_sessionopened
    :field user_data_pdh_tm_com_pdh_pget_comtxon: salsat_frame.user_data_pdh_tm_com.pdh_pget_comtxon
    :field user_data_pdh_tm_com_pdh_pget_comrxon: salsat_frame.user_data_pdh_tm_com.pdh_pget_comrxon
    :field user_data_pdh_tm_com_pdh_pget_arquplinkack: salsat_frame.user_data_pdh_tm_com.pdh_pget_arquplinkack
    :field user_data_pdh_tm_com_pdh_pget_comautotm: salsat_frame.user_data_pdh_tm_com.pdh_pget_comautotm
    :field pdh_pget_stdautotm: salsat_frame.user_data_pdh_tm_com.pdh_pget_stdautotm
    :field user_data_pdh_tm_com_pdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_com.pdh_pget_boolrfu3
    :field user_data_pdh_tm_com_pdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_com.pdh_pget_boolrfu4
    :field user_data_pdh_tm_com_pdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_com.pdh_pget_boolrfu5
    :field user_data_pdh_tm_com_pdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_com.pdh_pget_boolrfu6
    :field user_data_pdh_tm_com_pdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_com.pdh_pget_boolrfu7
    :field user_data_pdh_tm_com_pdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_com.pdh_pget_boolrfu8
    :field user_data_pdh_tm_com_pdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_com.pdh_pget_boolrfu9
    :field pdh_pget_sataitype: salsat_frame.user_data_pdh_tm_com.pdh_pget_sataitype
    :field user_data_pdh_tm_com_pdh_pget_txrepeatmode: salsat_frame.user_data_pdh_tm_com.pdh_pget_txrepeatmode
    :field pdh_pget_thresholdacktm: salsat_frame.user_data_pdh_tm_com.pdh_pget_thresholdacktm
    :field pdh_pget_thresholdcomtm: salsat_frame.user_data_pdh_tm_com.pdh_pget_thresholdcomtm
    :field pdh_pget_thresholdstdtm: salsat_frame.user_data_pdh_tm_com.pdh_pget_thresholdstdtm
    :field pdh_pget_stdtmautogenmode: salsat_frame.user_data_pdh_tm_com.pdh_pget_stdtmautogenmode
    :field pdh_pget_arrayrfucomtm: salsat_frame.user_data_pdh_tm_com.pdh_pget_arrayrfucomtm
    :field pdh_pget_arqseqnouplink: salsat_frame.user_data_pdh_tm_ack.pdh_pget_arqseqnouplink
    :field pdh_pget_arrayrfuacktm: salsat_frame.user_data_pdh_tm_ack.pdh_pget_arrayrfuacktm
    :field rw0_pget_systime: salsat_frame.user_data_rw0_tm_std.rw0_pget_systime
    :field rw0_pget_resetcnt: salsat_frame.user_data_rw0_tm_std.rw0_pget_resetcnt
    :field rw0_pget_fsmmainstate: salsat_frame.user_data_rw0_tm_std.rw0_pget_fsmmainstate
    :field rw0_pget_invrxframe: salsat_frame.user_data_rw0_tm_std.rw0_pget_invrxframe
    :field rw0_pget_comtimeout: salsat_frame.user_data_rw0_tm_std.rw0_pget_comtimeout
    :field rw0_pget_anomalyenvir: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalyenvir
    :field rw0_pget_anomalypwr: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalypwr
    :field rw0_pget_mtroff: salsat_frame.user_data_rw0_tm_std.rw0_pget_mtroff
    :field rw0_pget_mvlimit: salsat_frame.user_data_rw0_tm_std.rw0_pget_mvlimit
    :field rw0_pget_mtrovercur: salsat_frame.user_data_rw0_tm_std.rw0_pget_mtrovercur
    :field rw0_pget_faultgyro0: salsat_frame.user_data_rw0_tm_std.rw0_pget_faultgyro0
    :field rw0_pget_faultgyro1: salsat_frame.user_data_rw0_tm_std.rw0_pget_faultgyro1
    :field rw0_pget_boolrfu0: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu0
    :field rw0_pget_boolrfu1: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu1
    :field rw0_pget_boolrfu2: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu2
    :field rw0_pget_boolrfu3: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu3
    :field rw0_pget_boolrfu4: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu4
    :field rw0_pget_boolrfu5: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu5
    :field rw0_pget_boolrfu6: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu6
    :field rw0_pget_anomalycurmtr: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalycurmtr
    :field rw0_pget_anomalycurwde: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalycurwde
    :field rw0_pget_anomalycur3v3: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalycur3v3
    :field rw0_pget_anomalycur5v: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalycur5v
    :field rw0_pget_anomalyvltmtr: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalyvltmtr
    :field rw0_pget_anomalyvlt3v2: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalyvlt3v2
    :field rw0_pget_anomalyvlt5v: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalyvlt5v
    :field rw0_pget_anomalyvlt3v3: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalyvlt3v3
    :field rw0_pget_anomalyvlt3v3mcu: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalyvlt3v3mcu
    :field rw0_pget_anomalytmppwr: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalytmppwr
    :field rw0_pget_anomalygyro0: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalygyro0
    :field rw0_pget_anomalygyro1: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalygyro1
    :field rw0_pget_anomalypress: salsat_frame.user_data_rw0_tm_std.rw0_pget_anomalypress
    :field rw0_pget_boolrfu7: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu7
    :field rw0_pget_boolrfu8: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu8
    :field rw0_pget_boolrfu9: salsat_frame.user_data_rw0_tm_std.rw0_pget_boolrfu9
    :field rw0_pget_curmtr: salsat_frame.user_data_rw0_tm_std.rw0_pget_curmtr
    :field rw0_pget_curwde: salsat_frame.user_data_rw0_tm_std.rw0_pget_curwde
    :field rw0_pget_cur3v3: salsat_frame.user_data_rw0_tm_std.rw0_pget_cur3v3
    :field rw0_pget_cur5v: salsat_frame.user_data_rw0_tm_std.rw0_pget_cur5v
    :field rw0_pget_vltmtr: salsat_frame.user_data_rw0_tm_std.rw0_pget_vltmtr
    :field rw0_pget_vlt3v2: salsat_frame.user_data_rw0_tm_std.rw0_pget_vlt3v2
    :field rw0_pget_vlt5v: salsat_frame.user_data_rw0_tm_std.rw0_pget_vlt5v
    :field rw0_pget_vlt3v3: salsat_frame.user_data_rw0_tm_std.rw0_pget_vlt3v3
    :field rw0_pget_vlt3v3mcu: salsat_frame.user_data_rw0_tm_std.rw0_pget_vlt3v3mcu
    :field thm_rw0_pget_tmppwr: salsat_frame.user_data_rw0_tm_std.thm_rw0_pget_tmppwr
    :field thm_rw0_pget_tmppresssens: salsat_frame.user_data_rw0_tm_std.thm_rw0_pget_tmppresssens
    :field thm_rw0_pget_tmpgyro1: salsat_frame.user_data_rw0_tm_std.thm_rw0_pget_tmpgyro1
    :field rw0_pget_vltgyro0zref: salsat_frame.user_data_rw0_tm_std.rw0_pget_vltgyro0zref
    :field rw0_pget_vltgyro0z: salsat_frame.user_data_rw0_tm_std.rw0_pget_vltgyro0z
    :field rw0_pget_rategyro1x: salsat_frame.user_data_rw0_tm_std.rw0_pget_rategyro1x
    :field rw0_pget_rategyro1y: salsat_frame.user_data_rw0_tm_std.rw0_pget_rategyro1y
    :field rw0_pget_rategyro1z: salsat_frame.user_data_rw0_tm_std.rw0_pget_rategyro1z
    :field rw0_pget_press: salsat_frame.user_data_rw0_tm_std.rw0_pget_press
    :field user_data_rw0_tm_cntrl_rw0_pget_systime: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_systime
    :field rw0_pget_fsmcntrlstate: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_fsmcntrlstate
    :field rw0_pget_mtrnegdirsense: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_mtrnegdirsense
    :field rw0_pget_mtrrotdirchange: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_mtrrotdirchange
    :field rw0_pget_mtrrotzero: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_mtrrotzero
    :field rw0_pget_softstholdmtroff: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_softstholdmtroff
    :field rw0_pget_newhalledge: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_newhalledge
    :field rw0_pget_hallirqguard: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_hallirqguard
    :field rw0_pget_hallirqcollision: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_hallirqcollision
    :field rw0_pget_entryext: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_entryext
    :field rw0_pget_entryextmtrrate: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_entryextmtrrate
    :field rw0_pget_entryexttorque: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_entryexttorque
    :field rw0_pget_entryextsatrate: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_entryextsatrate
    :field rw0_pget_entryextsatangle: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_entryextsatangle
    :field rw0_pget_mtrcuractive: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_mtrcuractive
    :field rw0_pget_gyro1active: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_gyro1active
    :field user_data_rw0_tm_cntrl_rw0_pget_boolrfu0: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_boolrfu0
    :field user_data_rw0_tm_cntrl_rw0_pget_boolrfu1: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_boolrfu1
    :field rw0_pget_mvpwm: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_mvpwm
    :field rw0_pget_mtrrate: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_mtrrate
    :field rw0_pget_mtrratedot: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_mtrratedot
    :field rw0_pget_satrate: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_satrate
    :field rw0_pget_satangle: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_satangle
    :field user_data_rw0_tm_cntrl_rw0_pget_curmtr: salsat_frame.user_data_rw0_tm_cntrl.rw0_pget_curmtr
    :field rw1_pget_systime: salsat_frame.user_data_rw1_tm_std.rw1_pget_systime
    :field rw1_pget_resetcnt: salsat_frame.user_data_rw1_tm_std.rw1_pget_resetcnt
    :field rw1_pget_fsmmainstate: salsat_frame.user_data_rw1_tm_std.rw1_pget_fsmmainstate
    :field rw1_pget_invrxframe: salsat_frame.user_data_rw1_tm_std.rw1_pget_invrxframe
    :field rw1_pget_comtimeout: salsat_frame.user_data_rw1_tm_std.rw1_pget_comtimeout
    :field rw1_pget_anomalyenvir: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalyenvir
    :field rw1_pget_anomalypwr: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalypwr
    :field rw1_pget_mtroff: salsat_frame.user_data_rw1_tm_std.rw1_pget_mtroff
    :field rw1_pget_mvlimit: salsat_frame.user_data_rw1_tm_std.rw1_pget_mvlimit
    :field rw1_pget_mtrovercur: salsat_frame.user_data_rw1_tm_std.rw1_pget_mtrovercur
    :field rw1_pget_faultgyro0: salsat_frame.user_data_rw1_tm_std.rw1_pget_faultgyro0
    :field rw1_pget_faultgyro1: salsat_frame.user_data_rw1_tm_std.rw1_pget_faultgyro1
    :field rw1_pget_boolrfu0: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu0
    :field rw1_pget_boolrfu1: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu1
    :field rw1_pget_boolrfu2: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu2
    :field rw1_pget_boolrfu3: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu3
    :field rw1_pget_boolrfu4: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu4
    :field rw1_pget_boolrfu5: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu5
    :field rw1_pget_boolrfu6: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu6
    :field rw1_pget_anomalycurmtr: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalycurmtr
    :field rw1_pget_anomalycurwde: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalycurwde
    :field rw1_pget_anomalycur3v3: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalycur3v3
    :field rw1_pget_anomalycur5v: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalycur5v
    :field rw1_pget_anomalyvltmtr: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalyvltmtr
    :field rw1_pget_anomalyvlt3v2: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalyvlt3v2
    :field rw1_pget_anomalyvlt5v: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalyvlt5v
    :field rw1_pget_anomalyvlt3v3: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalyvlt3v3
    :field rw1_pget_anomalyvlt3v3mcu: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalyvlt3v3mcu
    :field rw1_pget_anomalytmppwr: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalytmppwr
    :field rw1_pget_anomalygyro0: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalygyro0
    :field rw1_pget_anomalygyro1: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalygyro1
    :field rw1_pget_anomalypress: salsat_frame.user_data_rw1_tm_std.rw1_pget_anomalypress
    :field rw1_pget_boolrfu7: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu7
    :field rw1_pget_boolrfu8: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu8
    :field rw1_pget_boolrfu9: salsat_frame.user_data_rw1_tm_std.rw1_pget_boolrfu9
    :field rw1_pget_curmtr: salsat_frame.user_data_rw1_tm_std.rw1_pget_curmtr
    :field rw1_pget_curwde: salsat_frame.user_data_rw1_tm_std.rw1_pget_curwde
    :field rw1_pget_cur3v3: salsat_frame.user_data_rw1_tm_std.rw1_pget_cur3v3
    :field rw1_pget_cur5v: salsat_frame.user_data_rw1_tm_std.rw1_pget_cur5v
    :field rw1_pget_vltmtr: salsat_frame.user_data_rw1_tm_std.rw1_pget_vltmtr
    :field rw1_pget_vlt3v2: salsat_frame.user_data_rw1_tm_std.rw1_pget_vlt3v2
    :field rw1_pget_vlt5v: salsat_frame.user_data_rw1_tm_std.rw1_pget_vlt5v
    :field rw1_pget_vlt3v3: salsat_frame.user_data_rw1_tm_std.rw1_pget_vlt3v3
    :field rw1_pget_vlt3v3mcu: salsat_frame.user_data_rw1_tm_std.rw1_pget_vlt3v3mcu
    :field thm_rw1_pget_tmppwr: salsat_frame.user_data_rw1_tm_std.thm_rw1_pget_tmppwr
    :field thm_rw1_pget_tmppresssens: salsat_frame.user_data_rw1_tm_std.thm_rw1_pget_tmppresssens
    :field thm_rw1_pget_tmpgyro1: salsat_frame.user_data_rw1_tm_std.thm_rw1_pget_tmpgyro1
    :field rw1_pget_vltgyro0zref: salsat_frame.user_data_rw1_tm_std.rw1_pget_vltgyro0zref
    :field rw1_pget_vltgyro0z: salsat_frame.user_data_rw1_tm_std.rw1_pget_vltgyro0z
    :field rw1_pget_rategyro1x: salsat_frame.user_data_rw1_tm_std.rw1_pget_rategyro1x
    :field rw1_pget_rategyro1y: salsat_frame.user_data_rw1_tm_std.rw1_pget_rategyro1y
    :field rw1_pget_rategyro1z: salsat_frame.user_data_rw1_tm_std.rw1_pget_rategyro1z
    :field rw1_pget_press: salsat_frame.user_data_rw1_tm_std.rw1_pget_press
    :field rw2_pget_systime: salsat_frame.user_data_rw2_tm_std.rw2_pget_systime
    :field rw2_pget_resetcnt: salsat_frame.user_data_rw2_tm_std.rw2_pget_resetcnt
    :field rw2_pget_fsmmainstate: salsat_frame.user_data_rw2_tm_std.rw2_pget_fsmmainstate
    :field rw2_pget_invrxframe: salsat_frame.user_data_rw2_tm_std.rw2_pget_invrxframe
    :field rw2_pget_comtimeout: salsat_frame.user_data_rw2_tm_std.rw2_pget_comtimeout
    :field rw2_pget_anomalyenvir: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalyenvir
    :field rw2_pget_anomalypwr: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalypwr
    :field rw2_pget_mtroff: salsat_frame.user_data_rw2_tm_std.rw2_pget_mtroff
    :field rw2_pget_mvlimit: salsat_frame.user_data_rw2_tm_std.rw2_pget_mvlimit
    :field rw2_pget_mtrovercur: salsat_frame.user_data_rw2_tm_std.rw2_pget_mtrovercur
    :field rw2_pget_faultgyro0: salsat_frame.user_data_rw2_tm_std.rw2_pget_faultgyro0
    :field rw2_pget_faultgyro1: salsat_frame.user_data_rw2_tm_std.rw2_pget_faultgyro1
    :field rw2_pget_boolrfu0: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu0
    :field rw2_pget_boolrfu1: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu1
    :field rw2_pget_boolrfu2: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu2
    :field rw2_pget_boolrfu3: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu3
    :field rw2_pget_boolrfu4: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu4
    :field rw2_pget_boolrfu5: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu5
    :field rw2_pget_boolrfu6: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu6
    :field rw2_pget_anomalycurmtr: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalycurmtr
    :field rw2_pget_anomalycurwde: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalycurwde
    :field rw2_pget_anomalycur3v3: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalycur3v3
    :field rw2_pget_anomalycur5v: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalycur5v
    :field rw2_pget_anomalyvltmtr: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalyvltmtr
    :field rw2_pget_anomalyvlt3v2: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalyvlt3v2
    :field rw2_pget_anomalyvlt5v: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalyvlt5v
    :field rw2_pget_anomalyvlt3v3: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalyvlt3v3
    :field rw2_pget_anomalyvlt3v3mcu: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalyvlt3v3mcu
    :field rw2_pget_anomalytmppwr: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalytmppwr
    :field rw2_pget_anomalygyro0: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalygyro0
    :field rw2_pget_anomalygyro1: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalygyro1
    :field rw2_pget_anomalypress: salsat_frame.user_data_rw2_tm_std.rw2_pget_anomalypress
    :field rw2_pget_boolrfu7: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu7
    :field rw2_pget_boolrfu8: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu8
    :field rw2_pget_boolrfu9: salsat_frame.user_data_rw2_tm_std.rw2_pget_boolrfu9
    :field rw2_pget_curmtr: salsat_frame.user_data_rw2_tm_std.rw2_pget_curmtr
    :field rw2_pget_curwde: salsat_frame.user_data_rw2_tm_std.rw2_pget_curwde
    :field rw2_pget_cur3v3: salsat_frame.user_data_rw2_tm_std.rw2_pget_cur3v3
    :field rw2_pget_cur5v: salsat_frame.user_data_rw2_tm_std.rw2_pget_cur5v
    :field rw2_pget_vltmtr: salsat_frame.user_data_rw2_tm_std.rw2_pget_vltmtr
    :field rw2_pget_vlt3v2: salsat_frame.user_data_rw2_tm_std.rw2_pget_vlt3v2
    :field rw2_pget_vlt5v: salsat_frame.user_data_rw2_tm_std.rw2_pget_vlt5v
    :field rw2_pget_vlt3v3: salsat_frame.user_data_rw2_tm_std.rw2_pget_vlt3v3
    :field rw2_pget_vlt3v3mcu: salsat_frame.user_data_rw2_tm_std.rw2_pget_vlt3v3mcu
    :field thm_rw2_pget_tmppwr: salsat_frame.user_data_rw2_tm_std.thm_rw2_pget_tmppwr
    :field thm_rw2_pget_tmppresssens: salsat_frame.user_data_rw2_tm_std.thm_rw2_pget_tmppresssens
    :field thm_rw2_pget_tmpgyro1: salsat_frame.user_data_rw2_tm_std.thm_rw2_pget_tmpgyro1
    :field rw2_pget_vltgyro0zref: salsat_frame.user_data_rw2_tm_std.rw2_pget_vltgyro0zref
    :field rw2_pget_vltgyro0z: salsat_frame.user_data_rw2_tm_std.rw2_pget_vltgyro0z
    :field rw2_pget_rategyro1x: salsat_frame.user_data_rw2_tm_std.rw2_pget_rategyro1x
    :field rw2_pget_rategyro1y: salsat_frame.user_data_rw2_tm_std.rw2_pget_rategyro1y
    :field rw2_pget_rategyro1z: salsat_frame.user_data_rw2_tm_std.rw2_pget_rategyro1z
    :field rw2_pget_press: salsat_frame.user_data_rw2_tm_std.rw2_pget_press
    :field user_data_rw2_tm_eeprom_rw2_pget_systime: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_systime
    :field rw2_pget_cntrlmode: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_cntrlmode
    :field rw2_pget_kpnumeeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_kpnumeeprom
    :field rw2_pget_kpdeneeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_kpdeneeprom
    :field rw2_pget_kinumeeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_kinumeeprom
    :field rw2_pget_kideneeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_kideneeprom
    :field rw2_pget_kdnumeeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_kdnumeeprom
    :field rw2_pget_kddeneeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_kddeneeprom
    :field rw2_pget_svlimiteeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_svlimiteeprom
    :field rw2_pget_mvlimiteeprompwm: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_mvlimiteeprompwm
    :field rw2_pget_gyro0offseteeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_gyro0offseteeprom
    :field rw2_pget_gyro1offseteeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_gyro1offseteeprom
    :field rw2_pget_gyro1activeeeprom: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_gyro1activeeeprom
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu0: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu0
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu1: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu1
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu2: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu2
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu3: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu3
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu4: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu4
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu5: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu5
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu6: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu6
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu7: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu7
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu8: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu8
    :field user_data_rw2_tm_eeprom_rw2_pget_boolrfu9: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu9
    :field rw2_pget_boolrfu10: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu10
    :field rw2_pget_boolrfu11: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu11
    :field rw2_pget_boolrfu12: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu12
    :field rw2_pget_boolrfu13: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu13
    :field rw2_pget_boolrfu14: salsat_frame.user_data_rw2_tm_eeprom.rw2_pget_boolrfu14
    :field user_data_rw0_tm_press_rw0_pget_systime: salsat_frame.user_data_rw0_tm_press.rw0_pget_systime
    :field rw0_pget_presscoeff0: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscoeff0
    :field rw0_pget_presscoeff1: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscoeff1
    :field rw0_pget_presscoeff2: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscoeff2
    :field rw0_pget_presscoeff3: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscoeff3
    :field rw0_pget_presscoeff4: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscoeff4
    :field rw0_pget_presscoeff5: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscoeff5
    :field rw0_pget_presscoeff6: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscoeff6
    :field rw0_pget_presscrc: salsat_frame.user_data_rw0_tm_press.rw0_pget_presscrc
    :field user_data_rw0_tm_press_thm_rw0_pget_tmppresssens: salsat_frame.user_data_rw0_tm_press.thm_rw0_pget_tmppresssens
    :field user_data_rw0_tm_press_rw0_pget_press: salsat_frame.user_data_rw0_tm_press.rw0_pget_press
    :field user_data_rw1_tm_press_rw1_pget_systime: salsat_frame.user_data_rw1_tm_press.rw1_pget_systime
    :field rw1_pget_presscoeff0: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscoeff0
    :field rw1_pget_presscoeff1: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscoeff1
    :field rw1_pget_presscoeff2: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscoeff2
    :field rw1_pget_presscoeff3: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscoeff3
    :field rw1_pget_presscoeff4: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscoeff4
    :field rw1_pget_presscoeff5: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscoeff5
    :field rw1_pget_presscoeff6: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscoeff6
    :field rw1_pget_presscrc: salsat_frame.user_data_rw1_tm_press.rw1_pget_presscrc
    :field user_data_rw1_tm_press_thm_rw1_pget_tmppresssens: salsat_frame.user_data_rw1_tm_press.thm_rw1_pget_tmppresssens
    :field user_data_rw1_tm_press_rw1_pget_press: salsat_frame.user_data_rw1_tm_press.rw1_pget_press
    :field user_data_rw2_tm_press_rw2_pget_systime: salsat_frame.user_data_rw2_tm_press.rw2_pget_systime
    :field rw2_pget_presscoeff0: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscoeff0
    :field rw2_pget_presscoeff1: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscoeff1
    :field rw2_pget_presscoeff2: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscoeff2
    :field rw2_pget_presscoeff3: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscoeff3
    :field rw2_pget_presscoeff4: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscoeff4
    :field rw2_pget_presscoeff5: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscoeff5
    :field rw2_pget_presscoeff6: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscoeff6
    :field rw2_pget_presscrc: salsat_frame.user_data_rw2_tm_press.rw2_pget_presscrc
    :field user_data_rw2_tm_press_thm_rw2_pget_tmppresssens: salsat_frame.user_data_rw2_tm_press.thm_rw2_pget_tmppresssens
    :field user_data_rw2_tm_press_rw2_pget_press: salsat_frame.user_data_rw2_tm_press.rw2_pget_press
    :field user_data_rw0_tm_cstm_0_rw0_pget_fsmmainstate: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_fsmmainstate
    :field user_data_rw0_tm_cstm_0_rw0_pget_entryextmtrrate: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_entryextmtrrate
    :field user_data_rw0_tm_cstm_0_rw0_pget_entryexttorque: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_entryexttorque
    :field user_data_rw0_tm_cstm_0_rw0_pget_entryextsatrate: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_entryextsatrate
    :field user_data_rw0_tm_cstm_0_rw0_pget_entryextsatangle: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_entryextsatangle
    :field user_data_rw0_tm_cstm_0_rw0_pget_mtrcuractive: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_mtrcuractive
    :field user_data_rw0_tm_cstm_0_rw0_pget_gyro1active: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_gyro1active
    :field user_data_rw0_tm_cstm_0_rw0_pget_boolrfu0: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_boolrfu0
    :field user_data_rw0_tm_cstm_0_rw0_pget_boolrfu1: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_boolrfu1
    :field user_data_rw0_tm_cstm_0_rw0_pget_mtrrate: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_mtrrate
    :field user_data_rw0_tm_cstm_0_rw0_pget_mtrratedot: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_mtrratedot
    :field user_data_rw0_tm_cstm_0_rw0_pget_satrate: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_satrate
    :field user_data_rw0_tm_cstm_0_rw0_pget_satangle: salsat_frame.user_data_rw0_tm_cstm_0.rw0_pget_satangle
    :field user_data_rw1_tm_cstm_0_rw1_pget_fsmmainstate: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_fsmmainstate
    :field rw1_pget_entryextmtrrate: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_entryextmtrrate
    :field rw1_pget_entryexttorque: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_entryexttorque
    :field rw1_pget_entryextsatrate: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_entryextsatrate
    :field rw1_pget_entryextsatangle: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_entryextsatangle
    :field rw1_pget_mtrcuractive: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_mtrcuractive
    :field rw1_pget_gyro1active: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_gyro1active
    :field user_data_rw1_tm_cstm_0_rw1_pget_boolrfu0: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_boolrfu0
    :field user_data_rw1_tm_cstm_0_rw1_pget_boolrfu1: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_boolrfu1
    :field rw1_pget_mtrrate: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_mtrrate
    :field rw1_pget_mtrratedot: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_mtrratedot
    :field rw1_pget_satrate: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_satrate
    :field rw1_pget_satangle: salsat_frame.user_data_rw1_tm_cstm_0.rw1_pget_satangle
    :field user_data_rw2_tm_cstm_0_rw2_pget_fsmmainstate: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_fsmmainstate
    :field rw2_pget_entryextmtrrate: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_entryextmtrrate
    :field rw2_pget_entryexttorque: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_entryexttorque
    :field rw2_pget_entryextsatrate: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_entryextsatrate
    :field rw2_pget_entryextsatangle: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_entryextsatangle
    :field rw2_pget_mtrcuractive: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_mtrcuractive
    :field rw2_pget_gyro1active: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_gyro1active
    :field user_data_rw2_tm_cstm_0_rw2_pget_boolrfu0: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_boolrfu0
    :field user_data_rw2_tm_cstm_0_rw2_pget_boolrfu1: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_boolrfu1
    :field rw2_pget_mtrrate: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_mtrrate
    :field rw2_pget_mtrratedot: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_mtrratedot
    :field rw2_pget_satrate: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_satrate
    :field rw2_pget_satangle: salsat_frame.user_data_rw2_tm_cstm_0.rw2_pget_satangle
    :field user_data_rw0_tm_swvers_rw0_pget_systime: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_systime
    :field rw0_pget_swversmajor: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swversmajor
    :field rw0_pget_swversminor: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swversminor
    :field rw0_pget_swbuildyear: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swbuildyear
    :field rw0_pget_swbuildmonth: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swbuildmonth
    :field rw0_pget_swbuildday: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swbuildday
    :field rw0_pget_swbuildhour: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swbuildhour
    :field rw0_pget_swbuildmin: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swbuildmin
    :field rw0_pget_swbuildsec: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_swbuildsec
    :field rw0_pget_serialnum: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_serialnum
    :field rw0_pget_devid: salsat_frame.user_data_rw0_tm_swvers.rw0_pget_devid
    :field user_data_rw1_tm_swvers_rw1_pget_systime: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_systime
    :field rw1_pget_swversmajor: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swversmajor
    :field rw1_pget_swversminor: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swversminor
    :field rw1_pget_swbuildyear: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swbuildyear
    :field rw1_pget_swbuildmonth: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swbuildmonth
    :field rw1_pget_swbuildday: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swbuildday
    :field rw1_pget_swbuildhour: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swbuildhour
    :field rw1_pget_swbuildmin: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swbuildmin
    :field rw1_pget_swbuildsec: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_swbuildsec
    :field rw1_pget_serialnum: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_serialnum
    :field rw1_pget_devid: salsat_frame.user_data_rw1_tm_swvers.rw1_pget_devid
    :field user_data_rw2_tm_swvers_rw2_pget_systime: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_systime
    :field rw2_pget_swversmajor: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swversmajor
    :field rw2_pget_swversminor: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swversminor
    :field rw2_pget_swbuildyear: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swbuildyear
    :field rw2_pget_swbuildmonth: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swbuildmonth
    :field rw2_pget_swbuildday: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swbuildday
    :field rw2_pget_swbuildhour: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swbuildhour
    :field rw2_pget_swbuildmin: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swbuildmin
    :field rw2_pget_swbuildsec: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_swbuildsec
    :field rw2_pget_serialnum: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_serialnum
    :field rw2_pget_devid: salsat_frame.user_data_rw2_tm_swvers.rw2_pget_devid
    :field user_data_rw0_tm_sram_rw0_pget_systime: salsat_frame.user_data_rw0_tm_sram.rw0_pget_systime
    :field rw0_pget_cntrlmode: salsat_frame.user_data_rw0_tm_sram.rw0_pget_cntrlmode
    :field rw0_pget_kpnumsram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_kpnumsram
    :field rw0_pget_kpdensram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_kpdensram
    :field rw0_pget_kinumsram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_kinumsram
    :field rw0_pget_kidensram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_kidensram
    :field rw0_pget_kdnumsram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_kdnumsram
    :field rw0_pget_kddensram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_kddensram
    :field rw0_pget_svlimitsram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_svlimitsram
    :field rw0_pget_mvlimitsrampwm: salsat_frame.user_data_rw0_tm_sram.rw0_pget_mvlimitsrampwm
    :field rw0_pget_gyro0offsetsram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_gyro0offsetsram
    :field rw0_pget_gyro1offsetsram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_gyro1offsetsram
    :field rw0_pget_gyro1activesram: salsat_frame.user_data_rw0_tm_sram.rw0_pget_gyro1activesram
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu0: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu0
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu1: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu1
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu2: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu2
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu3: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu3
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu4: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu4
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu5: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu5
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu6: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu6
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu7: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu7
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu8: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu8
    :field user_data_rw0_tm_sram_rw0_pget_boolrfu9: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu9
    :field rw0_pget_boolrfu10: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu10
    :field rw0_pget_boolrfu11: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu11
    :field rw0_pget_boolrfu12: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu12
    :field rw0_pget_boolrfu13: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu13
    :field rw0_pget_boolrfu14: salsat_frame.user_data_rw0_tm_sram.rw0_pget_boolrfu14
    :field user_data_rw1_tm_eeprom_rw1_pget_systime: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_systime
    :field rw1_pget_cntrlmode: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_cntrlmode
    :field rw1_pget_kpnumeeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_kpnumeeprom
    :field rw1_pget_kpdeneeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_kpdeneeprom
    :field rw1_pget_kinumeeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_kinumeeprom
    :field rw1_pget_kideneeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_kideneeprom
    :field rw1_pget_kdnumeeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_kdnumeeprom
    :field rw1_pget_kddeneeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_kddeneeprom
    :field rw1_pget_svlimiteeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_svlimiteeprom
    :field rw1_pget_mvlimiteeprompwm: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_mvlimiteeprompwm
    :field rw1_pget_gyro0offseteeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_gyro0offseteeprom
    :field rw1_pget_gyro1offseteeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_gyro1offseteeprom
    :field rw1_pget_gyro1activeeeprom: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_gyro1activeeeprom
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu0: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu0
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu1: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu1
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu2: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu2
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu3: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu3
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu4: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu4
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu5: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu5
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu6: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu6
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu7: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu7
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu8: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu8
    :field user_data_rw1_tm_eeprom_rw1_pget_boolrfu9: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu9
    :field rw1_pget_boolrfu10: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu10
    :field rw1_pget_boolrfu11: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu11
    :field rw1_pget_boolrfu12: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu12
    :field rw1_pget_boolrfu13: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu13
    :field rw1_pget_boolrfu14: salsat_frame.user_data_rw1_tm_eeprom.rw1_pget_boolrfu14
    :field user_data_rw0_tm_eeprom_rw0_pget_systime: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_systime
    :field user_data_rw0_tm_eeprom_rw0_pget_cntrlmode: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_cntrlmode
    :field rw0_pget_kpnumeeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_kpnumeeprom
    :field rw0_pget_kpdeneeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_kpdeneeprom
    :field rw0_pget_kinumeeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_kinumeeprom
    :field rw0_pget_kideneeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_kideneeprom
    :field rw0_pget_kdnumeeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_kdnumeeprom
    :field rw0_pget_kddeneeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_kddeneeprom
    :field rw0_pget_svlimiteeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_svlimiteeprom
    :field rw0_pget_mvlimiteeprompwm: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_mvlimiteeprompwm
    :field rw0_pget_gyro0offseteeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_gyro0offseteeprom
    :field rw0_pget_gyro1offseteeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_gyro1offseteeprom
    :field rw0_pget_gyro1activeeeprom: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_gyro1activeeeprom
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu0: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu0
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu1: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu1
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu2: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu2
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu3: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu3
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu4: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu4
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu5: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu5
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu6: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu6
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu7: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu7
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu8: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu8
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu9: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu9
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu10: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu10
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu11: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu11
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu12: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu12
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu13: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu13
    :field user_data_rw0_tm_eeprom_rw0_pget_boolrfu14: salsat_frame.user_data_rw0_tm_eeprom.rw0_pget_boolrfu14
    :field user_data_rw1_tm_sram_rw1_pget_systime: salsat_frame.user_data_rw1_tm_sram.rw1_pget_systime
    :field user_data_rw1_tm_sram_rw1_pget_cntrlmode: salsat_frame.user_data_rw1_tm_sram.rw1_pget_cntrlmode
    :field rw1_pget_kpnumsram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_kpnumsram
    :field rw1_pget_kpdensram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_kpdensram
    :field rw1_pget_kinumsram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_kinumsram
    :field rw1_pget_kidensram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_kidensram
    :field rw1_pget_kdnumsram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_kdnumsram
    :field rw1_pget_kddensram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_kddensram
    :field rw1_pget_svlimitsram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_svlimitsram
    :field rw1_pget_mvlimitsrampwm: salsat_frame.user_data_rw1_tm_sram.rw1_pget_mvlimitsrampwm
    :field rw1_pget_gyro0offsetsram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_gyro0offsetsram
    :field rw1_pget_gyro1offsetsram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_gyro1offsetsram
    :field rw1_pget_gyro1activesram: salsat_frame.user_data_rw1_tm_sram.rw1_pget_gyro1activesram
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu0: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu0
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu1: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu1
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu2: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu2
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu3: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu3
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu4: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu4
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu5: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu5
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu6: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu6
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu7: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu7
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu8: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu8
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu9: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu9
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu10: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu10
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu11: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu11
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu12: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu12
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu13: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu13
    :field user_data_rw1_tm_sram_rw1_pget_boolrfu14: salsat_frame.user_data_rw1_tm_sram.rw1_pget_boolrfu14
    :field user_data_rw2_tm_sram_rw2_pget_systime: salsat_frame.user_data_rw2_tm_sram.rw2_pget_systime
    :field user_data_rw2_tm_sram_rw2_pget_cntrlmode: salsat_frame.user_data_rw2_tm_sram.rw2_pget_cntrlmode
    :field rw2_pget_kpnumsram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_kpnumsram
    :field rw2_pget_kpdensram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_kpdensram
    :field rw2_pget_kinumsram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_kinumsram
    :field rw2_pget_kidensram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_kidensram
    :field rw2_pget_kdnumsram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_kdnumsram
    :field rw2_pget_kddensram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_kddensram
    :field rw2_pget_svlimitsram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_svlimitsram
    :field rw2_pget_mvlimitsrampwm: salsat_frame.user_data_rw2_tm_sram.rw2_pget_mvlimitsrampwm
    :field rw2_pget_gyro0offsetsram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_gyro0offsetsram
    :field rw2_pget_gyro1offsetsram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_gyro1offsetsram
    :field rw2_pget_gyro1activesram: salsat_frame.user_data_rw2_tm_sram.rw2_pget_gyro1activesram
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu0: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu0
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu1: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu1
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu2: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu2
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu3: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu3
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu4: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu4
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu5: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu5
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu6: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu6
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu7: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu7
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu8: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu8
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu9: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu9
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu10: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu10
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu11: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu11
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu12: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu12
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu13: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu13
    :field user_data_rw2_tm_sram_rw2_pget_boolrfu14: salsat_frame.user_data_rw2_tm_sram.rw2_pget_boolrfu14
    :field user_data_rw1_tm_cntrl_rw1_pget_systime: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_systime
    :field rw1_pget_fsmcntrlstate: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_fsmcntrlstate
    :field rw1_pget_mtrnegdirsense: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_mtrnegdirsense
    :field rw1_pget_mtrrotdirchange: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_mtrrotdirchange
    :field rw1_pget_mtrrotzero: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_mtrrotzero
    :field rw1_pget_softstholdmtroff: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_softstholdmtroff
    :field rw1_pget_newhalledge: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_newhalledge
    :field rw1_pget_hallirqguard: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_hallirqguard
    :field rw1_pget_hallirqcollision: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_hallirqcollision
    :field rw1_pget_entryext: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_entryext
    :field user_data_rw1_tm_cntrl_rw1_pget_entryextmtrrate: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_entryextmtrrate
    :field user_data_rw1_tm_cntrl_rw1_pget_entryexttorque: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_entryexttorque
    :field user_data_rw1_tm_cntrl_rw1_pget_entryextsatrate: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_entryextsatrate
    :field user_data_rw1_tm_cntrl_rw1_pget_entryextsatangle: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_entryextsatangle
    :field user_data_rw1_tm_cntrl_rw1_pget_mtrcuractive: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_mtrcuractive
    :field user_data_rw1_tm_cntrl_rw1_pget_gyro1active: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_gyro1active
    :field user_data_rw1_tm_cntrl_rw1_pget_boolrfu0: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_boolrfu0
    :field user_data_rw1_tm_cntrl_rw1_pget_boolrfu1: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_boolrfu1
    :field rw1_pget_mvpwm: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_mvpwm
    :field user_data_rw1_tm_cntrl_rw1_pget_mtrrate: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_mtrrate
    :field user_data_rw1_tm_cntrl_rw1_pget_mtrratedot: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_mtrratedot
    :field user_data_rw1_tm_cntrl_rw1_pget_satrate: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_satrate
    :field user_data_rw1_tm_cntrl_rw1_pget_satangle: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_satangle
    :field user_data_rw1_tm_cntrl_rw1_pget_curmtr: salsat_frame.user_data_rw1_tm_cntrl.rw1_pget_curmtr
    :field user_data_rw2_tm_cntrl_rw2_pget_systime: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_systime
    :field rw2_pget_fsmcntrlstate: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_fsmcntrlstate
    :field rw2_pget_mtrnegdirsense: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_mtrnegdirsense
    :field rw2_pget_mtrrotdirchange: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_mtrrotdirchange
    :field rw2_pget_mtrrotzero: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_mtrrotzero
    :field rw2_pget_softstholdmtroff: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_softstholdmtroff
    :field rw2_pget_newhalledge: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_newhalledge
    :field rw2_pget_hallirqguard: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_hallirqguard
    :field rw2_pget_hallirqcollision: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_hallirqcollision
    :field rw2_pget_entryext: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_entryext
    :field user_data_rw2_tm_cntrl_rw2_pget_entryextmtrrate: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_entryextmtrrate
    :field user_data_rw2_tm_cntrl_rw2_pget_entryexttorque: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_entryexttorque
    :field user_data_rw2_tm_cntrl_rw2_pget_entryextsatrate: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_entryextsatrate
    :field user_data_rw2_tm_cntrl_rw2_pget_entryextsatangle: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_entryextsatangle
    :field user_data_rw2_tm_cntrl_rw2_pget_mtrcuractive: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_mtrcuractive
    :field user_data_rw2_tm_cntrl_rw2_pget_gyro1active: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_gyro1active
    :field user_data_rw2_tm_cntrl_rw2_pget_boolrfu0: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_boolrfu0
    :field user_data_rw2_tm_cntrl_rw2_pget_boolrfu1: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_boolrfu1
    :field rw2_pget_mvpwm: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_mvpwm
    :field user_data_rw2_tm_cntrl_rw2_pget_mtrrate: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_mtrrate
    :field user_data_rw2_tm_cntrl_rw2_pget_mtrratedot: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_mtrratedot
    :field user_data_rw2_tm_cntrl_rw2_pget_satrate: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_satrate
    :field user_data_rw2_tm_cntrl_rw2_pget_satangle: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_satangle
    :field user_data_rw2_tm_cntrl_rw2_pget_curmtr: salsat_frame.user_data_rw2_tm_cntrl.rw2_pget_curmtr
    :field user_data_rw0_tm_cstm_2_rw0_pget_systime: salsat_frame.user_data_rw0_tm_cstm_2.rw0_pget_systime
    :field user_data_rw1_tm_cstm_2_rw1_pget_systime: salsat_frame.user_data_rw1_tm_cstm_2.rw1_pget_systime
    :field user_data_rw2_tm_cstm_2_rw2_pget_systime: salsat_frame.user_data_rw2_tm_cstm_2.rw2_pget_systime
    :field user_data_rw0_tm_cstm_3_rw0_pget_systime: salsat_frame.user_data_rw0_tm_cstm_3.rw0_pget_systime
    :field user_data_rw2_tm_cstm_4_rw2_pget_systime: salsat_frame.user_data_rw2_tm_cstm_4.rw2_pget_systime
    :field user_data_rw1_tm_cstm_3_rw1_pget_systime: salsat_frame.user_data_rw1_tm_cstm_3.rw1_pget_systime
    :field user_data_rw2_tm_cstm_3_rw2_pget_systime: salsat_frame.user_data_rw2_tm_cstm_3.rw2_pget_systime
    :field user_data_rw0_tm_cstm_4_rw0_pget_systime: salsat_frame.user_data_rw0_tm_cstm_4.rw0_pget_systime
    :field user_data_rw1_tm_cstm_4_rw1_pget_systime: salsat_frame.user_data_rw1_tm_cstm_4.rw1_pget_systime
    :field user_data_rw0_tm_cstm_1_rw0_pget_systime: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_systime
    :field user_data_rw0_tm_cstm_1_rw0_pget_fsmcntrlstate: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_fsmcntrlstate
    :field user_data_rw0_tm_cstm_1_rw0_pget_mtrnegdirsense: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_mtrnegdirsense
    :field user_data_rw0_tm_cstm_1_rw0_pget_mtrrotdirchange: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_mtrrotdirchange
    :field user_data_rw0_tm_cstm_1_rw0_pget_mtrrotzero: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_mtrrotzero
    :field user_data_rw0_tm_cstm_1_rw0_pget_softstholdmtroff: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_softstholdmtroff
    :field user_data_rw0_tm_cstm_1_rw0_pget_newhalledge: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_newhalledge
    :field user_data_rw0_tm_cstm_1_rw0_pget_hallirqguard: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_hallirqguard
    :field user_data_rw0_tm_cstm_1_rw0_pget_hallirqcollision: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_hallirqcollision
    :field user_data_rw0_tm_cstm_1_rw0_pget_entryext: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_entryext
    :field user_data_rw0_tm_cstm_1_rw0_pget_entryextmtrrate: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_entryextmtrrate
    :field user_data_rw0_tm_cstm_1_rw0_pget_entryexttorque: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_entryexttorque
    :field user_data_rw0_tm_cstm_1_rw0_pget_entryextsatrate: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_entryextsatrate
    :field user_data_rw0_tm_cstm_1_rw0_pget_entryextsatangle: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_entryextsatangle
    :field user_data_rw0_tm_cstm_1_rw0_pget_mtrcuractive: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_mtrcuractive
    :field user_data_rw0_tm_cstm_1_rw0_pget_gyro1active: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_gyro1active
    :field user_data_rw0_tm_cstm_1_rw0_pget_boolrfu0: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_boolrfu0
    :field user_data_rw0_tm_cstm_1_rw0_pget_boolrfu1: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_boolrfu1
    :field rw0_pget_rategyroz: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_rategyroz
    :field user_data_rw0_tm_cstm_1_rw0_pget_satrate: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_satrate
    :field user_data_rw0_tm_cstm_1_rw0_pget_vltgyro0zref: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_vltgyro0zref
    :field user_data_rw0_tm_cstm_1_rw0_pget_vltgyro0z: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_vltgyro0z
    :field user_data_rw0_tm_cstm_1_rw0_pget_rategyro1x: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_rategyro1x
    :field user_data_rw0_tm_cstm_1_rw0_pget_rategyro1y: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_rategyro1y
    :field user_data_rw0_tm_cstm_1_rw0_pget_rategyro1z: salsat_frame.user_data_rw0_tm_cstm_1.rw0_pget_rategyro1z
    :field user_data_rw1_tm_cstm_1_rw1_pget_systime: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_systime
    :field user_data_rw1_tm_cstm_1_rw1_pget_fsmcntrlstate: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_fsmcntrlstate
    :field user_data_rw1_tm_cstm_1_rw1_pget_mtrnegdirsense: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_mtrnegdirsense
    :field user_data_rw1_tm_cstm_1_rw1_pget_mtrrotdirchange: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_mtrrotdirchange
    :field user_data_rw1_tm_cstm_1_rw1_pget_mtrrotzero: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_mtrrotzero
    :field user_data_rw1_tm_cstm_1_rw1_pget_softstholdmtroff: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_softstholdmtroff
    :field user_data_rw1_tm_cstm_1_rw1_pget_newhalledge: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_newhalledge
    :field user_data_rw1_tm_cstm_1_rw1_pget_hallirqguard: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_hallirqguard
    :field user_data_rw1_tm_cstm_1_rw1_pget_hallirqcollision: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_hallirqcollision
    :field user_data_rw1_tm_cstm_1_rw1_pget_entryext: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_entryext
    :field user_data_rw1_tm_cstm_1_rw1_pget_entryextmtrrate: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_entryextmtrrate
    :field user_data_rw1_tm_cstm_1_rw1_pget_entryexttorque: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_entryexttorque
    :field user_data_rw1_tm_cstm_1_rw1_pget_entryextsatrate: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_entryextsatrate
    :field user_data_rw1_tm_cstm_1_rw1_pget_entryextsatangle: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_entryextsatangle
    :field user_data_rw1_tm_cstm_1_rw1_pget_mtrcuractive: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_mtrcuractive
    :field user_data_rw1_tm_cstm_1_rw1_pget_gyro1active: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_gyro1active
    :field user_data_rw1_tm_cstm_1_rw1_pget_boolrfu0: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_boolrfu0
    :field user_data_rw1_tm_cstm_1_rw1_pget_boolrfu1: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_boolrfu1
    :field rw1_pget_rategyroz: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_rategyroz
    :field user_data_rw1_tm_cstm_1_rw1_pget_satrate: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_satrate
    :field user_data_rw1_tm_cstm_1_rw1_pget_vltgyro0zref: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_vltgyro0zref
    :field user_data_rw1_tm_cstm_1_rw1_pget_vltgyro0z: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_vltgyro0z
    :field user_data_rw1_tm_cstm_1_rw1_pget_rategyro1x: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_rategyro1x
    :field user_data_rw1_tm_cstm_1_rw1_pget_rategyro1y: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_rategyro1y
    :field user_data_rw1_tm_cstm_1_rw1_pget_rategyro1z: salsat_frame.user_data_rw1_tm_cstm_1.rw1_pget_rategyro1z
    :field user_data_rw2_tm_cstm_1_rw2_pget_systime: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_systime
    :field user_data_rw2_tm_cstm_1_rw2_pget_fsmcntrlstate: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_fsmcntrlstate
    :field user_data_rw2_tm_cstm_1_rw2_pget_mtrnegdirsense: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_mtrnegdirsense
    :field user_data_rw2_tm_cstm_1_rw2_pget_mtrrotdirchange: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_mtrrotdirchange
    :field user_data_rw2_tm_cstm_1_rw2_pget_mtrrotzero: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_mtrrotzero
    :field user_data_rw2_tm_cstm_1_rw2_pget_softstholdmtroff: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_softstholdmtroff
    :field user_data_rw2_tm_cstm_1_rw2_pget_newhalledge: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_newhalledge
    :field user_data_rw2_tm_cstm_1_rw2_pget_hallirqguard: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_hallirqguard
    :field user_data_rw2_tm_cstm_1_rw2_pget_hallirqcollision: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_hallirqcollision
    :field user_data_rw2_tm_cstm_1_rw2_pget_entryext: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_entryext
    :field user_data_rw2_tm_cstm_1_rw2_pget_entryextmtrrate: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_entryextmtrrate
    :field user_data_rw2_tm_cstm_1_rw2_pget_entryexttorque: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_entryexttorque
    :field user_data_rw2_tm_cstm_1_rw2_pget_entryextsatrate: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_entryextsatrate
    :field user_data_rw2_tm_cstm_1_rw2_pget_entryextsatangle: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_entryextsatangle
    :field user_data_rw2_tm_cstm_1_rw2_pget_mtrcuractive: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_mtrcuractive
    :field user_data_rw2_tm_cstm_1_rw2_pget_gyro1active: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_gyro1active
    :field user_data_rw2_tm_cstm_1_rw2_pget_boolrfu0: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_boolrfu0
    :field user_data_rw2_tm_cstm_1_rw2_pget_boolrfu1: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_boolrfu1
    :field rw2_pget_rategyroz: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_rategyroz
    :field user_data_rw2_tm_cstm_1_rw2_pget_satrate: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_satrate
    :field user_data_rw2_tm_cstm_1_rw2_pget_vltgyro0zref: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_vltgyro0zref
    :field user_data_rw2_tm_cstm_1_rw2_pget_vltgyro0z: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_vltgyro0z
    :field user_data_rw2_tm_cstm_1_rw2_pget_rategyro1x: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_rategyro1x
    :field user_data_rw2_tm_cstm_1_rw2_pget_rategyro1y: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_rategyro1y
    :field user_data_rw2_tm_cstm_1_rw2_pget_rategyro1z: salsat_frame.user_data_rw2_tm_cstm_1.rw2_pget_rategyro1z
    :field user_data_rw0_tm_std_a_rw0_pget_systime: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_systime
    :field user_data_rw0_tm_std_a_rw0_pget_resetcnt: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_resetcnt
    :field user_data_rw0_tm_std_a_rw0_pget_fsmmainstate: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_fsmmainstate
    :field user_data_rw0_tm_std_a_rw0_pget_invrxframe: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_invrxframe
    :field user_data_rw0_tm_std_a_rw0_pget_comtimeout: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_comtimeout
    :field user_data_rw0_tm_std_a_rw0_pget_anomalyenvir: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalyenvir
    :field user_data_rw0_tm_std_a_rw0_pget_anomalypwr: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalypwr
    :field user_data_rw0_tm_std_a_rw0_pget_mtroff: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_mtroff
    :field user_data_rw0_tm_std_a_rw0_pget_mvlimit: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_mvlimit
    :field user_data_rw0_tm_std_a_rw0_pget_mtrovercur: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_mtrovercur
    :field rw0_pget_extadcconfigured: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_extadcconfigured
    :field rw0_pget_faultgyro: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_faultgyro
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu0: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu0
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu1: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu1
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu2: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu2
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu3: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu3
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu4: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu4
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu5: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu5
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu6: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu6
    :field rw0_pget_anomalycurmtrfine: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalycurmtrfine
    :field rw0_pget_anomalycurmtrcoarse: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalycurmtrcoarse
    :field user_data_rw0_tm_std_a_rw0_pget_anomalycurwde: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalycurwde
    :field user_data_rw0_tm_std_a_rw0_pget_anomalycur3v3: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalycur3v3
    :field user_data_rw0_tm_std_a_rw0_pget_anomalycur5v: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalycur5v
    :field user_data_rw0_tm_std_a_rw0_pget_anomalyvltmtr: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalyvltmtr
    :field user_data_rw0_tm_std_a_rw0_pget_anomalyvlt3v3: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalyvlt3v3
    :field user_data_rw0_tm_std_a_rw0_pget_anomalyvlt5v: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalyvlt5v
    :field user_data_rw0_tm_std_a_rw0_pget_anomalyvlt3v2: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalyvlt3v2
    :field rw0_pget_anomalyvlt3v2minus: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalyvlt3v2minus
    :field rw0_pget_anomalyvlt10v: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalyvlt10v
    :field user_data_rw0_tm_std_a_rw0_pget_anomalytmppwr: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalytmppwr
    :field rw0_pget_anomalygyro: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalygyro
    :field user_data_rw0_tm_std_a_rw0_pget_anomalypress: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_anomalypress
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu8: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu8
    :field user_data_rw0_tm_std_a_rw0_pget_boolrfu9: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_boolrfu9
    :field user_data_rw0_tm_std_a_rw0_pget_curmtr: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_curmtr
    :field user_data_rw0_tm_std_a_rw0_pget_cur3v3: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_cur3v3
    :field user_data_rw0_tm_std_a_rw0_pget_cur5v: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_cur5v
    :field user_data_rw0_tm_std_a_rw0_pget_curwde: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_curwde
    :field user_data_rw0_tm_std_a_rw0_pget_vltmtr: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_vltmtr
    :field user_data_rw0_tm_std_a_rw0_pget_vlt3v3: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_vlt3v3
    :field rw0_pget_vlt5va: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_vlt5va
    :field thm_rw0_pget_tmppwra: salsat_frame.user_data_rw0_tm_std_a.thm_rw0_pget_tmppwra
    :field user_data_rw0_tm_std_a_thm_rw0_pget_tmppresssens: salsat_frame.user_data_rw0_tm_std_a.thm_rw0_pget_tmppresssens
    :field user_data_rw0_tm_std_a_rw0_pget_press: salsat_frame.user_data_rw0_tm_std_a.rw0_pget_press
    :field user_data_rw2_tm_std_b_rw2_pget_systime: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_systime
    :field user_data_rw2_tm_std_b_rw2_pget_fsmmainstate: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_fsmmainstate
    :field rw2_pget_anomalycurmtrfine: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalycurmtrfine
    :field rw2_pget_anomalycurmtrcoarse: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalycurmtrcoarse
    :field user_data_rw2_tm_std_b_rw2_pget_anomalycurwde: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalycurwde
    :field user_data_rw2_tm_std_b_rw2_pget_anomalycur3v3: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalycur3v3
    :field user_data_rw2_tm_std_b_rw2_pget_anomalycur5v: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalycur5v
    :field user_data_rw2_tm_std_b_rw2_pget_anomalyvltmtr: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalyvltmtr
    :field user_data_rw2_tm_std_b_rw2_pget_anomalyvlt3v3: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalyvlt3v3
    :field user_data_rw2_tm_std_b_rw2_pget_anomalyvlt5v: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalyvlt5v
    :field user_data_rw2_tm_std_b_rw2_pget_anomalyvlt3v2: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalyvlt3v2
    :field rw2_pget_anomalyvlt3v2minus: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalyvlt3v2minus
    :field rw2_pget_anomalyvlt10v: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalyvlt10v
    :field user_data_rw2_tm_std_b_rw2_pget_anomalytmppwr: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalytmppwr
    :field rw2_pget_anomalygyro: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalygyro
    :field user_data_rw2_tm_std_b_rw2_pget_anomalypress: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_anomalypress
    :field user_data_rw2_tm_std_b_rw2_pget_boolrfu8: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_boolrfu8
    :field user_data_rw2_tm_std_b_rw2_pget_boolrfu9: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_boolrfu9
    :field rw2_pget_curmtrfine: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_curmtrfine
    :field user_data_rw2_tm_std_b_rw2_pget_vlt3v2: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_vlt3v2
    :field rw2_pget_vlt3v2minus: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_vlt3v2minus
    :field rw2_pget_vlt10v: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_vlt10v
    :field user_data_rw2_tm_std_b_thm_rw2_pget_tmpgyro1: salsat_frame.user_data_rw2_tm_std_b.thm_rw2_pget_tmpgyro1
    :field user_data_rw2_tm_std_b_rw2_pget_rategyro1x: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_rategyro1x
    :field user_data_rw2_tm_std_b_rw2_pget_rategyro1y: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_rategyro1y
    :field user_data_rw2_tm_std_b_rw2_pget_rategyro1z: salsat_frame.user_data_rw2_tm_std_b.rw2_pget_rategyro1z
    :field user_data_rw1_tm_std_b_rw1_pget_systime: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_systime
    :field user_data_rw1_tm_std_b_rw1_pget_fsmmainstate: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_fsmmainstate
    :field rw1_pget_anomalycurmtrfine: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalycurmtrfine
    :field rw1_pget_anomalycurmtrcoarse: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalycurmtrcoarse
    :field user_data_rw1_tm_std_b_rw1_pget_anomalycurwde: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalycurwde
    :field user_data_rw1_tm_std_b_rw1_pget_anomalycur3v3: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalycur3v3
    :field user_data_rw1_tm_std_b_rw1_pget_anomalycur5v: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalycur5v
    :field user_data_rw1_tm_std_b_rw1_pget_anomalyvltmtr: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalyvltmtr
    :field user_data_rw1_tm_std_b_rw1_pget_anomalyvlt3v3: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalyvlt3v3
    :field user_data_rw1_tm_std_b_rw1_pget_anomalyvlt5v: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalyvlt5v
    :field user_data_rw1_tm_std_b_rw1_pget_anomalyvlt3v2: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalyvlt3v2
    :field rw1_pget_anomalyvlt3v2minus: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalyvlt3v2minus
    :field rw1_pget_anomalyvlt10v: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalyvlt10v
    :field user_data_rw1_tm_std_b_rw1_pget_anomalytmppwr: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalytmppwr
    :field rw1_pget_anomalygyro: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalygyro
    :field user_data_rw1_tm_std_b_rw1_pget_anomalypress: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_anomalypress
    :field user_data_rw1_tm_std_b_rw1_pget_boolrfu8: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_boolrfu8
    :field user_data_rw1_tm_std_b_rw1_pget_boolrfu9: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_boolrfu9
    :field rw1_pget_curmtrfine: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_curmtrfine
    :field user_data_rw1_tm_std_b_rw1_pget_vlt3v2: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_vlt3v2
    :field rw1_pget_vlt3v2minus: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_vlt3v2minus
    :field rw1_pget_vlt10v: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_vlt10v
    :field user_data_rw1_tm_std_b_thm_rw1_pget_tmpgyro1: salsat_frame.user_data_rw1_tm_std_b.thm_rw1_pget_tmpgyro1
    :field user_data_rw1_tm_std_b_rw1_pget_rategyro1x: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_rategyro1x
    :field user_data_rw1_tm_std_b_rw1_pget_rategyro1y: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_rategyro1y
    :field user_data_rw1_tm_std_b_rw1_pget_rategyro1z: salsat_frame.user_data_rw1_tm_std_b.rw1_pget_rategyro1z
    :field user_data_rw0_tm_std_b_rw0_pget_systime: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_systime
    :field user_data_rw0_tm_std_b_rw0_pget_fsmmainstate: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_fsmmainstate
    :field user_data_rw0_tm_std_b_rw0_pget_anomalycurmtrfine: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalycurmtrfine
    :field user_data_rw0_tm_std_b_rw0_pget_anomalycurmtrcoarse: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalycurmtrcoarse
    :field user_data_rw0_tm_std_b_rw0_pget_anomalycurwde: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalycurwde
    :field user_data_rw0_tm_std_b_rw0_pget_anomalycur3v3: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalycur3v3
    :field user_data_rw0_tm_std_b_rw0_pget_anomalycur5v: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalycur5v
    :field user_data_rw0_tm_std_b_rw0_pget_anomalyvltmtr: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalyvltmtr
    :field user_data_rw0_tm_std_b_rw0_pget_anomalyvlt3v3: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalyvlt3v3
    :field user_data_rw0_tm_std_b_rw0_pget_anomalyvlt5v: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalyvlt5v
    :field user_data_rw0_tm_std_b_rw0_pget_anomalyvlt3v2: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalyvlt3v2
    :field user_data_rw0_tm_std_b_rw0_pget_anomalyvlt3v2minus: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalyvlt3v2minus
    :field user_data_rw0_tm_std_b_rw0_pget_anomalyvlt10v: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalyvlt10v
    :field user_data_rw0_tm_std_b_rw0_pget_anomalytmppwr: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalytmppwr
    :field user_data_rw0_tm_std_b_rw0_pget_anomalygyro: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalygyro
    :field user_data_rw0_tm_std_b_rw0_pget_anomalypress: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_anomalypress
    :field user_data_rw0_tm_std_b_rw0_pget_boolrfu8: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_boolrfu8
    :field user_data_rw0_tm_std_b_rw0_pget_boolrfu9: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_boolrfu9
    :field rw0_pget_curmtrfine: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_curmtrfine
    :field user_data_rw0_tm_std_b_rw0_pget_vlt3v2: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_vlt3v2
    :field rw0_pget_vlt3v2minus: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_vlt3v2minus
    :field rw0_pget_vlt10v: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_vlt10v
    :field user_data_rw0_tm_std_b_thm_rw0_pget_tmpgyro1: salsat_frame.user_data_rw0_tm_std_b.thm_rw0_pget_tmpgyro1
    :field user_data_rw0_tm_std_b_rw0_pget_rategyro1x: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_rategyro1x
    :field user_data_rw0_tm_std_b_rw0_pget_rategyro1y: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_rategyro1y
    :field user_data_rw0_tm_std_b_rw0_pget_rategyro1z: salsat_frame.user_data_rw0_tm_std_b.rw0_pget_rategyro1z
    :field user_data_rw2_tm_std_a_rw2_pget_systime: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_systime
    :field user_data_rw2_tm_std_a_rw2_pget_resetcnt: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_resetcnt
    :field user_data_rw2_tm_std_a_rw2_pget_fsmmainstate: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_fsmmainstate
    :field user_data_rw2_tm_std_a_rw2_pget_invrxframe: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_invrxframe
    :field user_data_rw2_tm_std_a_rw2_pget_comtimeout: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_comtimeout
    :field user_data_rw2_tm_std_a_rw2_pget_anomalyenvir: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalyenvir
    :field user_data_rw2_tm_std_a_rw2_pget_anomalypwr: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalypwr
    :field user_data_rw2_tm_std_a_rw2_pget_mtroff: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_mtroff
    :field user_data_rw2_tm_std_a_rw2_pget_mvlimit: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_mvlimit
    :field user_data_rw2_tm_std_a_rw2_pget_mtrovercur: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_mtrovercur
    :field rw2_pget_extadcconfigured: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_extadcconfigured
    :field rw2_pget_faultgyro: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_faultgyro
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu0: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu0
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu1: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu1
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu2: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu2
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu3: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu3
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu4: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu4
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu5: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu5
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu6: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu6
    :field user_data_rw2_tm_std_a_rw2_pget_anomalycurmtrfine: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalycurmtrfine
    :field user_data_rw2_tm_std_a_rw2_pget_anomalycurmtrcoarse: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalycurmtrcoarse
    :field user_data_rw2_tm_std_a_rw2_pget_anomalycurwde: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalycurwde
    :field user_data_rw2_tm_std_a_rw2_pget_anomalycur3v3: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalycur3v3
    :field user_data_rw2_tm_std_a_rw2_pget_anomalycur5v: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalycur5v
    :field user_data_rw2_tm_std_a_rw2_pget_anomalyvltmtr: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalyvltmtr
    :field user_data_rw2_tm_std_a_rw2_pget_anomalyvlt3v3: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalyvlt3v3
    :field user_data_rw2_tm_std_a_rw2_pget_anomalyvlt5v: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalyvlt5v
    :field user_data_rw2_tm_std_a_rw2_pget_anomalyvlt3v2: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalyvlt3v2
    :field user_data_rw2_tm_std_a_rw2_pget_anomalyvlt3v2minus: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalyvlt3v2minus
    :field user_data_rw2_tm_std_a_rw2_pget_anomalyvlt10v: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalyvlt10v
    :field user_data_rw2_tm_std_a_rw2_pget_anomalytmppwr: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalytmppwr
    :field user_data_rw2_tm_std_a_rw2_pget_anomalygyro: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalygyro
    :field user_data_rw2_tm_std_a_rw2_pget_anomalypress: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_anomalypress
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu8: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu8
    :field user_data_rw2_tm_std_a_rw2_pget_boolrfu9: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_boolrfu9
    :field user_data_rw2_tm_std_a_rw2_pget_curmtr: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_curmtr
    :field user_data_rw2_tm_std_a_rw2_pget_cur3v3: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_cur3v3
    :field user_data_rw2_tm_std_a_rw2_pget_cur5v: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_cur5v
    :field user_data_rw2_tm_std_a_rw2_pget_curwde: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_curwde
    :field user_data_rw2_tm_std_a_rw2_pget_vltmtr: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_vltmtr
    :field user_data_rw2_tm_std_a_rw2_pget_vlt3v3: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_vlt3v3
    :field rw2_pget_vlt5va: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_vlt5va
    :field thm_rw2_pget_tmppwra: salsat_frame.user_data_rw2_tm_std_a.thm_rw2_pget_tmppwra
    :field user_data_rw2_tm_std_a_thm_rw2_pget_tmppresssens: salsat_frame.user_data_rw2_tm_std_a.thm_rw2_pget_tmppresssens
    :field user_data_rw2_tm_std_a_rw2_pget_press: salsat_frame.user_data_rw2_tm_std_a.rw2_pget_press
    :field user_data_rw1_tm_std_a_rw1_pget_systime: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_systime
    :field user_data_rw1_tm_std_a_rw1_pget_resetcnt: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_resetcnt
    :field user_data_rw1_tm_std_a_rw1_pget_fsmmainstate: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_fsmmainstate
    :field user_data_rw1_tm_std_a_rw1_pget_invrxframe: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_invrxframe
    :field user_data_rw1_tm_std_a_rw1_pget_comtimeout: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_comtimeout
    :field user_data_rw1_tm_std_a_rw1_pget_anomalyenvir: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalyenvir
    :field user_data_rw1_tm_std_a_rw1_pget_anomalypwr: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalypwr
    :field user_data_rw1_tm_std_a_rw1_pget_mtroff: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_mtroff
    :field user_data_rw1_tm_std_a_rw1_pget_mvlimit: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_mvlimit
    :field user_data_rw1_tm_std_a_rw1_pget_mtrovercur: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_mtrovercur
    :field rw1_pget_extadcconfigured: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_extadcconfigured
    :field rw1_pget_faultgyro: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_faultgyro
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu0: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu0
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu1: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu1
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu2: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu2
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu3: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu3
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu4: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu4
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu5: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu5
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu6: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu6
    :field user_data_rw1_tm_std_a_rw1_pget_anomalycurmtrfine: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalycurmtrfine
    :field user_data_rw1_tm_std_a_rw1_pget_anomalycurmtrcoarse: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalycurmtrcoarse
    :field user_data_rw1_tm_std_a_rw1_pget_anomalycurwde: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalycurwde
    :field user_data_rw1_tm_std_a_rw1_pget_anomalycur3v3: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalycur3v3
    :field user_data_rw1_tm_std_a_rw1_pget_anomalycur5v: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalycur5v
    :field user_data_rw1_tm_std_a_rw1_pget_anomalyvltmtr: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalyvltmtr
    :field user_data_rw1_tm_std_a_rw1_pget_anomalyvlt3v3: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalyvlt3v3
    :field user_data_rw1_tm_std_a_rw1_pget_anomalyvlt5v: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalyvlt5v
    :field user_data_rw1_tm_std_a_rw1_pget_anomalyvlt3v2: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalyvlt3v2
    :field user_data_rw1_tm_std_a_rw1_pget_anomalyvlt3v2minus: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalyvlt3v2minus
    :field user_data_rw1_tm_std_a_rw1_pget_anomalyvlt10v: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalyvlt10v
    :field user_data_rw1_tm_std_a_rw1_pget_anomalytmppwr: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalytmppwr
    :field user_data_rw1_tm_std_a_rw1_pget_anomalygyro: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalygyro
    :field user_data_rw1_tm_std_a_rw1_pget_anomalypress: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_anomalypress
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu8: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu8
    :field user_data_rw1_tm_std_a_rw1_pget_boolrfu9: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_boolrfu9
    :field user_data_rw1_tm_std_a_rw1_pget_curmtr: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_curmtr
    :field user_data_rw1_tm_std_a_rw1_pget_cur3v3: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_cur3v3
    :field user_data_rw1_tm_std_a_rw1_pget_cur5v: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_cur5v
    :field user_data_rw1_tm_std_a_rw1_pget_curwde: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_curwde
    :field user_data_rw1_tm_std_a_rw1_pget_vltmtr: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_vltmtr
    :field user_data_rw1_tm_std_a_rw1_pget_vlt3v3: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_vlt3v3
    :field rw1_pget_vlt5va: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_vlt5va
    :field thm_rw1_pget_tmppwra: salsat_frame.user_data_rw1_tm_std_a.thm_rw1_pget_tmppwra
    :field user_data_rw1_tm_std_a_thm_rw1_pget_tmppresssens: salsat_frame.user_data_rw1_tm_std_a.thm_rw1_pget_tmppresssens
    :field user_data_rw1_tm_std_a_rw1_pget_press: salsat_frame.user_data_rw1_tm_std_a.rw1_pget_press
    :field slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_slk_sat.slkpdh_pget_systime
    :field slk_pget_satctrfrequencytx: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrfrequencytx
    :field slk_pget_satctrfrequencyrx: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrfrequencyrx
    :field slk_pget_satl2fifofullsvc: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2fifofullsvc
    :field slk_pget_satberrunning: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satberrunning
    :field slk_pget_satsetrxchannel: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satsetrxchannel
    :field slk_pget_satsettxchannel: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satsettxchannel
    :field slk_pget_satctrfddon: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrfddon
    :field slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_slk_sat.slkpdh_pget_boolrfu0
    :field slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_slk_sat.slkpdh_pget_boolrfu1
    :field slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_slk_sat.slkpdh_pget_boolrfu2
    :field slk_pget_satctrcaller: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrcaller
    :field slk_pget_satctrcallersendbroadcast: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrcallersendbroadcast
    :field slk_pget_satctrresponder: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrresponder
    :field slk_pget_satctrpayloaddir: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrpayloaddir
    :field slk_pget_satsettxgain: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satsettxgain
    :field slk_pget_satl2fifofullsdu: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2fifofullsdu
    :field slk_pget_satl2fifofullsduqos: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2fifofullsduqos
    :field slk_pget_satl2fifofullspdu: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2fifofullspdu
    :field slk_pget_satctrsrcscid: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrsrcscid
    :field slk_pget_satctrdstscid: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrdstscid
    :field slk_pget_satctratttxgain: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctratttxgain
    :field slk_pget_satctrchannel: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrchannel
    :field slk_pget_satctrmaxaitype: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrmaxaitype
    :field slk_pget_sataistate: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_sataistate
    :field slk_pget_satl2state: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2state
    :field slk_pget_sataitype: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_sataitype
    :field slk_pget_satfrc: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satfrc
    :field slk_pget_satchangechannelfrc: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satchangechannelfrc
    :field slk_pget_sataierr: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_sataierr
    :field slk_pget_satl2packetcountsdu: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2packetcountsdu
    :field slk_pget_satl2packetcountsduqos: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2packetcountsduqos
    :field slk_pget_satl2packetcountspdu: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2packetcountspdu
    :field slk_pget_satl2packetcountsvc: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satl2packetcountsvc
    :field thm_slk_pget_satboardtemperature: salsat_frame.user_data_pdh_tm_slk_sat.thm_slk_pget_satboardtemperature
    :field slk_pget_sattestmode: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_sattestmode
    :field slk_pget_satvoltage: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satvoltage
    :field slk_pget_satcurrent: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satcurrent
    :field slk_pget_satpower: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satpower
    :field slk_pget_satrcvdsir: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satrcvdsir
    :field slk_pget_satrxsir: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satrxsir
    :field slk_pget_satmaxsir: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satmaxsir
    :field slk_pget_satminsir: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satminsir
    :field slk_pget_satdistance: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satdistance
    :field slk_pget_satctrantmode: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrantmode
    :field slk_pget_satctrrfrange: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satctrrfrange
    :field slk_pget_satusedl2bytes: salsat_frame.user_data_pdh_tm_slk_sat.slk_pget_satusedl2bytes
    :field slkpdh_pget_saprxslktmcnt: salsat_frame.user_data_pdh_tm_slk_sat.slkpdh_pget_saprxslktmcnt
    :field user_data_pdh_tm_slk_sat2sat_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_slk_sat2sat.slkpdh_pget_systime
    :field slk_pget_sat2satctrfrequencytx: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrfrequencytx
    :field slk_pget_sat2satctrfrequencyrx: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrfrequencyrx
    :field slk_pget_sat2satl2fifofullsvc: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2fifofullsvc
    :field slk_pget_sat2satberrunning: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satberrunning
    :field slk_pget_sat2satsetrxchannel: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satsetrxchannel
    :field slk_pget_sat2satsettxchannel: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satsettxchannel
    :field user_data_pdh_tm_slk_sat2sat_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_slk_sat2sat.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_slk_sat2sat_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_slk_sat2sat.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_slk_sat2sat_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_slk_sat2sat.slkpdh_pget_boolrfu2
    :field slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_slk_sat2sat.slkpdh_pget_boolrfu3
    :field slk_pget_sat2satctrcaller: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrcaller
    :field slk_pget_sat2satctrcallersendbroadcast: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrcallersendbroadcast
    :field slk_pget_sat2satctrresponder: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrresponder
    :field slk_pget_sat2satctrpayloaddir: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrpayloaddir
    :field slk_pget_sat2satsettxgain: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satsettxgain
    :field slk_pget_sat2satl2fifofullsdu: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2fifofullsdu
    :field slk_pget_sat2satl2fifofullsduqos: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2fifofullsduqos
    :field slk_pget_sat2satl2fifofullspdu: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2fifofullspdu
    :field slk_pget_sat2satctrsrcscid: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrsrcscid
    :field slk_pget_sat2satctrdstscid: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrdstscid
    :field slk_pget_sat2satctratttxgain: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctratttxgain
    :field slk_pget_sat2satctrchannel: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrchannel
    :field slk_pget_sat2satctrmaxaitype: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrmaxaitype
    :field slk_pget_sat2sataistate: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2sataistate
    :field slk_pget_sat2satl2state: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2state
    :field slk_pget_sat2sataitype: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2sataitype
    :field slk_pget_sat2satfrc: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satfrc
    :field slk_pget_sat2satchangechannelfrc: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satchangechannelfrc
    :field slk_pget_sat2sataierr: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2sataierr
    :field slk_pget_sat2satl2packetcountsdu: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2packetcountsdu
    :field slk_pget_sat2satl2packetcountsduqos: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2packetcountsduqos
    :field slk_pget_sat2satl2packetcountspdu: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2packetcountspdu
    :field slk_pget_sat2satl2packetcountsvc: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satl2packetcountsvc
    :field thm_slk_pget_sat2satboardtemperature: salsat_frame.user_data_pdh_tm_slk_sat2sat.thm_slk_pget_sat2satboardtemperature
    :field slk_pget_sat2sattestmode: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2sattestmode
    :field slk_pget_sat2satvoltage: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satvoltage
    :field slk_pget_sat2satcurrent: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satcurrent
    :field slk_pget_sat2satpower: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satpower
    :field slk_pget_sat2satrcvdsir: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satrcvdsir
    :field slk_pget_sat2satrxsir: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satrxsir
    :field slk_pget_sat2satmaxsir: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satmaxsir
    :field slk_pget_sat2satminsir: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satminsir
    :field slk_pget_sat2satdistance: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satdistance
    :field slk_pget_sat2satctrantmode: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrantmode
    :field slk_pget_sat2satctrrfrange: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satctrrfrange
    :field slk_pget_sat2satusedl2bytes: salsat_frame.user_data_pdh_tm_slk_sat2sat.slk_pget_sat2satusedl2bytes
    :field user_data_pdh_tm_slk_sat2sat_slkpdh_pget_saprxslktmcnt: salsat_frame.user_data_pdh_tm_slk_sat2sat.slkpdh_pget_saprxslktmcnt
    :field user_data_pdh_tm_slk_std_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_systime
    :field slkpdh_pget_fsmsapstate: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_fsmsapstate
    :field slkpdh_pget_fsmslkstate: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_fsmslkstate
    :field slkpdh_pget_sapspiactive: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspiactive
    :field slkpdh_pget_sapadcconfigured: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapadcconfigured
    :field slkpdh_pget_sapspiinvstartsync: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspiinvstartsync
    :field slkpdh_pget_sapspinotready: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspinotready
    :field slkpdh_pget_sapspiinvfrom: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspiinvfrom
    :field slkpdh_pget_sapspiinvendsync: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspiinvendsync
    :field slkpdh_pget_sapspiinvlength: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspiinvlength
    :field slkpdh_pget_sapspiinvid: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspiinvid
    :field slkpdh_pget_sapspimissedendhdr: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspimissedendhdr
    :field slkpdh_pget_sappltuinvportid: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sappltuinvportid
    :field slkpdh_pget_sappltuinvversno: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sappltuinvversno
    :field slkpdh_pget_sappltuinvscid: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sappltuinvscid
    :field slkpdh_pget_sappltuinvcrc32: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sappltuinvcrc32
    :field slkpdh_pget_sappltuinvasm: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sappltuinvasm
    :field slkpdh_pget_sappltuinvfrmlen: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sappltuinvfrmlen
    :field slkpdh_pget_sapspiopactive: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapspiopactive
    :field slkpdh_pget_progrmodesat2satmain: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodesat2satmain
    :field slkpdh_pget_progrmodesat2satredund: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodesat2satredund
    :field slkpdh_pget_progrmodesatmain: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodesatmain
    :field slkpdh_pget_progrmodesatredund: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodesatredund
    :field slkpdh_pget_progrmodesatwopa: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodesatwopa
    :field slkpdh_pget_progrmodefree0: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodefree0
    :field slkpdh_pget_progrmodefree1: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodefree1
    :field slkpdh_pget_progrmodeboot: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_progrmodeboot
    :field slkpdh_pget_sapactive: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_sapactive
    :field user_data_pdh_tm_slk_std_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_boolrfu3
    :field slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_boolrfu4
    :field slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_boolrfu5
    :field slkpdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_boolrfu6
    :field slkpdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_boolrfu7
    :field slkpdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_boolrfu8
    :field slkpdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_boolrfu9
    :field slkpdh_pget_curtrx: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_curtrx
    :field slkpdh_pget_vlttrx: salsat_frame.user_data_pdh_tm_slk_std.slkpdh_pget_vlttrx
    :field user_data_pdh_tm_sap_std_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_systime
    :field user_data_pdh_tm_sap_std_slkpdh_pget_fsmsapstate: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_fsmsapstate
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspiactive: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspiactive
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapadcconfigured: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapadcconfigured
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspiinvstartsync: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspiinvstartsync
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspinotready: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspinotready
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspiinvfrom: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspiinvfrom
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspiinvendsync: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspiinvendsync
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspiinvlength: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspiinvlength
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspiinvid: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspiinvid
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sapspimissedendhdr: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sapspimissedendhdr
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sappltuinvportid: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sappltuinvportid
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sappltuinvversno: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sappltuinvversno
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sappltuinvscid: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sappltuinvscid
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sappltuinvcrc32: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sappltuinvcrc32
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sappltuinvasm: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sappltuinvasm
    :field user_data_pdh_tm_sap_std_slkpdh_pget_sappltuinvfrmlen: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_sappltuinvfrmlen
    :field user_data_pdh_tm_sap_std_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_std_slkpdh_pget_saprxslktmcnt: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_saprxslktmcnt
    :field slkpdh_pget_saptxslktmcnt: salsat_frame.user_data_pdh_tm_sap_std.slkpdh_pget_saptxslktmcnt
    :field user_data_pdh_tm_sap_eeprom_sat2sat_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_systime
    :field slkpdh_pget_sat2satctrfrequencytxeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrfrequencytxeeprom
    :field slkpdh_pget_sat2satctrfrequencyrxeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrfrequencyrxeeprom
    :field slkpdh_pget_sat2satctratttxgaineeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctratttxgaineeprom
    :field slkpdh_pget_sat2satctrchanneleeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrchanneleeprom
    :field slkpdh_pget_sat2satctrmaxaitypeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrmaxaitypeeeprom
    :field slkpdh_pget_sat2satctrantmodeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrantmodeeeprom
    :field slkpdh_pget_sat2satctrrfrangeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrrfrangeeeprom
    :field slkpdh_pget_sat2satctrcallereeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrcallereeprom
    :field slkpdh_pget_sat2satctrcallersendbroadcasteeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrcallersendbroadcasteeprom
    :field slkpdh_pget_sat2satctrrespondereeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrrespondereeprom
    :field slkpdh_pget_sat2satctrpayloaddireeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_sat2satctrpayloaddireeprom
    :field user_data_pdh_tm_sap_eeprom_sat2sat_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_eeprom_sat2sat_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_sap_eeprom_sat2sat_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_sap_eeprom_sat2sat_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_sap_eeprom_sat2sat.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_sap_sram_sat_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_systime
    :field slkpdh_pget_satctrfrequencytxsram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrfrequencytxsram
    :field slkpdh_pget_satctrfrequencyrxsram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrfrequencyrxsram
    :field slkpdh_pget_satctratttxgainsram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctratttxgainsram
    :field slkpdh_pget_satctrchannelsram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrchannelsram
    :field slkpdh_pget_satctrmaxaitypesram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrmaxaitypesram
    :field slkpdh_pget_satctrantmodesram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrantmodesram
    :field slkpdh_pget_satctrrfrangesram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrrfrangesram
    :field slkpdh_pget_satctrcallersram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrcallersram
    :field slkpdh_pget_satctrcallersendbroadcastsram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrcallersendbroadcastsram
    :field slkpdh_pget_satctrrespondersram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrrespondersram
    :field slkpdh_pget_satctrpayloaddirsram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrpayloaddirsram
    :field slkpdh_pget_satctrfddonsram: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_satctrfddonsram
    :field user_data_pdh_tm_sap_sram_sat_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_sram_sat_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_sap_sram_sat_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_sap_sram_sat.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_sap_eeprom_sat_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_systime
    :field slkpdh_pget_satctrfrequencytxeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrfrequencytxeeprom
    :field slkpdh_pget_satctrfrequencyrxeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrfrequencyrxeeprom
    :field slkpdh_pget_satctratttxgaineeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctratttxgaineeprom
    :field slkpdh_pget_satctrchanneleeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrchanneleeprom
    :field slkpdh_pget_satctrmaxaitypeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrmaxaitypeeeprom
    :field slkpdh_pget_satctrantmodeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrantmodeeeprom
    :field slkpdh_pget_satctrrfrangeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrrfrangeeeprom
    :field slkpdh_pget_satctrcallereeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrcallereeprom
    :field slkpdh_pget_satctrcallersendbroadcasteeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrcallersendbroadcasteeprom
    :field slkpdh_pget_satctrrespondereeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrrespondereeprom
    :field slkpdh_pget_satctrpayloaddireeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrpayloaddireeprom
    :field slkpdh_pget_satctrfddoneeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_satctrfddoneeprom
    :field user_data_pdh_tm_sap_eeprom_sat_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_eeprom_sat_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_sap_eeprom_sat_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_sap_eeprom_sat.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_sap_sram_sat2sat_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_systime
    :field slkpdh_pget_sat2satctrfrequencytxsram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrfrequencytxsram
    :field slkpdh_pget_sat2satctrfrequencyrxsram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrfrequencyrxsram
    :field slkpdh_pget_sat2satctratttxgainsram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctratttxgainsram
    :field slkpdh_pget_sat2satctrchannelsram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrchannelsram
    :field slkpdh_pget_sat2satctrmaxaitypesram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrmaxaitypesram
    :field slkpdh_pget_sat2satctrantmodesram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrantmodesram
    :field slkpdh_pget_sat2satctrrfrangesram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrrfrangesram
    :field slkpdh_pget_sat2satctrcallersram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrcallersram
    :field slkpdh_pget_sat2satctrcallersendbroadcastsram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrcallersendbroadcastsram
    :field slkpdh_pget_sat2satctrrespondersram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrrespondersram
    :field slkpdh_pget_sat2satctrpayloaddirsram: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_sat2satctrpayloaddirsram
    :field user_data_pdh_tm_sap_sram_sat2sat_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_sram_sat2sat_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_sap_sram_sat2sat_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_sap_sram_sat2sat_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_sap_sram_sat2sat.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_sap_pltu_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_systime
    :field slkpdh_pget_pltuscid: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltuscid
    :field slkpdh_pget_pltudfcid: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltudfcid
    :field slkpdh_pget_pltuversno: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltuversno
    :field slkpdh_pget_pltuportid: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltuportid
    :field slkpdh_pget_pltufrmseqno: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltufrmseqno
    :field slkpdh_pget_pltufrmlen: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltufrmlen
    :field slkpdh_pget_pltupdutypeid: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltupdutypeid
    :field slkpdh_pget_pltuqos: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltuqos
    :field slkpdh_pget_pltusrcdstid: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltusrcdstid
    :field slkpdh_pget_pltupcid: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltupcid
    :field user_data_pdh_tm_sap_pltu_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_pltu_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_sap_pltu_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_sap_pltu_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_boolrfu3
    :field slkpdh_pget_pltucrc32: salsat_frame.user_data_pdh_tm_sap_pltu.slkpdh_pget_pltucrc32
    :field user_data_pdh_tm_laynet_sram_tle_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_systime
    :field slkpdh_pget_networksatnum: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networksatnum
    :field slkpdh_pget_networktlesatnumsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlesatnumsram
    :field slkpdh_pget_networktleepochyrsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleepochyrsram
    :field slkpdh_pget_networktleepochdaysfldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleepochdaysfldsram
    :field slkpdh_pget_networktleepochdaysexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleepochdaysexpsram
    :field slkpdh_pget_networktlendotfldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlendotfldsram
    :field slkpdh_pget_networktlendotexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlendotexpsram
    :field slkpdh_pget_networktlenddotfldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlenddotfldsram
    :field slkpdh_pget_networktlenddotexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlenddotexpsram
    :field slkpdh_pget_networktlebstarfldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlebstarfldsram
    :field slkpdh_pget_networktlebstarexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlebstarexpsram
    :field slkpdh_pget_networktleinclofldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleinclofldsram
    :field slkpdh_pget_networktleincloexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleincloexpsram
    :field slkpdh_pget_networktlenodeofldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlenodeofldsram
    :field slkpdh_pget_networktlenodeoexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlenodeoexpsram
    :field slkpdh_pget_networktleeccofldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleeccofldsram
    :field slkpdh_pget_networktleeccoexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleeccoexpsram
    :field slkpdh_pget_networktleargpofldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleargpofldsram
    :field slkpdh_pget_networktleargpoexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktleargpoexpsram
    :field slkpdh_pget_networktlemofldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlemofldsram
    :field slkpdh_pget_networktlemoexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlemoexpsram
    :field slkpdh_pget_networktlenofldsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlenofldsram
    :field slkpdh_pget_networktlenoexpsram: salsat_frame.user_data_pdh_tm_laynet_sram_tle.slkpdh_pget_networktlenoexpsram
    :field user_data_pdh_tm_laynet_eeprom_tle_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_systime
    :field user_data_pdh_tm_laynet_eeprom_tle_slkpdh_pget_networksatnum: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networksatnum
    :field slkpdh_pget_networktlesatnumeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlesatnumeeprom
    :field slkpdh_pget_networktleepochyreeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleepochyreeprom
    :field slkpdh_pget_networktleepochdaysfldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleepochdaysfldeeprom
    :field slkpdh_pget_networktleepochdaysexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleepochdaysexpeeprom
    :field slkpdh_pget_networktlendotfldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlendotfldeeprom
    :field slkpdh_pget_networktlendotexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlendotexpeeprom
    :field slkpdh_pget_networktlenddotfldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlenddotfldeeprom
    :field slkpdh_pget_networktlenddotexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlenddotexpeeprom
    :field slkpdh_pget_networktlebstarfldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlebstarfldeeprom
    :field slkpdh_pget_networktlebstarexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlebstarexpeeprom
    :field slkpdh_pget_networktleinclofldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleinclofldeeprom
    :field slkpdh_pget_networktleincloexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleincloexpeeprom
    :field slkpdh_pget_networktlenodeofldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlenodeofldeeprom
    :field slkpdh_pget_networktlenodeoexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlenodeoexpeeprom
    :field slkpdh_pget_networktleeccofldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleeccofldeeprom
    :field slkpdh_pget_networktleeccoexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleeccoexpeeprom
    :field slkpdh_pget_networktleargpofldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleargpofldeeprom
    :field slkpdh_pget_networktleargpoexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktleargpoexpeeprom
    :field slkpdh_pget_networktlemofldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlemofldeeprom
    :field slkpdh_pget_networktlemoexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlemoexpeeprom
    :field slkpdh_pget_networktlenofldeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlenofldeeprom
    :field slkpdh_pget_networktlenoexpeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_tle.slkpdh_pget_networktlenoexpeeprom
    :field user_data_pdh_tm_laynet_sram_par_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_sram_par.slkpdh_pget_systime
    :field user_data_pdh_tm_laynet_sram_par_slkpdh_pget_networksatnum: salsat_frame.user_data_pdh_tm_laynet_sram_par.slkpdh_pget_networksatnum
    :field slkpdh_pget_networksatsrcsram: salsat_frame.user_data_pdh_tm_laynet_sram_par.slkpdh_pget_networksatsrcsram
    :field slkpdh_pget_networksatdstsram: salsat_frame.user_data_pdh_tm_laynet_sram_par.slkpdh_pget_networksatdstsram
    :field slkpdh_pget_networksat2satsrcsram: salsat_frame.user_data_pdh_tm_laynet_sram_par.slkpdh_pget_networksat2satsrcsram
    :field slkpdh_pget_networksat2satdstsram: salsat_frame.user_data_pdh_tm_laynet_sram_par.slkpdh_pget_networksat2satdstsram
    :field slkpdh_pget_networkcostmaxsram: salsat_frame.user_data_pdh_tm_laynet_sram_par.slkpdh_pget_networkcostmaxsram
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_systime
    :field slkpdh_pget_netfsmstate: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netfsmstate
    :field slkpdh_pget_netbasetrmsgperr: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasetrmsgperr
    :field slkpdh_pget_netbasetrmdijkstraerr: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasetrmdijkstraerr
    :field slkpdh_pget_netbasetrmjdayconfig: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasetrmjdayconfig
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu5
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu6
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu7
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu8
    :field user_data_pdh_tm_laynet_std_slkpdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu9
    :field slkpdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu10
    :field slkpdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu11
    :field slkpdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu12
    :field slkpdh_pget_netbasetrmtxseqnum: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasetrmtxseqnum
    :field slkpdh_pget_netbasetrmrxseqnum: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasetrmrxseqnum
    :field slkpdh_pget_netbasetrmfsmstate: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasetrmfsmstate
    :field slkpdh_pget_netbasercvsgperr: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasercvsgperr
    :field slkpdh_pget_netbasercvdijkstraerr: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasercvdijkstraerr
    :field slkpdh_pget_netbasercvjdayconfig: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasercvjdayconfig
    :field slkpdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu13
    :field slkpdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu14
    :field slkpdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu15
    :field slkpdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu16
    :field slkpdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu17
    :field slkpdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu18
    :field slkpdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu19
    :field slkpdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu20
    :field slkpdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu21
    :field slkpdh_pget_boolrfu22: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu22
    :field slkpdh_pget_boolrfu23: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu23
    :field slkpdh_pget_boolrfu24: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu24
    :field slkpdh_pget_boolrfu25: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_boolrfu25
    :field slkpdh_pget_netbasercvtxseqnum: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasercvtxseqnum
    :field slkpdh_pget_netbasercvrxseqnum: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasercvrxseqnum
    :field slkpdh_pget_netbasercvfsmstate: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netbasercvfsmstate
    :field slkpdh_pget_netspectrmsrcscid: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspectrmsrcscid
    :field slkpdh_pget_netspectrmdstscid: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspectrmdstscid
    :field slkpdh_pget_netspectrmantmode: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspectrmantmode
    :field slkpdh_pget_netspectrmrfrange: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspectrmrfrange
    :field slkpdh_pget_netspectrmzerosystime: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspectrmzerosystime
    :field slkpdh_pget_netspectrmzerojdfld: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspectrmzerojdfld
    :field slkpdh_pget_netspectrmzerojdexp: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspectrmzerojdexp
    :field slkpdh_pget_netspecrcvsrcscid: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspecrcvsrcscid
    :field slkpdh_pget_netspecrcvdstscid: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspecrcvdstscid
    :field slkpdh_pget_netspecrcvantmode: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspecrcvantmode
    :field slkpdh_pget_netspecrcvrfrange: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspecrcvrfrange
    :field slkpdh_pget_netspecrcvzerosystime: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspecrcvzerosystime
    :field slkpdh_pget_netspecrcvzerojdfld: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspecrcvzerojdfld
    :field slkpdh_pget_netspecrcvzerojdexp: salsat_frame.user_data_pdh_tm_laynet_std.slkpdh_pget_netspecrcvzerojdexp
    :field user_data_pdh_tm_laynet_sgp_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_systime
    :field user_data_pdh_tm_laynet_sgp_slkpdh_pget_networksatnum: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_networksatnum
    :field slkpdh_pget_networksgprangex: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_networksgprangex
    :field slkpdh_pget_networksgprangey: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_networksgprangey
    :field slkpdh_pget_networksgprangez: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_networksgprangez
    :field slkpdh_pget_networksgpvelx: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_networksgpvelx
    :field slkpdh_pget_networksgpvely: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_networksgpvely
    :field slkpdh_pget_networksgpvelz: salsat_frame.user_data_pdh_tm_laynet_sgp.slkpdh_pget_networksgpvelz
    :field user_data_pdh_tm_laynet_cost_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_cost.slkpdh_pget_systime
    :field slkpdh_pget_networkdijkstracost: salsat_frame.user_data_pdh_tm_laynet_cost.slkpdh_pget_networkdijkstracost
    :field user_data_pdh_tm_laynet_routing_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_routing.slkpdh_pget_systime
    :field slkpdh_pget_networkdijkstraroutingfrom: salsat_frame.user_data_pdh_tm_laynet_routing.slkpdh_pget_networkdijkstraroutingfrom
    :field slkpdh_pget_networkdijkstraroutingdistance: salsat_frame.user_data_pdh_tm_laynet_routing.slkpdh_pget_networkdijkstraroutingdistance
    :field user_data_pdh_tm_laynet_eeprom_par_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_eeprom_par.slkpdh_pget_systime
    :field user_data_pdh_tm_laynet_eeprom_par_slkpdh_pget_networksatnum: salsat_frame.user_data_pdh_tm_laynet_eeprom_par.slkpdh_pget_networksatnum
    :field slkpdh_pget_networksatsrceeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_par.slkpdh_pget_networksatsrceeprom
    :field slkpdh_pget_networksatdsteeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_par.slkpdh_pget_networksatdsteeprom
    :field slkpdh_pget_networksat2satsrceeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_par.slkpdh_pget_networksat2satsrceeprom
    :field slkpdh_pget_networksat2satdsteeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_par.slkpdh_pget_networksat2satdsteeprom
    :field slkpdh_pget_networkcostmaxeeprom: salsat_frame.user_data_pdh_tm_laynet_eeprom_par.slkpdh_pget_networkcostmaxeeprom
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_systime
    :field slkpdh_pget_trafsmstate: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trafsmstate
    :field slkpdh_pget_trabasetrmtxfifofull: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmtxfifofull
    :field slkpdh_pget_trabasetrmrxfifofull: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmrxfifofull
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_trabasetrmnak: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmnak
    :field slkpdh_pget_trabasetrmactivetxfifo0: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmactivetxfifo0
    :field slkpdh_pget_trabasetrmactivetxfifo1: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmactivetxfifo1
    :field slkpdh_pget_trabasetrmactivetxfifo2: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmactivetxfifo2
    :field slkpdh_pget_trabasetrmactiverxfifo0: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmactiverxfifo0
    :field slkpdh_pget_trabasetrmactiverxfifo1: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmactiverxfifo1
    :field slkpdh_pget_trabasetrmactiverxfifo2: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmactiverxfifo2
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_trabasetrmcpt: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmcpt
    :field slkpdh_pget_trabasetrml2fifofullsvc: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrml2fifofullsvc
    :field slkpdh_pget_trabasetrml2fifofullsdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrml2fifofullsdu
    :field slkpdh_pget_trabasetrml2fifofullsduqos: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrml2fifofullsduqos
    :field slkpdh_pget_trabasetrml2fifofullspdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrml2fifofullspdu
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_boolrfu1
    :field slkpdh_pget_trabasetrmtxseqnum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmtxseqnum
    :field slkpdh_pget_trabasetrmrxseqnum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmrxseqnum
    :field slkpdh_pget_trabasetrmfsmstate: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasetrmfsmstate
    :field slkpdh_pget_trabasercvtxfifofull: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvtxfifofull
    :field slkpdh_pget_trabasercvrxfifofull: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvrxfifofull
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_trabasercvnak: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvnak
    :field slkpdh_pget_trabasercvactivetxfifo0: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvactivetxfifo0
    :field slkpdh_pget_trabasercvactivetxfifo1: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvactivetxfifo1
    :field slkpdh_pget_trabasercvactivetxfifo2: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvactivetxfifo2
    :field slkpdh_pget_trabasercvactiverxfifo0: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvactiverxfifo0
    :field slkpdh_pget_trabasercvactiverxfifo1: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvactiverxfifo1
    :field slkpdh_pget_trabasercvactiverxfifo2: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvactiverxfifo2
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_trabasercvcpt: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvcpt
    :field slkpdh_pget_trabasercvl2fifofullsvc: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvl2fifofullsvc
    :field slkpdh_pget_trabasercvl2fifofullsdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvl2fifofullsdu
    :field slkpdh_pget_trabasercvl2fifofullsduqos: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvl2fifofullsduqos
    :field slkpdh_pget_trabasercvl2fifofullspdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvl2fifofullspdu
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_laytra_std_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_boolrfu3
    :field slkpdh_pget_trabasercvtxseqnum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvtxseqnum
    :field slkpdh_pget_trabasercvrxseqnum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvrxseqnum
    :field slkpdh_pget_trabasercvfsmstate: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_trabasercvfsmstate
    :field slkpdh_pget_traspectrmfifonum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspectrmfifonum
    :field slkpdh_pget_traspectrmtxacknum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspectrmtxacknum
    :field slkpdh_pget_traspectrmrxacknum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspectrmrxacknum
    :field slkpdh_pget_traspectrml2packetcountsdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspectrml2packetcountsdu
    :field slkpdh_pget_traspectrml2packetcountsduqos: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspectrml2packetcountsduqos
    :field slkpdh_pget_traspectrml2packetcountspdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspectrml2packetcountspdu
    :field slkpdh_pget_traspectrml2packetcountsvc: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspectrml2packetcountsvc
    :field slkpdh_pget_traspecrcvfifonum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspecrcvfifonum
    :field slkpdh_pget_traspecrcvtxacknum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspecrcvtxacknum
    :field slkpdh_pget_traspecrcvrxacknum: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspecrcvrxacknum
    :field slkpdh_pget_traspecrcvl2packetcountsdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspecrcvl2packetcountsdu
    :field slkpdh_pget_traspecrcvl2packetcountsduqos: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspecrcvl2packetcountsduqos
    :field slkpdh_pget_traspecrcvl2packetcountspdu: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspecrcvl2packetcountspdu
    :field slkpdh_pget_traspecrcvl2packetcountsvc: salsat_frame.user_data_pdh_tm_laytra_std.slkpdh_pget_traspecrcvl2packetcountsvc
    :field user_data_pdh_tm_layses_std_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_systime
    :field slkpdh_pget_sesfsmstate: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesfsmstate
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasetrmsesest: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmsesest
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasetrmseslost: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmseslost
    :field slkpdh_pget_sesbasetrmseschngsttmoutact: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmseschngsttmoutact
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasetrmwaitforaiandtrmt: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmwaitforaiandtrmt
    :field slkpdh_pget_sesbasetrmberrunning: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmberrunning
    :field slkpdh_pget_sesbasetrmsetrxchannel: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmsetrxchannel
    :field slkpdh_pget_sesbasetrmsettxchannel: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmsettxchannel
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasetrmcaller: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmcaller
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasetrmcallersendbcst: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmcallersendbcst
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasetrmresponder: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmresponder
    :field slkpdh_pget_sesbasetrmpayloaddir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmpayloaddir
    :field slkpdh_pget_sesbasetrmsettxgain: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmsettxgain
    :field slkpdh_pget_sesbasetrmfddon: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmfddon
    :field user_data_pdh_tm_layses_std_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_layses_std_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_layses_std_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_boolrfu2
    :field slkpdh_pget_sesbasetrmtxseqnum: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmtxseqnum
    :field slkpdh_pget_sesbasetrmrxseqnum: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmrxseqnum
    :field slkpdh_pget_sesbasetrmfsmstate: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasetrmfsmstate
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasercvsesest: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvsesest
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasercvseslost: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvseslost
    :field slkpdh_pget_sesbasercvseschngsttmoutact: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvseschngsttmoutact
    :field user_data_pdh_tm_layses_std_slkpdh_pget_sesbasercvwaitforaiandtrmt: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvwaitforaiandtrmt
    :field slkpdh_pget_sesbasercvberrunning: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvberrunning
    :field slkpdh_pget_sesbasercvsetrxchannel: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvsetrxchannel
    :field slkpdh_pget_sesbasercvsettxchannel: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvsettxchannel
    :field slkpdh_pget_sesbasercvcaller: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvcaller
    :field slkpdh_pget_sesbasercvcallersendbcst: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvcallersendbcst
    :field slkpdh_pget_sesbasercvresponder: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvresponder
    :field slkpdh_pget_sesbasercvpayloaddir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvpayloaddir
    :field slkpdh_pget_sesbasercvsettxgain: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvsettxgain
    :field slkpdh_pget_sesbasercvfddon: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvfddon
    :field user_data_pdh_tm_layses_std_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_layses_std_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_layses_std_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_boolrfu5
    :field slkpdh_pget_sesbasercvtxseqnum: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvtxseqnum
    :field slkpdh_pget_sesbasercvrxseqnum: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvrxseqnum
    :field slkpdh_pget_sesbasercvfsmstate: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesbasercvfsmstate
    :field slkpdh_pget_sesspectrmmactypemain: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmmactypemain
    :field slkpdh_pget_sesspectrmmactypesub: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmmactypesub
    :field slkpdh_pget_sesspectrmpara0: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmpara0
    :field slkpdh_pget_sesspectrmpara1: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmpara1
    :field slkpdh_pget_sesspectrmrestartattempts: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmrestartattempts
    :field slkpdh_pget_sesspectrmtxchangestatefrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmtxchangestatefrc
    :field slkpdh_pget_sesspectrmrxchangestatefrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmrxchangestatefrc
    :field slkpdh_pget_sesspectrmrcvdsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmrcvdsir
    :field slkpdh_pget_sesspectrmrxsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmrxsir
    :field slkpdh_pget_sesspectrmmaxsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmmaxsir
    :field slkpdh_pget_sesspectrmminsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmminsir
    :field slkpdh_pget_sesspectrmaistate: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmaistate
    :field slkpdh_pget_sesspectrml2state: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrml2state
    :field slkpdh_pget_sesspectrmaitype: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmaitype
    :field slkpdh_pget_sesspectrmaierr: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmaierr
    :field slkpdh_pget_sesspectrmfrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmfrc
    :field slkpdh_pget_sesspectrmchangechannelfrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspectrmchangechannelfrc
    :field slkpdh_pget_sesspecrcvmactypemain: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvmactypemain
    :field slkpdh_pget_sesspecrcvmactypesub: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvmactypesub
    :field slkpdh_pget_sesspecrcvpara0: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvpara0
    :field slkpdh_pget_sesspecrcvpara1: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvpara1
    :field slkpdh_pget_sesspecrcvrestartattempts: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvrestartattempts
    :field slkpdh_pget_sesspecrcvtxchangestatefrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvtxchangestatefrc
    :field slkpdh_pget_sesspecrcvrxchangestatefrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvrxchangestatefrc
    :field slkpdh_pget_sesspecrcvrcvdsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvrcvdsir
    :field slkpdh_pget_sesspecrcvrxsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvrxsir
    :field slkpdh_pget_sesspecrcvmaxsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvmaxsir
    :field slkpdh_pget_sesspecrcvminsir: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvminsir
    :field slkpdh_pget_sesspecrcvaistate: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvaistate
    :field slkpdh_pget_sesspecrcvl2state: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvl2state
    :field slkpdh_pget_sesspecrcvaitype: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvaitype
    :field slkpdh_pget_sesspecrcvaierr: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvaierr
    :field slkpdh_pget_sesspecrcvfrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvfrc
    :field slkpdh_pget_sesspecrcvchangechannelfrc: salsat_frame.user_data_pdh_tm_layses_std.slkpdh_pget_sesspecrcvchangechannelfrc
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_systime
    :field slkpdh_pget_prefsmstate: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prefsmstate
    :field slkpdh_pget_prebasetrmformatchangerqst: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmformatchangerqst
    :field slkpdh_pget_prebasetrmerrformatchange0: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange0
    :field slkpdh_pget_prebasetrmerrformatchange1: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange1
    :field slkpdh_pget_prebasetrmerrformatchange2: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange2
    :field slkpdh_pget_prebasetrmerrformatchange3: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange3
    :field slkpdh_pget_prebasetrmerrformatchange4: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange4
    :field slkpdh_pget_prebasetrmerrformatchange5: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange5
    :field slkpdh_pget_prebasetrmerrformatchange6: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange6
    :field slkpdh_pget_prebasetrmerrformatchange7: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange7
    :field slkpdh_pget_prebasetrmerrformatchange8: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange8
    :field slkpdh_pget_prebasetrmerrformatchange9: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmerrformatchange9
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu4
    :field slkpdh_pget_prebasetrmtxseqnum: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmtxseqnum
    :field slkpdh_pget_prebasetrmrxseqnum: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmrxseqnum
    :field slkpdh_pget_prebasetrmfsmstate: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasetrmfsmstate
    :field slkpdh_pget_prebasercvformatchangerqst: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercvformatchangerqst
    :field slkpdh_pget_prebasercverrformatchange0: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange0
    :field slkpdh_pget_prebasercverrformatchange1: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange1
    :field slkpdh_pget_prebasercverrformatchange2: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange2
    :field slkpdh_pget_prebasercverrformatchange3: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange3
    :field slkpdh_pget_prebasercverrformatchange4: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange4
    :field slkpdh_pget_prebasercverrformatchange5: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange5
    :field slkpdh_pget_prebasercverrformatchange6: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange6
    :field slkpdh_pget_prebasercverrformatchange7: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange7
    :field slkpdh_pget_prebasercverrformatchange8: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange8
    :field slkpdh_pget_prebasercverrformatchange9: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercverrformatchange9
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu5
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu6
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu7
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu8
    :field user_data_pdh_tm_laypre_std_slkpdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_boolrfu9
    :field slkpdh_pget_prebasercvtxseqnum: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercvtxseqnum
    :field slkpdh_pget_prebasercvrxseqnum: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercvrxseqnum
    :field slkpdh_pget_prebasercvfsmstate: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prebasercvfsmstate
    :field slkpdh_pget_prespectrmpkttypemain: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prespectrmpkttypemain
    :field slkpdh_pget_prespectrmpkttypesub: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prespectrmpkttypesub
    :field slkpdh_pget_prespecrcvpkttypemain: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prespecrcvpkttypemain
    :field slkpdh_pget_prespecrcvpkttypesub: salsat_frame.user_data_pdh_tm_laypre_std.slkpdh_pget_prespecrcvpkttypesub
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_systime
    :field slkpdh_pget_appfsmstate: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appfsmstate
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_appbasetrmpktloss: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasetrmpktloss
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_appbasetrmcrcerr: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasetrmcrcerr
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_appbasetrmpkthdrerr: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasetrmpkthdrerr
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu5
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu6
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu7
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu8
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu9
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu10
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu11
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu12
    :field slkpdh_pget_appbasetrmtxseqnum: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasetrmtxseqnum
    :field slkpdh_pget_appbasetrmrxseqnum: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasetrmrxseqnum
    :field slkpdh_pget_appbasetrmfsmstate: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasetrmfsmstate
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_appbasercvpktloss: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasercvpktloss
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_appbasercvcrcerr: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasercvcrcerr
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_appbasercvpkthdrerr: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasercvpkthdrerr
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu13
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu14
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu15
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu16
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu17
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu18
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu19
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu20
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu21
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu22: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu22
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu23: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu23
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu24: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu24
    :field user_data_pdh_tm_layapp_std_slkpdh_pget_boolrfu25: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_boolrfu25
    :field slkpdh_pget_appbasercvtxseqnum: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasercvtxseqnum
    :field slkpdh_pget_appbasercvrxseqnum: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasercvrxseqnum
    :field slkpdh_pget_appbasercvfsmstate: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appbasercvfsmstate
    :field slkpdh_pget_appspectrmpkttypemain: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspectrmpkttypemain
    :field slkpdh_pget_appspectrmpkttypesub: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspectrmpkttypesub
    :field slkpdh_pget_appspectrmpktlength: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspectrmpktlength
    :field slkpdh_pget_appspectrmpktnum: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspectrmpktnum
    :field slkpdh_pget_appspecrcvpkttypemain: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspecrcvpkttypemain
    :field slkpdh_pget_appspecrcvpkttypesub: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspecrcvpkttypesub
    :field slkpdh_pget_appspecrcvpktlength: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspecrcvpktlength
    :field slkpdh_pget_appspecrcvpktnum: salsat_frame.user_data_pdh_tm_layapp_std.slkpdh_pget_appspecrcvpktnum
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_systime
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netfsmstate: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netfsmstate
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasetrmsgperr: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasetrmsgperr
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasetrmdijkstraerr: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasetrmdijkstraerr
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasetrmjdayconfig: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasetrmjdayconfig
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu5
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu6
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu7
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu8
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu9
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu10
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu11
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu12
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasetrmfsmstate: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasetrmfsmstate
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasercvsgperr: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasercvsgperr
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasercvdijkstraerr: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasercvdijkstraerr
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasercvjdayconfig: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasercvjdayconfig
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu13
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu14
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu15
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu16
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu17
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu18
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu19
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu20
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu21
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu22: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu22
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu23: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu23
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu24: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu24
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_boolrfu25: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_boolrfu25
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netbasercvfsmstate: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netbasercvfsmstate
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netspectrmsrcscid: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netspectrmsrcscid
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netspectrmdstscid: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netspectrmdstscid
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netspecrcvsrcscid: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netspecrcvsrcscid
    :field user_data_pdh_tm_laynet_std_0_slkpdh_pget_netspecrcvdstscid: salsat_frame.user_data_pdh_tm_laynet_std_0.slkpdh_pget_netspecrcvdstscid
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_systime
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appfsmstate: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appfsmstate
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasetrmpktloss: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasetrmpktloss
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasetrmcrcerr: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasetrmcrcerr
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasetrmpkthdrerr: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasetrmpkthdrerr
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu5
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu6
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu7
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu8
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu9
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu10: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu10
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu11: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu11
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu12: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu12
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasetrmfsmstate: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasetrmfsmstate
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasercvpktloss: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasercvpktloss
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasercvcrcerr: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasercvcrcerr
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasercvpkthdrerr: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasercvpkthdrerr
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu13: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu13
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu14: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu14
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu15: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu15
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu16: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu16
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu17: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu17
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu18: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu18
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu19: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu19
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu20: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu20
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu21: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu21
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu22: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu22
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu23: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu23
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu24: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu24
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_boolrfu25: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_boolrfu25
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appbasercvfsmstate: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appbasercvfsmstate
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appspectrmpkttypemain: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspectrmpkttypemain
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appspectrmpkttypesub: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspectrmpkttypesub
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appspectrmpktnum: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspectrmpktnum
    :field slkpdh_pget_appspectrmtxseqnum: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspectrmtxseqnum
    :field slkpdh_pget_appspectrmrxseqnum: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspectrmrxseqnum
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appspecrcvpkttypemain: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspecrcvpkttypemain
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appspecrcvpkttypesub: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspecrcvpkttypesub
    :field user_data_pdh_tm_layapp_std_0_slkpdh_pget_appspecrcvpktnum: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspecrcvpktnum
    :field slkpdh_pget_appspecrcvtxseqnum: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspecrcvtxseqnum
    :field slkpdh_pget_appspecrcvrxseqnum: salsat_frame.user_data_pdh_tm_layapp_std_0.slkpdh_pget_appspecrcvrxseqnum
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_systime
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trafsmstate: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trafsmstate
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmtxfifofull: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmtxfifofull
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmrxfifofull: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmrxfifofull
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmnak: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmnak
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmactivetxfifo0: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmactivetxfifo0
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmactivetxfifo1: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmactivetxfifo1
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmactivetxfifo2: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmactivetxfifo2
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmactiverxfifo0: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmactiverxfifo0
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmactiverxfifo1: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmactiverxfifo1
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmactiverxfifo2: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmactiverxfifo2
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmcpt: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmcpt
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrml2fifofullsvc: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrml2fifofullsvc
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrml2fifofullsdu: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrml2fifofullsdu
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrml2fifofullsduqos: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrml2fifofullsduqos
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrml2fifofullspdu: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrml2fifofullspdu
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasetrmfsmstate: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasetrmfsmstate
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvtxfifofull: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvtxfifofull
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvrxfifofull: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvrxfifofull
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvnak: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvnak
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvactivetxfifo0: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvactivetxfifo0
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvactivetxfifo1: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvactivetxfifo1
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvactivetxfifo2: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvactivetxfifo2
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvactiverxfifo0: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvactiverxfifo0
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvactiverxfifo1: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvactiverxfifo1
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvactiverxfifo2: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvactiverxfifo2
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvcpt: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvcpt
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvl2fifofullsvc: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvl2fifofullsvc
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvl2fifofullsdu: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvl2fifofullsdu
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvl2fifofullsduqos: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvl2fifofullsduqos
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvl2fifofullspdu: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvl2fifofullspdu
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_trabasercvfsmstate: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_trabasercvfsmstate
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_traspectrmfifonum: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_traspectrmfifonum
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_traspectrmtxacknum: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_traspectrmtxacknum
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_traspectrmrxacknum: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_traspectrmrxacknum
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_traspecrcvfifonum: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_traspecrcvfifonum
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_traspecrcvtxacknum: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_traspecrcvtxacknum
    :field user_data_pdh_tm_laytra_std_0_slkpdh_pget_traspecrcvrxacknum: salsat_frame.user_data_pdh_tm_laytra_std_0.slkpdh_pget_traspecrcvrxacknum
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_systime
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prefsmstate: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prefsmstate
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmformatchangerqst: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmformatchangerqst
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange0: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange0
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange1: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange1
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange2: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange2
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange3: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange3
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange4: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange4
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange5: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange5
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange6: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange6
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange7: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange7
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange8: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange8
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmerrformatchange9: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmerrformatchange9
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasetrmfsmstate: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasetrmfsmstate
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercvformatchangerqst: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercvformatchangerqst
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange0: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange0
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange1: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange1
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange2: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange2
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange3: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange3
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange4: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange4
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange5: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange5
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange6: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange6
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange7: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange7
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange8: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange8
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercverrformatchange9: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercverrformatchange9
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu5
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu6: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu6
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu7: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu7
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu8: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu8
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_boolrfu9: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_boolrfu9
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prebasercvfsmstate: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prebasercvfsmstate
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prespectrmpkttypemain: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prespectrmpkttypemain
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prespectrmpkttypesub: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prespectrmpkttypesub
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prespecrcvpkttypemain: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prespecrcvpkttypemain
    :field user_data_pdh_tm_laypre_std_0_slkpdh_pget_prespecrcvpkttypesub: salsat_frame.user_data_pdh_tm_laypre_std_0.slkpdh_pget_prespecrcvpkttypesub
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_systime: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_systime
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesfsmstate: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesfsmstate
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmsesest: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmsesest
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmseslost: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmseslost
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmseschngsttmoutact: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmseschngsttmoutact
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmwaitforaiandtrmt: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmwaitforaiandtrmt
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmberrunning: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmberrunning
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmsetrxchannel: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmsetrxchannel
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmsettxchannel: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmsettxchannel
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmcaller: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmcaller
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmcallersendbcst: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmcallersendbcst
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmresponder: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmresponder
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmpayloaddir: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmpayloaddir
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmsettxgain: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmsettxgain
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmfddon: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmfddon
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasetrmfsmstate: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasetrmfsmstate
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvsesest: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvsesest
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvseslost: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvseslost
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvseschngsttmoutact: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvseschngsttmoutact
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvwaitforaiandtrmt: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvwaitforaiandtrmt
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvberrunning: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvberrunning
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvsetrxchannel: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvsetrxchannel
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvsettxchannel: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvsettxchannel
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvcaller: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvcaller
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvcallersendbcst: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvcallersendbcst
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvresponder: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvresponder
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvpayloaddir: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvpayloaddir
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvsettxgain: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvsettxgain
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvfddon: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvfddon
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_boolrfu5: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_boolrfu5
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesbasercvfsmstate: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesbasercvfsmstate
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspectrmmactypemain: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspectrmmactypemain
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspectrmmactypesub: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspectrmmactypesub
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspectrmpara0: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspectrmpara0
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspectrmpara1: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspectrmpara1
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspecrcvmactypemain: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspecrcvmactypemain
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspecrcvmactypesub: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspecrcvmactypesub
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspecrcvpara0: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspecrcvpara0
    :field user_data_pdh_tm_layses_std_0_slkpdh_pget_sesspecrcvpara1: salsat_frame.user_data_pdh_tm_layses_std_0.slkpdh_pget_sesspecrcvpara1
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_satctrfrequencytxsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrfrequencytxsram
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_satctrfrequencyrxsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrfrequencyrxsram
    :field slkpdh_pget_satctrpwrampoffsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrpwrampoffsram
    :field slkpdh_pget_satctrrxoffvalsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrrxoffvalsram
    :field slkpdh_pget_satctrtestmodevalsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrtestmodevalsram
    :field slkpdh_pget_satctrxmtmodesram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrxmtmodesram
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_satctratttxgainsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctratttxgainsram
    :field slkpdh_pget_satctrmaxaitypesrama: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrmaxaitypesrama
    :field slkpdh_pget_satctrtestmodesram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrtestmodesram
    :field slkpdh_pget_satctri2creadtemppowsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctri2creadtemppowsram
    :field slkpdh_pget_satctrtxonsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrtxonsram
    :field slkpdh_pget_satctrrxonsram: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_satctrrxonsram
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_sap_sram_sat_a_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_sap_sram_sat_a.slkpdh_pget_boolrfu4
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_satctrfrequencytxeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrfrequencytxeeprom
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_satctrfrequencyrxeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrfrequencyrxeeprom
    :field slkpdh_pget_satctrpwrampoffeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrpwrampoffeeprom
    :field slkpdh_pget_satctrrxoffvaleeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrrxoffvaleeprom
    :field slkpdh_pget_satctrtestmodevaleeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrtestmodevaleeprom
    :field slkpdh_pget_satctrxmtmodeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrxmtmodeeeprom
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_satctratttxgaineeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctratttxgaineeprom
    :field slkpdh_pget_satctrmaxaitypeeeproma: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrmaxaitypeeeproma
    :field slkpdh_pget_satctrtestmodeeeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrtestmodeeeprom
    :field slkpdh_pget_satctri2creadtemppoweeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctri2creadtemppoweeprom
    :field slkpdh_pget_satctrtxoneeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrtxoneeprom
    :field slkpdh_pget_satctrrxoneeprom: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_satctrrxoneeprom
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_boolrfu0: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_boolrfu0
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_boolrfu1: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_boolrfu1
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_boolrfu2: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_boolrfu2
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_boolrfu3: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_boolrfu3
    :field user_data_pdh_tm_sap_eeprom_sat_a_slkpdh_pget_boolrfu4: salsat_frame.user_data_pdh_tm_sap_eeprom_sat_a.slkpdh_pget_boolrfu4
    :field com0_pget_systime: salsat_frame.user_data_com0_tm_eeprom.com0_pget_systime
    :field com0_pget_frsynceeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_frsynceeprom
    :field com0_pget_frsynchameeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_frsynchameeprom
    :field com0_pget_bitsyncnumeeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_bitsyncnumeeprom
    :field com0_pget_srcideeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_srcideeprom
    :field com0_pget_bcstideeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_bcstideeprom
    :field com0_pget_syncbiterrnumeeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_syncbiterrnumeeprom
    :field com0_pget_syncburstnumeeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_syncburstnumeeprom
    :field com0_pget_syncchainnumeeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_syncchainnumeeprom
    :field com0_pget_hamcallsigneeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_hamcallsigneeprom
    :field com0_pget_resetcnt: salsat_frame.user_data_com0_tm_eeprom.com0_pget_resetcnt
    :field com0_pget_periodrdtrxtmeeprom: salsat_frame.user_data_com0_tm_eeprom.com0_pget_periodrdtrxtmeeprom
    :field com0_pget_rxsducnt: salsat_frame.user_data_com0_tm_eeprom.com0_pget_rxsducnt
    :field com0_pget_rxspducnt: salsat_frame.user_data_com0_tm_eeprom.com0_pget_rxspducnt
    :field com0_pget_periodautorecoveryreset: salsat_frame.user_data_com0_tm_eeprom.com0_pget_periodautorecoveryreset
    :field user_data_com0_tm_sram_com0_pget_systime: salsat_frame.user_data_com0_tm_sram.com0_pget_systime
    :field com0_pget_frsyncsram: salsat_frame.user_data_com0_tm_sram.com0_pget_frsyncsram
    :field com0_pget_frsynchamsram: salsat_frame.user_data_com0_tm_sram.com0_pget_frsynchamsram
    :field com0_pget_bitsyncnumsram: salsat_frame.user_data_com0_tm_sram.com0_pget_bitsyncnumsram
    :field com0_pget_srcidsram: salsat_frame.user_data_com0_tm_sram.com0_pget_srcidsram
    :field com0_pget_bcstidsram: salsat_frame.user_data_com0_tm_sram.com0_pget_bcstidsram
    :field com0_pget_syncbiterrnumsram: salsat_frame.user_data_com0_tm_sram.com0_pget_syncbiterrnumsram
    :field com0_pget_syncburstnumsram: salsat_frame.user_data_com0_tm_sram.com0_pget_syncburstnumsram
    :field com0_pget_syncchainnumsram: salsat_frame.user_data_com0_tm_sram.com0_pget_syncchainnumsram
    :field com0_pget_hamcallsignsram: salsat_frame.user_data_com0_tm_sram.com0_pget_hamcallsignsram
    :field com1_pget_systime: salsat_frame.user_data_com1_tm_std.com1_pget_systime
    :field com1_pget_resetcnt: salsat_frame.user_data_com1_tm_std.com1_pget_resetcnt
    :field com1_pget_rxsducnt: salsat_frame.user_data_com1_tm_std.com1_pget_rxsducnt
    :field com1_pget_rxspducnt: salsat_frame.user_data_com1_tm_std.com1_pget_rxspducnt
    :field com1_pget_fsmmainstate: salsat_frame.user_data_com1_tm_std.com1_pget_fsmmainstate
    :field com1_pget_invrxframe: salsat_frame.user_data_com1_tm_std.com1_pget_invrxframe
    :field com1_pget_comtimeout: salsat_frame.user_data_com1_tm_std.com1_pget_comtimeout
    :field com1_pget_anomalyenvir: salsat_frame.user_data_com1_tm_std.com1_pget_anomalyenvir
    :field com1_pget_anomalypwr: salsat_frame.user_data_com1_tm_std.com1_pget_anomalypwr
    :field com1_pget_pdurxfifofull: salsat_frame.user_data_com1_tm_std.com1_pget_pdurxfifofull
    :field com1_pget_rxmode: salsat_frame.user_data_com1_tm_std.com1_pget_rxmode
    :field com1_pget_trxrxovercur: salsat_frame.user_data_com1_tm_std.com1_pget_trxrxovercur
    :field com1_pget_trxtxovercur: salsat_frame.user_data_com1_tm_std.com1_pget_trxtxovercur
    :field com1_pget_boolrfu0: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu0
    :field com1_pget_boolrfu1: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu1
    :field com1_pget_boolrfu2: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu2
    :field com1_pget_boolrfu3: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu3
    :field com1_pget_boolrfu4: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu4
    :field com1_pget_boolrfu5: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu5
    :field com1_pget_boolrfu6: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu6
    :field com1_pget_boolrfu7: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu7
    :field com1_pget_anomalyrssi: salsat_frame.user_data_com1_tm_std.com1_pget_anomalyrssi
    :field com1_pget_anomalyrssirx: salsat_frame.user_data_com1_tm_std.com1_pget_anomalyrssirx
    :field com1_pget_anomalycd: salsat_frame.user_data_com1_tm_std.com1_pget_anomalycd
    :field com1_pget_anomalycurtrxrx: salsat_frame.user_data_com1_tm_std.com1_pget_anomalycurtrxrx
    :field com1_pget_anomalycurtrxtx: salsat_frame.user_data_com1_tm_std.com1_pget_anomalycurtrxtx
    :field com1_pget_anomalycur3v3: salsat_frame.user_data_com1_tm_std.com1_pget_anomalycur3v3
    :field com1_pget_anomalyvlttrxrx: salsat_frame.user_data_com1_tm_std.com1_pget_anomalyvlttrxrx
    :field com1_pget_anomalyvlttrxtx: salsat_frame.user_data_com1_tm_std.com1_pget_anomalyvlttrxtx
    :field com1_pget_anomalyvlt3v3: salsat_frame.user_data_com1_tm_std.com1_pget_anomalyvlt3v3
    :field com1_pget_anomalytmptnc: salsat_frame.user_data_com1_tm_std.com1_pget_anomalytmptnc
    :field com1_pget_boolrfu8: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu8
    :field com1_pget_boolrfu9: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu9
    :field com1_pget_boolrfu10: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu10
    :field com1_pget_boolrfu11: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu11
    :field com1_pget_boolrfu12: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu12
    :field com1_pget_boolrfu13: salsat_frame.user_data_com1_tm_std.com1_pget_boolrfu13
    :field com1_pget_rssi: salsat_frame.user_data_com1_tm_std.com1_pget_rssi
    :field com1_pget_rssirx: salsat_frame.user_data_com1_tm_std.com1_pget_rssirx
    :field com1_pget_cd: salsat_frame.user_data_com1_tm_std.com1_pget_cd
    :field com1_pget_curtrx: salsat_frame.user_data_com1_tm_std.com1_pget_curtrx
    :field com1_pget_curtrxtx: salsat_frame.user_data_com1_tm_std.com1_pget_curtrxtx
    :field com1_pget_cur3v3: salsat_frame.user_data_com1_tm_std.com1_pget_cur3v3
    :field com1_pget_vlttrx: salsat_frame.user_data_com1_tm_std.com1_pget_vlttrx
    :field com1_pget_vlttrxtx: salsat_frame.user_data_com1_tm_std.com1_pget_vlttrxtx
    :field com1_pget_vlt3v3: salsat_frame.user_data_com1_tm_std.com1_pget_vlt3v3
    :field thm_com1_pget_tmptnc: salsat_frame.user_data_com1_tm_std.thm_com1_pget_tmptnc
    :field com1_pget_timetoautorecoveryreset: salsat_frame.user_data_com1_tm_std.com1_pget_timetoautorecoveryreset
    :field com4_pget_systime: salsat_frame.user_data_com4_tm_fec.com4_pget_systime
    :field com4_pget_ltudecerrnum: salsat_frame.user_data_com4_tm_fec.com4_pget_ltudecerrnum
    :field com4_pget_ltuhdrbchrootcw13: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw13
    :field com4_pget_ltuhdrbchrootcw12: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw12
    :field com4_pget_ltuhdrbchrootcw11: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw11
    :field com4_pget_ltuhdrbchrootcw10: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw10
    :field com4_pget_ltuhdrbchrootcw9: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw9
    :field com4_pget_ltuhdrbchrootcw8: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw8
    :field com4_pget_ltuhdrbchrootcw7: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw7
    :field com4_pget_ltuhdrbchrootcw6: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw6
    :field com4_pget_ltuhdrbchrootcw5: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw5
    :field com4_pget_ltuhdrbchrootcw4: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw4
    :field com4_pget_ltuhdrbchrootcw3: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw3
    :field com4_pget_ltuhdrbchrootcw2: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw2
    :field com4_pget_ltuhdrbchrootcw1: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw1
    :field com4_pget_ltuhdrbchrootcw0: salsat_frame.user_data_com4_tm_fec.com4_pget_ltuhdrbchrootcw0
    :field com4_pget_rssirx: salsat_frame.user_data_com4_tm_fec.com4_pget_rssirx
    :field user_data_com1_tm_com_com1_pget_systime: salsat_frame.user_data_com1_tm_com.com1_pget_systime
    :field com1_pget_txltuhdrdstid: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrdstid
    :field com1_pget_txltuhdrsrcid: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrsrcid
    :field com1_pget_txltuhdrfrcnttx: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrfrcnttx
    :field com1_pget_txltuhdrfrcntrx: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrfrcntrx
    :field com1_pget_txltuhdrsnr: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrsnr
    :field com1_pget_txltuhdraitypesrc: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdraitypesrc
    :field com1_pget_txltuhdraitypedst: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdraitypedst
    :field com1_pget_txltuhdrdfcid: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrdfcid
    :field com1_pget_txltuhdrfrlength: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrfrlength
    :field com1_pget_txltuhdrcrc13: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrcrc13
    :field com1_pget_txltuhdrcrc5: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrcrc5
    :field com1_pget_txltuhdrudfl1: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrudfl1
    :field com1_pget_txltuhdrhailing: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrhailing
    :field com1_pget_txltuhdrrqbch: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrrqbch
    :field com1_pget_txltuhdrpdutypeid: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrpdutypeid
    :field com1_pget_txltuhdrarq: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrarq
    :field com1_pget_txltuhdrcaller: salsat_frame.user_data_com1_tm_com.com1_pget_txltuhdrcaller
    :field user_data_com1_tm_com_com1_pget_boolrfu0: salsat_frame.user_data_com1_tm_com.com1_pget_boolrfu0
    :field user_data_com1_tm_com_com1_pget_boolrfu1: salsat_frame.user_data_com1_tm_com.com1_pget_boolrfu1
    :field com1_pget_rxltuhdrdstid: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrdstid
    :field com1_pget_rxltuhdrsrcid: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrsrcid
    :field com1_pget_rxltuhdrfrcnttx: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrfrcnttx
    :field com1_pget_rxltuhdrfrcntrx: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrfrcntrx
    :field com1_pget_rxltuhdrsnr: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrsnr
    :field com1_pget_rxltuhdraitypesrc: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdraitypesrc
    :field com1_pget_rxltuhdraitypedst: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdraitypedst
    :field com1_pget_rxltuhdrdfcid: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrdfcid
    :field com1_pget_rxltuhdrfrlength: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrfrlength
    :field com1_pget_rxltuhdrcrc13: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrcrc13
    :field com1_pget_rxltuhdrcrc5: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrcrc5
    :field com1_pget_rxltuhdrudfl1: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrudfl1
    :field com1_pget_rxltuhdrhailing: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrhailing
    :field com1_pget_rxltuhdrrqbch: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrrqbch
    :field com1_pget_rxltuhdrpdutypeid: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrpdutypeid
    :field com1_pget_rxltuhdrarq: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrarq
    :field com1_pget_rxltuhdrcaller: salsat_frame.user_data_com1_tm_com.com1_pget_rxltuhdrcaller
    :field user_data_com1_tm_com_com1_pget_boolrfu2: salsat_frame.user_data_com1_tm_com.com1_pget_boolrfu2
    :field user_data_com1_tm_com_com1_pget_boolrfu3: salsat_frame.user_data_com1_tm_com.com1_pget_boolrfu3
    :field com1_pget_ltudecerrnum: salsat_frame.user_data_com1_tm_com.com1_pget_ltudecerrnum
    :field com1_pget_sdutxfifonum: salsat_frame.user_data_com1_tm_com.com1_pget_sdutxfifonum
    :field com1_pget_sessiontime: salsat_frame.user_data_com1_tm_com.com1_pget_sessiontime
    :field com1_pget_fsmcomstate: salsat_frame.user_data_com1_tm_com.com1_pget_fsmcomstate
    :field com1_pget_ltuhdrdec: salsat_frame.user_data_com1_tm_com.com1_pget_ltuhdrdec
    :field com1_pget_pdufirstblockdec: salsat_frame.user_data_com1_tm_com.com1_pget_pdufirstblockdec
    :field com1_pget_sduhdrdec: salsat_frame.user_data_com1_tm_com.com1_pget_sduhdrdec
    :field com1_pget_lturxcomplete: salsat_frame.user_data_com1_tm_com.com1_pget_lturxcomplete
    :field com1_pget_ltuhdrdecerr: salsat_frame.user_data_com1_tm_com.com1_pget_ltuhdrdecerr
    :field com1_pget_ltuhdrrxerr: salsat_frame.user_data_com1_tm_com.com1_pget_ltuhdrrxerr
    :field com1_pget_ltuhdrdeclock: salsat_frame.user_data_com1_tm_com.com1_pget_ltuhdrdeclock
    :field com1_pget_pdudecerr: salsat_frame.user_data_com1_tm_com.com1_pget_pdudecerr
    :field com1_pget_burst: salsat_frame.user_data_com1_tm_com.com1_pget_burst
    :field com1_pget_rangevalid: salsat_frame.user_data_com1_tm_com.com1_pget_rangevalid
    :field com1_pget_sdutxfifooverrun: salsat_frame.user_data_com1_tm_com.com1_pget_sdutxfifooverrun
    :field com1_pget_rxpducrcerr: salsat_frame.user_data_com1_tm_com.com1_pget_rxpducrcerr
    :field com1_pget_rxsducrcerr: salsat_frame.user_data_com1_tm_com.com1_pget_rxsducrcerr
    :field com1_pget_collectbcherr: salsat_frame.user_data_com1_tm_com.com1_pget_collectbcherr
    :field com1_pget_chmon: salsat_frame.user_data_com1_tm_com.com1_pget_chmon
    :field com1_pget_ltuerr: salsat_frame.user_data_com1_tm_com.com1_pget_ltuerr
    :field com1_pget_tddmode: salsat_frame.user_data_com1_tm_com.com1_pget_tddmode
    :field com1_pget_generaltxlock: salsat_frame.user_data_com1_tm_com.com1_pget_generaltxlock
    :field com1_pget_spktmodetxlock: salsat_frame.user_data_com1_tm_com.com1_pget_spktmodetxlock
    :field com1_pget_ack: salsat_frame.user_data_com1_tm_com.com1_pget_ack
    :field com1_pget_pktloss: salsat_frame.user_data_com1_tm_com.com1_pget_pktloss
    :field com1_pget_sessionest: salsat_frame.user_data_com1_tm_com.com1_pget_sessionest
    :field com1_pget_sessionopened: salsat_frame.user_data_com1_tm_com.com1_pget_sessionopened
    :field com1_pget_syncnewburst: salsat_frame.user_data_com1_tm_com.com1_pget_syncnewburst
    :field com1_pget_syncerrnumvalid: salsat_frame.user_data_com1_tm_com.com1_pget_syncerrnumvalid
    :field com1_pget_syncburstnumvalid: salsat_frame.user_data_com1_tm_com.com1_pget_syncburstnumvalid
    :field com1_pget_syncchainnumvalid: salsat_frame.user_data_com1_tm_com.com1_pget_syncchainnumvalid
    :field com1_pget_extsrcid: salsat_frame.user_data_com1_tm_com.com1_pget_extsrcid
    :field com1_pget_answpending: salsat_frame.user_data_com1_tm_com.com1_pget_answpending
    :field com1_pget_arqsyncloss: salsat_frame.user_data_com1_tm_com.com1_pget_arqsyncloss
    :field user_data_com1_tm_com_com1_pget_boolrfu5: salsat_frame.user_data_com1_tm_com.com1_pget_boolrfu5
    :field user_data_com1_tm_com_com1_pget_boolrfu6: salsat_frame.user_data_com1_tm_com.com1_pget_boolrfu6
    :field com1_pget_range: salsat_frame.user_data_com1_tm_com.com1_pget_range
    :field user_data_com1_tm_com_com1_pget_rssirx: salsat_frame.user_data_com1_tm_com.com1_pget_rssirx
    :field user_data_com1_tm_com_com1_pget_cd: salsat_frame.user_data_com1_tm_com.com1_pget_cd
    :field user_data_com4_tm_eeprom_com4_pget_systime: salsat_frame.user_data_com4_tm_eeprom.com4_pget_systime
    :field com4_pget_frsynceeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_frsynceeprom
    :field com4_pget_frsynchameeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_frsynchameeprom
    :field com4_pget_bitsyncnumeeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_bitsyncnumeeprom
    :field com4_pget_srcideeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_srcideeprom
    :field com4_pget_bcstideeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_bcstideeprom
    :field com4_pget_syncbiterrnumeeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_syncbiterrnumeeprom
    :field com4_pget_syncburstnumeeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_syncburstnumeeprom
    :field com4_pget_syncchainnumeeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_syncchainnumeeprom
    :field com4_pget_hamcallsigneeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_hamcallsigneeprom
    :field com4_pget_resetcnt: salsat_frame.user_data_com4_tm_eeprom.com4_pget_resetcnt
    :field com4_pget_periodrdtrxtmeeprom: salsat_frame.user_data_com4_tm_eeprom.com4_pget_periodrdtrxtmeeprom
    :field com4_pget_rxsducnt: salsat_frame.user_data_com4_tm_eeprom.com4_pget_rxsducnt
    :field com4_pget_rxspducnt: salsat_frame.user_data_com4_tm_eeprom.com4_pget_rxspducnt
    :field com4_pget_periodautorecoveryreset: salsat_frame.user_data_com4_tm_eeprom.com4_pget_periodautorecoveryreset
    :field user_data_com4_tm_sram_com4_pget_systime: salsat_frame.user_data_com4_tm_sram.com4_pget_systime
    :field com4_pget_frsyncsram: salsat_frame.user_data_com4_tm_sram.com4_pget_frsyncsram
    :field com4_pget_frsynchamsram: salsat_frame.user_data_com4_tm_sram.com4_pget_frsynchamsram
    :field com4_pget_bitsyncnumsram: salsat_frame.user_data_com4_tm_sram.com4_pget_bitsyncnumsram
    :field com4_pget_srcidsram: salsat_frame.user_data_com4_tm_sram.com4_pget_srcidsram
    :field com4_pget_bcstidsram: salsat_frame.user_data_com4_tm_sram.com4_pget_bcstidsram
    :field com4_pget_syncbiterrnumsram: salsat_frame.user_data_com4_tm_sram.com4_pget_syncbiterrnumsram
    :field com4_pget_syncburstnumsram: salsat_frame.user_data_com4_tm_sram.com4_pget_syncburstnumsram
    :field com4_pget_syncchainnumsram: salsat_frame.user_data_com4_tm_sram.com4_pget_syncchainnumsram
    :field com4_pget_hamcallsignsram: salsat_frame.user_data_com4_tm_sram.com4_pget_hamcallsignsram
    :field user_data_com1_tm_trx_com1_pget_systime: salsat_frame.user_data_com1_tm_trx.com1_pget_systime
    :field com1_pget_anomalytrxtreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxtreg
    :field com1_pget_anomalytrxrreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxrreg
    :field com1_pget_anomalytrxyreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxyreg
    :field com1_pget_anomalytrxsreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxsreg
    :field com1_pget_anomalytrxureg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxureg
    :field com1_pget_anomalytrxvreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxvreg
    :field com1_pget_anomalytrxnreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxnreg
    :field com1_pget_anomalytrxqreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxqreg
    :field com1_pget_anomalytrxpreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxpreg
    :field com1_pget_anomalytrxdreg: salsat_frame.user_data_com1_tm_trx.com1_pget_anomalytrxdreg
    :field com1_pget_txorrxfreqnotdefault: salsat_frame.user_data_com1_tm_trx.com1_pget_txorrxfreqnotdefault
    :field com1_pget_invtrxtmtxrx: salsat_frame.user_data_com1_tm_trx.com1_pget_invtrxtmtxrx
    :field com1_pget_trxcomtimeout: salsat_frame.user_data_com1_tm_trx.com1_pget_trxcomtimeout
    :field com1_pget_trxtmrxmode: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmrxmode
    :field com1_pget_trxtmbaudlow: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmbaudlow
    :field com1_pget_trxsetfreqboth: salsat_frame.user_data_com1_tm_trx.com1_pget_trxsetfreqboth
    :field com1_pget_trxtmsreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmsreg
    :field com1_pget_trxtmrreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmrreg
    :field com1_pget_trxtmtreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmtreg
    :field thm_com1_pget_trxtmyreg: salsat_frame.user_data_com1_tm_trx.thm_com1_pget_trxtmyreg
    :field com1_pget_trxtmqreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmqreg
    :field com1_pget_trxtmnreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmnreg
    :field com1_pget_trxtmdreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmdreg
    :field com1_pget_trxtmpreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmpreg
    :field com1_pget_trxtmvreg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmvreg
    :field com1_pget_trxtmureg: salsat_frame.user_data_com1_tm_trx.com1_pget_trxtmureg
    :field com1_pget_systimetrxtm: salsat_frame.user_data_com1_tm_trx.com1_pget_systimetrxtm
    :field com1_pget_periodrdtrxtmeeprom: salsat_frame.user_data_com1_tm_trx.com1_pget_periodrdtrxtmeeprom
    :field com1_pget_periodrdtrxtmsram: salsat_frame.user_data_com1_tm_trx.com1_pget_periodrdtrxtmsram
    :field user_data_com0_tm_arq_com0_pget_systime: salsat_frame.user_data_com0_tm_arq.com0_pget_systime
    :field com0_pget_txltuhdrfrcnttx: salsat_frame.user_data_com0_tm_arq.com0_pget_txltuhdrfrcnttx
    :field com0_pget_txltuhdrfrcntrx: salsat_frame.user_data_com0_tm_arq.com0_pget_txltuhdrfrcntrx
    :field com0_pget_rxltuhdrfrcnttx: salsat_frame.user_data_com0_tm_arq.com0_pget_rxltuhdrfrcnttx
    :field com0_pget_rxltuhdrfrcntrx: salsat_frame.user_data_com0_tm_arq.com0_pget_rxltuhdrfrcntrx
    :field com0_pget_frcnttx: salsat_frame.user_data_com0_tm_arq.com0_pget_frcnttx
    :field com0_pget_frcntrx: salsat_frame.user_data_com0_tm_arq.com0_pget_frcntrx
    :field com0_pget_senderrn: salsat_frame.user_data_com0_tm_arq.com0_pget_senderrn
    :field com0_pget_sendersb: salsat_frame.user_data_com0_tm_arq.com0_pget_sendersb
    :field com0_pget_receiverrn: salsat_frame.user_data_com0_tm_arq.com0_pget_receiverrn
    :field com0_pget_receiversb: salsat_frame.user_data_com0_tm_arq.com0_pget_receiversb
    :field com0_pget_sdutxfifonum: salsat_frame.user_data_com0_tm_arq.com0_pget_sdutxfifonum
    :field com0_pget_sdutxfifonumtdd: salsat_frame.user_data_com0_tm_arq.com0_pget_sdutxfifonumtdd
    :field com0_pget_sdutxfifoputpos: salsat_frame.user_data_com0_tm_arq.com0_pget_sdutxfifoputpos
    :field com0_pget_sdutxfifogetpos: salsat_frame.user_data_com0_tm_arq.com0_pget_sdutxfifogetpos
    :field user_data_com4_tm_arq_com4_pget_systime: salsat_frame.user_data_com4_tm_arq.com4_pget_systime
    :field com4_pget_txltuhdrfrcnttx: salsat_frame.user_data_com4_tm_arq.com4_pget_txltuhdrfrcnttx
    :field com4_pget_txltuhdrfrcntrx: salsat_frame.user_data_com4_tm_arq.com4_pget_txltuhdrfrcntrx
    :field com4_pget_rxltuhdrfrcnttx: salsat_frame.user_data_com4_tm_arq.com4_pget_rxltuhdrfrcnttx
    :field com4_pget_rxltuhdrfrcntrx: salsat_frame.user_data_com4_tm_arq.com4_pget_rxltuhdrfrcntrx
    :field com4_pget_frcnttx: salsat_frame.user_data_com4_tm_arq.com4_pget_frcnttx
    :field com4_pget_frcntrx: salsat_frame.user_data_com4_tm_arq.com4_pget_frcntrx
    :field com4_pget_senderrn: salsat_frame.user_data_com4_tm_arq.com4_pget_senderrn
    :field com4_pget_sendersb: salsat_frame.user_data_com4_tm_arq.com4_pget_sendersb
    :field com4_pget_receiverrn: salsat_frame.user_data_com4_tm_arq.com4_pget_receiverrn
    :field com4_pget_receiversb: salsat_frame.user_data_com4_tm_arq.com4_pget_receiversb
    :field com4_pget_sdutxfifonum: salsat_frame.user_data_com4_tm_arq.com4_pget_sdutxfifonum
    :field com4_pget_sdutxfifonumtdd: salsat_frame.user_data_com4_tm_arq.com4_pget_sdutxfifonumtdd
    :field com4_pget_sdutxfifoputpos: salsat_frame.user_data_com4_tm_arq.com4_pget_sdutxfifoputpos
    :field com4_pget_sdutxfifogetpos: salsat_frame.user_data_com4_tm_arq.com4_pget_sdutxfifogetpos
    :field user_data_com1_tm_arq_com1_pget_systime: salsat_frame.user_data_com1_tm_arq.com1_pget_systime
    :field user_data_com1_tm_arq_com1_pget_txltuhdrfrcnttx: salsat_frame.user_data_com1_tm_arq.com1_pget_txltuhdrfrcnttx
    :field user_data_com1_tm_arq_com1_pget_txltuhdrfrcntrx: salsat_frame.user_data_com1_tm_arq.com1_pget_txltuhdrfrcntrx
    :field user_data_com1_tm_arq_com1_pget_rxltuhdrfrcnttx: salsat_frame.user_data_com1_tm_arq.com1_pget_rxltuhdrfrcnttx
    :field user_data_com1_tm_arq_com1_pget_rxltuhdrfrcntrx: salsat_frame.user_data_com1_tm_arq.com1_pget_rxltuhdrfrcntrx
    :field com1_pget_frcnttx: salsat_frame.user_data_com1_tm_arq.com1_pget_frcnttx
    :field com1_pget_frcntrx: salsat_frame.user_data_com1_tm_arq.com1_pget_frcntrx
    :field com1_pget_senderrn: salsat_frame.user_data_com1_tm_arq.com1_pget_senderrn
    :field com1_pget_sendersb: salsat_frame.user_data_com1_tm_arq.com1_pget_sendersb
    :field com1_pget_receiverrn: salsat_frame.user_data_com1_tm_arq.com1_pget_receiverrn
    :field com1_pget_receiversb: salsat_frame.user_data_com1_tm_arq.com1_pget_receiversb
    :field user_data_com1_tm_arq_com1_pget_sdutxfifonum: salsat_frame.user_data_com1_tm_arq.com1_pget_sdutxfifonum
    :field com1_pget_sdutxfifonumtdd: salsat_frame.user_data_com1_tm_arq.com1_pget_sdutxfifonumtdd
    :field com1_pget_sdutxfifoputpos: salsat_frame.user_data_com1_tm_arq.com1_pget_sdutxfifoputpos
    :field com1_pget_sdutxfifogetpos: salsat_frame.user_data_com1_tm_arq.com1_pget_sdutxfifogetpos
    :field user_data_com0_tm_com_com0_pget_systime: salsat_frame.user_data_com0_tm_com.com0_pget_systime
    :field com0_pget_txltuhdrdstid: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrdstid
    :field com0_pget_txltuhdrsrcid: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrsrcid
    :field user_data_com0_tm_com_com0_pget_txltuhdrfrcnttx: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrfrcnttx
    :field user_data_com0_tm_com_com0_pget_txltuhdrfrcntrx: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrfrcntrx
    :field com0_pget_txltuhdrsnr: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrsnr
    :field com0_pget_txltuhdraitypesrc: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdraitypesrc
    :field com0_pget_txltuhdraitypedst: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdraitypedst
    :field com0_pget_txltuhdrdfcid: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrdfcid
    :field com0_pget_txltuhdrfrlength: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrfrlength
    :field com0_pget_txltuhdrcrc13: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrcrc13
    :field com0_pget_txltuhdrcrc5: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrcrc5
    :field com0_pget_txltuhdrudfl1: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrudfl1
    :field com0_pget_txltuhdrhailing: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrhailing
    :field com0_pget_txltuhdrrqbch: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrrqbch
    :field com0_pget_txltuhdrpdutypeid: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrpdutypeid
    :field com0_pget_txltuhdrarq: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrarq
    :field com0_pget_txltuhdrcaller: salsat_frame.user_data_com0_tm_com.com0_pget_txltuhdrcaller
    :field com0_pget_boolrfu0: salsat_frame.user_data_com0_tm_com.com0_pget_boolrfu0
    :field com0_pget_boolrfu1: salsat_frame.user_data_com0_tm_com.com0_pget_boolrfu1
    :field com0_pget_rxltuhdrdstid: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrdstid
    :field com0_pget_rxltuhdrsrcid: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrsrcid
    :field user_data_com0_tm_com_com0_pget_rxltuhdrfrcnttx: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrfrcnttx
    :field user_data_com0_tm_com_com0_pget_rxltuhdrfrcntrx: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrfrcntrx
    :field com0_pget_rxltuhdrsnr: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrsnr
    :field com0_pget_rxltuhdraitypesrc: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdraitypesrc
    :field com0_pget_rxltuhdraitypedst: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdraitypedst
    :field com0_pget_rxltuhdrdfcid: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrdfcid
    :field com0_pget_rxltuhdrfrlength: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrfrlength
    :field com0_pget_rxltuhdrcrc13: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrcrc13
    :field com0_pget_rxltuhdrcrc5: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrcrc5
    :field com0_pget_rxltuhdrudfl1: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrudfl1
    :field com0_pget_rxltuhdrhailing: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrhailing
    :field com0_pget_rxltuhdrrqbch: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrrqbch
    :field com0_pget_rxltuhdrpdutypeid: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrpdutypeid
    :field com0_pget_rxltuhdrarq: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrarq
    :field com0_pget_rxltuhdrcaller: salsat_frame.user_data_com0_tm_com.com0_pget_rxltuhdrcaller
    :field com0_pget_boolrfu2: salsat_frame.user_data_com0_tm_com.com0_pget_boolrfu2
    :field com0_pget_boolrfu3: salsat_frame.user_data_com0_tm_com.com0_pget_boolrfu3
    :field com0_pget_ltudecerrnum: salsat_frame.user_data_com0_tm_com.com0_pget_ltudecerrnum
    :field user_data_com0_tm_com_com0_pget_sdutxfifonum: salsat_frame.user_data_com0_tm_com.com0_pget_sdutxfifonum
    :field com0_pget_sessiontime: salsat_frame.user_data_com0_tm_com.com0_pget_sessiontime
    :field com0_pget_fsmcomstate: salsat_frame.user_data_com0_tm_com.com0_pget_fsmcomstate
    :field com0_pget_ltuhdrdec: salsat_frame.user_data_com0_tm_com.com0_pget_ltuhdrdec
    :field com0_pget_pdufirstblockdec: salsat_frame.user_data_com0_tm_com.com0_pget_pdufirstblockdec
    :field com0_pget_sduhdrdec: salsat_frame.user_data_com0_tm_com.com0_pget_sduhdrdec
    :field com0_pget_lturxcomplete: salsat_frame.user_data_com0_tm_com.com0_pget_lturxcomplete
    :field com0_pget_ltuhdrdecerr: salsat_frame.user_data_com0_tm_com.com0_pget_ltuhdrdecerr
    :field com0_pget_ltuhdrrxerr: salsat_frame.user_data_com0_tm_com.com0_pget_ltuhdrrxerr
    :field com0_pget_ltuhdrdeclock: salsat_frame.user_data_com0_tm_com.com0_pget_ltuhdrdeclock
    :field com0_pget_pdudecerr: salsat_frame.user_data_com0_tm_com.com0_pget_pdudecerr
    :field com0_pget_burst: salsat_frame.user_data_com0_tm_com.com0_pget_burst
    :field com0_pget_rangevalid: salsat_frame.user_data_com0_tm_com.com0_pget_rangevalid
    :field com0_pget_sdutxfifooverrun: salsat_frame.user_data_com0_tm_com.com0_pget_sdutxfifooverrun
    :field com0_pget_rxpducrcerr: salsat_frame.user_data_com0_tm_com.com0_pget_rxpducrcerr
    :field com0_pget_rxsducrcerr: salsat_frame.user_data_com0_tm_com.com0_pget_rxsducrcerr
    :field com0_pget_collectbcherr: salsat_frame.user_data_com0_tm_com.com0_pget_collectbcherr
    :field com0_pget_chmon: salsat_frame.user_data_com0_tm_com.com0_pget_chmon
    :field com0_pget_ltuerr: salsat_frame.user_data_com0_tm_com.com0_pget_ltuerr
    :field com0_pget_tddmode: salsat_frame.user_data_com0_tm_com.com0_pget_tddmode
    :field com0_pget_generaltxlock: salsat_frame.user_data_com0_tm_com.com0_pget_generaltxlock
    :field com0_pget_spktmodetxlock: salsat_frame.user_data_com0_tm_com.com0_pget_spktmodetxlock
    :field com0_pget_ack: salsat_frame.user_data_com0_tm_com.com0_pget_ack
    :field com0_pget_pktloss: salsat_frame.user_data_com0_tm_com.com0_pget_pktloss
    :field com0_pget_sessionest: salsat_frame.user_data_com0_tm_com.com0_pget_sessionest
    :field com0_pget_sessionopened: salsat_frame.user_data_com0_tm_com.com0_pget_sessionopened
    :field com0_pget_syncnewburst: salsat_frame.user_data_com0_tm_com.com0_pget_syncnewburst
    :field com0_pget_syncerrnumvalid: salsat_frame.user_data_com0_tm_com.com0_pget_syncerrnumvalid
    :field com0_pget_syncburstnumvalid: salsat_frame.user_data_com0_tm_com.com0_pget_syncburstnumvalid
    :field com0_pget_syncchainnumvalid: salsat_frame.user_data_com0_tm_com.com0_pget_syncchainnumvalid
    :field com0_pget_extsrcid: salsat_frame.user_data_com0_tm_com.com0_pget_extsrcid
    :field com0_pget_answpending: salsat_frame.user_data_com0_tm_com.com0_pget_answpending
    :field com0_pget_arqsyncloss: salsat_frame.user_data_com0_tm_com.com0_pget_arqsyncloss
    :field com0_pget_boolrfu5: salsat_frame.user_data_com0_tm_com.com0_pget_boolrfu5
    :field com0_pget_boolrfu6: salsat_frame.user_data_com0_tm_com.com0_pget_boolrfu6
    :field com0_pget_range: salsat_frame.user_data_com0_tm_com.com0_pget_range
    :field com0_pget_rssirx: salsat_frame.user_data_com0_tm_com.com0_pget_rssirx
    :field com0_pget_cd: salsat_frame.user_data_com0_tm_com.com0_pget_cd
    :field user_data_com4_tm_com_com4_pget_systime: salsat_frame.user_data_com4_tm_com.com4_pget_systime
    :field com4_pget_txltuhdrdstid: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrdstid
    :field com4_pget_txltuhdrsrcid: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrsrcid
    :field user_data_com4_tm_com_com4_pget_txltuhdrfrcnttx: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrfrcnttx
    :field user_data_com4_tm_com_com4_pget_txltuhdrfrcntrx: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrfrcntrx
    :field com4_pget_txltuhdrsnr: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrsnr
    :field com4_pget_txltuhdraitypesrc: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdraitypesrc
    :field com4_pget_txltuhdraitypedst: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdraitypedst
    :field com4_pget_txltuhdrdfcid: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrdfcid
    :field com4_pget_txltuhdrfrlength: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrfrlength
    :field com4_pget_txltuhdrcrc13: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrcrc13
    :field com4_pget_txltuhdrcrc5: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrcrc5
    :field com4_pget_txltuhdrudfl1: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrudfl1
    :field com4_pget_txltuhdrhailing: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrhailing
    :field com4_pget_txltuhdrrqbch: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrrqbch
    :field com4_pget_txltuhdrpdutypeid: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrpdutypeid
    :field com4_pget_txltuhdrarq: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrarq
    :field com4_pget_txltuhdrcaller: salsat_frame.user_data_com4_tm_com.com4_pget_txltuhdrcaller
    :field com4_pget_boolrfu0: salsat_frame.user_data_com4_tm_com.com4_pget_boolrfu0
    :field com4_pget_boolrfu1: salsat_frame.user_data_com4_tm_com.com4_pget_boolrfu1
    :field com4_pget_rxltuhdrdstid: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrdstid
    :field com4_pget_rxltuhdrsrcid: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrsrcid
    :field user_data_com4_tm_com_com4_pget_rxltuhdrfrcnttx: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrfrcnttx
    :field user_data_com4_tm_com_com4_pget_rxltuhdrfrcntrx: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrfrcntrx
    :field com4_pget_rxltuhdrsnr: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrsnr
    :field com4_pget_rxltuhdraitypesrc: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdraitypesrc
    :field com4_pget_rxltuhdraitypedst: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdraitypedst
    :field com4_pget_rxltuhdrdfcid: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrdfcid
    :field com4_pget_rxltuhdrfrlength: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrfrlength
    :field com4_pget_rxltuhdrcrc13: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrcrc13
    :field com4_pget_rxltuhdrcrc5: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrcrc5
    :field com4_pget_rxltuhdrudfl1: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrudfl1
    :field com4_pget_rxltuhdrhailing: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrhailing
    :field com4_pget_rxltuhdrrqbch: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrrqbch
    :field com4_pget_rxltuhdrpdutypeid: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrpdutypeid
    :field com4_pget_rxltuhdrarq: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrarq
    :field com4_pget_rxltuhdrcaller: salsat_frame.user_data_com4_tm_com.com4_pget_rxltuhdrcaller
    :field com4_pget_boolrfu2: salsat_frame.user_data_com4_tm_com.com4_pget_boolrfu2
    :field com4_pget_boolrfu3: salsat_frame.user_data_com4_tm_com.com4_pget_boolrfu3
    :field user_data_com4_tm_com_com4_pget_ltudecerrnum: salsat_frame.user_data_com4_tm_com.com4_pget_ltudecerrnum
    :field user_data_com4_tm_com_com4_pget_sdutxfifonum: salsat_frame.user_data_com4_tm_com.com4_pget_sdutxfifonum
    :field com4_pget_sessiontime: salsat_frame.user_data_com4_tm_com.com4_pget_sessiontime
    :field com4_pget_fsmcomstate: salsat_frame.user_data_com4_tm_com.com4_pget_fsmcomstate
    :field com4_pget_ltuhdrdec: salsat_frame.user_data_com4_tm_com.com4_pget_ltuhdrdec
    :field com4_pget_pdufirstblockdec: salsat_frame.user_data_com4_tm_com.com4_pget_pdufirstblockdec
    :field com4_pget_sduhdrdec: salsat_frame.user_data_com4_tm_com.com4_pget_sduhdrdec
    :field com4_pget_lturxcomplete: salsat_frame.user_data_com4_tm_com.com4_pget_lturxcomplete
    :field com4_pget_ltuhdrdecerr: salsat_frame.user_data_com4_tm_com.com4_pget_ltuhdrdecerr
    :field com4_pget_ltuhdrrxerr: salsat_frame.user_data_com4_tm_com.com4_pget_ltuhdrrxerr
    :field com4_pget_ltuhdrdeclock: salsat_frame.user_data_com4_tm_com.com4_pget_ltuhdrdeclock
    :field com4_pget_pdudecerr: salsat_frame.user_data_com4_tm_com.com4_pget_pdudecerr
    :field com4_pget_burst: salsat_frame.user_data_com4_tm_com.com4_pget_burst
    :field com4_pget_rangevalid: salsat_frame.user_data_com4_tm_com.com4_pget_rangevalid
    :field com4_pget_sdutxfifooverrun: salsat_frame.user_data_com4_tm_com.com4_pget_sdutxfifooverrun
    :field com4_pget_rxpducrcerr: salsat_frame.user_data_com4_tm_com.com4_pget_rxpducrcerr
    :field com4_pget_rxsducrcerr: salsat_frame.user_data_com4_tm_com.com4_pget_rxsducrcerr
    :field com4_pget_collectbcherr: salsat_frame.user_data_com4_tm_com.com4_pget_collectbcherr
    :field com4_pget_chmon: salsat_frame.user_data_com4_tm_com.com4_pget_chmon
    :field com4_pget_ltuerr: salsat_frame.user_data_com4_tm_com.com4_pget_ltuerr
    :field com4_pget_tddmode: salsat_frame.user_data_com4_tm_com.com4_pget_tddmode
    :field com4_pget_generaltxlock: salsat_frame.user_data_com4_tm_com.com4_pget_generaltxlock
    :field com4_pget_spktmodetxlock: salsat_frame.user_data_com4_tm_com.com4_pget_spktmodetxlock
    :field com4_pget_ack: salsat_frame.user_data_com4_tm_com.com4_pget_ack
    :field com4_pget_pktloss: salsat_frame.user_data_com4_tm_com.com4_pget_pktloss
    :field com4_pget_sessionest: salsat_frame.user_data_com4_tm_com.com4_pget_sessionest
    :field com4_pget_sessionopened: salsat_frame.user_data_com4_tm_com.com4_pget_sessionopened
    :field com4_pget_syncnewburst: salsat_frame.user_data_com4_tm_com.com4_pget_syncnewburst
    :field com4_pget_syncerrnumvalid: salsat_frame.user_data_com4_tm_com.com4_pget_syncerrnumvalid
    :field com4_pget_syncburstnumvalid: salsat_frame.user_data_com4_tm_com.com4_pget_syncburstnumvalid
    :field com4_pget_syncchainnumvalid: salsat_frame.user_data_com4_tm_com.com4_pget_syncchainnumvalid
    :field com4_pget_extsrcid: salsat_frame.user_data_com4_tm_com.com4_pget_extsrcid
    :field com4_pget_answpending: salsat_frame.user_data_com4_tm_com.com4_pget_answpending
    :field com4_pget_arqsyncloss: salsat_frame.user_data_com4_tm_com.com4_pget_arqsyncloss
    :field com4_pget_boolrfu5: salsat_frame.user_data_com4_tm_com.com4_pget_boolrfu5
    :field com4_pget_boolrfu6: salsat_frame.user_data_com4_tm_com.com4_pget_boolrfu6
    :field com4_pget_range: salsat_frame.user_data_com4_tm_com.com4_pget_range
    :field user_data_com4_tm_com_com4_pget_rssirx: salsat_frame.user_data_com4_tm_com.com4_pget_rssirx
    :field com4_pget_cd: salsat_frame.user_data_com4_tm_com.com4_pget_cd
    :field user_data_com1_tm_eeprom_com1_pget_systime: salsat_frame.user_data_com1_tm_eeprom.com1_pget_systime
    :field com1_pget_frsynceeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_frsynceeprom
    :field com1_pget_frsynchameeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_frsynchameeprom
    :field com1_pget_bitsyncnumeeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_bitsyncnumeeprom
    :field com1_pget_srcideeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_srcideeprom
    :field com1_pget_bcstideeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_bcstideeprom
    :field com1_pget_syncbiterrnumeeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_syncbiterrnumeeprom
    :field com1_pget_syncburstnumeeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_syncburstnumeeprom
    :field com1_pget_syncchainnumeeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_syncchainnumeeprom
    :field com1_pget_hamcallsigneeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_hamcallsigneeprom
    :field user_data_com1_tm_eeprom_com1_pget_resetcnt: salsat_frame.user_data_com1_tm_eeprom.com1_pget_resetcnt
    :field user_data_com1_tm_eeprom_com1_pget_periodrdtrxtmeeprom: salsat_frame.user_data_com1_tm_eeprom.com1_pget_periodrdtrxtmeeprom
    :field user_data_com1_tm_eeprom_com1_pget_rxsducnt: salsat_frame.user_data_com1_tm_eeprom.com1_pget_rxsducnt
    :field user_data_com1_tm_eeprom_com1_pget_rxspducnt: salsat_frame.user_data_com1_tm_eeprom.com1_pget_rxspducnt
    :field com1_pget_periodautorecoveryreset: salsat_frame.user_data_com1_tm_eeprom.com1_pget_periodautorecoveryreset
    :field user_data_com0_tm_fec_com0_pget_systime: salsat_frame.user_data_com0_tm_fec.com0_pget_systime
    :field user_data_com0_tm_fec_com0_pget_ltudecerrnum: salsat_frame.user_data_com0_tm_fec.com0_pget_ltudecerrnum
    :field com0_pget_ltuhdrbchrootcw13: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw13
    :field com0_pget_ltuhdrbchrootcw12: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw12
    :field com0_pget_ltuhdrbchrootcw11: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw11
    :field com0_pget_ltuhdrbchrootcw10: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw10
    :field com0_pget_ltuhdrbchrootcw9: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw9
    :field com0_pget_ltuhdrbchrootcw8: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw8
    :field com0_pget_ltuhdrbchrootcw7: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw7
    :field com0_pget_ltuhdrbchrootcw6: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw6
    :field com0_pget_ltuhdrbchrootcw5: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw5
    :field com0_pget_ltuhdrbchrootcw4: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw4
    :field com0_pget_ltuhdrbchrootcw3: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw3
    :field com0_pget_ltuhdrbchrootcw2: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw2
    :field com0_pget_ltuhdrbchrootcw1: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw1
    :field com0_pget_ltuhdrbchrootcw0: salsat_frame.user_data_com0_tm_fec.com0_pget_ltuhdrbchrootcw0
    :field user_data_com0_tm_fec_com0_pget_rssirx: salsat_frame.user_data_com0_tm_fec.com0_pget_rssirx
    :field user_data_com1_tm_fec_com1_pget_systime: salsat_frame.user_data_com1_tm_fec.com1_pget_systime
    :field user_data_com1_tm_fec_com1_pget_ltudecerrnum: salsat_frame.user_data_com1_tm_fec.com1_pget_ltudecerrnum
    :field com1_pget_ltuhdrbchrootcw13: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw13
    :field com1_pget_ltuhdrbchrootcw12: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw12
    :field com1_pget_ltuhdrbchrootcw11: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw11
    :field com1_pget_ltuhdrbchrootcw10: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw10
    :field com1_pget_ltuhdrbchrootcw9: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw9
    :field com1_pget_ltuhdrbchrootcw8: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw8
    :field com1_pget_ltuhdrbchrootcw7: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw7
    :field com1_pget_ltuhdrbchrootcw6: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw6
    :field com1_pget_ltuhdrbchrootcw5: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw5
    :field com1_pget_ltuhdrbchrootcw4: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw4
    :field com1_pget_ltuhdrbchrootcw3: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw3
    :field com1_pget_ltuhdrbchrootcw2: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw2
    :field com1_pget_ltuhdrbchrootcw1: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw1
    :field com1_pget_ltuhdrbchrootcw0: salsat_frame.user_data_com1_tm_fec.com1_pget_ltuhdrbchrootcw0
    :field user_data_com1_tm_fec_com1_pget_rssirx: salsat_frame.user_data_com1_tm_fec.com1_pget_rssirx
    :field user_data_com0_tm_swvers_com0_pget_systime: salsat_frame.user_data_com0_tm_swvers.com0_pget_systime
    :field com0_pget_swversmajor: salsat_frame.user_data_com0_tm_swvers.com0_pget_swversmajor
    :field com0_pget_swversminor: salsat_frame.user_data_com0_tm_swvers.com0_pget_swversminor
    :field com0_pget_swbuildyear: salsat_frame.user_data_com0_tm_swvers.com0_pget_swbuildyear
    :field com0_pget_swbuildmonth: salsat_frame.user_data_com0_tm_swvers.com0_pget_swbuildmonth
    :field com0_pget_swbuildday: salsat_frame.user_data_com0_tm_swvers.com0_pget_swbuildday
    :field com0_pget_swbuildhour: salsat_frame.user_data_com0_tm_swvers.com0_pget_swbuildhour
    :field com0_pget_swbuildmin: salsat_frame.user_data_com0_tm_swvers.com0_pget_swbuildmin
    :field com0_pget_swbuildsec: salsat_frame.user_data_com0_tm_swvers.com0_pget_swbuildsec
    :field com0_pget_serialnum: salsat_frame.user_data_com0_tm_swvers.com0_pget_serialnum
    :field com0_pget_devid: salsat_frame.user_data_com0_tm_swvers.com0_pget_devid
    :field user_data_com1_tm_swvers_com1_pget_systime: salsat_frame.user_data_com1_tm_swvers.com1_pget_systime
    :field com1_pget_swversmajor: salsat_frame.user_data_com1_tm_swvers.com1_pget_swversmajor
    :field com1_pget_swversminor: salsat_frame.user_data_com1_tm_swvers.com1_pget_swversminor
    :field com1_pget_swbuildyear: salsat_frame.user_data_com1_tm_swvers.com1_pget_swbuildyear
    :field com1_pget_swbuildmonth: salsat_frame.user_data_com1_tm_swvers.com1_pget_swbuildmonth
    :field com1_pget_swbuildday: salsat_frame.user_data_com1_tm_swvers.com1_pget_swbuildday
    :field com1_pget_swbuildhour: salsat_frame.user_data_com1_tm_swvers.com1_pget_swbuildhour
    :field com1_pget_swbuildmin: salsat_frame.user_data_com1_tm_swvers.com1_pget_swbuildmin
    :field com1_pget_swbuildsec: salsat_frame.user_data_com1_tm_swvers.com1_pget_swbuildsec
    :field com1_pget_serialnum: salsat_frame.user_data_com1_tm_swvers.com1_pget_serialnum
    :field com1_pget_devid: salsat_frame.user_data_com1_tm_swvers.com1_pget_devid
    :field user_data_com4_tm_swvers_com4_pget_systime: salsat_frame.user_data_com4_tm_swvers.com4_pget_systime
    :field com4_pget_swversmajor: salsat_frame.user_data_com4_tm_swvers.com4_pget_swversmajor
    :field com4_pget_swversminor: salsat_frame.user_data_com4_tm_swvers.com4_pget_swversminor
    :field com4_pget_swbuildyear: salsat_frame.user_data_com4_tm_swvers.com4_pget_swbuildyear
    :field com4_pget_swbuildmonth: salsat_frame.user_data_com4_tm_swvers.com4_pget_swbuildmonth
    :field com4_pget_swbuildday: salsat_frame.user_data_com4_tm_swvers.com4_pget_swbuildday
    :field com4_pget_swbuildhour: salsat_frame.user_data_com4_tm_swvers.com4_pget_swbuildhour
    :field com4_pget_swbuildmin: salsat_frame.user_data_com4_tm_swvers.com4_pget_swbuildmin
    :field com4_pget_swbuildsec: salsat_frame.user_data_com4_tm_swvers.com4_pget_swbuildsec
    :field com4_pget_serialnum: salsat_frame.user_data_com4_tm_swvers.com4_pget_serialnum
    :field com4_pget_devid: salsat_frame.user_data_com4_tm_swvers.com4_pget_devid
    :field user_data_com1_tm_sram_com1_pget_systime: salsat_frame.user_data_com1_tm_sram.com1_pget_systime
    :field com1_pget_frsyncsram: salsat_frame.user_data_com1_tm_sram.com1_pget_frsyncsram
    :field com1_pget_frsynchamsram: salsat_frame.user_data_com1_tm_sram.com1_pget_frsynchamsram
    :field com1_pget_bitsyncnumsram: salsat_frame.user_data_com1_tm_sram.com1_pget_bitsyncnumsram
    :field com1_pget_srcidsram: salsat_frame.user_data_com1_tm_sram.com1_pget_srcidsram
    :field com1_pget_bcstidsram: salsat_frame.user_data_com1_tm_sram.com1_pget_bcstidsram
    :field com1_pget_syncbiterrnumsram: salsat_frame.user_data_com1_tm_sram.com1_pget_syncbiterrnumsram
    :field com1_pget_syncburstnumsram: salsat_frame.user_data_com1_tm_sram.com1_pget_syncburstnumsram
    :field com1_pget_syncchainnumsram: salsat_frame.user_data_com1_tm_sram.com1_pget_syncchainnumsram
    :field com1_pget_hamcallsignsram: salsat_frame.user_data_com1_tm_sram.com1_pget_hamcallsignsram
    :field user_data_com0_tm_std_com0_pget_systime: salsat_frame.user_data_com0_tm_std.com0_pget_systime
    :field user_data_com0_tm_std_com0_pget_resetcnt: salsat_frame.user_data_com0_tm_std.com0_pget_resetcnt
    :field user_data_com0_tm_std_com0_pget_rxsducnt: salsat_frame.user_data_com0_tm_std.com0_pget_rxsducnt
    :field user_data_com0_tm_std_com0_pget_rxspducnt: salsat_frame.user_data_com0_tm_std.com0_pget_rxspducnt
    :field com0_pget_fsmmainstate: salsat_frame.user_data_com0_tm_std.com0_pget_fsmmainstate
    :field com0_pget_invrxframe: salsat_frame.user_data_com0_tm_std.com0_pget_invrxframe
    :field com0_pget_comtimeout: salsat_frame.user_data_com0_tm_std.com0_pget_comtimeout
    :field com0_pget_anomalyenvir: salsat_frame.user_data_com0_tm_std.com0_pget_anomalyenvir
    :field com0_pget_anomalypwr: salsat_frame.user_data_com0_tm_std.com0_pget_anomalypwr
    :field com0_pget_pdurxfifofull: salsat_frame.user_data_com0_tm_std.com0_pget_pdurxfifofull
    :field com0_pget_rxmode: salsat_frame.user_data_com0_tm_std.com0_pget_rxmode
    :field com0_pget_trxrxovercur: salsat_frame.user_data_com0_tm_std.com0_pget_trxrxovercur
    :field com0_pget_trxtxovercur: salsat_frame.user_data_com0_tm_std.com0_pget_trxtxovercur
    :field user_data_com0_tm_std_com0_pget_boolrfu0: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu0
    :field user_data_com0_tm_std_com0_pget_boolrfu1: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu1
    :field user_data_com0_tm_std_com0_pget_boolrfu2: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu2
    :field user_data_com0_tm_std_com0_pget_boolrfu3: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu3
    :field com0_pget_boolrfu4: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu4
    :field user_data_com0_tm_std_com0_pget_boolrfu5: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu5
    :field user_data_com0_tm_std_com0_pget_boolrfu6: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu6
    :field com0_pget_boolrfu7: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu7
    :field com0_pget_anomalyrssi: salsat_frame.user_data_com0_tm_std.com0_pget_anomalyrssi
    :field com0_pget_anomalyrssirx: salsat_frame.user_data_com0_tm_std.com0_pget_anomalyrssirx
    :field com0_pget_anomalycd: salsat_frame.user_data_com0_tm_std.com0_pget_anomalycd
    :field com0_pget_anomalycurtrxrx: salsat_frame.user_data_com0_tm_std.com0_pget_anomalycurtrxrx
    :field com0_pget_anomalycurtrxtx: salsat_frame.user_data_com0_tm_std.com0_pget_anomalycurtrxtx
    :field com0_pget_anomalycur3v3: salsat_frame.user_data_com0_tm_std.com0_pget_anomalycur3v3
    :field com0_pget_anomalyvlttrxrx: salsat_frame.user_data_com0_tm_std.com0_pget_anomalyvlttrxrx
    :field com0_pget_anomalyvlttrxtx: salsat_frame.user_data_com0_tm_std.com0_pget_anomalyvlttrxtx
    :field com0_pget_anomalyvlt3v3: salsat_frame.user_data_com0_tm_std.com0_pget_anomalyvlt3v3
    :field com0_pget_anomalytmptnc: salsat_frame.user_data_com0_tm_std.com0_pget_anomalytmptnc
    :field com0_pget_boolrfu8: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu8
    :field com0_pget_boolrfu9: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu9
    :field com0_pget_boolrfu10: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu10
    :field com0_pget_boolrfu11: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu11
    :field com0_pget_boolrfu12: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu12
    :field com0_pget_boolrfu13: salsat_frame.user_data_com0_tm_std.com0_pget_boolrfu13
    :field com0_pget_rssi: salsat_frame.user_data_com0_tm_std.com0_pget_rssi
    :field user_data_com0_tm_std_com0_pget_rssirx: salsat_frame.user_data_com0_tm_std.com0_pget_rssirx
    :field user_data_com0_tm_std_com0_pget_cd: salsat_frame.user_data_com0_tm_std.com0_pget_cd
    :field com0_pget_curtrx: salsat_frame.user_data_com0_tm_std.com0_pget_curtrx
    :field com0_pget_curtrxtx: salsat_frame.user_data_com0_tm_std.com0_pget_curtrxtx
    :field com0_pget_cur3v3: salsat_frame.user_data_com0_tm_std.com0_pget_cur3v3
    :field com0_pget_vlttrx: salsat_frame.user_data_com0_tm_std.com0_pget_vlttrx
    :field com0_pget_vlttrxtx: salsat_frame.user_data_com0_tm_std.com0_pget_vlttrxtx
    :field com0_pget_vlt3v3: salsat_frame.user_data_com0_tm_std.com0_pget_vlt3v3
    :field thm_com0_pget_tmptnc: salsat_frame.user_data_com0_tm_std.thm_com0_pget_tmptnc
    :field com0_pget_timetoautorecoveryreset: salsat_frame.user_data_com0_tm_std.com0_pget_timetoautorecoveryreset
    :field user_data_com4_tm_std_com4_pget_systime: salsat_frame.user_data_com4_tm_std.com4_pget_systime
    :field user_data_com4_tm_std_com4_pget_resetcnt: salsat_frame.user_data_com4_tm_std.com4_pget_resetcnt
    :field user_data_com4_tm_std_com4_pget_rxsducnt: salsat_frame.user_data_com4_tm_std.com4_pget_rxsducnt
    :field user_data_com4_tm_std_com4_pget_rxspducnt: salsat_frame.user_data_com4_tm_std.com4_pget_rxspducnt
    :field com4_pget_fsmmainstate: salsat_frame.user_data_com4_tm_std.com4_pget_fsmmainstate
    :field com4_pget_invrxframe: salsat_frame.user_data_com4_tm_std.com4_pget_invrxframe
    :field com4_pget_comtimeout: salsat_frame.user_data_com4_tm_std.com4_pget_comtimeout
    :field com4_pget_anomalyenvir: salsat_frame.user_data_com4_tm_std.com4_pget_anomalyenvir
    :field com4_pget_anomalypwr: salsat_frame.user_data_com4_tm_std.com4_pget_anomalypwr
    :field com4_pget_pdurxfifofull: salsat_frame.user_data_com4_tm_std.com4_pget_pdurxfifofull
    :field com4_pget_rxmode: salsat_frame.user_data_com4_tm_std.com4_pget_rxmode
    :field com4_pget_trxrxovercur: salsat_frame.user_data_com4_tm_std.com4_pget_trxrxovercur
    :field com4_pget_trxtxovercur: salsat_frame.user_data_com4_tm_std.com4_pget_trxtxovercur
    :field user_data_com4_tm_std_com4_pget_boolrfu0: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu0
    :field user_data_com4_tm_std_com4_pget_boolrfu1: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu1
    :field user_data_com4_tm_std_com4_pget_boolrfu2: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu2
    :field user_data_com4_tm_std_com4_pget_boolrfu3: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu3
    :field com4_pget_boolrfu4: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu4
    :field user_data_com4_tm_std_com4_pget_boolrfu5: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu5
    :field user_data_com4_tm_std_com4_pget_boolrfu6: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu6
    :field com4_pget_boolrfu7: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu7
    :field com4_pget_anomalyrssi: salsat_frame.user_data_com4_tm_std.com4_pget_anomalyrssi
    :field com4_pget_anomalyrssirx: salsat_frame.user_data_com4_tm_std.com4_pget_anomalyrssirx
    :field com4_pget_anomalycd: salsat_frame.user_data_com4_tm_std.com4_pget_anomalycd
    :field com4_pget_anomalycurtrxrx: salsat_frame.user_data_com4_tm_std.com4_pget_anomalycurtrxrx
    :field com4_pget_anomalycurtrxtx: salsat_frame.user_data_com4_tm_std.com4_pget_anomalycurtrxtx
    :field com4_pget_anomalycur3v3: salsat_frame.user_data_com4_tm_std.com4_pget_anomalycur3v3
    :field com4_pget_anomalyvlttrxrx: salsat_frame.user_data_com4_tm_std.com4_pget_anomalyvlttrxrx
    :field com4_pget_anomalyvlttrxtx: salsat_frame.user_data_com4_tm_std.com4_pget_anomalyvlttrxtx
    :field com4_pget_anomalyvlt3v3: salsat_frame.user_data_com4_tm_std.com4_pget_anomalyvlt3v3
    :field com4_pget_anomalytmptnc: salsat_frame.user_data_com4_tm_std.com4_pget_anomalytmptnc
    :field com4_pget_boolrfu8: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu8
    :field com4_pget_boolrfu9: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu9
    :field com4_pget_boolrfu10: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu10
    :field com4_pget_boolrfu11: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu11
    :field com4_pget_boolrfu12: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu12
    :field com4_pget_boolrfu13: salsat_frame.user_data_com4_tm_std.com4_pget_boolrfu13
    :field com4_pget_rssi: salsat_frame.user_data_com4_tm_std.com4_pget_rssi
    :field user_data_com4_tm_std_com4_pget_rssirx: salsat_frame.user_data_com4_tm_std.com4_pget_rssirx
    :field user_data_com4_tm_std_com4_pget_cd: salsat_frame.user_data_com4_tm_std.com4_pget_cd
    :field com4_pget_curtrx: salsat_frame.user_data_com4_tm_std.com4_pget_curtrx
    :field com4_pget_curtrxtx: salsat_frame.user_data_com4_tm_std.com4_pget_curtrxtx
    :field com4_pget_cur3v3: salsat_frame.user_data_com4_tm_std.com4_pget_cur3v3
    :field com4_pget_vlttrx: salsat_frame.user_data_com4_tm_std.com4_pget_vlttrx
    :field com4_pget_vlttrxtx: salsat_frame.user_data_com4_tm_std.com4_pget_vlttrxtx
    :field com4_pget_vlt3v3: salsat_frame.user_data_com4_tm_std.com4_pget_vlt3v3
    :field thm_com4_pget_tmptnc: salsat_frame.user_data_com4_tm_std.thm_com4_pget_tmptnc
    :field com4_pget_timetoautorecoveryreset: salsat_frame.user_data_com4_tm_std.com4_pget_timetoautorecoveryreset
    :field user_data_com4_tm_trx_com4_pget_systime: salsat_frame.user_data_com4_tm_trx.com4_pget_systime
    :field com4_pget_freqsetting: salsat_frame.user_data_com4_tm_trx.com4_pget_freqsetting
    :field com4_pget_trxcomtimeout: salsat_frame.user_data_com4_tm_trx.com4_pget_trxcomtimeout
    :field com4_pget_trxtype: salsat_frame.user_data_com4_tm_trx.com4_pget_trxtype
    :field com4_pget_trxwaitbeforefreqset: salsat_frame.user_data_com4_tm_trx.com4_pget_trxwaitbeforefreqset
    :field user_data_com4_tm_trx_com4_pget_boolrfu2: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu2
    :field user_data_com4_tm_trx_com4_pget_boolrfu3: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu3
    :field user_data_com4_tm_trx_com4_pget_boolrfu4: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu4
    :field user_data_com4_tm_trx_com4_pget_boolrfu5: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu5
    :field user_data_com4_tm_trx_com4_pget_boolrfu6: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu6
    :field user_data_com4_tm_trx_com4_pget_boolrfu7: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu7
    :field user_data_com4_tm_trx_com4_pget_boolrfu8: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu8
    :field user_data_com4_tm_trx_com4_pget_boolrfu9: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu9
    :field user_data_com4_tm_trx_com4_pget_boolrfu10: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu10
    :field user_data_com4_tm_trx_com4_pget_boolrfu11: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu11
    :field user_data_com4_tm_trx_com4_pget_boolrfu12: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu12
    :field user_data_com4_tm_trx_com4_pget_boolrfu13: salsat_frame.user_data_com4_tm_trx.com4_pget_boolrfu13
    :field com4_pget_txfreqicom_10_1: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_10_1
    :field com4_pget_txfreqicom_100_10: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_100_10
    :field com4_pget_txfreqicom_1k_100: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_1k_100
    :field com4_pget_txfreqicom_10k_1k: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_10k_1k
    :field com4_pget_txfreqicom_100k_10k: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_100k_10k
    :field com4_pget_txfreqicom_1m_100k: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_1m_100k
    :field com4_pget_txfreqicom_10m_1m: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_10m_1m
    :field com4_pget_txfreqicom_100m_10m: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_100m_10m
    :field com4_pget_txfreqicom_1g_100m: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_1g_100m
    :field com4_pget_txfreqicom_10g_1g: salsat_frame.user_data_com4_tm_trx.com4_pget_txfreqicom_10g_1g
    :field com4_pget_rxfreqicom_10_1: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_10_1
    :field com4_pget_rxfreqicom_100_10: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_100_10
    :field com4_pget_rxfreqicom_1k_100: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_1k_100
    :field com4_pget_rxfreqicom_10k_1k: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_10k_1k
    :field com4_pget_rxfreqicom_100k_10k: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_100k_10k
    :field com4_pget_rxfreqicom_1m_100k: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_1m_100k
    :field com4_pget_rxfreqicom_10m_1m: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_10m_1m
    :field com4_pget_rxfreqicom_100m_10m: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_100m_10m
    :field com4_pget_rxfreqicom_1g_100m: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_1g_100m
    :field com4_pget_rxfreqicom_10g_1g: salsat_frame.user_data_com4_tm_trx.com4_pget_rxfreqicom_10g_1g
    :field user_data_com0_tm_trx_com0_pget_systime: salsat_frame.user_data_com0_tm_trx.com0_pget_systime
    :field com0_pget_anomalytrxtreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxtreg
    :field com0_pget_anomalytrxrreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxrreg
    :field com0_pget_anomalytrxyreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxyreg
    :field com0_pget_anomalytrxsreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxsreg
    :field com0_pget_anomalytrxureg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxureg
    :field com0_pget_anomalytrxvreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxvreg
    :field com0_pget_anomalytrxnreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxnreg
    :field com0_pget_anomalytrxqreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxqreg
    :field com0_pget_anomalytrxpreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxpreg
    :field com0_pget_anomalytrxdreg: salsat_frame.user_data_com0_tm_trx.com0_pget_anomalytrxdreg
    :field com0_pget_txorrxfreqnotdefault: salsat_frame.user_data_com0_tm_trx.com0_pget_txorrxfreqnotdefault
    :field com0_pget_invtrxtmtxrx: salsat_frame.user_data_com0_tm_trx.com0_pget_invtrxtmtxrx
    :field com0_pget_trxcomtimeout: salsat_frame.user_data_com0_tm_trx.com0_pget_trxcomtimeout
    :field com0_pget_trxtmrxmode: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmrxmode
    :field com0_pget_trxtmbaudlow: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmbaudlow
    :field com0_pget_trxsetfreqboth: salsat_frame.user_data_com0_tm_trx.com0_pget_trxsetfreqboth
    :field com0_pget_trxtmsreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmsreg
    :field com0_pget_trxtmrreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmrreg
    :field com0_pget_trxtmtreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmtreg
    :field thm_com0_pget_trxtmyreg: salsat_frame.user_data_com0_tm_trx.thm_com0_pget_trxtmyreg
    :field com0_pget_trxtmqreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmqreg
    :field com0_pget_trxtmnreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmnreg
    :field com0_pget_trxtmdreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmdreg
    :field com0_pget_trxtmpreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmpreg
    :field com0_pget_trxtmvreg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmvreg
    :field com0_pget_trxtmureg: salsat_frame.user_data_com0_tm_trx.com0_pget_trxtmureg
    :field com0_pget_systimetrxtm: salsat_frame.user_data_com0_tm_trx.com0_pget_systimetrxtm
    :field user_data_com0_tm_trx_com0_pget_periodrdtrxtmeeprom: salsat_frame.user_data_com0_tm_trx.com0_pget_periodrdtrxtmeeprom
    :field com0_pget_periodrdtrxtmsram: salsat_frame.user_data_com0_tm_trx.com0_pget_periodrdtrxtmsram
    :field user_data_com0_tm_rndpkt_com0_pget_systime: salsat_frame.user_data_com0_tm_rndpkt.com0_pget_systime
    :field com0_pget_rndpktcnt: salsat_frame.user_data_com0_tm_rndpkt.com0_pget_rndpktcnt
    :field com0_pget_rndpkttype: salsat_frame.user_data_com0_tm_rndpkt.com0_pget_rndpkttype
    :field com0_pget_rnddata: salsat_frame.user_data_com0_tm_rndpkt.com0_pget_rnddata
    :field user_data_com1_tm_rndpkt_com1_pget_systime: salsat_frame.user_data_com1_tm_rndpkt.com1_pget_systime
    :field com1_pget_rndpktcnt: salsat_frame.user_data_com1_tm_rndpkt.com1_pget_rndpktcnt
    :field com1_pget_rndpkttype: salsat_frame.user_data_com1_tm_rndpkt.com1_pget_rndpkttype
    :field com1_pget_rnddata: salsat_frame.user_data_com1_tm_rndpkt.com1_pget_rnddata
    :field user_data_com4_tm_rndpkt_com4_pget_systime: salsat_frame.user_data_com4_tm_rndpkt.com4_pget_systime
    :field com4_pget_rndpktcnt: salsat_frame.user_data_com4_tm_rndpkt.com4_pget_rndpktcnt
    :field com4_pget_rndpkttype: salsat_frame.user_data_com4_tm_rndpkt.com4_pget_rndpkttype
    :field com4_pget_rnddata: salsat_frame.user_data_com4_tm_rndpkt.com4_pget_rnddata
    :field user_data_com0_tm_mem_32_com0_pget_systime: salsat_frame.user_data_com0_tm_mem_32.com0_pget_systime
    :field com0_pget_memdatatype: salsat_frame.user_data_com0_tm_mem_32.com0_pget_memdatatype
    :field com0_pget_memdata32: salsat_frame.user_data_com0_tm_mem_32.com0_pget_memdata32
    :field user_data_com1_tm_mem_32_com0_pget_systime: salsat_frame.user_data_com1_tm_mem_32.com0_pget_systime
    :field user_data_com1_tm_mem_32_com0_pget_memdatatype: salsat_frame.user_data_com1_tm_mem_32.com0_pget_memdatatype
    :field user_data_com1_tm_mem_32_com0_pget_memdata32: salsat_frame.user_data_com1_tm_mem_32.com0_pget_memdata32
    :field user_data_com4_tm_mem_32_com0_pget_systime: salsat_frame.user_data_com4_tm_mem_32.com0_pget_systime
    :field user_data_com4_tm_mem_32_com0_pget_memdatatype: salsat_frame.user_data_com4_tm_mem_32.com0_pget_memdatatype
    :field user_data_com4_tm_mem_32_com0_pget_memdata32: salsat_frame.user_data_com4_tm_mem_32.com0_pget_memdata32
    :field user_data_com4_tm_com_extd_com4_pget_systime: salsat_frame.user_data_com4_tm_com_extd.com4_pget_systime
    :field user_data_com4_tm_com_extd_com4_pget_frsyncsram: salsat_frame.user_data_com4_tm_com_extd.com4_pget_frsyncsram
    :field user_data_com4_tm_com_extd_com4_pget_frsynchamsram: salsat_frame.user_data_com4_tm_com_extd.com4_pget_frsynchamsram
    :field user_data_com4_tm_com_extd_com4_pget_bitsyncnumsram: salsat_frame.user_data_com4_tm_com_extd.com4_pget_bitsyncnumsram
    :field user_data_com4_tm_com_extd_com4_pget_syncbiterrnumsram: salsat_frame.user_data_com4_tm_com_extd.com4_pget_syncbiterrnumsram
    :field user_data_com4_tm_com_extd_com4_pget_syncburstnumsram: salsat_frame.user_data_com4_tm_com_extd.com4_pget_syncburstnumsram
    :field user_data_com4_tm_com_extd_com4_pget_syncchainnumsram: salsat_frame.user_data_com4_tm_com_extd.com4_pget_syncchainnumsram
    :field com4_pget_frsyncbitmaskrx: salsat_frame.user_data_com4_tm_com_extd.com4_pget_frsyncbitmaskrx
    :field com4_pget_syncbiterrnumrx: salsat_frame.user_data_com4_tm_com_extd.com4_pget_syncbiterrnumrx
    :field com4_pget_syncburstnumrx: salsat_frame.user_data_com4_tm_com_extd.com4_pget_syncburstnumrx
    :field com4_pget_syncchainnumrx: salsat_frame.user_data_com4_tm_com_extd.com4_pget_syncchainnumrx
    :field com4_pget_tmcomextdrfu: salsat_frame.user_data_com4_tm_com_extd.com4_pget_tmcomextdrfu
    :field user_data_com0_tm_std_a_com0_pget_resetcnt: salsat_frame.user_data_com0_tm_std_a.com0_pget_resetcnt
    :field user_data_com0_tm_std_a_com0_pget_rxsducnt: salsat_frame.user_data_com0_tm_std_a.com0_pget_rxsducnt
    :field user_data_com0_tm_std_a_com0_pget_rxspducnt: salsat_frame.user_data_com0_tm_std_a.com0_pget_rxspducnt
    :field user_data_com0_tm_std_a_com0_pget_fsmmainstate: salsat_frame.user_data_com0_tm_std_a.com0_pget_fsmmainstate
    :field user_data_com0_tm_std_a_com0_pget_invrxframe: salsat_frame.user_data_com0_tm_std_a.com0_pget_invrxframe
    :field user_data_com0_tm_std_a_com0_pget_comtimeout: salsat_frame.user_data_com0_tm_std_a.com0_pget_comtimeout
    :field user_data_com0_tm_std_a_com0_pget_anomalyenvir: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalyenvir
    :field user_data_com0_tm_std_a_com0_pget_anomalypwr: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalypwr
    :field user_data_com0_tm_std_a_com0_pget_pdurxfifofull: salsat_frame.user_data_com0_tm_std_a.com0_pget_pdurxfifofull
    :field user_data_com0_tm_std_a_com0_pget_rxmode: salsat_frame.user_data_com0_tm_std_a.com0_pget_rxmode
    :field user_data_com0_tm_std_a_com0_pget_trxrxovercur: salsat_frame.user_data_com0_tm_std_a.com0_pget_trxrxovercur
    :field user_data_com0_tm_std_a_com0_pget_trxtxovercur: salsat_frame.user_data_com0_tm_std_a.com0_pget_trxtxovercur
    :field com0_pget_initeepromparcompl: salsat_frame.user_data_com0_tm_std_a.com0_pget_initeepromparcompl
    :field user_data_com0_tm_std_a_com0_pget_boolrfu0: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu0
    :field user_data_com0_tm_std_a_com0_pget_boolrfu1: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu1
    :field user_data_com0_tm_std_a_com0_pget_boolrfu2: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu2
    :field user_data_com0_tm_std_a_com0_pget_boolrfu3: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu3
    :field user_data_com0_tm_std_a_com0_pget_boolrfu4: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu4
    :field user_data_com0_tm_std_a_com0_pget_boolrfu5: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu5
    :field user_data_com0_tm_std_a_com0_pget_boolrfu6: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu6
    :field user_data_com0_tm_std_a_com0_pget_anomalyrssi: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalyrssi
    :field user_data_com0_tm_std_a_com0_pget_anomalyrssirx: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalyrssirx
    :field user_data_com0_tm_std_a_com0_pget_anomalycd: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalycd
    :field user_data_com0_tm_std_a_com0_pget_anomalycurtrxrx: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalycurtrxrx
    :field user_data_com0_tm_std_a_com0_pget_anomalycurtrxtx: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalycurtrxtx
    :field user_data_com0_tm_std_a_com0_pget_anomalycur3v3: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalycur3v3
    :field user_data_com0_tm_std_a_com0_pget_anomalyvlttrxrx: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalyvlttrxrx
    :field user_data_com0_tm_std_a_com0_pget_anomalyvlttrxtx: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalyvlttrxtx
    :field user_data_com0_tm_std_a_com0_pget_anomalyvlt3v3: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalyvlt3v3
    :field user_data_com0_tm_std_a_com0_pget_anomalytmptnc: salsat_frame.user_data_com0_tm_std_a.com0_pget_anomalytmptnc
    :field user_data_com0_tm_std_a_com0_pget_boolrfu7: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu7
    :field user_data_com0_tm_std_a_com0_pget_boolrfu8: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu8
    :field user_data_com0_tm_std_a_com0_pget_boolrfu9: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu9
    :field user_data_com0_tm_std_a_com0_pget_boolrfu10: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu10
    :field user_data_com0_tm_std_a_com0_pget_boolrfu11: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu11
    :field user_data_com0_tm_std_a_com0_pget_boolrfu12: salsat_frame.user_data_com0_tm_std_a.com0_pget_boolrfu12
    :field com0_pget_rssi_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_rssi_a
    :field com0_pget_rssirx_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_rssirx_a
    :field com0_pget_cd_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_cd_a
    :field com0_pget_curtrx_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_curtrx_a
    :field com0_pget_curtrxtx_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_curtrxtx_a
    :field com0_pget_cur3v3_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_cur3v3_a
    :field com0_pget_vlttrx_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_vlttrx_a
    :field com0_pget_vlttrxtx_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_vlttrxtx_a
    :field com0_pget_vlt3v3_a: salsat_frame.user_data_com0_tm_std_a.com0_pget_vlt3v3_a
    :field thm_com0_pget_tmptnc_a: salsat_frame.user_data_com0_tm_std_a.thm_com0_pget_tmptnc_a
    :field user_data_com0_tm_std_a_thm_com0_pget_trxtmyreg: salsat_frame.user_data_com0_tm_std_a.thm_com0_pget_trxtmyreg
    :field user_data_com0_tm_std_a_com0_pget_timetoautorecoveryreset: salsat_frame.user_data_com0_tm_std_a.com0_pget_timetoautorecoveryreset
    :field user_data_com1_tm_std_a_com1_pget_resetcnt: salsat_frame.user_data_com1_tm_std_a.com1_pget_resetcnt
    :field user_data_com1_tm_std_a_com1_pget_rxsducnt: salsat_frame.user_data_com1_tm_std_a.com1_pget_rxsducnt
    :field user_data_com1_tm_std_a_com1_pget_rxspducnt: salsat_frame.user_data_com1_tm_std_a.com1_pget_rxspducnt
    :field user_data_com1_tm_std_a_com1_pget_fsmmainstate: salsat_frame.user_data_com1_tm_std_a.com1_pget_fsmmainstate
    :field user_data_com1_tm_std_a_com1_pget_invrxframe: salsat_frame.user_data_com1_tm_std_a.com1_pget_invrxframe
    :field user_data_com1_tm_std_a_com1_pget_comtimeout: salsat_frame.user_data_com1_tm_std_a.com1_pget_comtimeout
    :field user_data_com1_tm_std_a_com1_pget_anomalyenvir: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalyenvir
    :field user_data_com1_tm_std_a_com1_pget_anomalypwr: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalypwr
    :field user_data_com1_tm_std_a_com1_pget_pdurxfifofull: salsat_frame.user_data_com1_tm_std_a.com1_pget_pdurxfifofull
    :field user_data_com1_tm_std_a_com1_pget_rxmode: salsat_frame.user_data_com1_tm_std_a.com1_pget_rxmode
    :field user_data_com1_tm_std_a_com1_pget_trxrxovercur: salsat_frame.user_data_com1_tm_std_a.com1_pget_trxrxovercur
    :field user_data_com1_tm_std_a_com1_pget_trxtxovercur: salsat_frame.user_data_com1_tm_std_a.com1_pget_trxtxovercur
    :field com1_pget_initeepromparcompl: salsat_frame.user_data_com1_tm_std_a.com1_pget_initeepromparcompl
    :field user_data_com1_tm_std_a_com1_pget_boolrfu0: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu0
    :field user_data_com1_tm_std_a_com1_pget_boolrfu1: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu1
    :field user_data_com1_tm_std_a_com1_pget_boolrfu2: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu2
    :field user_data_com1_tm_std_a_com1_pget_boolrfu3: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu3
    :field user_data_com1_tm_std_a_com1_pget_boolrfu4: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu4
    :field user_data_com1_tm_std_a_com1_pget_boolrfu5: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu5
    :field user_data_com1_tm_std_a_com1_pget_boolrfu6: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu6
    :field user_data_com1_tm_std_a_com1_pget_anomalyrssi: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalyrssi
    :field user_data_com1_tm_std_a_com1_pget_anomalyrssirx: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalyrssirx
    :field user_data_com1_tm_std_a_com1_pget_anomalycd: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalycd
    :field user_data_com1_tm_std_a_com1_pget_anomalycurtrxrx: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalycurtrxrx
    :field user_data_com1_tm_std_a_com1_pget_anomalycurtrxtx: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalycurtrxtx
    :field user_data_com1_tm_std_a_com1_pget_anomalycur3v3: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalycur3v3
    :field user_data_com1_tm_std_a_com1_pget_anomalyvlttrxrx: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalyvlttrxrx
    :field user_data_com1_tm_std_a_com1_pget_anomalyvlttrxtx: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalyvlttrxtx
    :field user_data_com1_tm_std_a_com1_pget_anomalyvlt3v3: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalyvlt3v3
    :field user_data_com1_tm_std_a_com1_pget_anomalytmptnc: salsat_frame.user_data_com1_tm_std_a.com1_pget_anomalytmptnc
    :field user_data_com1_tm_std_a_com1_pget_boolrfu7: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu7
    :field user_data_com1_tm_std_a_com1_pget_boolrfu8: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu8
    :field user_data_com1_tm_std_a_com1_pget_boolrfu9: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu9
    :field user_data_com1_tm_std_a_com1_pget_boolrfu10: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu10
    :field user_data_com1_tm_std_a_com1_pget_boolrfu11: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu11
    :field user_data_com1_tm_std_a_com1_pget_boolrfu12: salsat_frame.user_data_com1_tm_std_a.com1_pget_boolrfu12
    :field com1_pget_rssi_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_rssi_a
    :field com1_pget_rssirx_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_rssirx_a
    :field com1_pget_cd_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_cd_a
    :field com1_pget_curtrx_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_curtrx_a
    :field com1_pget_curtrxtx_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_curtrxtx_a
    :field com1_pget_cur3v3_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_cur3v3_a
    :field com1_pget_vlttrx_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_vlttrx_a
    :field com1_pget_vlttrxtx_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_vlttrxtx_a
    :field com1_pget_vlt3v3_a: salsat_frame.user_data_com1_tm_std_a.com1_pget_vlt3v3_a
    :field thm_com1_pget_tmptnc_a: salsat_frame.user_data_com1_tm_std_a.thm_com1_pget_tmptnc_a
    :field user_data_com1_tm_std_a_thm_com1_pget_trxtmyreg: salsat_frame.user_data_com1_tm_std_a.thm_com1_pget_trxtmyreg
    :field user_data_com1_tm_std_a_com1_pget_timetoautorecoveryreset: salsat_frame.user_data_com1_tm_std_a.com1_pget_timetoautorecoveryreset
    :field user_data_com4_tm_std_a_com4_pget_resetcnt: salsat_frame.user_data_com4_tm_std_a.com4_pget_resetcnt
    :field user_data_com4_tm_std_a_com4_pget_rxsducnt: salsat_frame.user_data_com4_tm_std_a.com4_pget_rxsducnt
    :field user_data_com4_tm_std_a_com4_pget_rxspducnt: salsat_frame.user_data_com4_tm_std_a.com4_pget_rxspducnt
    :field user_data_com4_tm_std_a_com4_pget_fsmmainstate: salsat_frame.user_data_com4_tm_std_a.com4_pget_fsmmainstate
    :field user_data_com4_tm_std_a_com4_pget_invrxframe: salsat_frame.user_data_com4_tm_std_a.com4_pget_invrxframe
    :field user_data_com4_tm_std_a_com4_pget_comtimeout: salsat_frame.user_data_com4_tm_std_a.com4_pget_comtimeout
    :field user_data_com4_tm_std_a_com4_pget_anomalyenvir: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalyenvir
    :field user_data_com4_tm_std_a_com4_pget_anomalypwr: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalypwr
    :field user_data_com4_tm_std_a_com4_pget_pdurxfifofull: salsat_frame.user_data_com4_tm_std_a.com4_pget_pdurxfifofull
    :field user_data_com4_tm_std_a_com4_pget_rxmode: salsat_frame.user_data_com4_tm_std_a.com4_pget_rxmode
    :field user_data_com4_tm_std_a_com4_pget_trxrxovercur: salsat_frame.user_data_com4_tm_std_a.com4_pget_trxrxovercur
    :field user_data_com4_tm_std_a_com4_pget_trxtxovercur: salsat_frame.user_data_com4_tm_std_a.com4_pget_trxtxovercur
    :field com4_pget_initeepromparcompl: salsat_frame.user_data_com4_tm_std_a.com4_pget_initeepromparcompl
    :field user_data_com4_tm_std_a_com4_pget_boolrfu0: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu0
    :field user_data_com4_tm_std_a_com4_pget_boolrfu1: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu1
    :field user_data_com4_tm_std_a_com4_pget_boolrfu2: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu2
    :field user_data_com4_tm_std_a_com4_pget_boolrfu3: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu3
    :field user_data_com4_tm_std_a_com4_pget_boolrfu4: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu4
    :field user_data_com4_tm_std_a_com4_pget_boolrfu5: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu5
    :field user_data_com4_tm_std_a_com4_pget_boolrfu6: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu6
    :field user_data_com4_tm_std_a_com4_pget_anomalyrssi: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalyrssi
    :field user_data_com4_tm_std_a_com4_pget_anomalyrssirx: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalyrssirx
    :field user_data_com4_tm_std_a_com4_pget_anomalycd: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalycd
    :field user_data_com4_tm_std_a_com4_pget_anomalycur3v3: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalycur3v3
    :field user_data_com4_tm_std_a_com4_pget_anomalyvlt3v3: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalyvlt3v3
    :field user_data_com4_tm_std_a_com4_pget_anomalytmptnc: salsat_frame.user_data_com4_tm_std_a.com4_pget_anomalytmptnc
    :field user_data_com4_tm_std_a_com4_pget_boolrfu7: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu7
    :field user_data_com4_tm_std_a_com4_pget_boolrfu8: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu8
    :field user_data_com4_tm_std_a_com4_pget_boolrfu9: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu9
    :field user_data_com4_tm_std_a_com4_pget_boolrfu10: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu10
    :field user_data_com4_tm_std_a_com4_pget_boolrfu11: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu11
    :field user_data_com4_tm_std_a_com4_pget_boolrfu12: salsat_frame.user_data_com4_tm_std_a.com4_pget_boolrfu12
    :field com4_pget_cur3v3_a: salsat_frame.user_data_com4_tm_std_a.com4_pget_cur3v3_a
    :field com4_pget_vlt3v3_a: salsat_frame.user_data_com4_tm_std_a.com4_pget_vlt3v3_a
    :field thm_com4_pget_tmptnc_a: salsat_frame.user_data_com4_tm_std_a.thm_com4_pget_tmptnc_a
    :field user_data_com4_tm_std_a_com0_pget_timetoautorecoveryreset: salsat_frame.user_data_com4_tm_std_a.com0_pget_timetoautorecoveryreset
    :field user_data_com0_tm_rtc_com0_pget_systime: salsat_frame.user_data_com0_tm_rtc.com0_pget_systime
    :field com0_pget_rtcinitcomplete: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcinitcomplete
    :field com0_pget_rtcinvreg: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcinvreg
    :field com0_pget_rtcspiactive: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcspiactive
    :field com0_pget_rtcspirelease: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcspirelease
    :field com0_pget_rtcconfcomplete: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcconfcomplete
    :field com0_pget_rtcwrtime: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcwrtime
    :field com0_pget_rtcttavailable: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcttavailable
    :field user_data_com0_tm_rtc_com0_pget_boolrfu1: salsat_frame.user_data_com0_tm_rtc.com0_pget_boolrfu1
    :field com0_pget_rtcsec01: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec01
    :field com0_pget_rtcsec001: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec001
    :field com0_pget_rtcsec10: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec10
    :field com0_pget_rtcsec1: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec1
    :field com0_pget_rtcsec01alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec01alarm
    :field com0_pget_rtcsec001alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec001alarm
    :field com0_pget_rtcsec10alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec10alarm
    :field com0_pget_rtcsec1alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec1alarm
    :field com0_pget_rtcmin10: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmin10
    :field com0_pget_rtcmin1: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmin1
    :field com0_pget_rtcmin10alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmin10alarm
    :field com0_pget_rtcmin1alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmin1alarm
    :field com0_pget_rtchour10: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtchour10
    :field com0_pget_rtchour1: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtchour1
    :field com0_pget_rtchour10alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtchour10alarm
    :field com0_pget_rtchour1alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtchour1alarm
    :field com0_pget_rtcday: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcday
    :field com0_pget_rtcdayalarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdayalarm
    :field com0_pget_rtcdate10: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdate10
    :field com0_pget_rtcdate1: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdate1
    :field com0_pget_rtcdate10alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdate10alarm
    :field com0_pget_rtcdate1alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdate1alarm
    :field com0_pget_rtcmonth10: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmonth10
    :field com0_pget_rtcmonth1: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmonth1
    :field com0_pget_rtcyear10: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcyear10
    :field com0_pget_rtcyear1: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcyear1
    :field com0_pget_rtcregcontrol: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcregcontrol
    :field com0_pget_rtcregstatus: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcregstatus
    :field com0_pget_rtcregtricklecharger: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcregtricklecharger
    :field com0_pget_rtc12: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtc12
    :field com0_pget_rtcpm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcpm
    :field com0_pget_rtccentury: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtccentury
    :field com0_pget_rtc12alarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtc12alarm
    :field com0_pget_rtcpmalarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcpmalarm
    :field com0_pget_rtcdyalarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdyalarm
    :field com0_pget_rtcam1: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcam1
    :field com0_pget_rtcam2: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcam2
    :field com0_pget_rtcam3: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcam3
    :field com0_pget_rtcam4: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcam4
    :field user_data_com0_tm_rtc_com0_pget_boolrfu2: salsat_frame.user_data_com0_tm_rtc.com0_pget_boolrfu2
    :field user_data_com0_tm_rtc_com0_pget_boolrfu3: salsat_frame.user_data_com0_tm_rtc.com0_pget_boolrfu3
    :field user_data_com0_tm_rtc_com0_pget_boolrfu4: salsat_frame.user_data_com0_tm_rtc.com0_pget_boolrfu4
    :field user_data_com0_tm_rtc_com0_pget_boolrfu5: salsat_frame.user_data_com0_tm_rtc.com0_pget_boolrfu5
    :field user_data_com0_tm_rtc_com0_pget_boolrfu6: salsat_frame.user_data_com0_tm_rtc.com0_pget_boolrfu6
    :field user_data_com0_tm_rtc_com0_pget_boolrfu7: salsat_frame.user_data_com0_tm_rtc.com0_pget_boolrfu7
    :field com0_pget_rtcyear: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcyear
    :field com0_pget_rtcmonth: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmonth
    :field com0_pget_rtcmin: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcmin
    :field com0_pget_rtcminalarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcminalarm
    :field com0_pget_rtchour: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtchour
    :field com0_pget_rtchouralarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtchouralarm
    :field com0_pget_rtcdate: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdate
    :field com0_pget_rtcdatealarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcdatealarm
    :field com0_pget_rtcsec: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsec
    :field com0_pget_rtcsecalarm: salsat_frame.user_data_com0_tm_rtc.com0_pget_rtcsecalarm
    :field user_data_com1_tm_rtc_com1_pget_systime: salsat_frame.user_data_com1_tm_rtc.com1_pget_systime
    :field com1_pget_rtcinitcomplete: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcinitcomplete
    :field com1_pget_rtcinvreg: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcinvreg
    :field com1_pget_rtcspiactive: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcspiactive
    :field com1_pget_rtcspirelease: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcspirelease
    :field com1_pget_rtcconfcomplete: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcconfcomplete
    :field com1_pget_rtcwrtime: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcwrtime
    :field com1_pget_rtcttavailable: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcttavailable
    :field user_data_com1_tm_rtc_com1_pget_boolrfu1: salsat_frame.user_data_com1_tm_rtc.com1_pget_boolrfu1
    :field com1_pget_rtcsec01: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec01
    :field com1_pget_rtcsec001: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec001
    :field com1_pget_rtcsec10: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec10
    :field com1_pget_rtcsec1: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec1
    :field com1_pget_rtcsec01alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec01alarm
    :field com1_pget_rtcsec001alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec001alarm
    :field com1_pget_rtcsec10alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec10alarm
    :field com1_pget_rtcsec1alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec1alarm
    :field com1_pget_rtcmin10: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmin10
    :field com1_pget_rtcmin1: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmin1
    :field com1_pget_rtcmin10alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmin10alarm
    :field com1_pget_rtcmin1alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmin1alarm
    :field com1_pget_rtchour10: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtchour10
    :field com1_pget_rtchour1: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtchour1
    :field com1_pget_rtchour10alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtchour10alarm
    :field com1_pget_rtchour1alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtchour1alarm
    :field com1_pget_rtcday: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcday
    :field com1_pget_rtcdayalarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdayalarm
    :field com1_pget_rtcdate10: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdate10
    :field com1_pget_rtcdate1: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdate1
    :field com1_pget_rtcdate10alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdate10alarm
    :field com1_pget_rtcdate1alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdate1alarm
    :field com1_pget_rtcmonth10: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmonth10
    :field com1_pget_rtcmonth1: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmonth1
    :field com1_pget_rtcyear10: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcyear10
    :field com1_pget_rtcyear1: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcyear1
    :field com1_pget_rtcregcontrol: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcregcontrol
    :field com1_pget_rtcregstatus: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcregstatus
    :field com1_pget_rtcregtricklecharger: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcregtricklecharger
    :field com1_pget_rtc12: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtc12
    :field com1_pget_rtcpm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcpm
    :field com1_pget_rtccentury: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtccentury
    :field com1_pget_rtc12alarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtc12alarm
    :field com1_pget_rtcpmalarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcpmalarm
    :field com1_pget_rtcdyalarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdyalarm
    :field com1_pget_rtcam1: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcam1
    :field com1_pget_rtcam2: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcam2
    :field com1_pget_rtcam3: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcam3
    :field com1_pget_rtcam4: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcam4
    :field user_data_com1_tm_rtc_com1_pget_boolrfu2: salsat_frame.user_data_com1_tm_rtc.com1_pget_boolrfu2
    :field user_data_com1_tm_rtc_com1_pget_boolrfu3: salsat_frame.user_data_com1_tm_rtc.com1_pget_boolrfu3
    :field user_data_com1_tm_rtc_com1_pget_boolrfu4: salsat_frame.user_data_com1_tm_rtc.com1_pget_boolrfu4
    :field user_data_com1_tm_rtc_com1_pget_boolrfu5: salsat_frame.user_data_com1_tm_rtc.com1_pget_boolrfu5
    :field user_data_com1_tm_rtc_com1_pget_boolrfu6: salsat_frame.user_data_com1_tm_rtc.com1_pget_boolrfu6
    :field user_data_com1_tm_rtc_com1_pget_boolrfu7: salsat_frame.user_data_com1_tm_rtc.com1_pget_boolrfu7
    :field com1_pget_rtcyear: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcyear
    :field com1_pget_rtcmonth: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmonth
    :field com1_pget_rtcmin: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcmin
    :field com1_pget_rtcminalarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcminalarm
    :field com1_pget_rtchour: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtchour
    :field com1_pget_rtchouralarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtchouralarm
    :field com1_pget_rtcdate: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdate
    :field com1_pget_rtcdatealarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcdatealarm
    :field com1_pget_rtcsec: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsec
    :field com1_pget_rtcsecalarm: salsat_frame.user_data_com1_tm_rtc.com1_pget_rtcsecalarm
    :field user_data_com4_tm_rtc_com4_pget_systime: salsat_frame.user_data_com4_tm_rtc.com4_pget_systime
    :field com4_pget_rtcinitcomplete: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcinitcomplete
    :field com4_pget_rtcinvreg: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcinvreg
    :field com4_pget_rtcspiactive: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcspiactive
    :field com4_pget_rtcspirelease: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcspirelease
    :field com4_pget_rtcconfcomplete: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcconfcomplete
    :field com4_pget_rtcwrtime: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcwrtime
    :field com4_pget_rtcttavailable: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcttavailable
    :field user_data_com4_tm_rtc_com4_pget_boolrfu1: salsat_frame.user_data_com4_tm_rtc.com4_pget_boolrfu1
    :field com4_pget_rtcsec01: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec01
    :field com4_pget_rtcsec001: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec001
    :field com4_pget_rtcsec10: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec10
    :field com4_pget_rtcsec1: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec1
    :field com4_pget_rtcsec01alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec01alarm
    :field com4_pget_rtcsec001alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec001alarm
    :field com4_pget_rtcsec10alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec10alarm
    :field com4_pget_rtcsec1alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec1alarm
    :field com4_pget_rtcmin10: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmin10
    :field com4_pget_rtcmin1: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmin1
    :field com4_pget_rtcmin10alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmin10alarm
    :field com4_pget_rtcmin1alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmin1alarm
    :field com4_pget_rtchour10: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtchour10
    :field com4_pget_rtchour1: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtchour1
    :field com4_pget_rtchour10alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtchour10alarm
    :field com4_pget_rtchour1alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtchour1alarm
    :field com4_pget_rtcday: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcday
    :field com4_pget_rtcdayalarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdayalarm
    :field com4_pget_rtcdate10: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdate10
    :field com4_pget_rtcdate1: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdate1
    :field com4_pget_rtcdate10alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdate10alarm
    :field com4_pget_rtcdate1alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdate1alarm
    :field com4_pget_rtcmonth10: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmonth10
    :field com4_pget_rtcmonth1: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmonth1
    :field com4_pget_rtcyear10: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcyear10
    :field com4_pget_rtcyear1: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcyear1
    :field com4_pget_rtcregcontrol: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcregcontrol
    :field com4_pget_rtcregstatus: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcregstatus
    :field com4_pget_rtcregtricklecharger: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcregtricklecharger
    :field com4_pget_rtc12: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtc12
    :field com4_pget_rtcpm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcpm
    :field com4_pget_rtccentury: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtccentury
    :field com4_pget_rtc12alarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtc12alarm
    :field com4_pget_rtcpmalarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcpmalarm
    :field com4_pget_rtcdyalarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdyalarm
    :field com4_pget_rtcam1: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcam1
    :field com4_pget_rtcam2: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcam2
    :field com4_pget_rtcam3: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcam3
    :field com4_pget_rtcam4: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcam4
    :field user_data_com4_tm_rtc_com4_pget_boolrfu2: salsat_frame.user_data_com4_tm_rtc.com4_pget_boolrfu2
    :field user_data_com4_tm_rtc_com4_pget_boolrfu3: salsat_frame.user_data_com4_tm_rtc.com4_pget_boolrfu3
    :field user_data_com4_tm_rtc_com4_pget_boolrfu4: salsat_frame.user_data_com4_tm_rtc.com4_pget_boolrfu4
    :field user_data_com4_tm_rtc_com4_pget_boolrfu5: salsat_frame.user_data_com4_tm_rtc.com4_pget_boolrfu5
    :field user_data_com4_tm_rtc_com4_pget_boolrfu6: salsat_frame.user_data_com4_tm_rtc.com4_pget_boolrfu6
    :field user_data_com4_tm_rtc_com4_pget_boolrfu7: salsat_frame.user_data_com4_tm_rtc.com4_pget_boolrfu7
    :field com4_pget_rtcyear: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcyear
    :field com4_pget_rtcmonth: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmonth
    :field com4_pget_rtcmin: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcmin
    :field com4_pget_rtcminalarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcminalarm
    :field com4_pget_rtchour: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtchour
    :field com4_pget_rtchouralarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtchouralarm
    :field com4_pget_rtcdate: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdate
    :field com4_pget_rtcdatealarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcdatealarm
    :field com4_pget_rtcsec: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsec
    :field com4_pget_rtcsecalarm: salsat_frame.user_data_com4_tm_rtc.com4_pget_rtcsecalarm
    :field eps_pget_s00_cur_solx_pos: salsat_frame.user_data_eps_all_adc.eps_pget_s00_cur_solx_pos
    :field eps_pget_s01_cur_solx_neg: salsat_frame.user_data_eps_all_adc.eps_pget_s01_cur_solx_neg
    :field eps_pget_s02_cur_soly_pos: salsat_frame.user_data_eps_all_adc.eps_pget_s02_cur_soly_pos
    :field eps_pget_s03_cur_soly_neg: salsat_frame.user_data_eps_all_adc.eps_pget_s03_cur_soly_neg
    :field eps_pget_s04_cur_solz_pos: salsat_frame.user_data_eps_all_adc.eps_pget_s04_cur_solz_pos
    :field eps_pget_s05_cur_solz_neg: salsat_frame.user_data_eps_all_adc.eps_pget_s05_cur_solz_neg
    :field eps_pget_s06_v_sol: salsat_frame.user_data_eps_all_adc.eps_pget_s06_v_sol
    :field eps_pget_s07_a_mc: salsat_frame.user_data_eps_all_adc.eps_pget_s07_a_mc
    :field eps_pget_s08_a_mcz: salsat_frame.user_data_eps_all_adc.eps_pget_s08_a_mcz
    :field eps_pget_s09_a_mcy: salsat_frame.user_data_eps_all_adc.eps_pget_s09_a_mcy
    :field eps_pget_s10_a_mcx: salsat_frame.user_data_eps_all_adc.eps_pget_s10_a_mcx
    :field eps_pget_s11_a_rw0: salsat_frame.user_data_eps_all_adc.eps_pget_s11_a_rw0
    :field eps_pget_s12_a_in_bat1: salsat_frame.user_data_eps_all_adc.eps_pget_s12_a_in_bat1
    :field eps_pget_s13_v_bat1: salsat_frame.user_data_eps_all_adc.eps_pget_s13_v_bat1
    :field eps_pget_s14_a_out_charger1: salsat_frame.user_data_eps_all_adc.eps_pget_s14_a_out_charger1
    :field thm_pget_s15_th_bat1: salsat_frame.user_data_eps_all_adc.thm_pget_s15_th_bat1
    :field eps_pget_s16_a_rw1: salsat_frame.user_data_eps_all_adc.eps_pget_s16_a_rw1
    :field eps_pget_s17_a_rw2: salsat_frame.user_data_eps_all_adc.eps_pget_s17_a_rw2
    :field eps_pget_s18_a_trx0: salsat_frame.user_data_eps_all_adc.eps_pget_s18_a_trx0
    :field eps_pget_s19_a_slink: salsat_frame.user_data_eps_all_adc.eps_pget_s19_a_slink
    :field eps_pget_s20_a_out_bat1: salsat_frame.user_data_eps_all_adc.eps_pget_s20_a_out_bat1
    :field thm_pget_s21_th_charger1: salsat_frame.user_data_eps_all_adc.thm_pget_s21_th_charger1
    :field eps_pget_s22_v_sum: salsat_frame.user_data_eps_all_adc.eps_pget_s22_v_sum
    :field eps_pget_s23_a_in_charger1: salsat_frame.user_data_eps_all_adc.eps_pget_s23_a_in_charger1
    :field eps_pget_s24_v_bat0: salsat_frame.user_data_eps_all_adc.eps_pget_s24_v_bat0
    :field eps_pget_s25_a_out_charger0: salsat_frame.user_data_eps_all_adc.eps_pget_s25_a_out_charger0
    :field eps_pget_s26_a_in_charger0: salsat_frame.user_data_eps_all_adc.eps_pget_s26_a_in_charger0
    :field eps_pget_s27_a_sens0: salsat_frame.user_data_eps_all_adc.eps_pget_s27_a_sens0
    :field thm_pget_s28_th_charger0: salsat_frame.user_data_eps_all_adc.thm_pget_s28_th_charger0
    :field eps_pget_s29_a_out_bat0: salsat_frame.user_data_eps_all_adc.eps_pget_s29_a_out_bat0
    :field eps_pget_s30_a_in_bat0: salsat_frame.user_data_eps_all_adc.eps_pget_s30_a_in_bat0
    :field thm_pget_s31_th_bat0: salsat_frame.user_data_eps_all_adc.thm_pget_s31_th_bat0
    :field eps_pget_s32_a_pdh0: salsat_frame.user_data_eps_all_adc.eps_pget_s32_a_pdh0
    :field eps_pget_s33_a_pdh1: salsat_frame.user_data_eps_all_adc.eps_pget_s33_a_pdh1
    :field eps_pget_s34_a_tnc0: salsat_frame.user_data_eps_all_adc.eps_pget_s34_a_tnc0
    :field eps_pget_s35_a_tnc1: salsat_frame.user_data_eps_all_adc.eps_pget_s35_a_tnc1
    :field eps_pget_s36_a_sens1: salsat_frame.user_data_eps_all_adc.eps_pget_s36_a_sens1
    :field eps_pget_s37_a_iso_mult0: salsat_frame.user_data_eps_all_adc.eps_pget_s37_a_iso_mult0
    :field eps_pget_s38_a_iso_mult1: salsat_frame.user_data_eps_all_adc.eps_pget_s38_a_iso_mult1
    :field eps_pget_s39_a_sun1: salsat_frame.user_data_eps_all_adc.eps_pget_s39_a_sun1
    :field eps_pget_s40_a_trx1: salsat_frame.user_data_eps_all_adc.eps_pget_s40_a_trx1
    :field eps_pget_s41_a_res: salsat_frame.user_data_eps_all_adc.eps_pget_s41_a_res
    :field eps_pget_s42_a_tempsens: salsat_frame.user_data_eps_all_adc.eps_pget_s42_a_tempsens
    :field eps_pget_s43_v_in_dcdc_b: salsat_frame.user_data_eps_all_adc.eps_pget_s43_v_in_dcdc_b
    :field eps_pget_s44_v_3v3: salsat_frame.user_data_eps_all_adc.eps_pget_s44_v_3v3
    :field eps_pget_s45_v_5v: salsat_frame.user_data_eps_all_adc.eps_pget_s45_v_5v
    :field eps_pget_s46_v_in_dcdc_a: salsat_frame.user_data_eps_all_adc.eps_pget_s46_v_in_dcdc_a
    :field eps_pget_s47_a_sun0: salsat_frame.user_data_eps_all_adc.eps_pget_s47_a_sun0
    :field thm_pget_adc0_temperature: salsat_frame.user_data_eps_all_adc.thm_pget_adc0_temperature
    :field thm_pget_adc1_temperature: salsat_frame.user_data_eps_all_adc.thm_pget_adc1_temperature
    :field thm_pget_adc2_temperature: salsat_frame.user_data_eps_all_adc.thm_pget_adc2_temperature
    :field thm_pget_th_obc: salsat_frame.user_data_eps_int_adc.thm_pget_th_obc
    :field eps_pget_a_obc: salsat_frame.user_data_eps_int_adc.eps_pget_a_obc
    :field eps_pget_v_obc: salsat_frame.user_data_eps_int_adc.eps_pget_v_obc
    :field thm_pget_th_stm: salsat_frame.user_data_eps_int_adc.thm_pget_th_stm
    :field eps_pget_main_3v3_0: salsat_frame.user_data_eps_switch_state.eps_pget_main_3v3_0
    :field eps_pget_main_3v3_1: salsat_frame.user_data_eps_switch_state.eps_pget_main_3v3_1
    :field eps_pget_heat_1: salsat_frame.user_data_eps_switch_state.eps_pget_heat_1
    :field eps_pget_heat_0: salsat_frame.user_data_eps_switch_state.eps_pget_heat_0
    :field eps_pget_reserve: salsat_frame.user_data_eps_switch_state.eps_pget_reserve
    :field eps_pget_trx1: salsat_frame.user_data_eps_switch_state.eps_pget_trx1
    :field eps_pget_trx0: salsat_frame.user_data_eps_switch_state.eps_pget_trx0
    :field eps_pget_sun0: salsat_frame.user_data_eps_switch_state.eps_pget_sun0
    :field eps_pget_sun1: salsat_frame.user_data_eps_switch_state.eps_pget_sun1
    :field eps_pget_iso_mult1: salsat_frame.user_data_eps_switch_state.eps_pget_iso_mult1
    :field eps_pget_iso_mult0: salsat_frame.user_data_eps_switch_state.eps_pget_iso_mult0
    :field eps_pget_tnc1: salsat_frame.user_data_eps_switch_state.eps_pget_tnc1
    :field eps_pget_tnc0: salsat_frame.user_data_eps_switch_state.eps_pget_tnc0
    :field eps_pget_pdh1: salsat_frame.user_data_eps_switch_state.eps_pget_pdh1
    :field eps_pget_tempsens: salsat_frame.user_data_eps_switch_state.eps_pget_tempsens
    :field eps_pget_pdh0: salsat_frame.user_data_eps_switch_state.eps_pget_pdh0
    :field eps_pget_rw2_pwr: salsat_frame.user_data_eps_switch_state.eps_pget_rw2_pwr
    :field eps_pget_rw1_pwr: salsat_frame.user_data_eps_switch_state.eps_pget_rw1_pwr
    :field eps_pget_rw0_pwr: salsat_frame.user_data_eps_switch_state.eps_pget_rw0_pwr
    :field eps_pget_sens0: salsat_frame.user_data_eps_switch_state.eps_pget_sens0
    :field eps_pget_sens1: salsat_frame.user_data_eps_switch_state.eps_pget_sens1
    :field eps_pget_mcx: salsat_frame.user_data_eps_switch_state.eps_pget_mcx
    :field eps_pget_mcy: salsat_frame.user_data_eps_switch_state.eps_pget_mcy
    :field eps_pget_mcz: salsat_frame.user_data_eps_switch_state.eps_pget_mcz
    :field eps_pget_mc_main: salsat_frame.user_data_eps_switch_state.eps_pget_mc_main
    :field eps_pget_main_unreg0: salsat_frame.user_data_eps_switch_state.eps_pget_main_unreg0
    :field eps_pget_main_unreg1: salsat_frame.user_data_eps_switch_state.eps_pget_main_unreg1
    :field eps_pget_charger0: salsat_frame.user_data_eps_switch_state.eps_pget_charger0
    :field eps_pget_charger1: salsat_frame.user_data_eps_switch_state.eps_pget_charger1
    :field eps_pget_dcdc_a: salsat_frame.user_data_eps_switch_state.eps_pget_dcdc_a
    :field eps_pget_dcdc_b: salsat_frame.user_data_eps_switch_state.eps_pget_dcdc_b
    :field eps_pget_lb_pwr: salsat_frame.user_data_eps_switch_state.eps_pget_lb_pwr
    :field eps_pget_rw0_wde: salsat_frame.user_data_eps_switch_state.eps_pget_rw0_wde
    :field eps_pget_rw1_wde: salsat_frame.user_data_eps_switch_state.eps_pget_rw1_wde
    :field eps_pget_rw2_wde: salsat_frame.user_data_eps_switch_state.eps_pget_rw2_wde
    :field eps_pget_sw35_unused: salsat_frame.user_data_eps_switch_state.eps_pget_sw35_unused
    :field eps_pget_dcdc_a_err: salsat_frame.user_data_eps_switch_state.eps_pget_dcdc_a_err
    :field eps_pget_dcdc_b_err: salsat_frame.user_data_eps_switch_state.eps_pget_dcdc_b_err
    :field eps_pget_charger0_err: salsat_frame.user_data_eps_switch_state.eps_pget_charger0_err
    :field eps_pget_charger1_err: salsat_frame.user_data_eps_switch_state.eps_pget_charger1_err
    :field eps_pget_runtime: salsat_frame.user_data_eps_thread_info.eps_pget_runtime
    :field eps_pget_imalivecounter: salsat_frame.user_data_eps_thread_info.eps_pget_imalivecounter
    :field eps_pget_periodcounter: salsat_frame.user_data_eps_thread_info.eps_pget_periodcounter
    :field eps_pget_unfinishedcounter: salsat_frame.user_data_eps_thread_info.eps_pget_unfinishedcounter
    :field eps_pget_buffertime: salsat_frame.user_data_eps_thread_info.eps_pget_buffertime
    :field eps_pget_realalgotime: salsat_frame.user_data_eps_thread_info.eps_pget_realalgotime
    :field user_data_eps_std_tm_eps_pget_s00_cur_solx_pos: salsat_frame.user_data_eps_std_tm.eps_pget_s00_cur_solx_pos
    :field user_data_eps_std_tm_eps_pget_s01_cur_solx_neg: salsat_frame.user_data_eps_std_tm.eps_pget_s01_cur_solx_neg
    :field user_data_eps_std_tm_eps_pget_s02_cur_soly_pos: salsat_frame.user_data_eps_std_tm.eps_pget_s02_cur_soly_pos
    :field user_data_eps_std_tm_eps_pget_s03_cur_soly_neg: salsat_frame.user_data_eps_std_tm.eps_pget_s03_cur_soly_neg
    :field user_data_eps_std_tm_eps_pget_s04_cur_solz_pos: salsat_frame.user_data_eps_std_tm.eps_pget_s04_cur_solz_pos
    :field user_data_eps_std_tm_eps_pget_s05_cur_solz_neg: salsat_frame.user_data_eps_std_tm.eps_pget_s05_cur_solz_neg
    :field user_data_eps_std_tm_eps_pget_s06_v_sol: salsat_frame.user_data_eps_std_tm.eps_pget_s06_v_sol
    :field user_data_eps_std_tm_eps_pget_s24_v_bat0: salsat_frame.user_data_eps_std_tm.eps_pget_s24_v_bat0
    :field user_data_eps_std_tm_eps_pget_s26_a_in_charger0: salsat_frame.user_data_eps_std_tm.eps_pget_s26_a_in_charger0
    :field user_data_eps_std_tm_eps_pget_s25_a_out_charger0: salsat_frame.user_data_eps_std_tm.eps_pget_s25_a_out_charger0
    :field user_data_eps_std_tm_eps_pget_s13_v_bat1: salsat_frame.user_data_eps_std_tm.eps_pget_s13_v_bat1
    :field user_data_eps_std_tm_eps_pget_s23_a_in_charger1: salsat_frame.user_data_eps_std_tm.eps_pget_s23_a_in_charger1
    :field user_data_eps_std_tm_eps_pget_s14_a_out_charger1: salsat_frame.user_data_eps_std_tm.eps_pget_s14_a_out_charger1
    :field user_data_eps_std_tm_eps_pget_s22_v_sum: salsat_frame.user_data_eps_std_tm.eps_pget_s22_v_sum
    :field user_data_eps_std_tm_eps_pget_s44_v_3v3: salsat_frame.user_data_eps_std_tm.eps_pget_s44_v_3v3
    :field user_data_eps_std_tm_eps_pget_s45_v_5v: salsat_frame.user_data_eps_std_tm.eps_pget_s45_v_5v
    :field user_data_eps_std_tm_thm_pget_s31_th_bat0: salsat_frame.user_data_eps_std_tm.thm_pget_s31_th_bat0
    :field user_data_eps_std_tm_thm_pget_s15_th_bat1: salsat_frame.user_data_eps_std_tm.thm_pget_s15_th_bat1
    :field user_data_eps_std_tm_thm_pget_th_obc: salsat_frame.user_data_eps_std_tm.thm_pget_th_obc
    :field user_data_eps_std_tm_eps_pget_a_obc: salsat_frame.user_data_eps_std_tm.eps_pget_a_obc
    :field user_data_eps_std_tm_eps_pget_v_obc: salsat_frame.user_data_eps_std_tm.eps_pget_v_obc
    :field user_data_eps_std_tm_eps_pget_s30_a_in_bat0: salsat_frame.user_data_eps_std_tm.eps_pget_s30_a_in_bat0
    :field user_data_eps_std_tm_eps_pget_s29_a_out_bat0: salsat_frame.user_data_eps_std_tm.eps_pget_s29_a_out_bat0
    :field user_data_eps_std_tm_eps_pget_s12_a_in_bat1: salsat_frame.user_data_eps_std_tm.eps_pget_s12_a_in_bat1
    :field user_data_eps_std_tm_eps_pget_s20_a_out_bat1: salsat_frame.user_data_eps_std_tm.eps_pget_s20_a_out_bat1
    :field user_data_eps_ext_tm_a_eps_pget_s18_a_trx0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s18_a_trx0
    :field user_data_eps_ext_tm_a_eps_pget_s40_a_trx1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s40_a_trx1
    :field user_data_eps_ext_tm_a_eps_pget_s34_a_tnc0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s34_a_tnc0
    :field user_data_eps_ext_tm_a_eps_pget_s35_a_tnc1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s35_a_tnc1
    :field user_data_eps_ext_tm_a_eps_pget_s47_a_sun0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s47_a_sun0
    :field user_data_eps_ext_tm_a_eps_pget_s39_a_sun1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s39_a_sun1
    :field user_data_eps_ext_tm_a_eps_pget_s27_a_sens0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s27_a_sens0
    :field user_data_eps_ext_tm_a_eps_pget_s36_a_sens1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s36_a_sens1
    :field user_data_eps_ext_tm_a_thm_pget_s28_th_charger0: salsat_frame.user_data_eps_ext_tm_a.thm_pget_s28_th_charger0
    :field user_data_eps_ext_tm_a_thm_pget_s21_th_charger1: salsat_frame.user_data_eps_ext_tm_a.thm_pget_s21_th_charger1
    :field user_data_eps_ext_tm_a_eps_pget_main_3v3_0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_main_3v3_0
    :field user_data_eps_ext_tm_a_eps_pget_main_3v3_1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_main_3v3_1
    :field user_data_eps_ext_tm_a_eps_pget_trx0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_trx0
    :field user_data_eps_ext_tm_a_eps_pget_trx1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_trx1
    :field user_data_eps_ext_tm_a_eps_pget_sun0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_sun0
    :field user_data_eps_ext_tm_a_eps_pget_sun1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_sun1
    :field user_data_eps_ext_tm_a_eps_pget_iso_mult0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_iso_mult0
    :field user_data_eps_ext_tm_a_eps_pget_iso_mult1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_iso_mult1
    :field user_data_eps_ext_tm_a_eps_pget_pdh0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_pdh0
    :field user_data_eps_ext_tm_a_eps_pget_pdh1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_pdh1
    :field user_data_eps_ext_tm_a_eps_pget_tnc0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_tnc0
    :field user_data_eps_ext_tm_a_eps_pget_tnc1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_tnc1
    :field user_data_eps_ext_tm_a_eps_pget_sens0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_sens0
    :field user_data_eps_ext_tm_a_eps_pget_sens1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_sens1
    :field user_data_eps_ext_tm_a_eps_pget_rw0_pwr: salsat_frame.user_data_eps_ext_tm_a.eps_pget_rw0_pwr
    :field user_data_eps_ext_tm_a_eps_pget_rw1_pwr: salsat_frame.user_data_eps_ext_tm_a.eps_pget_rw1_pwr
    :field user_data_eps_ext_tm_a_eps_pget_rw2_pwr: salsat_frame.user_data_eps_ext_tm_a.eps_pget_rw2_pwr
    :field user_data_eps_ext_tm_a_eps_pget_main_unreg0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_main_unreg0
    :field user_data_eps_ext_tm_a_eps_pget_main_unreg1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_main_unreg1
    :field user_data_eps_ext_tm_a_eps_pget_charger0: salsat_frame.user_data_eps_ext_tm_a.eps_pget_charger0
    :field user_data_eps_ext_tm_a_eps_pget_charger1: salsat_frame.user_data_eps_ext_tm_a.eps_pget_charger1
    :field user_data_eps_ext_tm_a_eps_pget_dcdc_a: salsat_frame.user_data_eps_ext_tm_a.eps_pget_dcdc_a
    :field user_data_eps_ext_tm_a_eps_pget_dcdc_b: salsat_frame.user_data_eps_ext_tm_a.eps_pget_dcdc_b
    :field user_data_eps_ext_tm_a_eps_pget_rw0_wde: salsat_frame.user_data_eps_ext_tm_a.eps_pget_rw0_wde
    :field user_data_eps_ext_tm_a_eps_pget_rw1_wde: salsat_frame.user_data_eps_ext_tm_a.eps_pget_rw1_wde
    :field user_data_eps_ext_tm_a_eps_pget_rw2_wde: salsat_frame.user_data_eps_ext_tm_a.eps_pget_rw2_wde
    :field user_data_eps_ext_tm_a_eps_pget_mc_main: salsat_frame.user_data_eps_ext_tm_a.eps_pget_mc_main
    :field user_data_eps_ext_tm_a_eps_pget_mcx: salsat_frame.user_data_eps_ext_tm_a.eps_pget_mcx
    :field user_data_eps_ext_tm_a_eps_pget_mcy: salsat_frame.user_data_eps_ext_tm_a.eps_pget_mcy
    :field user_data_eps_ext_tm_a_eps_pget_mcz: salsat_frame.user_data_eps_ext_tm_a.eps_pget_mcz
    :field user_data_eps_ext_tm_a_eps_pget_reserve: salsat_frame.user_data_eps_ext_tm_a.eps_pget_reserve
    :field user_data_eps_ext_tm_a_eps_pget_tempsens: salsat_frame.user_data_eps_ext_tm_a.eps_pget_tempsens
    :field user_data_eps_ext_tm_a_eps_pget_dcdc_a_err: salsat_frame.user_data_eps_ext_tm_a.eps_pget_dcdc_a_err
    :field user_data_eps_ext_tm_a_eps_pget_s46_v_in_dcdc_a: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s46_v_in_dcdc_a
    :field user_data_eps_ext_tm_a_eps_pget_s43_v_in_dcdc_b: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s43_v_in_dcdc_b
    :field user_data_eps_ext_tm_a_eps_pget_s42_a_tempsens: salsat_frame.user_data_eps_ext_tm_a.eps_pget_s42_a_tempsens
    :field user_data_eps_ext_tm_a_eps_pget_realalgotime: salsat_frame.user_data_eps_ext_tm_a.eps_pget_realalgotime
    :field user_data_eps_ext_tm_b_eps_pget_heat_0: salsat_frame.user_data_eps_ext_tm_b.eps_pget_heat_0
    :field user_data_eps_ext_tm_b_eps_pget_heat_1: salsat_frame.user_data_eps_ext_tm_b.eps_pget_heat_1
    :field user_data_eps_ext_tm_b_eps_pget_lb_pwr: salsat_frame.user_data_eps_ext_tm_b.eps_pget_lb_pwr
    :field eps_pget_ant0rel: salsat_frame.user_data_eps_ext_tm_b.eps_pget_ant0rel
    :field eps_pget_ant1rel: salsat_frame.user_data_eps_ext_tm_b.eps_pget_ant1rel
    :field user_data_eps_ext_tm_b_eps_pget_dcdc_b_err: salsat_frame.user_data_eps_ext_tm_b.eps_pget_dcdc_b_err
    :field user_data_eps_ext_tm_b_eps_pget_charger0_err: salsat_frame.user_data_eps_ext_tm_b.eps_pget_charger0_err
    :field user_data_eps_ext_tm_b_eps_pget_charger1_err: salsat_frame.user_data_eps_ext_tm_b.eps_pget_charger1_err
    :field user_data_eps_ext_tm_b_eps_pget_s07_a_mc: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s07_a_mc
    :field user_data_eps_ext_tm_b_eps_pget_s10_a_mcx: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s10_a_mcx
    :field user_data_eps_ext_tm_b_eps_pget_s09_a_mcy: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s09_a_mcy
    :field user_data_eps_ext_tm_b_eps_pget_s08_a_mcz: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s08_a_mcz
    :field user_data_eps_ext_tm_b_eps_pget_s11_a_rw0: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s11_a_rw0
    :field user_data_eps_ext_tm_b_eps_pget_s16_a_rw1: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s16_a_rw1
    :field user_data_eps_ext_tm_b_eps_pget_s17_a_rw2: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s17_a_rw2
    :field user_data_eps_ext_tm_b_eps_pget_s19_a_slink: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s19_a_slink
    :field user_data_eps_ext_tm_b_eps_pget_s32_a_pdh0: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s32_a_pdh0
    :field user_data_eps_ext_tm_b_eps_pget_s33_a_pdh1: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s33_a_pdh1
    :field user_data_eps_ext_tm_b_eps_pget_s37_a_iso_mult0: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s37_a_iso_mult0
    :field user_data_eps_ext_tm_b_eps_pget_s38_a_iso_mult1: salsat_frame.user_data_eps_ext_tm_b.eps_pget_s38_a_iso_mult1
    :field eps_pget_adcuseflag: salsat_frame.user_data_eps_ext_tm_b.eps_pget_adcuseflag
    :field eps_pget_analyzereactepsirqs: salsat_frame.user_data_eps_ext_tm_b.eps_pget_analyzereactepsirqs
    :field eps_irq_pget_subsysirqonoff: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_subsysirqonoff
    :field eps_irq_pget_dcdcairqonoff: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_dcdcairqonoff
    :field eps_irq_pget_dcdcbirqonoff: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_dcdcbirqonoff
    :field eps_irq_pget_charger0irqonoff: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_charger0irqonoff
    :field eps_irq_pget_charger1irqonoff: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_charger1irqonoff
    :field eps_irq_pget_subsysovercurrcounter: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_subsysovercurrcounter
    :field eps_irq_pget_dcdcaerrorcounter: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_dcdcaerrorcounter
    :field eps_irq_pget_dcdcberrorcounter: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_dcdcberrorcounter
    :field eps_irq_pget_charger0errorcounter: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_charger0errorcounter
    :field eps_irq_pget_charger1errorcounter: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_charger1errorcounter
    :field eps_irq_pget_solarundervoltagecounter: salsat_frame.user_data_eps_ext_tm_b.eps_irq_pget_solarundervoltagecounter
    :field eps_pget_s00_cur_solx_pos_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s00_cur_solx_pos_raw
    :field eps_pget_s01_cur_solx_neg_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s01_cur_solx_neg_raw
    :field eps_pget_s02_cur_soly_pos_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s02_cur_soly_pos_raw
    :field eps_pget_s03_cur_soly_neg_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s03_cur_soly_neg_raw
    :field eps_pget_s04_cur_solz_pos_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s04_cur_solz_pos_raw
    :field eps_pget_s05_cur_solz_neg_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s05_cur_solz_neg_raw
    :field eps_pget_s06_v_sol_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s06_v_sol_raw
    :field eps_pget_s07_a_mc_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s07_a_mc_raw
    :field eps_pget_s08_a_mcz_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s08_a_mcz_raw
    :field eps_pget_s09_a_mcy_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s09_a_mcy_raw
    :field eps_pget_s10_a_mcx_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s10_a_mcx_raw
    :field eps_pget_s11_a_rw0_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s11_a_rw0_raw
    :field eps_pget_s12_a_in_bat1_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s12_a_in_bat1_raw
    :field eps_pget_s13_v_bat1_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s13_v_bat1_raw
    :field eps_pget_s14_a_out_charger1_raw: salsat_frame.user_data_eps_rawadc0values.eps_pget_s14_a_out_charger1_raw
    :field thm_pget_s15_th_bat1_raw: salsat_frame.user_data_eps_rawadc0values.thm_pget_s15_th_bat1_raw
    :field eps_pget_s16_a_rw1_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s16_a_rw1_raw
    :field eps_pget_s17_a_rw2_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s17_a_rw2_raw
    :field eps_pget_s18_a_trx0_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s18_a_trx0_raw
    :field eps_pget_s19_a_slink_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s19_a_slink_raw
    :field eps_pget_s20_a_out_bat1_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s20_a_out_bat1_raw
    :field thm_pget_s21_th_charger1_raw: salsat_frame.user_data_eps_rawadc1values.thm_pget_s21_th_charger1_raw
    :field eps_pget_s22_v_sum_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s22_v_sum_raw
    :field eps_pget_s23_a_in_charger1_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s23_a_in_charger1_raw
    :field eps_pget_s24_v_bat0_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s24_v_bat0_raw
    :field eps_pget_s25_a_out_charger0_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s25_a_out_charger0_raw
    :field eps_pget_s26_a_in_charger0_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s26_a_in_charger0_raw
    :field eps_pget_s27_a_sens0_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s27_a_sens0_raw
    :field thm_pget_s28_th_charger0_raw: salsat_frame.user_data_eps_rawadc1values.thm_pget_s28_th_charger0_raw
    :field eps_pget_s29_a_out_bat0_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s29_a_out_bat0_raw
    :field eps_pget_s30_a_in_bat0_raw: salsat_frame.user_data_eps_rawadc1values.eps_pget_s30_a_in_bat0_raw
    :field thm_pget_s31_th_bat0_raw: salsat_frame.user_data_eps_rawadc1values.thm_pget_s31_th_bat0_raw
    :field eps_pget_s32_a_pdh0_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s32_a_pdh0_raw
    :field eps_pget_s33_a_pdh1_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s33_a_pdh1_raw
    :field eps_pget_s34_a_tnc0_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s34_a_tnc0_raw
    :field eps_pget_s35_a_tnc1_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s35_a_tnc1_raw
    :field eps_pget_s36_a_sens1_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s36_a_sens1_raw
    :field eps_pget_s37_a_iso_mult0_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s37_a_iso_mult0_raw
    :field eps_pget_s38_a_iso_mult1_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s38_a_iso_mult1_raw
    :field eps_pget_s39_a_sun1_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s39_a_sun1_raw
    :field eps_pget_s40_a_trx1_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s40_a_trx1_raw
    :field eps_pget_s41_a_res_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s41_a_res_raw
    :field eps_pget_s42_a_tempsens_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s42_a_tempsens_raw
    :field eps_pget_s43_v_in_dcdc_b_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s43_v_in_dcdc_b_raw
    :field eps_pget_s44_v_3v3_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s44_v_3v3_raw
    :field eps_pget_s45_v_5v_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s45_v_5v_raw
    :field eps_pget_s46_v_dcdc_a_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s46_v_dcdc_a_raw
    :field eps_pget_s47_a_sun0_raw: salsat_frame.user_data_eps_rawadc2values.eps_pget_s47_a_sun0_raw
    :field user_data_eps_rawthm_thm_pget_s15_th_bat1_raw: salsat_frame.user_data_eps_rawthm.thm_pget_s15_th_bat1_raw
    :field user_data_eps_rawthm_thm_pget_s21_th_charger1_raw: salsat_frame.user_data_eps_rawthm.thm_pget_s21_th_charger1_raw
    :field user_data_eps_rawthm_thm_pget_s28_th_charger0_raw: salsat_frame.user_data_eps_rawthm.thm_pget_s28_th_charger0_raw
    :field user_data_eps_rawthm_thm_pget_s31_th_bat0_raw: salsat_frame.user_data_eps_rawthm.thm_pget_s31_th_bat0_raw
    :field thm_pget_th_stm_raw: salsat_frame.user_data_eps_rawthm.thm_pget_th_stm_raw
    :field user_data_salsa_fw_std_tm_sat_pget_obc_act: salsat_frame.user_data_salsa_fw_std_tm.sat_pget_obc_act
    :field user_data_salsa_fw_std_tm_sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_salsa_fw_std_tm.sat_pget_fw_updater_activeslotnum
    :field user_data_salsa_fw_std_tm_sat_pget_selectedslotnum: salsat_frame.user_data_salsa_fw_std_tm.sat_pget_selectedslotnum
    :field user_data_salsa_fw_std_tm_sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_salsa_fw_std_tm.sat_pget_currentlyrunningsoftwareslot
    :field user_data_salsa_fw_std_tm_sat_pget_realalgotime: salsat_frame.user_data_salsa_fw_std_tm.sat_pget_realalgotime
    :field user_data_salsa_fw_update_tm_sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_currentlyrunningsoftwareslot
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_state: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_state
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_activeslotnum
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_tmpimgaddr: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_tmpimgaddr
    :field user_data_salsa_fw_update_tm_sat_pget_selectedslotnum: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_selectedslotnum
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slotnumundererase: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slotnumundererase
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slotnumundercrc: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slotnumundercrc
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_activeimagelength: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_activeimagelength
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_numwrittensequences: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_numwrittensequences
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_nextexpectedsequence: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_nextexpectedsequence
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_totalmissingsequences: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_totalmissingsequences
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_missingsequenceswriteidx: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_missingsequenceswriteidx
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slot0_isfree
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slot1_isfree
    :field user_data_salsa_fw_update_tm_sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_salsa_fw_update_tm.sat_pget_fw_updater_slot2_isfree
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot0_isfree
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot1_isfree
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot2_isfree
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot0_isundererase: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot0_isundererase
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot1_isundererase: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot1_isundererase
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot2_isundererase: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot2_isundererase
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot0_ishealthy: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot0_ishealthy
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot1_ishealthy: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot1_ishealthy
    :field user_data_salsa_fw_update_slot_tm_sat_pget_fw_updater_slot2_ishealthy: salsat_frame.user_data_salsa_fw_update_slot_tm.sat_pget_fw_updater_slot2_ishealthy
    :field user_data_salsa_fw_update_missingintervalls_sat_pget_fw_updater_missingsequencestartarray: salsat_frame.user_data_salsa_fw_update_missingintervalls.sat_pget_fw_updater_missingsequencestartarray
    :field user_data_salsa_fw_update_missingintervalls_sat_pget_fw_updater_missingsequenceendarray: salsat_frame.user_data_salsa_fw_update_missingintervalls.sat_pget_fw_updater_missingsequenceendarray
    :field salsa_pget_flash1_status: salsat_frame.user_data_salsa_tm_flash_status.salsa_pget_flash1_status
    :field salsa_pget_flash2_status: salsat_frame.user_data_salsa_tm_flash_status.salsa_pget_flash2_status
    :field salsa_pget_flash1_be_in_progress: salsat_frame.user_data_salsa_tm_flash_status.salsa_pget_flash1_be_in_progress
    :field salsa_pget_flash2_be_in_progress: salsat_frame.user_data_salsa_tm_flash_status.salsa_pget_flash2_be_in_progress
    :field salsa_pget_flash1_se_in_progress: salsat_frame.user_data_salsa_tm_flash_status.salsa_pget_flash1_se_in_progress
    :field salsa_pget_flash2_se_in_progress: salsat_frame.user_data_salsa_tm_flash_status.salsa_pget_flash2_se_in_progress
    :field salsa_pget_fpga_boot_slot: salsat_frame.user_data_salsa_tm_flash_status.salsa_pget_fpga_boot_slot
    :field salsa_pget_lms_calib_valid_a1: salsat_frame.user_data_salsa_tm_pmu_regs_valid.salsa_pget_lms_calib_valid_a1
    :field salsa_pget_lms_calib_valid_b1: salsat_frame.user_data_salsa_tm_pmu_regs_valid.salsa_pget_lms_calib_valid_b1
    :field salsa_pget_lms_regs_valid_a1: salsat_frame.user_data_salsa_tm_pmu_regs_valid.salsa_pget_lms_regs_valid_a1
    :field salsa_pget_lms_regs_valid_b1: salsat_frame.user_data_salsa_tm_pmu_regs_valid.salsa_pget_lms_regs_valid_b1
    :field salsa_pget_clk_regs_valid_a1: salsat_frame.user_data_salsa_tm_pmu_regs_valid.salsa_pget_clk_regs_valid_a1
    :field salsa_pget_clk_regs_valid_b1: salsat_frame.user_data_salsa_tm_pmu_regs_valid.salsa_pget_clk_regs_valid_b1
    :field salsa_pget_clk_conf: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_clk_conf
    :field salsa_pget_fpga_conf: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_fpga_conf
    :field salsa_pget_fpga_init_done: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_fpga_init_done
    :field salsa_pget_lms_conf: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_lms_conf
    :field salsa_pget_lms_calibrated: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_lms_calibrated
    :field salsa_pget_fft_size: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_fft_size
    :field salsa_pget_fft_window: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_fft_window
    :field salsa_pget_fft_decim: salsat_frame.user_data_salsa_tm_boot_status.salsa_pget_fft_decim
    :field salsa_pget_pmua1_status: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmua1_status
    :field salsa_pget_pmub1_status: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmub1_status
    :field salsa_pget_pmua2_status: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmua2_status
    :field salsa_pget_pmub2_status: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmub2_status
    :field salsa_pget_pmua_be_in_progress: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmua_be_in_progress
    :field salsa_pget_pmub_be_in_progress: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmub_be_in_progress
    :field salsa_pget_pmua_se_in_progress: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmua_se_in_progress
    :field salsa_pget_pmub_se_in_progress: salsat_frame.user_data_salsa_tm_pmu_status.salsa_pget_pmub_se_in_progress
    :field salsa_pget_lms_pmua_user: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_lms_pmua_user
    :field salsa_pget_lms_pmua_mode: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_lms_pmua_mode
    :field salsa_pget_pmub_user: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_pmub_user
    :field salsa_pget_pmub_mode: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_pmub_mode
    :field salsa_pget_fpga_user: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_fpga_user
    :field salsa_pget_fpga_mode: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_fpga_mode
    :field salsa_pget_flash_user: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_flash_user
    :field salsa_pget_flash_mode: salsat_frame.user_data_salsa_tm_interface_usage.salsa_pget_flash_mode
    :field salsa_pget_rxfreq: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_rxfreq
    :field salsa_pget_lms_temp: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_lms_temp
    :field salsa_pget_bw: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_bw
    :field salsa_pget_lna: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_lna
    :field salsa_pget_rxport: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_rxport
    :field salsa_pget_tia: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_tia
    :field salsa_pget_lnaport: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_lnaport
    :field salsa_pget_pga: salsat_frame.user_data_salsa_tm_rq_lms_tm.salsa_pget_pga
    :field salsa_pget_lms_reg_address: salsat_frame.user_data_salsa_tm_get_lms_register.salsa_pget_lms_reg_address
    :field salsa_pget_lms_reg_value: salsat_frame.user_data_salsa_tm_get_lms_register.salsa_pget_lms_reg_value
    :field user_data_salsa_tm_std_tm_salsa_pget_rxfreq: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_rxfreq
    :field user_data_salsa_tm_std_tm_salsa_pget_lms_temp: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_lms_temp
    :field user_data_salsa_tm_std_tm_salsa_pget_bw: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_bw
    :field user_data_salsa_tm_std_tm_salsa_pget_lna: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_lna
    :field user_data_salsa_tm_std_tm_salsa_pget_rxport: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_rxport
    :field user_data_salsa_tm_std_tm_salsa_pget_tia: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_tia
    :field user_data_salsa_tm_std_tm_salsa_pget_lnaport: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_lnaport
    :field user_data_salsa_tm_std_tm_salsa_pget_pga: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_pga
    :field salsa_pget_mario: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_mario
    :field salsa_pget_fpga_alive: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_fpga_alive
    :field salsa_pget_v_ic43: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_v_ic43
    :field salsa_pget_i_ic43: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_i_ic43
    :field salsa_pget_v_ic40: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_v_ic40
    :field salsa_pget_i_ic40: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_i_ic40
    :field salsa_pget_v_ic39: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_v_ic39
    :field salsa_pget_i_ic39: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_i_ic39
    :field salsa_pget_v_ic25: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_v_ic25
    :field salsa_pget_i_ic25: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_i_ic25
    :field salsa_pget_v_ic21: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_v_ic21
    :field salsa_pget_i_ic21: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_i_ic21
    :field salsa_pget_v_ic19: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_v_ic19
    :field salsa_pget_i_ic19: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_i_ic19
    :field salsa_pget_v_ic17: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_v_ic17
    :field salsa_pget_i_ic17: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_i_ic17
    :field salsa_pget_t_t1: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_t_t1
    :field salsa_pget_t_t2: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_t_t2
    :field salsa_pget_t_t3: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_t_t3
    :field salsa_pget_t_t4: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_t_t4
    :field salsa_pget_stm_boot_slot: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_stm_boot_slot
    :field user_data_salsa_tm_std_tm_salsa_pget_fpga_boot_slot: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_fpga_boot_slot
    :field salsa_pget_flash_sw_master: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_flash_sw_master
    :field salsa_pget_flash_sw_device: salsat_frame.user_data_salsa_tm_std_tm.salsa_pget_flash_sw_device
    :field salsa_pget_sector_count: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_sector_count
    :field salsa_pget_max_frames: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_max_frames
    :field salsa_pget_rx1l_vhf_used: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx1l_vhf_used
    :field salsa_pget_rx2l_vhf_used: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx2l_vhf_used
    :field salsa_pget_rx1w_uhf_used: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx1w_uhf_used
    :field salsa_pget_rx2w_srd_used: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx2w_srd_used
    :field salsa_pget_rx1h_sband_used: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx1h_sband_used
    :field salsa_pget_rx2h_sband_used: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx2h_sband_used
    :field salsa_pget_rx1l_vhf_freq: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx1l_vhf_freq
    :field salsa_pget_rx2l_vhf_freq: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx2l_vhf_freq
    :field salsa_pget_rx1w_uhf_freq: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx1w_uhf_freq
    :field salsa_pget_rx2w_srd_freq: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx2w_srd_freq
    :field salsa_pget_rx1h_sband_freq: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx1h_sband_freq
    :field salsa_pget_rx2h_sband_freq: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_rx2h_sband_freq
    :field user_data_salsa_tm_get_record_info_salsa_pget_lna: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_lna
    :field salsa_pget_lna_gain_rx2: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_lna_gain_rx2
    :field user_data_salsa_tm_get_record_info_salsa_pget_tia: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_tia
    :field salsa_pget_tia_gain_rx2: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_tia_gain_rx2
    :field user_data_salsa_tm_get_record_info_salsa_pget_pga: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_pga
    :field salsa_pget_pga_gain_rx2: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_pga_gain_rx2
    :field user_data_salsa_tm_get_record_info_salsa_pget_bw: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_bw
    :field salsa_pget_fft_record_rate: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_fft_record_rate
    :field salsa_pget_record_hours: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_record_hours
    :field salsa_pget_record_minutes: salsat_frame.user_data_salsa_tm_get_record_info.salsa_pget_record_minutes
    :field user_data_salsa_tm_lms_register_salsa_pget_lms_reg_address: salsat_frame.user_data_salsa_tm_lms_register.salsa_pget_lms_reg_address
    :field user_data_salsa_tm_lms_register_salsa_pget_lms_reg_value: salsat_frame.user_data_salsa_tm_lms_register.salsa_pget_lms_reg_value
    :field salsa_pget_max_v_stm: salsat_frame.user_data_salsa_tm_rq_max_v_threshold.salsa_pget_max_v_stm
    :field salsa_pget_max_v_fpga1v2: salsat_frame.user_data_salsa_tm_rq_max_v_threshold.salsa_pget_max_v_fpga1v2
    :field salsa_pget_max_v_fpga3v3: salsat_frame.user_data_salsa_tm_rq_max_v_threshold.salsa_pget_max_v_fpga3v3
    :field salsa_pget_max_v_lms: salsat_frame.user_data_salsa_tm_rq_max_v_threshold.salsa_pget_max_v_lms
    :field salsa_pget_max_v_ddr: salsat_frame.user_data_salsa_tm_rq_max_v_threshold.salsa_pget_max_v_ddr
    :field salsa_pget_max_v_pmu: salsat_frame.user_data_salsa_tm_rq_max_v_threshold.salsa_pget_max_v_pmu
    :field salsa_pget_max_v_flash: salsat_frame.user_data_salsa_tm_rq_max_v_threshold.salsa_pget_max_v_flash
    :field salsa_pget_max_i_stm: salsat_frame.user_data_salsa_tm_rq_max_i_threshold.salsa_pget_max_i_stm
    :field salsa_pget_max_i_fpga1v2: salsat_frame.user_data_salsa_tm_rq_max_i_threshold.salsa_pget_max_i_fpga1v2
    :field salsa_pget_max_i_fpga3v3: salsat_frame.user_data_salsa_tm_rq_max_i_threshold.salsa_pget_max_i_fpga3v3
    :field salsa_pget_max_i_lms: salsat_frame.user_data_salsa_tm_rq_max_i_threshold.salsa_pget_max_i_lms
    :field salsa_pget_max_i_ddr: salsat_frame.user_data_salsa_tm_rq_max_i_threshold.salsa_pget_max_i_ddr
    :field salsa_pget_max_i_pmu: salsat_frame.user_data_salsa_tm_rq_max_i_threshold.salsa_pget_max_i_pmu
    :field salsa_pget_max_i_flash: salsat_frame.user_data_salsa_tm_rq_max_i_threshold.salsa_pget_max_i_flash
    :field salsa_pget_min_v_stm: salsat_frame.user_data_salsa_tm_rq_min_v_threshold.salsa_pget_min_v_stm
    :field salsa_pget_min_v_fpga1v2: salsat_frame.user_data_salsa_tm_rq_min_v_threshold.salsa_pget_min_v_fpga1v2
    :field salsa_pget_min_v_fpga3v3: salsat_frame.user_data_salsa_tm_rq_min_v_threshold.salsa_pget_min_v_fpga3v3
    :field salsa_pget_min_v_lms: salsat_frame.user_data_salsa_tm_rq_min_v_threshold.salsa_pget_min_v_lms
    :field salsa_pget_min_v_ddr: salsat_frame.user_data_salsa_tm_rq_min_v_threshold.salsa_pget_min_v_ddr
    :field salsa_pget_min_v_pmu: salsat_frame.user_data_salsa_tm_rq_min_v_threshold.salsa_pget_min_v_pmu
    :field salsa_pget_min_v_flash: salsat_frame.user_data_salsa_tm_rq_min_v_threshold.salsa_pget_min_v_flash
    :field salsa_pget_min_i_stm: salsat_frame.user_data_salsa_tm_rq_min_i_threshold.salsa_pget_min_i_stm
    :field salsa_pget_min_i_fpga1v2: salsat_frame.user_data_salsa_tm_rq_min_i_threshold.salsa_pget_min_i_fpga1v2
    :field salsa_pget_min_i_fpga3v3: salsat_frame.user_data_salsa_tm_rq_min_i_threshold.salsa_pget_min_i_fpga3v3
    :field salsa_pget_min_i_lms: salsat_frame.user_data_salsa_tm_rq_min_i_threshold.salsa_pget_min_i_lms
    :field salsa_pget_min_i_ddr: salsat_frame.user_data_salsa_tm_rq_min_i_threshold.salsa_pget_min_i_ddr
    :field salsa_pget_min_i_pmu: salsat_frame.user_data_salsa_tm_rq_min_i_threshold.salsa_pget_min_i_pmu
    :field salsa_pget_min_i_flash: salsat_frame.user_data_salsa_tm_rq_min_i_threshold.salsa_pget_min_i_flash
    :field salsa_pget_pmu_config_id: salsat_frame.user_data_salsa_tm_read_lms_regs.salsa_pget_pmu_config_id
    :field user_data_salsa_tm_read_lms_regs_salsa_pget_max_frames: salsat_frame.user_data_salsa_tm_read_lms_regs.salsa_pget_max_frames
    :field salsa_pget_pmu_content: salsat_frame.user_data_salsa_tm_read_lms_regs.salsa_pget_pmu_content
    :field user_data_salsa_tm_read_lms_calib_salsa_pget_pmu_config_id: salsat_frame.user_data_salsa_tm_read_lms_calib.salsa_pget_pmu_config_id
    :field user_data_salsa_tm_read_lms_calib_salsa_pget_max_frames: salsat_frame.user_data_salsa_tm_read_lms_calib.salsa_pget_max_frames
    :field user_data_salsa_tm_read_lms_calib_salsa_pget_pmu_content: salsat_frame.user_data_salsa_tm_read_lms_calib.salsa_pget_pmu_content
    :field user_data_salsa_tm_read_clk_regs_salsa_pget_pmu_config_id: salsat_frame.user_data_salsa_tm_read_clk_regs.salsa_pget_pmu_config_id
    :field user_data_salsa_tm_read_clk_regs_salsa_pget_max_frames: salsat_frame.user_data_salsa_tm_read_clk_regs.salsa_pget_max_frames
    :field user_data_salsa_tm_read_clk_regs_salsa_pget_pmu_content: salsat_frame.user_data_salsa_tm_read_clk_regs.salsa_pget_pmu_content
    :field user_data_salsa_tm_read_missing_frames_salsa_pget_pmu_content: salsat_frame.user_data_salsa_tm_read_missing_frames.salsa_pget_pmu_content
    :field salsa_pget_failed_to_verify: salsat_frame.user_data_salsa_tm_upload_status.salsa_pget_failed_to_verify
    :field salsa_pget_config_failed_page: salsat_frame.user_data_salsa_tm_upload_status.salsa_pget_config_failed_page
    :field user_data_salsa_updates_std_tm_sat_pget_obc_act: salsat_frame.user_data_salsa_updates_std_tm.sat_pget_obc_act
    :field user_data_salsa_updates_std_tm_sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_salsa_updates_std_tm.sat_pget_fw_updater_activeslotnum
    :field user_data_salsa_updates_std_tm_sat_pget_selectedslotnum: salsat_frame.user_data_salsa_updates_std_tm.sat_pget_selectedslotnum
    :field user_data_salsa_updates_std_tm_sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_salsa_updates_std_tm.sat_pget_currentlyrunningsoftwareslot
    :field user_data_salsa_updates_std_tm_sat_pget_realalgotime: salsat_frame.user_data_salsa_updates_std_tm.sat_pget_realalgotime
    :field user_data_salsa_updates_tm_sat_pget_currentlyrunningsoftwareslot: salsat_frame.user_data_salsa_updates_tm.sat_pget_currentlyrunningsoftwareslot
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_state: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_state
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_activeslotnum: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_activeslotnum
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_tmpimgaddr: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_tmpimgaddr
    :field salsa_pget_updating_device: salsat_frame.user_data_salsa_updates_tm.salsa_pget_updating_device
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slotnumundererase: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slotnumundererase
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slotnumundercrc: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slotnumundercrc
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_activeimagelength: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_activeimagelength
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_numwrittensequences: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_numwrittensequences
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_nextexpectedsequence: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_nextexpectedsequence
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_totalmissingsequences: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_totalmissingsequences
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_missingsequenceswriteidx: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_missingsequenceswriteidx
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slot0_isfree
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slot1_isfree
    :field user_data_salsa_updates_tm_sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_salsa_updates_tm.sat_pget_fw_updater_slot2_isfree
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot0_hasvalidimage: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot0_hasvalidimage
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot1_hasvalidimage: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot1_hasvalidimage
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot2_hasvalidimage: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot2_hasvalidimage
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot0_isfree: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot0_isfree
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot1_isfree: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot1_isfree
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot2_isfree: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot2_isfree
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot0_isundererase: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot0_isundererase
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot1_isundererase: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot1_isundererase
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot2_isundererase: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot2_isundererase
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot0_ishealthy: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot0_ishealthy
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot1_ishealthy: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot1_ishealthy
    :field user_data_salsa_updates_slot_tm_sat_pget_fw_updater_slot2_ishealthy: salsat_frame.user_data_salsa_updates_slot_tm.sat_pget_fw_updater_slot2_ishealthy
    :field user_data_salsa_updates_missingintervalls_sat_pget_fw_updater_missingsequencestartarray: salsat_frame.user_data_salsa_updates_missingintervalls.sat_pget_fw_updater_missingsequencestartarray
    :field user_data_salsa_updates_missingintervalls_sat_pget_fw_updater_missingsequenceendarray: salsat_frame.user_data_salsa_updates_missingintervalls.sat_pget_fw_updater_missingsequenceendarray
    :field user_data_salsa_info_fdir_pget_rodoserrorcounter: salsat_frame.user_data_salsa_info.fdir_pget_rodoserrorcounter
    :field user_data_salsa_info_fdir_pget_gitversion: salsat_frame.user_data_salsa_info.fdir_pget_gitversion
    :field user_data_salsa_info_fdir_pget_compiletimeinsec: salsat_frame.user_data_salsa_info.fdir_pget_compiletimeinsec
    :field user_data_salsa_info_shared_reset_counter: salsat_frame.user_data_salsa_info.shared_reset_counter
    :field user_data_salsa_info_fdir_pget_ismodifiedversion: salsat_frame.user_data_salsa_info.fdir_pget_ismodifiedversion
    :field user_data_salsa_sat_thread_info_fdir_pget_runtime: salsat_frame.user_data_salsa_sat_thread_info.fdir_pget_runtime
    :field user_data_salsa_sat_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_salsa_sat_thread_info.fdir_pget_imalivecounter
    :field user_data_salsa_sat_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_salsa_sat_thread_info.fdir_pget_realalgotime
    :field user_data_salsa_link_std_tm_pdh_pget_pleps_link_frames_received: salsat_frame.user_data_salsa_link_std_tm.pdh_pget_pleps_link_frames_received
    :field user_data_salsa_link_std_tm_pdh_pget_pleps_link_frames_sent: salsat_frame.user_data_salsa_link_std_tm.pdh_pget_pleps_link_frames_sent
    :field user_data_salsa_link_thread_info_fdir_pget_runtime: salsat_frame.user_data_salsa_link_thread_info.fdir_pget_runtime
    :field user_data_salsa_link_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_salsa_link_thread_info.fdir_pget_imalivecounter
    :field user_data_salsa_link_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_salsa_link_thread_info.fdir_pget_realalgotime
    :field user_data_salsa_hk_thread_info_fdir_pget_runtime: salsat_frame.user_data_salsa_hk_thread_info.fdir_pget_runtime
    :field user_data_salsa_hk_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_salsa_hk_thread_info.fdir_pget_imalivecounter
    :field user_data_salsa_hk_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_salsa_hk_thread_info.fdir_pget_realalgotime
    :field user_data_salsa_fpga_thread_info_fdir_pget_runtime: salsat_frame.user_data_salsa_fpga_thread_info.fdir_pget_runtime
    :field user_data_salsa_fpga_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_salsa_fpga_thread_info.fdir_pget_imalivecounter
    :field user_data_salsa_fpga_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_salsa_fpga_thread_info.fdir_pget_realalgotime
    :field user_data_salsa_lms_thread_info_fdir_pget_runtime: salsat_frame.user_data_salsa_lms_thread_info.fdir_pget_runtime
    :field user_data_salsa_lms_thread_info_fdir_pget_imalivecounter: salsat_frame.user_data_salsa_lms_thread_info.fdir_pget_imalivecounter
    :field user_data_salsa_lms_thread_info_fdir_pget_realalgotime: salsat_frame.user_data_salsa_lms_thread_info.fdir_pget_realalgotime
    :field salsa_pget_fft_record_in_progress: salsat_frame.user_data_salsa_tm_get_fft_recording_status.salsa_pget_fft_record_in_progress
    :field salsa_pget_fft_count: salsat_frame.user_data_salsa_tm_get_fft_recording_status.salsa_pget_fft_count
    :field salsa_pget_fft_count_last: salsat_frame.user_data_salsa_tm_get_fft_recording_status.salsa_pget_fft_count_last
    :field salsa_pget_lms_calib_boot_slot: salsat_frame.user_data_salsa_tm_get_boot_configs.salsa_pget_lms_calib_boot_slot
    :field salsa_pget_lms_regs_boot_slot: salsat_frame.user_data_salsa_tm_get_boot_configs.salsa_pget_lms_regs_boot_slot
    :field salsa_pget_clk_regs_boot_slot: salsat_frame.user_data_salsa_tm_get_boot_configs.salsa_pget_clk_regs_boot_slot
    :field user_data_salsa_tm_get_boot_configs_salsa_pget_fpga_boot_slot: salsat_frame.user_data_salsa_tm_get_boot_configs.salsa_pget_fpga_boot_slot
    :field salsa_pget_ina_boot_slot: salsat_frame.user_data_salsa_tm_get_boot_configs.salsa_pget_ina_boot_slot
    :field user_data_salsa_tm_read_pmu_page_salsa_pget_pmu_config_id: salsat_frame.user_data_salsa_tm_read_pmu_page.salsa_pget_pmu_config_id
    :field user_data_salsa_tm_read_pmu_page_salsa_pget_max_frames: salsat_frame.user_data_salsa_tm_read_pmu_page.salsa_pget_max_frames
    :field user_data_salsa_tm_read_pmu_page_salsa_pget_pmu_content: salsat_frame.user_data_salsa_tm_read_pmu_page.salsa_pget_pmu_content
    :field salsa_pget_read_flash: salsat_frame.user_data_salsa_tm_read_flash_page.salsa_pget_read_flash
    :field salsa_pget_mem_page: salsat_frame.user_data_salsa_tm_read_flash_page.salsa_pget_mem_page
    :field salsa_pget_mem_sector: salsat_frame.user_data_salsa_tm_read_flash_page.salsa_pget_mem_sector
    :field user_data_salsa_tm_read_flash_page_salsa_pget_pmu_config_id: salsat_frame.user_data_salsa_tm_read_flash_page.salsa_pget_pmu_config_id
    :field user_data_salsa_tm_read_flash_page_salsa_pget_pmu_content: salsat_frame.user_data_salsa_tm_read_flash_page.salsa_pget_pmu_content
    :field salsa_pget_sci_crc16_value: salsat_frame.user_data_salsa_tm_get_fft_crc_value.salsa_pget_sci_crc16_value
    :field salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_wov
    :field salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_wuv
    :field salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_wp
    :field salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_wsp
    :field salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_wsm
    :field salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_olov
    :field salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_oluv
    :field salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_olp
    :field salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_critp
    :field salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_critm
    :field salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_cnvr
    :field salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_smba
    :field salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_ovf
    :field salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_d2
    :field salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_d1
    :field salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_ina_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_wov
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_wuv
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_wp
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_wsp
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_wsm
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_olov
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_oluv
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_olp
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_critp
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_critm
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_cnvr
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_smba
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_ovf
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_d2
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_d1
    :field user_data_salsa_tm_get_ina_stm_status_salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_get_ina_stm_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_wov
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_wuv
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_wp
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_wsp
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_wsm
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_olov
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_oluv
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_olp
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_critp
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_critm
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_cnvr
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_smba
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_ovf
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_d2
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_d1
    :field user_data_salsa_tm_get_ina_fpga1v2_status_salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_get_ina_fpga1v2_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_wov
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_wuv
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_wp
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_wsp
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_wsm
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_olov
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_oluv
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_olp
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_critp
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_critm
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_cnvr
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_smba
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_ovf
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_d2
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_d1
    :field user_data_salsa_tm_get_ina_fpga3v3_status_salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_get_ina_fpga3v3_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_wov
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_wuv
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_wp
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_wsp
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_wsm
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_olov
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_oluv
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_olp
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_critp
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_critm
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_cnvr
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_smba
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_ovf
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_d2
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_d1
    :field user_data_salsa_tm_get_ina_lms_status_salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_get_ina_lms_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_wov
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_wuv
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_wp
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_wsp
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_wsm
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_olov
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_oluv
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_olp
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_critp
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_critm
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_cnvr
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_smba
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_ovf
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_d2
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_d1
    :field user_data_salsa_tm_get_ina_ddr_status_salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_get_ina_ddr_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_wov
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_wuv
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_wp
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_wsp
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_wsm
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_olov
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_oluv
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_olp
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_critp
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_critm
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_cnvr
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_smba
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_ovf
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_d2
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_d1
    :field user_data_salsa_tm_get_ina_pmu_status_salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_get_ina_pmu_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_wov: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_wov
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_wuv: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_wuv
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_wp: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_wp
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_wsp: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_wsp
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_wsm: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_wsm
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_olov: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_olov
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_oluv: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_oluv
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_olp: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_olp
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_critp: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_critp
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_critm: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_critm
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_cnvr: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_cnvr
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_smba: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_smba
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_ovf: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_ovf
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_d2: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_d2
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_d1: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_d1
    :field user_data_salsa_tm_get_ina_flash_status_salsa_pget_ina_d0: salsat_frame.user_data_salsa_tm_get_ina_flash_status.salsa_pget_ina_d0
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_sector_count: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_sector_count
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_max_frames: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_max_frames
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_rx1l_vhf_used: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_rx1l_vhf_used
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_rx2l_vhf_used: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_rx2l_vhf_used
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_rx1w_uhf_used: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_rx1w_uhf_used
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_rx2w_srd_used: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_rx2w_srd_used
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_rx1h_sband_used: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_rx1h_sband_used
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_rx2h_sband_used: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_rx2h_sband_used
    :field salsa_pget_record_start_time: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_record_start_time
    :field salsa_pget_record_end_time: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_record_end_time
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_fft_record_rate: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_fft_record_rate
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_record_hours: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_record_hours
    :field user_data_salsa_tm_get_recording_timestamps_salsa_pget_record_minutes: salsat_frame.user_data_salsa_tm_get_recording_timestamps.salsa_pget_record_minutes
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_sector_count: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_sector_count
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_max_frames: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_max_frames
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_rx1l_vhf_used: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_rx1l_vhf_used
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_rx2l_vhf_used: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_rx2l_vhf_used
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_rx1w_uhf_used: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_rx1w_uhf_used
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_rx2w_srd_used: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_rx2w_srd_used
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_rx1h_sband_used: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_rx1h_sband_used
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_rx2h_sband_used: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_rx2h_sband_used
    :field salsa_pget_start_year: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_start_year
    :field salsa_pget_end_year: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_end_year
    :field salsa_pget_start_month: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_start_month
    :field salsa_pget_end_month: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_end_month
    :field salsa_pget_start_day: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_start_day
    :field salsa_pget_end_day: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_end_day
    :field salsa_pget_start_hours: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_start_hours
    :field salsa_pget_end_hours: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_end_hours
    :field salsa_pget_start_minutes: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_start_minutes
    :field salsa_pget_end_minutes: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_end_minutes
    :field salsa_pget_start_seconds: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_start_seconds
    :field salsa_pget_end_seconds: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_end_seconds
    :field salsa_pget_start_centiseconds: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_start_centiseconds
    :field salsa_pget_end_centiseconds: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_end_centiseconds
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_fft_record_rate: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_fft_record_rate
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_record_hours: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_record_hours
    :field user_data_salsa_tm_get_recording_datetime_salsa_pget_record_minutes: salsat_frame.user_data_salsa_tm_get_recording_datetime.salsa_pget_record_minutes
    :field salsa_pget_fft_frame_data_length: salsat_frame.user_data_salsa_tm_get_fft_frame_data_length.salsa_pget_fft_frame_data_length
    :field adcs_pget_imodechklistthisstepactive: salsat_frame.user_data_adcs_std_tm.adcs_pget_imodechklistthisstepactive
    :field adcs_pget_iattdetfinalstate: salsat_frame.user_data_adcs_std_tm.adcs_pget_iattdetfinalstate
    :field adcs_pget_isensorarrayavailstatusga: salsat_frame.user_data_adcs_std_tm.adcs_pget_isensorarrayavailstatusga
    :field adcs_pget_isensorarrayavailstatusmfsa: salsat_frame.user_data_adcs_std_tm.adcs_pget_isensorarrayavailstatusmfsa
    :field adcs_pget_isensorarrayavailstatussusea: salsat_frame.user_data_adcs_std_tm.adcs_pget_isensorarrayavailstatussusea
    :field adcs_pget_iactarrayavailstatusrwa: salsat_frame.user_data_adcs_std_tm.adcs_pget_iactarrayavailstatusrwa
    :field adcs_pget_iactarrayavailstatusmata: salsat_frame.user_data_adcs_std_tm.adcs_pget_iactarrayavailstatusmata
    :field adcs_pget_attdetmfsdistcorrmode: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdetmfsdistcorrmode
    :field adcs_pget_attdetsusedistcorrmode: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdetsusedistcorrmode
    :field adcs_pget_attdettrackigrfdeltab: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdettrackigrfdeltab
    :field adcs_pget_attdetsusealbedotracking: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdetsusealbedotracking
    :field adcs_pget_suse1albedoflag: salsat_frame.user_data_adcs_std_tm.adcs_pget_suse1albedoflag
    :field adcs_pget_suse2albedoflag: salsat_frame.user_data_adcs_std_tm.adcs_pget_suse2albedoflag
    :field adcs_pget_suse3albedoflag: salsat_frame.user_data_adcs_std_tm.adcs_pget_suse3albedoflag
    :field adcs_pget_suse4albedoflag: salsat_frame.user_data_adcs_std_tm.adcs_pget_suse4albedoflag
    :field adcs_pget_suse5albedoflag: salsat_frame.user_data_adcs_std_tm.adcs_pget_suse5albedoflag
    :field adcs_pget_suse6albedoflag: salsat_frame.user_data_adcs_std_tm.adcs_pget_suse6albedoflag
    :field adcs_pget_attdetautovirtualizemfsa: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdetautovirtualizemfsa
    :field adcs_pget_attdetautovirtualizesusea: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdetautovirtualizesusea
    :field adcs_pget_attdetnarrowvectors: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdetnarrowvectors
    :field adcs_pget_attdetmismatchingvectors: salsat_frame.user_data_adcs_std_tm.adcs_pget_attdetmismatchingvectors
    :field adcs_pget_omegaxoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_omegaxoptimal_sat
    :field adcs_pget_omegayoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_omegayoptimal_sat
    :field adcs_pget_omegazoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_omegazoptimal_sat
    :field adcs_pget_magxoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_magxoptimal_sat
    :field adcs_pget_magyoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_magyoptimal_sat
    :field adcs_pget_magzoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_magzoptimal_sat
    :field adcs_pget_sunxoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_sunxoptimal_sat
    :field adcs_pget_sunyoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_sunyoptimal_sat
    :field adcs_pget_sunzoptimal_sat: salsat_frame.user_data_adcs_std_tm.adcs_pget_sunzoptimal_sat
    :field adcs_pget_dctrltorquerwax_sat_lr: salsat_frame.user_data_adcs_std_tm.adcs_pget_dctrltorquerwax_sat_lr
    :field adcs_pget_dctrltorquerway_sat_lr: salsat_frame.user_data_adcs_std_tm.adcs_pget_dctrltorquerway_sat_lr
    :field adcs_pget_dctrltorquerwaz_sat_lr: salsat_frame.user_data_adcs_std_tm.adcs_pget_dctrltorquerwaz_sat_lr
    :field adcs_pget_dctrlmagmomentmatax_sat_lr: salsat_frame.user_data_adcs_std_tm.adcs_pget_dctrlmagmomentmatax_sat_lr
    :field adcs_pget_dctrlmagmomentmatay_sat_lr: salsat_frame.user_data_adcs_std_tm.adcs_pget_dctrlmagmomentmatay_sat_lr
    :field adcs_pget_dctrlmagmomentmataz_sat_lr: salsat_frame.user_data_adcs_std_tm.adcs_pget_dctrlmagmomentmataz_sat_lr
    :field adcs_pget_ireadtorquerwx_mfr: salsat_frame.user_data_adcs_std_tm.adcs_pget_ireadtorquerwx_mfr
    :field adcs_pget_ireadtorquerwy_mfr: salsat_frame.user_data_adcs_std_tm.adcs_pget_ireadtorquerwy_mfr
    :field adcs_pget_ireadtorquerwz_mfr: salsat_frame.user_data_adcs_std_tm.adcs_pget_ireadtorquerwz_mfr
    :field adcs_pget_ireadrotspeedrwx_mfr: salsat_frame.user_data_adcs_std_tm.adcs_pget_ireadrotspeedrwx_mfr
    :field adcs_pget_ireadrotspeedrwy_mfr: salsat_frame.user_data_adcs_std_tm.adcs_pget_ireadrotspeedrwy_mfr
    :field adcs_pget_ireadrotspeedrwz_mfr: salsat_frame.user_data_adcs_std_tm.adcs_pget_ireadrotspeedrwz_mfr
    :field adcs_pget_sgp4latxpef: salsat_frame.user_data_adcs_std_tm.adcs_pget_sgp4latxpef
    :field adcs_pget_sgp4longypef: salsat_frame.user_data_adcs_std_tm.adcs_pget_sgp4longypef
    :field adcs_pget_sgp4altpef: salsat_frame.user_data_adcs_std_tm.adcs_pget_sgp4altpef
    :field adcs_pget_attitudeerrorangle: salsat_frame.user_data_adcs_std_tm.adcs_pget_attitudeerrorangle
    :field adcs_pget_targetdata_distance: salsat_frame.user_data_adcs_std_tm.adcs_pget_targetdata_distance
    :field adcs_pget_targetdata_controlisactive: salsat_frame.user_data_adcs_std_tm.adcs_pget_targetdata_controlisactive
    :field adcs_pget_ecitosatdcmoptimalu1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalu1_lr
    :field adcs_pget_ecitosatdcmoptimalu2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalu2_lr
    :field adcs_pget_ecitosatdcmoptimalu3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalu3_lr
    :field adcs_pget_ecitosatdcmoptimalv1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalv1_lr
    :field adcs_pget_ecitosatdcmoptimalv2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalv2_lr
    :field adcs_pget_ecitosatdcmoptimalv3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalv3_lr
    :field adcs_pget_ecitosatdcmoptimalw1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalw1_lr
    :field adcs_pget_ecitosatdcmoptimalw2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalw2_lr
    :field adcs_pget_ecitosatdcmoptimalw3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitosatdcmoptimalw3_lr
    :field adcs_pget_ecitotgtdcmu1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmu1_lr
    :field adcs_pget_ecitotgtdcmu2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmu2_lr
    :field adcs_pget_ecitotgtdcmu3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmu3_lr
    :field adcs_pget_ecitotgtdcmv1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmv1_lr
    :field adcs_pget_ecitotgtdcmv2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmv2_lr
    :field adcs_pget_ecitotgtdcmv3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmv3_lr
    :field adcs_pget_ecitotgtdcmw1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmw1_lr
    :field adcs_pget_ecitotgtdcmw2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmw2_lr
    :field adcs_pget_ecitotgtdcmw3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_ecitotgtdcmw3_lr
    :field adcs_pget_sattotgtdcmerroru1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerroru1_lr
    :field adcs_pget_sattotgtdcmerroru2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerroru2_lr
    :field adcs_pget_sattotgtdcmerroru3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerroru3_lr
    :field adcs_pget_sattotgtdcmerrorv1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerrorv1_lr
    :field adcs_pget_sattotgtdcmerrorv2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerrorv2_lr
    :field adcs_pget_sattotgtdcmerrorv3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerrorv3_lr
    :field adcs_pget_sattotgtdcmerrorw1_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerrorw1_lr
    :field adcs_pget_sattotgtdcmerrorw2_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerrorw2_lr
    :field adcs_pget_sattotgtdcmerrorw3_lr: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sattotgtdcmerrorw3_lr
    :field adcs_pget_igrfbmagxeci: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_igrfbmagxeci
    :field adcs_pget_igrfbmagyeci: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_igrfbmagyeci
    :field adcs_pget_igrfbmagzeci: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_igrfbmagzeci
    :field adcs_pget_sunmodelrxeci: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sunmodelrxeci
    :field adcs_pget_sunmodelryeci: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sunmodelryeci
    :field adcs_pget_sunmodelrzeci: salsat_frame.user_data_adcs_ext_tm_a.adcs_pget_sunmodelrzeci
    :field adcs_pget_g1mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmu1
    :field adcs_pget_g1mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmu2
    :field adcs_pget_g1mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmu3
    :field adcs_pget_g1mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmv1
    :field adcs_pget_g1mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmv2
    :field adcs_pget_g1mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmv3
    :field adcs_pget_g1mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmw1
    :field adcs_pget_g1mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmw2
    :field adcs_pget_g1mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g1mfrtosatdcmw3
    :field adcs_pget_g2mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmu1
    :field adcs_pget_g2mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmu2
    :field adcs_pget_g2mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmu3
    :field adcs_pget_g2mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmv1
    :field adcs_pget_g2mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmv2
    :field adcs_pget_g2mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmv3
    :field adcs_pget_g2mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmw1
    :field adcs_pget_g2mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmw2
    :field adcs_pget_g2mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g2mfrtosatdcmw3
    :field adcs_pget_g3mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmu1
    :field adcs_pget_g3mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmu2
    :field adcs_pget_g3mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmu3
    :field adcs_pget_g3mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmv1
    :field adcs_pget_g3mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmv2
    :field adcs_pget_g3mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmv3
    :field adcs_pget_g3mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmw1
    :field adcs_pget_g3mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmw2
    :field adcs_pget_g3mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g3mfrtosatdcmw3
    :field adcs_pget_g4mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmu1
    :field adcs_pget_g4mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmu2
    :field adcs_pget_g4mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmu3
    :field adcs_pget_g4mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmv1
    :field adcs_pget_g4mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmv2
    :field adcs_pget_g4mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmv3
    :field adcs_pget_g4mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmw1
    :field adcs_pget_g4mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmw2
    :field adcs_pget_g4mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g1_to_4.adcs_pget_g4mfrtosatdcmw3
    :field adcs_pget_g5mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmu1
    :field adcs_pget_g5mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmu2
    :field adcs_pget_g5mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmu3
    :field adcs_pget_g5mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmv1
    :field adcs_pget_g5mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmv2
    :field adcs_pget_g5mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmv3
    :field adcs_pget_g5mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmw1
    :field adcs_pget_g5mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmw2
    :field adcs_pget_g5mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g5mfrtosatdcmw3
    :field adcs_pget_g6mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmu1
    :field adcs_pget_g6mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmu2
    :field adcs_pget_g6mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmu3
    :field adcs_pget_g6mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmv1
    :field adcs_pget_g6mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmv2
    :field adcs_pget_g6mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmv3
    :field adcs_pget_g6mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmw1
    :field adcs_pget_g6mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmw2
    :field adcs_pget_g6mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g6mfrtosatdcmw3
    :field adcs_pget_g7mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmu1
    :field adcs_pget_g7mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmu2
    :field adcs_pget_g7mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmu3
    :field adcs_pget_g7mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmv1
    :field adcs_pget_g7mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmv2
    :field adcs_pget_g7mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmv3
    :field adcs_pget_g7mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmw1
    :field adcs_pget_g7mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmw2
    :field adcs_pget_g7mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g7mfrtosatdcmw3
    :field adcs_pget_g8mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmu1
    :field adcs_pget_g8mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmu2
    :field adcs_pget_g8mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmu3
    :field adcs_pget_g8mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmv1
    :field adcs_pget_g8mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmv2
    :field adcs_pget_g8mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmv3
    :field adcs_pget_g8mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmw1
    :field adcs_pget_g8mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmw2
    :field adcs_pget_g8mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_g5_to_8.adcs_pget_g8mfrtosatdcmw3
    :field adcs_pget_mfs1mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmu1
    :field adcs_pget_mfs1mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmu2
    :field adcs_pget_mfs1mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmu3
    :field adcs_pget_mfs1mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmv1
    :field adcs_pget_mfs1mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmv2
    :field adcs_pget_mfs1mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmv3
    :field adcs_pget_mfs1mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmw1
    :field adcs_pget_mfs1mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmw2
    :field adcs_pget_mfs1mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs1mfrtosatdcmw3
    :field adcs_pget_mfs2mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmu1
    :field adcs_pget_mfs2mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmu2
    :field adcs_pget_mfs2mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmu3
    :field adcs_pget_mfs2mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmv1
    :field adcs_pget_mfs2mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmv2
    :field adcs_pget_mfs2mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmv3
    :field adcs_pget_mfs2mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmw1
    :field adcs_pget_mfs2mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmw2
    :field adcs_pget_mfs2mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs2mfrtosatdcmw3
    :field adcs_pget_mfs3mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmu1
    :field adcs_pget_mfs3mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmu2
    :field adcs_pget_mfs3mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmu3
    :field adcs_pget_mfs3mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmv1
    :field adcs_pget_mfs3mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmv2
    :field adcs_pget_mfs3mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmv3
    :field adcs_pget_mfs3mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmw1
    :field adcs_pget_mfs3mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmw2
    :field adcs_pget_mfs3mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs3mfrtosatdcmw3
    :field adcs_pget_mfs4mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmu1
    :field adcs_pget_mfs4mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmu2
    :field adcs_pget_mfs4mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmu3
    :field adcs_pget_mfs4mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmv1
    :field adcs_pget_mfs4mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmv2
    :field adcs_pget_mfs4mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmv3
    :field adcs_pget_mfs4mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmw1
    :field adcs_pget_mfs4mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmw2
    :field adcs_pget_mfs4mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4.adcs_pget_mfs4mfrtosatdcmw3
    :field adcs_pget_suse1mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmu1
    :field adcs_pget_suse1mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmu2
    :field adcs_pget_suse1mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmu3
    :field adcs_pget_suse1mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmv1
    :field adcs_pget_suse1mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmv2
    :field adcs_pget_suse1mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmv3
    :field adcs_pget_suse1mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmw1
    :field adcs_pget_suse1mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmw2
    :field adcs_pget_suse1mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse1mfrtosatdcmw3
    :field adcs_pget_suse2mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmu1
    :field adcs_pget_suse2mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmu2
    :field adcs_pget_suse2mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmu3
    :field adcs_pget_suse2mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmv1
    :field adcs_pget_suse2mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmv2
    :field adcs_pget_suse2mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmv3
    :field adcs_pget_suse2mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmw1
    :field adcs_pget_suse2mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmw2
    :field adcs_pget_suse2mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse2mfrtosatdcmw3
    :field adcs_pget_suse3mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmu1
    :field adcs_pget_suse3mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmu2
    :field adcs_pget_suse3mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmu3
    :field adcs_pget_suse3mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmv1
    :field adcs_pget_suse3mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmv2
    :field adcs_pget_suse3mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmv3
    :field adcs_pget_suse3mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmw1
    :field adcs_pget_suse3mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmw2
    :field adcs_pget_suse3mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3.adcs_pget_suse3mfrtosatdcmw3
    :field adcs_pget_suse4mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmu1
    :field adcs_pget_suse4mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmu2
    :field adcs_pget_suse4mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmu3
    :field adcs_pget_suse4mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmv1
    :field adcs_pget_suse4mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmv2
    :field adcs_pget_suse4mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmv3
    :field adcs_pget_suse4mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmw1
    :field adcs_pget_suse4mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmw2
    :field adcs_pget_suse4mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse4mfrtosatdcmw3
    :field adcs_pget_suse5mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmu1
    :field adcs_pget_suse5mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmu2
    :field adcs_pget_suse5mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmu3
    :field adcs_pget_suse5mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmv1
    :field adcs_pget_suse5mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmv2
    :field adcs_pget_suse5mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmv3
    :field adcs_pget_suse5mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmw1
    :field adcs_pget_suse5mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmw2
    :field adcs_pget_suse5mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse5mfrtosatdcmw3
    :field adcs_pget_suse6mfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmu1
    :field adcs_pget_suse6mfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmu2
    :field adcs_pget_suse6mfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmu3
    :field adcs_pget_suse6mfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmv1
    :field adcs_pget_suse6mfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmv2
    :field adcs_pget_suse6mfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmv3
    :field adcs_pget_suse6mfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmw1
    :field adcs_pget_suse6mfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmw2
    :field adcs_pget_suse6mfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6.adcs_pget_suse6mfrtosatdcmw3
    :field adcs_pget_rwamfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmu1
    :field adcs_pget_rwamfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmu2
    :field adcs_pget_rwamfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmu3
    :field adcs_pget_rwamfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmv1
    :field adcs_pget_rwamfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmv2
    :field adcs_pget_rwamfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmv3
    :field adcs_pget_rwamfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmw1
    :field adcs_pget_rwamfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmw2
    :field adcs_pget_rwamfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_rwa.adcs_pget_rwamfrtosatdcmw3
    :field adcs_pget_matamfrtosatdcmu1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmu1
    :field adcs_pget_matamfrtosatdcmu2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmu2
    :field adcs_pget_matamfrtosatdcmu3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmu3
    :field adcs_pget_matamfrtosatdcmv1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmv1
    :field adcs_pget_matamfrtosatdcmv2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmv2
    :field adcs_pget_matamfrtosatdcmv3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmv3
    :field adcs_pget_matamfrtosatdcmw1: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmw1
    :field adcs_pget_matamfrtosatdcmw2: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmw2
    :field adcs_pget_matamfrtosatdcmw3: salsat_frame.user_data_adcs_cal_dcm_mfrtosat_mata.adcs_pget_matamfrtosatdcmw3
    :field adcs_pget_g1offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g1offsetx
    :field adcs_pget_g1offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g1offsety
    :field adcs_pget_g1offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g1offsetz
    :field adcs_pget_g2offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g2offsetx
    :field adcs_pget_g2offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g2offsety
    :field adcs_pget_g2offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g2offsetz
    :field adcs_pget_g3offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g3offsetx
    :field adcs_pget_g3offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g3offsety
    :field adcs_pget_g3offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g3offsetz
    :field adcs_pget_g4offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g4offsetx
    :field adcs_pget_g4offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g4offsety
    :field adcs_pget_g4offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g4offsetz
    :field adcs_pget_g5offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g5offsetx
    :field adcs_pget_g5offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g5offsety
    :field adcs_pget_g5offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g5offsetz
    :field adcs_pget_g6offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g6offsetx
    :field adcs_pget_g6offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g6offsety
    :field adcs_pget_g6offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g6offsetz
    :field adcs_pget_g7offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g7offsetx
    :field adcs_pget_g7offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g7offsety
    :field adcs_pget_g7offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g7offsetz
    :field adcs_pget_g8offsetx: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g8offsetx
    :field adcs_pget_g8offsety: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g8offsety
    :field adcs_pget_g8offsetz: salsat_frame.user_data_adcs_cal_offset_g1_to_8.adcs_pget_g8offsetz
    :field adcs_pget_mfs1offsetx: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs1offsetx
    :field adcs_pget_mfs1offsety: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs1offsety
    :field adcs_pget_mfs1offsetz: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs1offsetz
    :field adcs_pget_mfs2offsetx: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs2offsetx
    :field adcs_pget_mfs2offsety: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs2offsety
    :field adcs_pget_mfs2offsetz: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs2offsetz
    :field adcs_pget_mfs3offsetx: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs3offsetx
    :field adcs_pget_mfs3offsety: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs3offsety
    :field adcs_pget_mfs3offsetz: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs3offsetz
    :field adcs_pget_mfs4offsetx: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs4offsetx
    :field adcs_pget_mfs4offsety: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs4offsety
    :field adcs_pget_mfs4offsetz: salsat_frame.user_data_adcs_cal_offset_mfs1_to_4.adcs_pget_mfs4offsetz
    :field adcs_pget_suse1currentthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse1currentthreshold
    :field adcs_pget_suse1psdmaxxthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse1psdmaxxthreshold
    :field adcs_pget_suse1psdmaxythreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse1psdmaxythreshold
    :field adcs_pget_suse2currentthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse2currentthreshold
    :field adcs_pget_suse2psdmaxxthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse2psdmaxxthreshold
    :field adcs_pget_suse2psdmaxythreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse2psdmaxythreshold
    :field adcs_pget_suse3currentthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse3currentthreshold
    :field adcs_pget_suse3psdmaxxthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse3psdmaxxthreshold
    :field adcs_pget_suse3psdmaxythreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse3psdmaxythreshold
    :field adcs_pget_suse4currentthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse4currentthreshold
    :field adcs_pget_suse4psdmaxxthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse4psdmaxxthreshold
    :field adcs_pget_suse4psdmaxythreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse4psdmaxythreshold
    :field adcs_pget_suse5currentthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse5currentthreshold
    :field adcs_pget_suse5psdmaxxthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse5psdmaxxthreshold
    :field adcs_pget_suse5psdmaxythreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse5psdmaxythreshold
    :field adcs_pget_suse6currentthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse6currentthreshold
    :field adcs_pget_suse6psdmaxxthreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse6psdmaxxthreshold
    :field adcs_pget_suse6psdmaxythreshold: salsat_frame.user_data_adcs_cal_threshold_suse1_to_6.adcs_pget_suse6psdmaxythreshold
    :field adcs_pget_suse1darkcurrentx1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse1darkcurrentx1
    :field adcs_pget_suse1darkcurrentx2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse1darkcurrentx2
    :field adcs_pget_suse1darkcurrenty1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse1darkcurrenty1
    :field adcs_pget_suse1darkcurrenty2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse1darkcurrenty2
    :field adcs_pget_suse2darkcurrentx1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse2darkcurrentx1
    :field adcs_pget_suse2darkcurrentx2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse2darkcurrentx2
    :field adcs_pget_suse2darkcurrenty1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse2darkcurrenty1
    :field adcs_pget_suse2darkcurrenty2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse2darkcurrenty2
    :field adcs_pget_suse3darkcurrentx1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse3darkcurrentx1
    :field adcs_pget_suse3darkcurrentx2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse3darkcurrentx2
    :field adcs_pget_suse3darkcurrenty1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse3darkcurrenty1
    :field adcs_pget_suse3darkcurrenty2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse3darkcurrenty2
    :field adcs_pget_suse4darkcurrentx1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse4darkcurrentx1
    :field adcs_pget_suse4darkcurrentx2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse4darkcurrentx2
    :field adcs_pget_suse4darkcurrenty1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse4darkcurrenty1
    :field adcs_pget_suse4darkcurrenty2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse4darkcurrenty2
    :field adcs_pget_suse5darkcurrentx1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse5darkcurrentx1
    :field adcs_pget_suse5darkcurrentx2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse5darkcurrentx2
    :field adcs_pget_suse5darkcurrenty1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse5darkcurrenty1
    :field adcs_pget_suse5darkcurrenty2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse5darkcurrenty2
    :field adcs_pget_suse6darkcurrentx1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse6darkcurrentx1
    :field adcs_pget_suse6darkcurrentx2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse6darkcurrentx2
    :field adcs_pget_suse6darkcurrenty1: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse6darkcurrenty1
    :field adcs_pget_suse6darkcurrenty2: salsat_frame.user_data_adcs_cal_darkcurrent_suse1_to_6.adcs_pget_suse6darkcurrenty2
    :field adcs_pget_g1tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol2coefxaxis
    :field adcs_pget_g1tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol1coefxaxis
    :field adcs_pget_g1tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol0coefxaxis
    :field adcs_pget_g1tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol2coefyaxis
    :field adcs_pget_g1tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol1coefyaxis
    :field adcs_pget_g1tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol0coefyaxis
    :field adcs_pget_g1tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol2coefzaxis
    :field adcs_pget_g1tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol1coefzaxis
    :field adcs_pget_g1tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g1.adcs_pget_g1tbiaspol0coefzaxis
    :field adcs_pget_g2tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol2coefxaxis
    :field adcs_pget_g2tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol1coefxaxis
    :field adcs_pget_g2tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol0coefxaxis
    :field adcs_pget_g2tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol2coefyaxis
    :field adcs_pget_g2tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol1coefyaxis
    :field adcs_pget_g2tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol0coefyaxis
    :field adcs_pget_g2tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol2coefzaxis
    :field adcs_pget_g2tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol1coefzaxis
    :field adcs_pget_g2tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g2.adcs_pget_g2tbiaspol0coefzaxis
    :field adcs_pget_g3tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol2coefxaxis
    :field adcs_pget_g3tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol1coefxaxis
    :field adcs_pget_g3tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol0coefxaxis
    :field adcs_pget_g3tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol2coefyaxis
    :field adcs_pget_g3tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol1coefyaxis
    :field adcs_pget_g3tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol0coefyaxis
    :field adcs_pget_g3tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol2coefzaxis
    :field adcs_pget_g3tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol1coefzaxis
    :field adcs_pget_g3tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g3.adcs_pget_g3tbiaspol0coefzaxis
    :field adcs_pget_g4tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol2coefxaxis
    :field adcs_pget_g4tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol1coefxaxis
    :field adcs_pget_g4tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol0coefxaxis
    :field adcs_pget_g4tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol2coefyaxis
    :field adcs_pget_g4tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol1coefyaxis
    :field adcs_pget_g4tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol0coefyaxis
    :field adcs_pget_g4tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol2coefzaxis
    :field adcs_pget_g4tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol1coefzaxis
    :field adcs_pget_g4tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g4.adcs_pget_g4tbiaspol0coefzaxis
    :field adcs_pget_g5tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol2coefxaxis
    :field adcs_pget_g5tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol1coefxaxis
    :field adcs_pget_g5tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol0coefxaxis
    :field adcs_pget_g5tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol2coefyaxis
    :field adcs_pget_g5tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol1coefyaxis
    :field adcs_pget_g5tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol0coefyaxis
    :field adcs_pget_g5tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol2coefzaxis
    :field adcs_pget_g5tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol1coefzaxis
    :field adcs_pget_g5tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g5.adcs_pget_g5tbiaspol0coefzaxis
    :field adcs_pget_g6tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol2coefxaxis
    :field adcs_pget_g6tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol1coefxaxis
    :field adcs_pget_g6tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol0coefxaxis
    :field adcs_pget_g6tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol2coefyaxis
    :field adcs_pget_g6tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol1coefyaxis
    :field adcs_pget_g6tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol0coefyaxis
    :field adcs_pget_g6tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol2coefzaxis
    :field adcs_pget_g6tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol1coefzaxis
    :field adcs_pget_g6tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g6.adcs_pget_g6tbiaspol0coefzaxis
    :field adcs_pget_g7tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol2coefxaxis
    :field adcs_pget_g7tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol1coefxaxis
    :field adcs_pget_g7tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol0coefxaxis
    :field adcs_pget_g7tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol2coefyaxis
    :field adcs_pget_g7tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol1coefyaxis
    :field adcs_pget_g7tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol0coefyaxis
    :field adcs_pget_g7tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol2coefzaxis
    :field adcs_pget_g7tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol1coefzaxis
    :field adcs_pget_g7tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g7.adcs_pget_g7tbiaspol0coefzaxis
    :field adcs_pget_g8tbiaspol2coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol2coefxaxis
    :field adcs_pget_g8tbiaspol1coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol1coefxaxis
    :field adcs_pget_g8tbiaspol0coefxaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol0coefxaxis
    :field adcs_pget_g8tbiaspol2coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol2coefyaxis
    :field adcs_pget_g8tbiaspol1coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol1coefyaxis
    :field adcs_pget_g8tbiaspol0coefyaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol0coefyaxis
    :field adcs_pget_g8tbiaspol2coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol2coefzaxis
    :field adcs_pget_g8tbiaspol1coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol1coefzaxis
    :field adcs_pget_g8tbiaspol0coefzaxis: salsat_frame.user_data_adcs_cal_tcomp_g8.adcs_pget_g8tbiaspol0coefzaxis
    :field adcs_pget_suse1mappingpol0coefx: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol0coefx
    :field adcs_pget_suse1mappingpol1coefx: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol1coefx
    :field adcs_pget_suse1mappingpol2coefx: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol2coefx
    :field adcs_pget_suse1mappingpol3coefx: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol3coefx
    :field adcs_pget_suse1mappingpol0coefy: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol0coefy
    :field adcs_pget_suse1mappingpol1coefy: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol1coefy
    :field adcs_pget_suse1mappingpol2coefy: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol2coefy
    :field adcs_pget_suse1mappingpol3coefy: salsat_frame.user_data_adcs_cal_mapping_suse1.adcs_pget_suse1mappingpol3coefy
    :field adcs_pget_suse2mappingpol0coefx: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol0coefx
    :field adcs_pget_suse2mappingpol1coefx: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol1coefx
    :field adcs_pget_suse2mappingpol2coefx: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol2coefx
    :field adcs_pget_suse2mappingpol3coefx: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol3coefx
    :field adcs_pget_suse2mappingpol0coefy: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol0coefy
    :field adcs_pget_suse2mappingpol1coefy: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol1coefy
    :field adcs_pget_suse2mappingpol2coefy: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol2coefy
    :field adcs_pget_suse2mappingpol3coefy: salsat_frame.user_data_adcs_cal_mapping_suse2.adcs_pget_suse2mappingpol3coefy
    :field adcs_pget_suse3mappingpol0coefx: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol0coefx
    :field adcs_pget_suse3mappingpol1coefx: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol1coefx
    :field adcs_pget_suse3mappingpol2coefx: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol2coefx
    :field adcs_pget_suse3mappingpol3coefx: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol3coefx
    :field adcs_pget_suse3mappingpol0coefy: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol0coefy
    :field adcs_pget_suse3mappingpol1coefy: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol1coefy
    :field adcs_pget_suse3mappingpol2coefy: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol2coefy
    :field adcs_pget_suse3mappingpol3coefy: salsat_frame.user_data_adcs_cal_mapping_suse3.adcs_pget_suse3mappingpol3coefy
    :field adcs_pget_suse4mappingpol0coefx: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol0coefx
    :field adcs_pget_suse4mappingpol1coefx: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol1coefx
    :field adcs_pget_suse4mappingpol2coefx: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol2coefx
    :field adcs_pget_suse4mappingpol3coefx: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol3coefx
    :field adcs_pget_suse4mappingpol0coefy: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol0coefy
    :field adcs_pget_suse4mappingpol1coefy: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol1coefy
    :field adcs_pget_suse4mappingpol2coefy: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol2coefy
    :field adcs_pget_suse4mappingpol3coefy: salsat_frame.user_data_adcs_cal_mapping_suse4.adcs_pget_suse4mappingpol3coefy
    :field adcs_pget_suse5mappingpol0coefx: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol0coefx
    :field adcs_pget_suse5mappingpol1coefx: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol1coefx
    :field adcs_pget_suse5mappingpol2coefx: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol2coefx
    :field adcs_pget_suse5mappingpol3coefx: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol3coefx
    :field adcs_pget_suse5mappingpol0coefy: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol0coefy
    :field adcs_pget_suse5mappingpol1coefy: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol1coefy
    :field adcs_pget_suse5mappingpol2coefy: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol2coefy
    :field adcs_pget_suse5mappingpol3coefy: salsat_frame.user_data_adcs_cal_mapping_suse5.adcs_pget_suse5mappingpol3coefy
    :field adcs_pget_suse6mappingpol0coefx: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol0coefx
    :field adcs_pget_suse6mappingpol1coefx: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol1coefx
    :field adcs_pget_suse6mappingpol2coefx: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol2coefx
    :field adcs_pget_suse6mappingpol3coefx: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol3coefx
    :field adcs_pget_suse6mappingpol0coefy: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol0coefy
    :field adcs_pget_suse6mappingpol1coefy: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol1coefy
    :field adcs_pget_suse6mappingpol2coefy: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol2coefy
    :field adcs_pget_suse6mappingpol3coefy: salsat_frame.user_data_adcs_cal_mapping_suse6.adcs_pget_suse6mappingpol3coefy
    :field adcs_pget_ecitosatdcmoptimalu1: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalu1
    :field adcs_pget_ecitosatdcmoptimalu2: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalu2
    :field adcs_pget_ecitosatdcmoptimalu3: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalu3
    :field adcs_pget_ecitosatdcmoptimalv1: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalv1
    :field adcs_pget_ecitosatdcmoptimalv2: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalv2
    :field adcs_pget_ecitosatdcmoptimalv3: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalv3
    :field adcs_pget_ecitosatdcmoptimalw1: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalw1
    :field adcs_pget_ecitosatdcmoptimalw2: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalw2
    :field adcs_pget_ecitosatdcmoptimalw3: salsat_frame.user_data_adcs_att_dcm_ecitosat_optimal.adcs_pget_ecitosatdcmoptimalw3
    :field adcs_pget_ecitotgtdcmu1: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmu1
    :field adcs_pget_ecitotgtdcmu2: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmu2
    :field adcs_pget_ecitotgtdcmu3: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmu3
    :field adcs_pget_ecitotgtdcmv1: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmv1
    :field adcs_pget_ecitotgtdcmv2: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmv2
    :field adcs_pget_ecitotgtdcmv3: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmv3
    :field adcs_pget_ecitotgtdcmw1: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmw1
    :field adcs_pget_ecitotgtdcmw2: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmw2
    :field adcs_pget_ecitotgtdcmw3: salsat_frame.user_data_adcs_att_dcm_ecitotgt.adcs_pget_ecitotgtdcmw3
    :field adcs_pget_omegaxga_sat: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_omegaxga_sat
    :field adcs_pget_omegayga_sat: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_omegayga_sat
    :field adcs_pget_omegazga_sat: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_omegazga_sat
    :field adcs_pget_ga_useflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_ga_useflag
    :field adcs_pget_g1_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g1_validflag
    :field adcs_pget_g2_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g2_validflag
    :field adcs_pget_g3_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g3_validflag
    :field adcs_pget_g4_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g4_validflag
    :field adcs_pget_g5_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g5_validflag
    :field adcs_pget_g6_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g6_validflag
    :field adcs_pget_g7_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g7_validflag
    :field adcs_pget_g8_validflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_g8_validflag
    :field adcs_pget_attdetgahighprecmodeflag: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_attdetgahighprecmodeflag
    :field adcs_pget_iinusecountga: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_iinusecountga
    :field adcs_pget_isensorstateg1: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg1
    :field adcs_pget_isensorstateg2: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg2
    :field adcs_pget_isensorstateg3: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg3
    :field adcs_pget_isensorstateg4: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg4
    :field adcs_pget_isensorstateg5: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg5
    :field adcs_pget_isensorstateg6: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg6
    :field adcs_pget_isensorstateg7: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg7
    :field adcs_pget_isensorstateg8: salsat_frame.user_data_adcs_sensea_ga_std_tm.adcs_pget_isensorstateg8
    :field adcs_pget_dxmfsa_sat: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_dxmfsa_sat
    :field adcs_pget_dymfsa_sat: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_dymfsa_sat
    :field adcs_pget_dzmfsa_sat: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_dzmfsa_sat
    :field adcs_pget_mfsa_useflag: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_mfsa_useflag
    :field adcs_pget_mfs1_validflag: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_mfs1_validflag
    :field adcs_pget_mfs2_validflag: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_mfs2_validflag
    :field adcs_pget_mfs3_validflag: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_mfs3_validflag
    :field adcs_pget_mfs4_validflag: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_mfs4_validflag
    :field user_data_adcs_sensea_mfsa_std_tm_adcs_pget_attdetmfsdistcorrmode: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_attdetmfsdistcorrmode
    :field adcs_pget_iinusecountmfsa: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_iinusecountmfsa
    :field adcs_pget_isensorstatemfs1: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_isensorstatemfs1
    :field adcs_pget_isensorstatemfs2: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_isensorstatemfs2
    :field adcs_pget_isensorstatemfs3: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_isensorstatemfs3
    :field adcs_pget_isensorstatemfs4: salsat_frame.user_data_adcs_sensea_mfsa_std_tm.adcs_pget_isensorstatemfs4
    :field adcs_pget_dxsusea_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_dxsusea_sat
    :field adcs_pget_dysusea_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_dysusea_sat
    :field adcs_pget_dzsusea_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_dzsusea_sat
    :field adcs_pget_susea_useflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_susea_useflag
    :field adcs_pget_suse1_validflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse1_validflag
    :field adcs_pget_suse2_validflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse2_validflag
    :field adcs_pget_suse3_validflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse3_validflag
    :field adcs_pget_suse4_validflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse4_validflag
    :field adcs_pget_suse5_validflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse5_validflag
    :field adcs_pget_suse6_validflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse6_validflag
    :field user_data_adcs_sensea_susea_std_tm_adcs_pget_suse1albedoflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse1albedoflag
    :field user_data_adcs_sensea_susea_std_tm_adcs_pget_suse2albedoflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse2albedoflag
    :field user_data_adcs_sensea_susea_std_tm_adcs_pget_suse3albedoflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse3albedoflag
    :field user_data_adcs_sensea_susea_std_tm_adcs_pget_suse4albedoflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse4albedoflag
    :field user_data_adcs_sensea_susea_std_tm_adcs_pget_suse5albedoflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse5albedoflag
    :field user_data_adcs_sensea_susea_std_tm_adcs_pget_suse6albedoflag: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_suse6albedoflag
    :field user_data_adcs_sensea_susea_std_tm_adcs_pget_attdetsusedistcorrmode: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_attdetsusedistcorrmode
    :field adcs_pget_iinusecountsusea: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_iinusecountsusea
    :field adcs_pget_isensorstates1: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_isensorstates1
    :field adcs_pget_isensorstates2: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_isensorstates2
    :field adcs_pget_isensorstates3: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_isensorstates3
    :field adcs_pget_isensorstates4: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_isensorstates4
    :field adcs_pget_isensorstates5: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_isensorstates5
    :field adcs_pget_isensorstates6: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_isensorstates6
    :field adcs_pget_cursumsuse1_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_cursumsuse1_sat
    :field adcs_pget_cursumsuse2_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_cursumsuse2_sat
    :field adcs_pget_cursumsuse3_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_cursumsuse3_sat
    :field adcs_pget_cursumsuse4_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_cursumsuse4_sat
    :field adcs_pget_cursumsuse5_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_cursumsuse5_sat
    :field adcs_pget_cursumsuse6_sat: salsat_frame.user_data_adcs_sensea_susea_std_tm.adcs_pget_cursumsuse6_sat
    :field adcs_pget_dctrltorquerwaz_sat: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_dctrltorquerwaz_sat
    :field adcs_pget_dctrltorquerwax_sat: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_dctrltorquerwax_sat
    :field adcs_pget_dctrltorquerway_sat: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_dctrltorquerway_sat
    :field adcs_pget_rwa_useflag: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_rwa_useflag
    :field user_data_adcs_acta_rwa_std_tm_adcs_pget_iactarrayavailstatusrwa: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_iactarrayavailstatusrwa
    :field adcs_pget_iactstaterwx: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_iactstaterwx
    :field adcs_pget_iactstaterwy: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_iactstaterwy
    :field adcs_pget_iactstaterwz: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_iactstaterwz
    :field adcs_pget_rwxruntime: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_rwxruntime
    :field adcs_pget_rwyruntime: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_rwyruntime
    :field adcs_pget_rwzruntime: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_rwzruntime
    :field adcs_pget_rwxruntimethreshold: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_rwxruntimethreshold
    :field adcs_pget_rwyruntimethreshold: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_rwyruntimethreshold
    :field adcs_pget_rwzruntimethreshold: salsat_frame.user_data_adcs_acta_rwa_std_tm.adcs_pget_rwzruntimethreshold
    :field adcs_pget_dctrlmagmomentmatax_sat: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_dctrlmagmomentmatax_sat
    :field adcs_pget_dctrlmagmomentmatay_sat: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_dctrlmagmomentmatay_sat
    :field adcs_pget_dctrlmagmomentmataz_sat: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_dctrlmagmomentmataz_sat
    :field adcs_pget_mata_useflag: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_mata_useflag
    :field user_data_adcs_acta_mata_std_tm_adcs_pget_iactarrayavailstatusmata: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_iactarrayavailstatusmata
    :field adcs_pget_iactstatematx: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_iactstatematx
    :field adcs_pget_iactstatematy: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_iactstatematy
    :field adcs_pget_iactstatematz: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_iactstatematz
    :field adcs_pget_matxruntime: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_matxruntime
    :field adcs_pget_matyruntime: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_matyruntime
    :field adcs_pget_matzruntime: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_matzruntime
    :field adcs_pget_matxruntimethreshold: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_matxruntimethreshold
    :field adcs_pget_matyruntimethreshold: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_matyruntimethreshold
    :field adcs_pget_matzruntimethreshold: salsat_frame.user_data_adcs_acta_mata_std_tm.adcs_pget_matzruntimethreshold
    :field adcs_pget_omegaxg1_sat: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_omegaxg1_sat
    :field adcs_pget_omegayg1_sat: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_omegayg1_sat
    :field adcs_pget_omegazg1_sat: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_omegazg1_sat
    :field thm_pget_tempg1: salsat_frame.user_data_adcs_sense_g1_omega.thm_pget_tempg1
    :field adcs_pget_g1_useflag: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_g1_useflag
    :field adcs_pget_g1_useflaglock: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_g1_useflaglock
    :field adcs_pget_g1_powerflag: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_g1_powerflag
    :field adcs_pget_g1_powerflaglock: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_g1_powerflaglock
    :field adcs_pget_g1_healthflag: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_g1_healthflag
    :field user_data_adcs_sense_g1_omega_adcs_pget_g1_validflag: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_g1_validflag
    :field user_data_adcs_sense_g1_omega_adcs_pget_isensorstateg1: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_isensorstateg1
    :field adcs_pget_ififofilllevelg1: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_ififofilllevelg1
    :field adcs_pget_isensorstatusg1: salsat_frame.user_data_adcs_sense_g1_omega.adcs_pget_isensorstatusg1
    :field adcs_pget_omegaxg2_sat: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_omegaxg2_sat
    :field adcs_pget_omegayg2_sat: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_omegayg2_sat
    :field adcs_pget_omegazg2_sat: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_omegazg2_sat
    :field thm_pget_tempg2: salsat_frame.user_data_adcs_sense_g2_omega.thm_pget_tempg2
    :field adcs_pget_g2_useflag: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_g2_useflag
    :field adcs_pget_g2_useflaglock: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_g2_useflaglock
    :field adcs_pget_g2_powerflag: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_g2_powerflag
    :field adcs_pget_g2_powerflaglock: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_g2_powerflaglock
    :field adcs_pget_g2_healthflag: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_g2_healthflag
    :field user_data_adcs_sense_g2_omega_adcs_pget_g2_validflag: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_g2_validflag
    :field user_data_adcs_sense_g2_omega_adcs_pget_isensorstateg2: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_isensorstateg2
    :field adcs_pget_ififofilllevelg2: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_ififofilllevelg2
    :field adcs_pget_isensorstatusg2: salsat_frame.user_data_adcs_sense_g2_omega.adcs_pget_isensorstatusg2
    :field adcs_pget_omegaxg3_sat: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_omegaxg3_sat
    :field adcs_pget_omegayg3_sat: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_omegayg3_sat
    :field adcs_pget_omegazg3_sat: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_omegazg3_sat
    :field thm_pget_tempg3: salsat_frame.user_data_adcs_sense_g3_omega.thm_pget_tempg3
    :field adcs_pget_g3_useflag: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_g3_useflag
    :field adcs_pget_g3_useflaglock: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_g3_useflaglock
    :field adcs_pget_g3_powerflag: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_g3_powerflag
    :field adcs_pget_g3_powerflaglock: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_g3_powerflaglock
    :field adcs_pget_g3_healthflag: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_g3_healthflag
    :field user_data_adcs_sense_g3_omega_adcs_pget_g3_validflag: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_g3_validflag
    :field user_data_adcs_sense_g3_omega_adcs_pget_isensorstateg3: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_isensorstateg3
    :field adcs_pget_ififofilllevelg3: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_ififofilllevelg3
    :field adcs_pget_isensorstatusg3: salsat_frame.user_data_adcs_sense_g3_omega.adcs_pget_isensorstatusg3
    :field adcs_pget_omegaxg4_sat: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_omegaxg4_sat
    :field adcs_pget_omegayg4_sat: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_omegayg4_sat
    :field adcs_pget_omegazg4_sat: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_omegazg4_sat
    :field thm_pget_tempg4: salsat_frame.user_data_adcs_sense_g4_omega.thm_pget_tempg4
    :field adcs_pget_g4_useflag: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_g4_useflag
    :field adcs_pget_g4_useflaglock: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_g4_useflaglock
    :field adcs_pget_g4_powerflag: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_g4_powerflag
    :field adcs_pget_g4_powerflaglock: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_g4_powerflaglock
    :field adcs_pget_g4_healthflag: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_g4_healthflag
    :field user_data_adcs_sense_g4_omega_adcs_pget_g4_validflag: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_g4_validflag
    :field user_data_adcs_sense_g4_omega_adcs_pget_isensorstateg4: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_isensorstateg4
    :field adcs_pget_ififofilllevelg4: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_ififofilllevelg4
    :field adcs_pget_isensorstatusg4: salsat_frame.user_data_adcs_sense_g4_omega.adcs_pget_isensorstatusg4
    :field adcs_pget_omegaxg5_sat: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_omegaxg5_sat
    :field adcs_pget_omegayg5_sat: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_omegayg5_sat
    :field adcs_pget_omegazg5_sat: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_omegazg5_sat
    :field thm_pget_tempg5: salsat_frame.user_data_adcs_sense_g5_omega.thm_pget_tempg5
    :field adcs_pget_g5_useflag: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_g5_useflag
    :field adcs_pget_g5_useflaglock: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_g5_useflaglock
    :field adcs_pget_g5_powerflag: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_g5_powerflag
    :field adcs_pget_g5_powerflaglock: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_g5_powerflaglock
    :field adcs_pget_g5_healthflag: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_g5_healthflag
    :field user_data_adcs_sense_g5_omega_adcs_pget_g5_validflag: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_g5_validflag
    :field user_data_adcs_sense_g5_omega_adcs_pget_isensorstateg5: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_isensorstateg5
    :field adcs_pget_ififofilllevelg5: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_ififofilllevelg5
    :field adcs_pget_isensorstatusg5: salsat_frame.user_data_adcs_sense_g5_omega.adcs_pget_isensorstatusg5
    :field adcs_pget_omegaxg6_sat: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_omegaxg6_sat
    :field adcs_pget_omegayg6_sat: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_omegayg6_sat
    :field adcs_pget_omegazg6_sat: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_omegazg6_sat
    :field thm_pget_tempg6: salsat_frame.user_data_adcs_sense_g6_omega.thm_pget_tempg6
    :field adcs_pget_g6_useflag: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_g6_useflag
    :field adcs_pget_g6_useflaglock: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_g6_useflaglock
    :field adcs_pget_g6_powerflag: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_g6_powerflag
    :field adcs_pget_g6_powerflaglock: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_g6_powerflaglock
    :field adcs_pget_g6_healthflag: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_g6_healthflag
    :field user_data_adcs_sense_g6_omega_adcs_pget_g6_validflag: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_g6_validflag
    :field user_data_adcs_sense_g6_omega_adcs_pget_isensorstateg6: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_isensorstateg6
    :field adcs_pget_ififofilllevelg6: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_ififofilllevelg6
    :field adcs_pget_isensorstatusg6: salsat_frame.user_data_adcs_sense_g6_omega.adcs_pget_isensorstatusg6
    :field adcs_pget_omegaxg7_sat: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_omegaxg7_sat
    :field adcs_pget_omegayg7_sat: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_omegayg7_sat
    :field adcs_pget_omegazg7_sat: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_omegazg7_sat
    :field thm_pget_tempg7: salsat_frame.user_data_adcs_sense_g7_omega.thm_pget_tempg7
    :field adcs_pget_g7_useflag: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_g7_useflag
    :field adcs_pget_g7_useflaglock: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_g7_useflaglock
    :field adcs_pget_g7_powerflag: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_g7_powerflag
    :field adcs_pget_g7_powerflaglock: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_g7_powerflaglock
    :field adcs_pget_g7_healthflag: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_g7_healthflag
    :field user_data_adcs_sense_g7_omega_adcs_pget_g7_validflag: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_g7_validflag
    :field user_data_adcs_sense_g7_omega_adcs_pget_isensorstateg7: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_isensorstateg7
    :field adcs_pget_ififofilllevelg7: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_ififofilllevelg7
    :field adcs_pget_isensorstatusg7: salsat_frame.user_data_adcs_sense_g7_omega.adcs_pget_isensorstatusg7
    :field adcs_pget_omegaxg8_sat: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_omegaxg8_sat
    :field adcs_pget_omegayg8_sat: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_omegayg8_sat
    :field adcs_pget_omegazg8_sat: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_omegazg8_sat
    :field thm_pget_tempg8: salsat_frame.user_data_adcs_sense_g8_omega.thm_pget_tempg8
    :field adcs_pget_g8_useflag: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_g8_useflag
    :field adcs_pget_g8_useflaglock: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_g8_useflaglock
    :field adcs_pget_g8_powerflag: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_g8_powerflag
    :field adcs_pget_g8_powerflaglock: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_g8_powerflaglock
    :field adcs_pget_g8_healthflag: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_g8_healthflag
    :field user_data_adcs_sense_g8_omega_adcs_pget_g8_validflag: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_g8_validflag
    :field user_data_adcs_sense_g8_omega_adcs_pget_isensorstateg8: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_isensorstateg8
    :field adcs_pget_ififofilllevelg8: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_ififofilllevelg8
    :field adcs_pget_isensorstatusg8: salsat_frame.user_data_adcs_sense_g8_omega.adcs_pget_isensorstatusg8
    :field adcs_pget_dxmfs1_sat: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_dxmfs1_sat
    :field adcs_pget_dymfs1_sat: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_dymfs1_sat
    :field adcs_pget_dzmfs1_sat: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_dzmfs1_sat
    :field adcs_pget_mfs1_useflag: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_mfs1_useflag
    :field adcs_pget_mfs1_useflaglock: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_mfs1_useflaglock
    :field adcs_pget_mfs1_powerflag: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_mfs1_powerflag
    :field adcs_pget_mfs1_powerflaglock: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_mfs1_powerflaglock
    :field adcs_pget_mfs1_healthflag: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_mfs1_healthflag
    :field user_data_adcs_sense_mfs1_b_adcs_pget_mfs1_validflag: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_mfs1_validflag
    :field user_data_adcs_sense_mfs1_b_adcs_pget_isensorstatemfs1: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_isensorstatemfs1
    :field adcs_pget_isensorstatusmfs1: salsat_frame.user_data_adcs_sense_mfs1_b.adcs_pget_isensorstatusmfs1
    :field adcs_pget_dxmfs2_sat: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_dxmfs2_sat
    :field adcs_pget_dymfs2_sat: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_dymfs2_sat
    :field adcs_pget_dzmfs2_sat: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_dzmfs2_sat
    :field adcs_pget_mfs2_useflag: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_mfs2_useflag
    :field adcs_pget_mfs2_useflaglock: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_mfs2_useflaglock
    :field adcs_pget_mfs2_powerflag: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_mfs2_powerflag
    :field adcs_pget_mfs2_powerflaglock: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_mfs2_powerflaglock
    :field adcs_pget_mfs2_healthflag: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_mfs2_healthflag
    :field user_data_adcs_sense_mfs2_b_adcs_pget_mfs2_validflag: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_mfs2_validflag
    :field user_data_adcs_sense_mfs2_b_adcs_pget_isensorstatemfs2: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_isensorstatemfs2
    :field adcs_pget_isensorstatusmfs2: salsat_frame.user_data_adcs_sense_mfs2_b.adcs_pget_isensorstatusmfs2
    :field adcs_pget_dxmfs3_sat: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_dxmfs3_sat
    :field adcs_pget_dymfs3_sat: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_dymfs3_sat
    :field adcs_pget_dzmfs3_sat: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_dzmfs3_sat
    :field adcs_pget_mfs3_useflag: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_mfs3_useflag
    :field adcs_pget_mfs3_useflaglock: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_mfs3_useflaglock
    :field adcs_pget_mfs3_powerflag: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_mfs3_powerflag
    :field adcs_pget_mfs3_powerflaglock: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_mfs3_powerflaglock
    :field adcs_pget_mfs3_healthflag: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_mfs3_healthflag
    :field user_data_adcs_sense_mfs3_b_adcs_pget_mfs3_validflag: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_mfs3_validflag
    :field user_data_adcs_sense_mfs3_b_adcs_pget_isensorstatemfs3: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_isensorstatemfs3
    :field adcs_pget_isensorstatusmfs3: salsat_frame.user_data_adcs_sense_mfs3_b.adcs_pget_isensorstatusmfs3
    :field adcs_pget_dxmfs4_sat: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_dxmfs4_sat
    :field adcs_pget_dymfs4_sat: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_dymfs4_sat
    :field adcs_pget_dzmfs4_sat: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_dzmfs4_sat
    :field adcs_pget_mfs4_useflag: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_mfs4_useflag
    :field adcs_pget_mfs4_useflaglock: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_mfs4_useflaglock
    :field adcs_pget_mfs4_powerflag: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_mfs4_powerflag
    :field adcs_pget_mfs4_powerflaglock: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_mfs4_powerflaglock
    :field adcs_pget_mfs4_healthflag: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_mfs4_healthflag
    :field user_data_adcs_sense_mfs4_b_adcs_pget_mfs4_validflag: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_mfs4_validflag
    :field user_data_adcs_sense_mfs4_b_adcs_pget_isensorstatemfs4: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_isensorstatemfs4
    :field adcs_pget_isensorstatusmfs4: salsat_frame.user_data_adcs_sense_mfs4_b.adcs_pget_isensorstatusmfs4
    :field adcs_pget_dxsuse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_dxsuse1_sat
    :field adcs_pget_dysuse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_dysuse1_sat
    :field adcs_pget_dzsuse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_dzsuse1_sat
    :field thm_pget_tempsuse1: salsat_frame.user_data_adcs_sense_suse1_d.thm_pget_tempsuse1
    :field user_data_adcs_sense_suse1_d_adcs_pget_cursumsuse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_cursumsuse1_sat
    :field adcs_pget_curx1suse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_curx1suse1_sat
    :field adcs_pget_curx2suse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_curx2suse1_sat
    :field adcs_pget_cury1suse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_cury1suse1_sat
    :field adcs_pget_cury2suse1_sat: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_cury2suse1_sat
    :field adcs_pget_suse1_useflag: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_suse1_useflag
    :field adcs_pget_suse1_useflaglock: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_suse1_useflaglock
    :field adcs_pget_suse1_powerflag: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_suse1_powerflag
    :field adcs_pget_suse1_powerflaglock: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_suse1_powerflaglock
    :field adcs_pget_suse1_healthflag: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_suse1_healthflag
    :field user_data_adcs_sense_suse1_d_adcs_pget_suse1_validflag: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_suse1_validflag
    :field user_data_adcs_sense_suse1_d_adcs_pget_isensorstates1: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_isensorstates1
    :field adcs_pget_isensorstatuss1: salsat_frame.user_data_adcs_sense_suse1_d.adcs_pget_isensorstatuss1
    :field adcs_pget_dxsuse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_dxsuse2_sat
    :field adcs_pget_dysuse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_dysuse2_sat
    :field adcs_pget_dzsuse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_dzsuse2_sat
    :field thm_pget_tempsuse2: salsat_frame.user_data_adcs_sense_suse2_d.thm_pget_tempsuse2
    :field user_data_adcs_sense_suse2_d_adcs_pget_cursumsuse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_cursumsuse2_sat
    :field adcs_pget_curx1suse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_curx1suse2_sat
    :field adcs_pget_curx2suse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_curx2suse2_sat
    :field adcs_pget_cury1suse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_cury1suse2_sat
    :field adcs_pget_cury2suse2_sat: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_cury2suse2_sat
    :field adcs_pget_suse2_useflag: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_suse2_useflag
    :field adcs_pget_suse2_useflaglock: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_suse2_useflaglock
    :field adcs_pget_suse2_powerflag: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_suse2_powerflag
    :field adcs_pget_suse2_powerflaglock: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_suse2_powerflaglock
    :field adcs_pget_suse2_healthflag: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_suse2_healthflag
    :field user_data_adcs_sense_suse2_d_adcs_pget_suse2_validflag: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_suse2_validflag
    :field user_data_adcs_sense_suse2_d_adcs_pget_isensorstates2: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_isensorstates2
    :field adcs_pget_isensorstatuss2: salsat_frame.user_data_adcs_sense_suse2_d.adcs_pget_isensorstatuss2
    :field adcs_pget_dxsuse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_dxsuse3_sat
    :field adcs_pget_dysuse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_dysuse3_sat
    :field adcs_pget_dzsuse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_dzsuse3_sat
    :field thm_pget_tempsuse3: salsat_frame.user_data_adcs_sense_suse3_d.thm_pget_tempsuse3
    :field user_data_adcs_sense_suse3_d_adcs_pget_cursumsuse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_cursumsuse3_sat
    :field adcs_pget_curx1suse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_curx1suse3_sat
    :field adcs_pget_curx2suse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_curx2suse3_sat
    :field adcs_pget_cury1suse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_cury1suse3_sat
    :field adcs_pget_cury2suse3_sat: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_cury2suse3_sat
    :field adcs_pget_suse3_useflag: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_suse3_useflag
    :field adcs_pget_suse3_useflaglock: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_suse3_useflaglock
    :field adcs_pget_suse3_powerflag: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_suse3_powerflag
    :field adcs_pget_suse3_powerflaglock: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_suse3_powerflaglock
    :field adcs_pget_suse3_healthflag: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_suse3_healthflag
    :field user_data_adcs_sense_suse3_d_adcs_pget_suse3_validflag: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_suse3_validflag
    :field user_data_adcs_sense_suse3_d_adcs_pget_isensorstates3: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_isensorstates3
    :field adcs_pget_isensorstatuss3: salsat_frame.user_data_adcs_sense_suse3_d.adcs_pget_isensorstatuss3
    :field adcs_pget_dxsuse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_dxsuse4_sat
    :field adcs_pget_dysuse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_dysuse4_sat
    :field adcs_pget_dzsuse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_dzsuse4_sat
    :field thm_pget_tempsuse4: salsat_frame.user_data_adcs_sense_suse4_d.thm_pget_tempsuse4
    :field user_data_adcs_sense_suse4_d_adcs_pget_cursumsuse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_cursumsuse4_sat
    :field adcs_pget_curx1suse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_curx1suse4_sat
    :field adcs_pget_curx2suse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_curx2suse4_sat
    :field adcs_pget_cury1suse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_cury1suse4_sat
    :field adcs_pget_cury2suse4_sat: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_cury2suse4_sat
    :field adcs_pget_suse4_useflag: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_suse4_useflag
    :field adcs_pget_suse4_useflaglock: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_suse4_useflaglock
    :field adcs_pget_suse4_powerflag: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_suse4_powerflag
    :field adcs_pget_suse4_powerflaglock: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_suse4_powerflaglock
    :field adcs_pget_suse4_healthflag: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_suse4_healthflag
    :field user_data_adcs_sense_suse4_d_adcs_pget_suse4_validflag: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_suse4_validflag
    :field user_data_adcs_sense_suse4_d_adcs_pget_isensorstates4: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_isensorstates4
    :field adcs_pget_isensorstatuss4: salsat_frame.user_data_adcs_sense_suse4_d.adcs_pget_isensorstatuss4
    :field adcs_pget_dxsuse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_dxsuse5_sat
    :field adcs_pget_dysuse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_dysuse5_sat
    :field adcs_pget_dzsuse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_dzsuse5_sat
    :field thm_pget_tempsuse5: salsat_frame.user_data_adcs_sense_suse5_d.thm_pget_tempsuse5
    :field user_data_adcs_sense_suse5_d_adcs_pget_cursumsuse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_cursumsuse5_sat
    :field adcs_pget_curx1suse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_curx1suse5_sat
    :field adcs_pget_curx2suse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_curx2suse5_sat
    :field adcs_pget_cury1suse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_cury1suse5_sat
    :field adcs_pget_cury2suse5_sat: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_cury2suse5_sat
    :field adcs_pget_suse5_useflag: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_suse5_useflag
    :field adcs_pget_suse5_useflaglock: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_suse5_useflaglock
    :field adcs_pget_suse5_powerflag: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_suse5_powerflag
    :field adcs_pget_suse5_powerflaglock: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_suse5_powerflaglock
    :field adcs_pget_suse5_healthflag: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_suse5_healthflag
    :field user_data_adcs_sense_suse5_d_adcs_pget_suse5_validflag: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_suse5_validflag
    :field user_data_adcs_sense_suse5_d_adcs_pget_isensorstates5: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_isensorstates5
    :field adcs_pget_isensorstatuss5: salsat_frame.user_data_adcs_sense_suse5_d.adcs_pget_isensorstatuss5
    :field adcs_pget_dxsuse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_dxsuse6_sat
    :field adcs_pget_dysuse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_dysuse6_sat
    :field adcs_pget_dzsuse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_dzsuse6_sat
    :field thm_pget_tempsuse6: salsat_frame.user_data_adcs_sense_suse6_d.thm_pget_tempsuse6
    :field user_data_adcs_sense_suse6_d_adcs_pget_cursumsuse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_cursumsuse6_sat
    :field adcs_pget_curx1suse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_curx1suse6_sat
    :field adcs_pget_curx2suse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_curx2suse6_sat
    :field adcs_pget_cury1suse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_cury1suse6_sat
    :field adcs_pget_cury2suse6_sat: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_cury2suse6_sat
    :field adcs_pget_suse6_useflag: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_suse6_useflag
    :field adcs_pget_suse6_useflaglock: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_suse6_useflaglock
    :field adcs_pget_suse6_powerflag: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_suse6_powerflag
    :field adcs_pget_suse6_powerflaglock: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_suse6_powerflaglock
    :field adcs_pget_suse6_healthflag: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_suse6_healthflag
    :field user_data_adcs_sense_suse6_d_adcs_pget_suse6_validflag: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_suse6_validflag
    :field user_data_adcs_sense_suse6_d_adcs_pget_isensorstates6: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_isensorstates6
    :field adcs_pget_isensorstatuss6: salsat_frame.user_data_adcs_sense_suse6_d.adcs_pget_isensorstatuss6
    :field adcs_pget_dcmdmagmomentmatax_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dcmdmagmomentmatax_sat
    :field adcs_pget_dcmdmagmomentmatay_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dcmdmagmomentmatay_sat
    :field adcs_pget_dcmdmagmomentmataz_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dcmdmagmomentmataz_sat
    :field user_data_adcs_acta_mata_loop_vec_adcs_pget_dctrlmagmomentmatax_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlmagmomentmatax_sat
    :field user_data_adcs_acta_mata_loop_vec_adcs_pget_dctrlmagmomentmatay_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlmagmomentmatay_sat
    :field user_data_adcs_acta_mata_loop_vec_adcs_pget_dctrlmagmomentmataz_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlmagmomentmataz_sat
    :field adcs_pget_dctrlmagmomentnamatax_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlmagmomentnamatax_sat
    :field adcs_pget_dctrlmagmomentnamatay_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlmagmomentnamatay_sat
    :field adcs_pget_dctrlmagmomentnamataz_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlmagmomentnamataz_sat
    :field adcs_pget_dctrlcurrentmatax_mfr: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlcurrentmatax_mfr
    :field adcs_pget_dctrlcurrentmatay_mfr: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlcurrentmatay_mfr
    :field adcs_pget_dctrlcurrentmataz_mfr: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrlcurrentmataz_mfr
    :field adcs_pget_dcmdtorquematax_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dcmdtorquematax_sat
    :field adcs_pget_dcmdtorquematay_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dcmdtorquematay_sat
    :field adcs_pget_dcmdtorquemataz_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dcmdtorquemataz_sat
    :field adcs_pget_dctrltorquematax_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrltorquematax_sat
    :field adcs_pget_dctrltorquematay_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrltorquematay_sat
    :field adcs_pget_dctrltorquemataz_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrltorquemataz_sat
    :field adcs_pget_dctrltorquenamatax_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrltorquenamatax_sat
    :field adcs_pget_dctrltorquenamatay_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrltorquenamatay_sat
    :field adcs_pget_dctrltorquenamataz_sat: salsat_frame.user_data_adcs_acta_mata_loop_vec.adcs_pget_dctrltorquenamataz_sat
    :field adcs_pget_dcmdtorquerwax_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dcmdtorquerwax_sat
    :field adcs_pget_dcmdtorquerway_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dcmdtorquerway_sat
    :field adcs_pget_dcmdtorquerwaz_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dcmdtorquerwaz_sat
    :field user_data_adcs_acta_rwa_loop_vec_adcs_pget_dctrltorquerwax_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dctrltorquerwax_sat
    :field user_data_adcs_acta_rwa_loop_vec_adcs_pget_dctrltorquerway_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dctrltorquerway_sat
    :field user_data_adcs_acta_rwa_loop_vec_adcs_pget_dctrltorquerwaz_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dctrltorquerwaz_sat
    :field adcs_pget_dctrltorquenarwax_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dctrltorquenarwax_sat
    :field adcs_pget_dctrltorquenarway_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dctrltorquenarway_sat
    :field adcs_pget_dctrltorquenarwaz_sat: salsat_frame.user_data_adcs_acta_rwa_loop_vec.adcs_pget_dctrltorquenarwaz_sat
    :field adcs_pget_rwx_useflag: salsat_frame.user_data_adcs_act_rwx_info.adcs_pget_rwx_useflag
    :field adcs_pget_rwx_useflaglock: salsat_frame.user_data_adcs_act_rwx_info.adcs_pget_rwx_useflaglock
    :field adcs_pget_rwx_powerflag: salsat_frame.user_data_adcs_act_rwx_info.adcs_pget_rwx_powerflag
    :field adcs_pget_rwx_powerflaglock: salsat_frame.user_data_adcs_act_rwx_info.adcs_pget_rwx_powerflaglock
    :field adcs_pget_rwx_healthflag: salsat_frame.user_data_adcs_act_rwx_info.adcs_pget_rwx_healthflag
    :field adcs_pget_rwx_validflag: salsat_frame.user_data_adcs_act_rwx_info.adcs_pget_rwx_validflag
    :field user_data_adcs_act_rwx_info_adcs_pget_iactstaterwx: salsat_frame.user_data_adcs_act_rwx_info.adcs_pget_iactstaterwx
    :field adcs_pget_rwy_useflag: salsat_frame.user_data_adcs_act_rwy_info.adcs_pget_rwy_useflag
    :field adcs_pget_rwy_useflaglock: salsat_frame.user_data_adcs_act_rwy_info.adcs_pget_rwy_useflaglock
    :field adcs_pget_rwy_powerflag: salsat_frame.user_data_adcs_act_rwy_info.adcs_pget_rwy_powerflag
    :field adcs_pget_rwy_powerflaglock: salsat_frame.user_data_adcs_act_rwy_info.adcs_pget_rwy_powerflaglock
    :field adcs_pget_rwy_healthflag: salsat_frame.user_data_adcs_act_rwy_info.adcs_pget_rwy_healthflag
    :field adcs_pget_rwy_validflag: salsat_frame.user_data_adcs_act_rwy_info.adcs_pget_rwy_validflag
    :field user_data_adcs_act_rwy_info_adcs_pget_iactstaterwy: salsat_frame.user_data_adcs_act_rwy_info.adcs_pget_iactstaterwy
    :field adcs_pget_rwz_useflag: salsat_frame.user_data_adcs_act_rwz_info.adcs_pget_rwz_useflag
    :field adcs_pget_rwz_useflaglock: salsat_frame.user_data_adcs_act_rwz_info.adcs_pget_rwz_useflaglock
    :field adcs_pget_rwz_powerflag: salsat_frame.user_data_adcs_act_rwz_info.adcs_pget_rwz_powerflag
    :field adcs_pget_rwz_powerflaglock: salsat_frame.user_data_adcs_act_rwz_info.adcs_pget_rwz_powerflaglock
    :field adcs_pget_rwz_healthflag: salsat_frame.user_data_adcs_act_rwz_info.adcs_pget_rwz_healthflag
    :field adcs_pget_rwz_validflag: salsat_frame.user_data_adcs_act_rwz_info.adcs_pget_rwz_validflag
    :field user_data_adcs_act_rwz_info_adcs_pget_iactstaterwz: salsat_frame.user_data_adcs_act_rwz_info.adcs_pget_iactstaterwz
    :field adcs_pget_matx_useflag: salsat_frame.user_data_adcs_act_matx_info.adcs_pget_matx_useflag
    :field adcs_pget_matx_useflaglock: salsat_frame.user_data_adcs_act_matx_info.adcs_pget_matx_useflaglock
    :field adcs_pget_matx_powerflag: salsat_frame.user_data_adcs_act_matx_info.adcs_pget_matx_powerflag
    :field adcs_pget_matx_powerflaglock: salsat_frame.user_data_adcs_act_matx_info.adcs_pget_matx_powerflaglock
    :field adcs_pget_matx_healthflag: salsat_frame.user_data_adcs_act_matx_info.adcs_pget_matx_healthflag
    :field adcs_pget_matx_validflag: salsat_frame.user_data_adcs_act_matx_info.adcs_pget_matx_validflag
    :field user_data_adcs_act_matx_info_adcs_pget_iactstatematx: salsat_frame.user_data_adcs_act_matx_info.adcs_pget_iactstatematx
    :field adcs_pget_maty_useflag: salsat_frame.user_data_adcs_act_maty_info.adcs_pget_maty_useflag
    :field adcs_pget_maty_useflaglock: salsat_frame.user_data_adcs_act_maty_info.adcs_pget_maty_useflaglock
    :field adcs_pget_maty_powerflag: salsat_frame.user_data_adcs_act_maty_info.adcs_pget_maty_powerflag
    :field adcs_pget_maty_powerflaglock: salsat_frame.user_data_adcs_act_maty_info.adcs_pget_maty_powerflaglock
    :field adcs_pget_maty_healthflag: salsat_frame.user_data_adcs_act_maty_info.adcs_pget_maty_healthflag
    :field adcs_pget_maty_validflag: salsat_frame.user_data_adcs_act_maty_info.adcs_pget_maty_validflag
    :field user_data_adcs_act_maty_info_adcs_pget_iactstatematy: salsat_frame.user_data_adcs_act_maty_info.adcs_pget_iactstatematy
    :field adcs_pget_matz_useflag: salsat_frame.user_data_adcs_act_matz_info.adcs_pget_matz_useflag
    :field adcs_pget_matz_useflaglock: salsat_frame.user_data_adcs_act_matz_info.adcs_pget_matz_useflaglock
    :field adcs_pget_matz_powerflag: salsat_frame.user_data_adcs_act_matz_info.adcs_pget_matz_powerflag
    :field adcs_pget_matz_powerflaglock: salsat_frame.user_data_adcs_act_matz_info.adcs_pget_matz_powerflaglock
    :field adcs_pget_matz_healthflag: salsat_frame.user_data_adcs_act_matz_info.adcs_pget_matz_healthflag
    :field adcs_pget_matz_validflag: salsat_frame.user_data_adcs_act_matz_info.adcs_pget_matz_validflag
    :field user_data_adcs_act_matz_info_adcs_pget_iactstatematz: salsat_frame.user_data_adcs_act_matz_info.adcs_pget_iactstatematz
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg5_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg5_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg5_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg5_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg5_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg5_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg6_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg6_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg6_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg6_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg6_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg6_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg7_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg7_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg7_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg7_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg7_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg7_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegaxg8_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegaxg8_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegayg8_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegayg8_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_omegazg8_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_omegazg8_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxmfs1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxmfs1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dymfs1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dymfs1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzmfs1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzmfs1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxmfs2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxmfs2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dymfs2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dymfs2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzmfs2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzmfs2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxmfs3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxmfs3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dymfs3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dymfs3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzmfs3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzmfs3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxmfs4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxmfs4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dymfs4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dymfs4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzmfs4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzmfs4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxsuse1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxsuse1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dysuse1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dysuse1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzsuse1_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzsuse1_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxsuse2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxsuse2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dysuse2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dysuse2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzsuse2_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzsuse2_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxsuse3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxsuse3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dysuse3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dysuse3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzsuse3_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzsuse3_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxsuse4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxsuse4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dysuse4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dysuse4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzsuse4_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzsuse4_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxsuse5_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxsuse5_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dysuse5_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dysuse5_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzsuse5_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzsuse5_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dxsuse6_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dxsuse6_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dysuse6_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dysuse6_sat
    :field user_data_adcs_sense_all_vec_adcs_pget_dzsuse6_sat: salsat_frame.user_data_adcs_sense_all_vec.adcs_pget_dzsuse6_sat
    :field user_data_adcs_g_all_info_adcs_pget_g1_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g1_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g1_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g1_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g1_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g1_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g1_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g1_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g1_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g1_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g1_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g1_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg1: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg1
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg1: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg1
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg1: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg1
    :field user_data_adcs_g_all_info_adcs_pget_g2_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g2_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g2_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g2_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g2_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g2_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g2_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g2_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g2_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g2_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g2_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g2_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg2: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg2
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg2: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg2
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg2: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg2
    :field user_data_adcs_g_all_info_adcs_pget_g3_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g3_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g3_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g3_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g3_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g3_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g3_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g3_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g3_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g3_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g3_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g3_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg3: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg3
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg3: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg3
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg3: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg3
    :field user_data_adcs_g_all_info_adcs_pget_g4_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g4_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g4_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g4_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g4_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g4_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g4_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g4_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g4_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g4_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g4_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g4_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg4: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg4
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg4: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg4
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg4: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg4
    :field user_data_adcs_g_all_info_adcs_pget_g5_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g5_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g5_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g5_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g5_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g5_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g5_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g5_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g5_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g5_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g5_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g5_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg5: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg5
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg5: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg5
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg5: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg5
    :field user_data_adcs_g_all_info_adcs_pget_g6_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g6_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g6_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g6_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g6_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g6_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g6_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g6_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g6_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g6_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g6_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g6_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg6: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg6
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg6: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg6
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg6: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg6
    :field user_data_adcs_g_all_info_adcs_pget_g7_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g7_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g7_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g7_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g7_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g7_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g7_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g7_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g7_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g7_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g7_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g7_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg7: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg7
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg7: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg7
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg7: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg7
    :field user_data_adcs_g_all_info_adcs_pget_g8_useflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g8_useflag
    :field user_data_adcs_g_all_info_adcs_pget_g8_useflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g8_useflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g8_powerflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g8_powerflag
    :field user_data_adcs_g_all_info_adcs_pget_g8_powerflaglock: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g8_powerflaglock
    :field user_data_adcs_g_all_info_adcs_pget_g8_healthflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g8_healthflag
    :field user_data_adcs_g_all_info_adcs_pget_g8_validflag: salsat_frame.user_data_adcs_g_all_info.adcs_pget_g8_validflag
    :field user_data_adcs_g_all_info_adcs_pget_isensorstateg8: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstateg8
    :field user_data_adcs_g_all_info_adcs_pget_ififofilllevelg8: salsat_frame.user_data_adcs_g_all_info.adcs_pget_ififofilllevelg8
    :field user_data_adcs_g_all_info_adcs_pget_isensorstatusg8: salsat_frame.user_data_adcs_g_all_info.adcs_pget_isensorstatusg8
    :field user_data_adcs_thm_thm_pget_tempg1: salsat_frame.user_data_adcs_thm.thm_pget_tempg1
    :field user_data_adcs_thm_thm_pget_tempg2: salsat_frame.user_data_adcs_thm.thm_pget_tempg2
    :field user_data_adcs_thm_thm_pget_tempg3: salsat_frame.user_data_adcs_thm.thm_pget_tempg3
    :field user_data_adcs_thm_thm_pget_tempg4: salsat_frame.user_data_adcs_thm.thm_pget_tempg4
    :field user_data_adcs_thm_thm_pget_tempg5: salsat_frame.user_data_adcs_thm.thm_pget_tempg5
    :field user_data_adcs_thm_thm_pget_tempg6: salsat_frame.user_data_adcs_thm.thm_pget_tempg6
    :field user_data_adcs_thm_thm_pget_tempg7: salsat_frame.user_data_adcs_thm.thm_pget_tempg7
    :field user_data_adcs_thm_thm_pget_tempg8: salsat_frame.user_data_adcs_thm.thm_pget_tempg8
    :field user_data_adcs_thm_thm_pget_tempsuse1: salsat_frame.user_data_adcs_thm.thm_pget_tempsuse1
    :field user_data_adcs_thm_thm_pget_tempsuse2: salsat_frame.user_data_adcs_thm.thm_pget_tempsuse2
    :field user_data_adcs_thm_thm_pget_tempsuse3: salsat_frame.user_data_adcs_thm.thm_pget_tempsuse3
    :field user_data_adcs_thm_thm_pget_tempsuse4: salsat_frame.user_data_adcs_thm.thm_pget_tempsuse4
    :field user_data_adcs_thm_thm_pget_tempsuse5: salsat_frame.user_data_adcs_thm.thm_pget_tempsuse5
    :field user_data_adcs_thm_thm_pget_tempsuse6: salsat_frame.user_data_adcs_thm.thm_pget_tempsuse6
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs1_useflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs1_useflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs1_useflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs1_useflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs1_powerflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs1_powerflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs1_powerflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs1_powerflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs1_healthflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs1_healthflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs1_validflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs1_validflag
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatemfs1: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatemfs1
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatusmfs1: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatusmfs1
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs2_useflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs2_useflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs2_useflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs2_useflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs2_powerflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs2_powerflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs2_powerflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs2_powerflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs2_healthflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs2_healthflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs2_validflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs2_validflag
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatemfs2: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatemfs2
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatusmfs2: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatusmfs2
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs3_useflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs3_useflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs3_useflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs3_useflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs3_powerflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs3_powerflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs3_powerflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs3_powerflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs3_healthflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs3_healthflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs3_validflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs3_validflag
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatemfs3: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatemfs3
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatusmfs3: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatusmfs3
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs4_useflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs4_useflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs4_useflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs4_useflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs4_powerflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs4_powerflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs4_powerflaglock: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs4_powerflaglock
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs4_healthflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs4_healthflag
    :field user_data_adcs_mfs_all_info_adcs_pget_mfs4_validflag: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_mfs4_validflag
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatemfs4: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatemfs4
    :field user_data_adcs_mfs_all_info_adcs_pget_isensorstatusmfs4: salsat_frame.user_data_adcs_mfs_all_info.adcs_pget_isensorstatusmfs4
    :field user_data_adcs_suse_all_info_adcs_pget_suse1_useflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse1_useflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse1_useflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse1_useflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse1_powerflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse1_powerflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse1_powerflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse1_powerflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse1_healthflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse1_healthflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse1_validflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse1_validflag
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstates1: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstates1
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstatuss1: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstatuss1
    :field user_data_adcs_suse_all_info_adcs_pget_suse2_useflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse2_useflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse2_useflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse2_useflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse2_powerflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse2_powerflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse2_powerflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse2_powerflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse2_healthflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse2_healthflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse2_validflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse2_validflag
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstates2: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstates2
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstatuss2: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstatuss2
    :field user_data_adcs_suse_all_info_adcs_pget_suse3_useflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse3_useflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse3_useflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse3_useflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse3_powerflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse3_powerflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse3_powerflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse3_powerflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse3_healthflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse3_healthflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse3_validflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse3_validflag
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstates3: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstates3
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstatuss3: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstatuss3
    :field user_data_adcs_suse_all_info_adcs_pget_suse4_useflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse4_useflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse4_useflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse4_useflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse4_powerflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse4_powerflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse4_powerflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse4_powerflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse4_healthflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse4_healthflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse4_validflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse4_validflag
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstates4: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstates4
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstatuss4: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstatuss4
    :field user_data_adcs_suse_all_info_adcs_pget_suse5_useflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse5_useflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse5_useflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse5_useflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse5_powerflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse5_powerflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse5_powerflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse5_powerflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse5_healthflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse5_healthflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse5_validflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse5_validflag
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstates5: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstates5
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstatuss5: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstatuss5
    :field user_data_adcs_suse_all_info_adcs_pget_suse6_useflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse6_useflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse6_useflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse6_useflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse6_powerflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse6_powerflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse6_powerflaglock: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse6_powerflaglock
    :field user_data_adcs_suse_all_info_adcs_pget_suse6_healthflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse6_healthflag
    :field user_data_adcs_suse_all_info_adcs_pget_suse6_validflag: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_suse6_validflag
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstates6: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstates6
    :field user_data_adcs_suse_all_info_adcs_pget_isensorstatuss6: salsat_frame.user_data_adcs_suse_all_info.adcs_pget_isensorstatuss6
    :field user_data_adcs_env_sgp4_adcs_pget_sgp4latxpef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4latxpef
    :field user_data_adcs_env_sgp4_adcs_pget_sgp4longypef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4longypef
    :field user_data_adcs_env_sgp4_adcs_pget_sgp4altpef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4altpef
    :field adcs_pget_sgp4posxpef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4posxpef
    :field adcs_pget_sgp4posypef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4posypef
    :field adcs_pget_sgp4poszpef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4poszpef
    :field adcs_pget_sgp4velxpef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4velxpef
    :field adcs_pget_sgp4velypef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4velypef
    :field adcs_pget_sgp4velzpef: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4velzpef
    :field adcs_pget_sgp4posxteme: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4posxteme
    :field adcs_pget_sgp4posyteme: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4posyteme
    :field adcs_pget_sgp4poszteme: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4poszteme
    :field adcs_pget_sgp4velxteme: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4velxteme
    :field adcs_pget_sgp4velyteme: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4velyteme
    :field adcs_pget_sgp4velzteme: salsat_frame.user_data_adcs_env_sgp4.adcs_pget_sgp4velzteme
    :field adcs_pget_igrfbmagxned: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagxned
    :field adcs_pget_igrfbmagyned: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagyned
    :field adcs_pget_igrfbmagzned: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagzned
    :field adcs_pget_igrfbmagxecef: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagxecef
    :field adcs_pget_igrfbmagyecef: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagyecef
    :field adcs_pget_igrfbmagzecef: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagzecef
    :field user_data_adcs_env_igrf_adcs_pget_igrfbmagxeci: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagxeci
    :field user_data_adcs_env_igrf_adcs_pget_igrfbmagyeci: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagyeci
    :field user_data_adcs_env_igrf_adcs_pget_igrfbmagzeci: salsat_frame.user_data_adcs_env_igrf.adcs_pget_igrfbmagzeci
    :field user_data_adcs_env_sun_adcs_pget_sunmodelrxeci: salsat_frame.user_data_adcs_env_sun.adcs_pget_sunmodelrxeci
    :field user_data_adcs_env_sun_adcs_pget_sunmodelryeci: salsat_frame.user_data_adcs_env_sun.adcs_pget_sunmodelryeci
    :field user_data_adcs_env_sun_adcs_pget_sunmodelrzeci: salsat_frame.user_data_adcs_env_sun.adcs_pget_sunmodelrzeci
    :field adcs_pget_sattotgtdcmerroru1: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerroru1
    :field adcs_pget_sattotgtdcmerroru2: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerroru2
    :field adcs_pget_sattotgtdcmerroru3: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerroru3
    :field adcs_pget_sattotgtdcmerrorv1: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerrorv1
    :field adcs_pget_sattotgtdcmerrorv2: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerrorv2
    :field adcs_pget_sattotgtdcmerrorv3: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerrorv3
    :field adcs_pget_sattotgtdcmerrorw1: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerrorw1
    :field adcs_pget_sattotgtdcmerrorw2: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerrorw2
    :field adcs_pget_sattotgtdcmerrorw3: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_sattotgtdcmerrorw3
    :field user_data_adcs_att_dcm_sattotgt_adcs_pget_attitudeerrorangle: salsat_frame.user_data_adcs_att_dcm_sattotgt.adcs_pget_attitudeerrorangle
    :field adcs_pget_ireadstaterwx_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadstaterwx_mfr
    :field adcs_pget_ireadstaterwy_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadstaterwy_mfr
    :field adcs_pget_ireadstaterwz_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadstaterwz_mfr
    :field user_data_adcs_act_rw_tm_adcs_pget_ireadtorquerwx_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadtorquerwx_mfr
    :field user_data_adcs_act_rw_tm_adcs_pget_ireadtorquerwy_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadtorquerwy_mfr
    :field user_data_adcs_act_rw_tm_adcs_pget_ireadtorquerwz_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadtorquerwz_mfr
    :field user_data_adcs_act_rw_tm_adcs_pget_ireadrotspeedrwx_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadrotspeedrwx_mfr
    :field user_data_adcs_act_rw_tm_adcs_pget_ireadrotspeedrwy_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadrotspeedrwy_mfr
    :field user_data_adcs_act_rw_tm_adcs_pget_ireadrotspeedrwz_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadrotspeedrwz_mfr
    :field adcs_pget_ireadangularraterwx_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadangularraterwx_mfr
    :field adcs_pget_ireadangularraterwy_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadangularraterwy_mfr
    :field adcs_pget_ireadangularraterwz_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadangularraterwz_mfr
    :field adcs_pget_ireadanglerwx_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadanglerwx_mfr
    :field adcs_pget_ireadanglerwy_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadanglerwy_mfr
    :field adcs_pget_ireadanglerwz_mfr: salsat_frame.user_data_adcs_act_rw_tm.adcs_pget_ireadanglerwz_mfr
    :field adcs_pget_pdkfactor: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_pdkfactor
    :field adcs_pget_pdkdfactor: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_pdkdfactor
    :field adcs_pget_pdcontrollawselector: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_pdcontrollawselector
    :field adcs_pget_pdomegakfactor: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_pdomegakfactor
    :field adcs_pget_pdomegakdfactor: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_pdomegakdfactor
    :field adcs_pget_pdomegacontrollawselector: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_pdomegacontrollawselector
    :field adcs_pget_bdotcfactor: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_bdotcfactor
    :field adcs_pget_bdotmfsafilterrotationthreshold: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_bdotmfsafilterrotationthreshold
    :field adcs_pget_ibdotfilterdepth: salsat_frame.user_data_adcs_ctrl_parameter_info.adcs_pget_ibdotfilterdepth
    :field adcs_debug_pget_icalimodegbias: salsat_frame.user_data_adcs_cal_g_offset_info.adcs_debug_pget_icalimodegbias
    :field adcs_debug_pget_icalistategbias: salsat_frame.user_data_adcs_cal_g_offset_info.adcs_debug_pget_icalistategbias
    :field adcs_debug_pget_icalilastcalelapsedtimegbias: salsat_frame.user_data_adcs_cal_g_offset_info.adcs_debug_pget_icalilastcalelapsedtimegbias
    :field adcs_debug_pget_icalicalibintervallgbias: salsat_frame.user_data_adcs_cal_g_offset_info.adcs_debug_pget_icalicalibintervallgbias
    :field adcs_debug_pget_icalicalibstepgbias: salsat_frame.user_data_adcs_cal_g_offset_info.adcs_debug_pget_icalicalibstepgbias
    :field adcs_pget_targetdata_latitude: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_latitude
    :field adcs_pget_targetdata_longitude: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_longitude
    :field adcs_pget_targetdata_altitude: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_altitude
    :field adcs_pget_targetdata_controlmindistance: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_controlmindistance
    :field user_data_adcs_att_target_info_adcs_pget_targetdata_distance: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_distance
    :field adcs_pget_targetdata_targetpanel: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_targetpanel
    :field adcs_pget_targetdata_offsetanglex: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_offsetanglex
    :field adcs_pget_targetdata_offsetangley: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_offsetangley
    :field adcs_pget_targetdata_offsetanglez: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_offsetanglez
    :field user_data_adcs_att_target_info_adcs_pget_targetdata_controlisactive: salsat_frame.user_data_adcs_att_target_info.adcs_pget_targetdata_controlisactive
    :field adcs_pget_attdet_pointingxsat: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingxsat
    :field adcs_pget_attdet_pointingysat: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingysat
    :field adcs_pget_attdet_pointingzsat: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingzsat
    :field adcs_pget_attdet_pointingxpef: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingxpef
    :field adcs_pget_attdet_pointingypef: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingypef
    :field adcs_pget_attdet_pointingzpef: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingzpef
    :field adcs_pget_attdet_pointingxtemed: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingxtemed
    :field adcs_pget_attdet_pointingytemed: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingytemed
    :field adcs_pget_attdet_pointingztemed: salsat_frame.user_data_adcs_att_pointing_info.adcs_pget_attdet_pointingztemed
    :field adcs_pget_bdotdeltabx: salsat_frame.user_data_adcs_ctrl_bdot_info.adcs_pget_bdotdeltabx
    :field adcs_pget_bdotdeltaby: salsat_frame.user_data_adcs_ctrl_bdot_info.adcs_pget_bdotdeltaby
    :field adcs_pget_bdotdeltabz: salsat_frame.user_data_adcs_ctrl_bdot_info.adcs_pget_bdotdeltabz
    :field adcs_pget_bdotdeltab_omega: salsat_frame.user_data_adcs_ctrl_bdot_info.adcs_pget_bdotdeltab_omega
    :field adcs_pget_dbdotcmdmagmomentx_sat: salsat_frame.user_data_adcs_ctrl_bdot_output.adcs_pget_dbdotcmdmagmomentx_sat
    :field adcs_pget_dbdotcmdmagmomenty_sat: salsat_frame.user_data_adcs_ctrl_bdot_output.adcs_pget_dbdotcmdmagmomenty_sat
    :field adcs_pget_dbdotcmdmagmomentz_sat: salsat_frame.user_data_adcs_ctrl_bdot_output.adcs_pget_dbdotcmdmagmomentz_sat
    :field adcs_pget_dpdcmdtorquex_sat: salsat_frame.user_data_adcs_ctrl_pd_output.adcs_pget_dpdcmdtorquex_sat
    :field adcs_pget_dpdcmdtorquey_sat: salsat_frame.user_data_adcs_ctrl_pd_output.adcs_pget_dpdcmdtorquey_sat
    :field adcs_pget_dpdcmdtorquez_sat: salsat_frame.user_data_adcs_ctrl_pd_output.adcs_pget_dpdcmdtorquez_sat
    :field adcs_pget_cmdfifofilllevel: salsat_frame.user_data_adcs_cmdfifoinfo.adcs_pget_cmdfifofilllevel
    :field adcs_pget_cmdfifoisrewritable: salsat_frame.user_data_adcs_cmdfifoinfo.adcs_pget_cmdfifoisrewritable
    :field adcs_pget_cmdfifomaxobservedfilllevel: salsat_frame.user_data_adcs_cmdfifoinfo.adcs_pget_cmdfifomaxobservedfilllevel
    :field adcs_pget_cmdfifooverflowcount: salsat_frame.user_data_adcs_cmdfifoinfo.adcs_pget_cmdfifooverflowcount
    :field adcs_pget_cmdfifomsgcount: salsat_frame.user_data_adcs_cmdfifoinfo.adcs_pget_cmdfifomsgcount
    :field adcs_pget_cmdfifomaxobservedbytecount: salsat_frame.user_data_adcs_cmdfifoinfo.adcs_pget_cmdfifomaxobservedbytecount
    :field adcs_pget_rwcmdfifofilllevel: salsat_frame.user_data_adcs_rwcmdfifoinfo.adcs_pget_rwcmdfifofilllevel
    :field adcs_pget_rwcmdfifoisrewritable: salsat_frame.user_data_adcs_rwcmdfifoinfo.adcs_pget_rwcmdfifoisrewritable
    :field adcs_pget_rwcmdfifomaxobservedfilllevel: salsat_frame.user_data_adcs_rwcmdfifoinfo.adcs_pget_rwcmdfifomaxobservedfilllevel
    :field adcs_pget_rwcmdfifooverflowcount: salsat_frame.user_data_adcs_rwcmdfifoinfo.adcs_pget_rwcmdfifooverflowcount
    :field adcs_pget_rwcmdfifomsgcount: salsat_frame.user_data_adcs_rwcmdfifoinfo.adcs_pget_rwcmdfifomsgcount
    :field adcs_pget_rwcmdfifomaxobservedbytecount: salsat_frame.user_data_adcs_rwcmdfifoinfo.adcs_pget_rwcmdfifomaxobservedbytecount
    :field adcs_pget_runtime: salsat_frame.user_data_adcs_thread_info.adcs_pget_runtime
    :field adcs_pget_imalivecounter: salsat_frame.user_data_adcs_thread_info.adcs_pget_imalivecounter
    :field adcs_pget_periodcounter: salsat_frame.user_data_adcs_thread_info.adcs_pget_periodcounter
    :field adcs_pget_unfinishedcounter: salsat_frame.user_data_adcs_thread_info.adcs_pget_unfinishedcounter
    :field adcs_pget_buffertime: salsat_frame.user_data_adcs_thread_info.adcs_pget_buffertime
    :field adcs_pget_realalgotime: salsat_frame.user_data_adcs_thread_info.adcs_pget_realalgotime
    :field adcs_pget_tleepocheyear: salsat_frame.user_data_adcs_env_tle.adcs_pget_tleepocheyear
    :field adcs_pget_tleepochedecimalday: salsat_frame.user_data_adcs_env_tle.adcs_pget_tleepochedecimalday
    :field adcs_pget_tlebstar: salsat_frame.user_data_adcs_env_tle.adcs_pget_tlebstar
    :field adcs_pget_tleeccentricity: salsat_frame.user_data_adcs_env_tle.adcs_pget_tleeccentricity
    :field adcs_pget_tleargperigee: salsat_frame.user_data_adcs_env_tle.adcs_pget_tleargperigee
    :field adcs_pget_tleinclination: salsat_frame.user_data_adcs_env_tle.adcs_pget_tleinclination
    :field adcs_pget_tlemeananomaly: salsat_frame.user_data_adcs_env_tle.adcs_pget_tlemeananomaly
    :field adcs_pget_tlemeanmotion: salsat_frame.user_data_adcs_env_tle.adcs_pget_tlemeanmotion
    :field adcs_pget_tleraan: salsat_frame.user_data_adcs_env_tle.adcs_pget_tleraan
    :field adcs_pget_tlesatelliteid: salsat_frame.user_data_adcs_env_tle.adcs_pget_tlesatelliteid
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetnarrowvectors: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetnarrowvectors
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetmismatchingvectors: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetmismatchingvectors
    :field user_data_adcs_attdet_determination_info_adcs_pget_suse1albedoflag: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_suse1albedoflag
    :field user_data_adcs_attdet_determination_info_adcs_pget_suse2albedoflag: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_suse2albedoflag
    :field user_data_adcs_attdet_determination_info_adcs_pget_suse3albedoflag: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_suse3albedoflag
    :field user_data_adcs_attdet_determination_info_adcs_pget_suse4albedoflag: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_suse4albedoflag
    :field user_data_adcs_attdet_determination_info_adcs_pget_suse5albedoflag: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_suse5albedoflag
    :field user_data_adcs_attdet_determination_info_adcs_pget_suse6albedoflag: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_suse6albedoflag
    :field adcs_pget_attdetalbedoanglesuse1: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetalbedoanglesuse1
    :field adcs_pget_attdetalbedoanglesuse2: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetalbedoanglesuse2
    :field adcs_pget_attdetalbedoanglesuse3: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetalbedoanglesuse3
    :field adcs_pget_attdetalbedoanglesuse4: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetalbedoanglesuse4
    :field adcs_pget_attdetalbedoanglesuse5: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetalbedoanglesuse5
    :field adcs_pget_attdetalbedoanglesuse6: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetalbedoanglesuse6
    :field adcs_pget_attdetvectorsangle_sensor: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetvectorsangle_sensor
    :field adcs_pget_attdetvectorsangle_model: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetvectorsangle_model
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetmfsdistcorrmode: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetmfsdistcorrmode
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetsusedistcorrmode: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetsusedistcorrmode
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetgahighprecmodeflag: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetgahighprecmodeflag
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdettrackigrfdeltab: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdettrackigrfdeltab
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetsusealbedotracking: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetsusealbedotracking
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetautovirtualizemfsa: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetautovirtualizemfsa
    :field user_data_adcs_attdet_determination_info_adcs_pget_attdetautovirtualizesusea: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetautovirtualizesusea
    :field adcs_pget_attdetnarrowvectorsanglethreshold: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetnarrowvectorsanglethreshold
    :field adcs_pget_attdetmissmatchingvectorsthreshold: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetmissmatchingvectorsthreshold
    :field adcs_pget_attdetsusealbedoanglethreshold: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetsusealbedoanglethreshold
    :field adcs_pget_attdetmfsadiscompensationthreshold: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetmfsadiscompensationthreshold
    :field adcs_pget_attdetsuseadiscompensationthreshold: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetsuseadiscompensationthreshold
    :field adcs_pget_attdetmfsameasurementpause: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_attdetmfsameasurementpause
    :field adcs_pget_matadischargepause: salsat_frame.user_data_adcs_attdet_determination_info.adcs_pget_matadischargepause
    :field linkgs_pget_time: salsat_frame.user_data_linkgs_tm_std.linkgs_pget_time
    :field linkgs_com_ant_fsm: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_fsm
    :field linkgs_com_ant_satazimuth: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_satazimuth
    :field linkgs_com_ant_satelevation: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_satelevation
    :field linkgs_com_ant_antazimuth: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_antazimuth
    :field linkgs_com_ant_antelevation: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_antelevation
    :field linkgs_com_ant_downlink: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_downlink
    :field linkgs_com_ant_uplink: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_uplink
    :field linkgs_com_ant_scn: salsat_frame.user_data_linkgs_tm_std.linkgs_com_ant_scn
    :field linkgs_slk_ant_fsm: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_fsm
    :field linkgs_slk_ant_satazimuth: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_satazimuth
    :field linkgs_slk_ant_satelevation: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_satelevation
    :field linkgs_slk_ant_antazimuth: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_antazimuth
    :field linkgs_slk_ant_antelevation: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_antelevation
    :field linkgs_slk_ant_uplink: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_uplink
    :field linkgs_slk_ant_downlink: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_downlink
    :field linkgs_slk_ant_scn: salsat_frame.user_data_linkgs_tm_std.linkgs_slk_ant_scn
    :field linkgs_clientid: salsat_frame.user_data_linkgs_tm_std.linkgs_clientid
    :field linkgs_clientip: salsat_frame.user_data_linkgs_tm_std.linkgs_clientip
    :field linkgs_latestframe_servertime: salsat_frame.user_data_linkgs_tm_std.linkgs_latestframe_servertime
    :field linkgs_latestframe_origin: salsat_frame.user_data_linkgs_tm_std.linkgs_latestframe_origin
    :field user_data_linkgs_tm_clientconnected_linkgs_clientid: salsat_frame.user_data_linkgs_tm_clientconnected.linkgs_clientid
    :field user_data_linkgs_tm_clientconnected_linkgs_clientip: salsat_frame.user_data_linkgs_tm_clientconnected.linkgs_clientip
    :field user_data_linkgs_tm_clientdisconnected_linkgs_clientid: salsat_frame.user_data_linkgs_tm_clientdisconnected.linkgs_clientid
    :field user_data_linkgs_tm_clientdisconnected_linkgs_clientip: salsat_frame.user_data_linkgs_tm_clientdisconnected.linkgs_clientip
    :field linkgs_aistate: salsat_frame.user_data_linkgs_tm_state.linkgs_aistate
    :field linkgs_rxfrequency: salsat_frame.user_data_linkgs_tm_state.linkgs_rxfrequency
    :field linkgs_txfrequency: salsat_frame.user_data_linkgs_tm_state.linkgs_txfrequency
    :field linkgs_rcvfecmod: salsat_frame.user_data_linkgs_tm_state.linkgs_rcvfecmod
    :field linkgs_xmtfecmod: salsat_frame.user_data_linkgs_tm_state.linkgs_xmtfecmod
    :field linkgs_servicetype: salsat_frame.user_data_linkgs_tm_state.linkgs_servicetype
    :field linkgs_minsir: salsat_frame.user_data_linkgs_tm_state.linkgs_minsir
    :field linkgs_maxsir: salsat_frame.user_data_linkgs_tm_state.linkgs_maxsir
    :field linkgs_tempgnd: salsat_frame.user_data_linkgs_tm_state.linkgs_tempgnd
    :field linkgs_tempsat: salsat_frame.user_data_linkgs_tm_state.linkgs_tempsat
    :field linkgs_fading: salsat_frame.user_data_linkgs_tm_state.linkgs_fading
    :field linkgs_contacttime: salsat_frame.user_data_linkgs_tm_state.linkgs_contacttime
    :field linkgs_systime: salsat_frame.user_data_linkgs_tm_state.linkgs_systime
    :field user_data_linkgs_tm_std_a_linkgs_pget_time: salsat_frame.user_data_linkgs_tm_std_a.linkgs_pget_time
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_fsm: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_fsm
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_satazimuth: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_satazimuth
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_satelevation: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_satelevation
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_antazimuth: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_antazimuth
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_antelevation: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_antelevation
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_downlink: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_downlink
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_uplink: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_uplink
    :field user_data_linkgs_tm_std_a_linkgs_com_ant_scn: salsat_frame.user_data_linkgs_tm_std_a.linkgs_com_ant_scn
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_fsm: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_fsm
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_satazimuth: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_satazimuth
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_satelevation: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_satelevation
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_antazimuth: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_antazimuth
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_antelevation: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_antelevation
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_uplink: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_uplink
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_downlink: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_downlink
    :field user_data_linkgs_tm_std_a_linkgs_slk_ant_scn: salsat_frame.user_data_linkgs_tm_std_a.linkgs_slk_ant_scn
    :field user_data_linkgs_tm_std_a_linkgs_clientid: salsat_frame.user_data_linkgs_tm_std_a.linkgs_clientid
    :field user_data_linkgs_tm_std_a_linkgs_clientip: salsat_frame.user_data_linkgs_tm_std_a.linkgs_clientip
    :field user_data_linkgs_tm_std_a_linkgs_latestframe_servertime: salsat_frame.user_data_linkgs_tm_std_a.linkgs_latestframe_servertime
    :field user_data_linkgs_tm_std_a_linkgs_latestframe_origin: salsat_frame.user_data_linkgs_tm_std_a.linkgs_latestframe_origin
    :field linkgs_txchannela: salsat_frame.user_data_linkgs_tm_std_a.linkgs_txchannela
    :field linkgs_pget_slkarq: salsat_frame.user_data_linkgs_tm_std_a.linkgs_pget_slkarq
    :field linkgs_pget_arrayrfustdtma: salsat_frame.user_data_linkgs_tm_std_a.linkgs_pget_arrayrfustdtma
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.salsat_frame = Salsat.SalsatFrame(self._io, self, self._root)

    class Com4TmRtc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_rtcinitcomplete = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcinvreg = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcspiactive = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcspirelease = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcconfcomplete = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcwrtime = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcttavailable = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_rtcsec01 = self._io.read_u1()
            self.com4_pget_rtcsec001 = self._io.read_u1()
            self.com4_pget_rtcsec10 = self._io.read_u1()
            self.com4_pget_rtcsec1 = self._io.read_u1()
            self.com4_pget_rtcsec01alarm = self._io.read_u1()
            self.com4_pget_rtcsec001alarm = self._io.read_u1()
            self.com4_pget_rtcsec10alarm = self._io.read_u1()
            self.com4_pget_rtcsec1alarm = self._io.read_u1()
            self.com4_pget_rtcmin10 = self._io.read_u1()
            self.com4_pget_rtcmin1 = self._io.read_u1()
            self.com4_pget_rtcmin10alarm = self._io.read_u1()
            self.com4_pget_rtcmin1alarm = self._io.read_u1()
            self.com4_pget_rtchour10 = self._io.read_u1()
            self.com4_pget_rtchour1 = self._io.read_u1()
            self.com4_pget_rtchour10alarm = self._io.read_u1()
            self.com4_pget_rtchour1alarm = self._io.read_u1()
            self.com4_pget_rtcday = self._io.read_u1()
            self.com4_pget_rtcdayalarm = self._io.read_u1()
            self.com4_pget_rtcdate10 = self._io.read_u1()
            self.com4_pget_rtcdate1 = self._io.read_u1()
            self.com4_pget_rtcdate10alarm = self._io.read_u1()
            self.com4_pget_rtcdate1alarm = self._io.read_u1()
            self.com4_pget_rtcmonth10 = self._io.read_u1()
            self.com4_pget_rtcmonth1 = self._io.read_u1()
            self.com4_pget_rtcyear10 = self._io.read_u1()
            self.com4_pget_rtcyear1 = self._io.read_u1()
            self.com4_pget_rtcregcontrol = self._io.read_u1()
            self.com4_pget_rtcregstatus = self._io.read_u1()
            self.com4_pget_rtcregtricklecharger = self._io.read_u1()
            self.com4_pget_rtc12 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcpm = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtccentury = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtc12alarm = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcpmalarm = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcdyalarm = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcam1 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcam2 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcam3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rtcam4 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_rtcyear = self._io.read_u2le()
            self.com4_pget_rtcmonth = self._io.read_u1()
            self.com4_pget_rtcmin = self._io.read_u1()
            self.com4_pget_rtcminalarm = self._io.read_u1()
            self.com4_pget_rtchour = self._io.read_u1()
            self.com4_pget_rtchouralarm = self._io.read_u1()
            self.com4_pget_rtcdate = self._io.read_u1()
            self.com4_pget_rtcdatealarm = self._io.read_u1()
            self.com4_pget_rtcsec = self._io.read_u2le()
            self.com4_pget_rtcsecalarm = self._io.read_u2le()


    class Rw1TmPress(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_presscoeff0 = self._io.read_u2le()
            self.rw1_pget_presscoeff1 = self._io.read_u2le()
            self.rw1_pget_presscoeff2 = self._io.read_u2le()
            self.rw1_pget_presscoeff3 = self._io.read_u2le()
            self.rw1_pget_presscoeff4 = self._io.read_u2le()
            self.rw1_pget_presscoeff5 = self._io.read_u2le()
            self.rw1_pget_presscoeff6 = self._io.read_u2le()
            self.rw1_pget_presscrc = self._io.read_u2le()
            self.thm_rw1_pget_tmppresssens = self._io.read_u4le()
            self.rw1_pget_press = self._io.read_u4le()


    class AdcsSenseG5Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg5_sat = self._io.read_s2le()
            self.adcs_pget_omegayg5_sat = self._io.read_s2le()
            self.adcs_pget_omegazg5_sat = self._io.read_s2le()
            self.thm_pget_tempg5 = self._io.read_s2le()
            self.adcs_pget_g5_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg5 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg5 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg5 = self._io.read_u1()


    class FdaTmLongtermMagZ(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_longterm_mag_z = self._io.read_s2le()


    class Com4TmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_resetcnt = self._io.read_u2le()
            self.com4_pget_rxsducnt = self._io.read_u2le()
            self.com4_pget_rxspducnt = self._io.read_u2le()
            self.com4_pget_fsmmainstate = self._io.read_u1()
            self.com4_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.com4_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_pdurxfifofull = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxmode = self._io.read_bits_int_be(1) != 0
            self.com4_pget_trxrxovercur = self._io.read_bits_int_be(1) != 0
            self.com4_pget_trxtxovercur = self._io.read_bits_int_be(1) != 0
            self.com4_pget_initeepromparcompl = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyrssi = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyrssirx = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalycd = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalytmptnc = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_cur3v3_a = self._io.read_u2le()
            self.com4_pget_vlt3v3_a = self._io.read_u2le()
            self.thm_com4_pget_tmptnc_a = self._io.read_u2le()
            self.com0_pget_timetoautorecoveryreset = self._io.read_u4le()


    class AdcsSenseAllVec(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg1_sat = self._io.read_s2le()
            self.adcs_pget_omegayg1_sat = self._io.read_s2le()
            self.adcs_pget_omegazg1_sat = self._io.read_s2le()
            self.adcs_pget_omegaxg2_sat = self._io.read_s2le()
            self.adcs_pget_omegayg2_sat = self._io.read_s2le()
            self.adcs_pget_omegazg2_sat = self._io.read_s2le()
            self.adcs_pget_omegaxg3_sat = self._io.read_s2le()
            self.adcs_pget_omegayg3_sat = self._io.read_s2le()
            self.adcs_pget_omegazg3_sat = self._io.read_s2le()
            self.adcs_pget_omegaxg4_sat = self._io.read_s2le()
            self.adcs_pget_omegayg4_sat = self._io.read_s2le()
            self.adcs_pget_omegazg4_sat = self._io.read_s2le()
            self.adcs_pget_omegaxg5_sat = self._io.read_s2le()
            self.adcs_pget_omegayg5_sat = self._io.read_s2le()
            self.adcs_pget_omegazg5_sat = self._io.read_s2le()
            self.adcs_pget_omegaxg6_sat = self._io.read_s2le()
            self.adcs_pget_omegayg6_sat = self._io.read_s2le()
            self.adcs_pget_omegazg6_sat = self._io.read_s2le()
            self.adcs_pget_omegaxg7_sat = self._io.read_s2le()
            self.adcs_pget_omegayg7_sat = self._io.read_s2le()
            self.adcs_pget_omegazg7_sat = self._io.read_s2le()
            self.adcs_pget_omegaxg8_sat = self._io.read_s2le()
            self.adcs_pget_omegayg8_sat = self._io.read_s2le()
            self.adcs_pget_omegazg8_sat = self._io.read_s2le()
            self.adcs_pget_dxmfs1_sat = self._io.read_s2le()
            self.adcs_pget_dymfs1_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs1_sat = self._io.read_s2le()
            self.adcs_pget_dxmfs2_sat = self._io.read_s2le()
            self.adcs_pget_dymfs2_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs2_sat = self._io.read_s2le()
            self.adcs_pget_dxmfs3_sat = self._io.read_s2le()
            self.adcs_pget_dymfs3_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs3_sat = self._io.read_s2le()
            self.adcs_pget_dxmfs4_sat = self._io.read_s2le()
            self.adcs_pget_dymfs4_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs4_sat = self._io.read_s2le()
            self.adcs_pget_dxsuse1_sat = self._io.read_s2le()
            self.adcs_pget_dysuse1_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse1_sat = self._io.read_s2le()
            self.adcs_pget_dxsuse2_sat = self._io.read_s2le()
            self.adcs_pget_dysuse2_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse2_sat = self._io.read_s2le()
            self.adcs_pget_dxsuse3_sat = self._io.read_s2le()
            self.adcs_pget_dysuse3_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse3_sat = self._io.read_s2le()
            self.adcs_pget_dxsuse4_sat = self._io.read_s2le()
            self.adcs_pget_dysuse4_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse4_sat = self._io.read_s2le()
            self.adcs_pget_dxsuse5_sat = self._io.read_s2le()
            self.adcs_pget_dysuse5_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse5_sat = self._io.read_s2le()
            self.adcs_pget_dxsuse6_sat = self._io.read_s2le()
            self.adcs_pget_dysuse6_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse6_sat = self._io.read_s2le()


    class SatHeater0Info(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_heater0_useflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater0_useflaglock = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater0_powerflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater0_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater0_healthflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater0_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_heater0_togglecounter = self._io.read_u1()
            self.sat_pget_heater0_totalglowtime = self._io.read_u1()


    class Com4TmCom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_txltuhdrdstid = self._io.read_u1()
            self.com4_pget_txltuhdrsrcid = self._io.read_u1()
            self.com4_pget_txltuhdrfrcnttx = self._io.read_u1()
            self.com4_pget_txltuhdrfrcntrx = self._io.read_u1()
            self.com4_pget_txltuhdrsnr = self._io.read_u1()
            self.com4_pget_txltuhdraitypesrc = self._io.read_u1()
            self.com4_pget_txltuhdraitypedst = self._io.read_u1()
            self.com4_pget_txltuhdrdfcid = self._io.read_u1()
            self.com4_pget_txltuhdrfrlength = self._io.read_u2le()
            self.com4_pget_txltuhdrcrc13 = self._io.read_u2le()
            self.com4_pget_txltuhdrcrc5 = self._io.read_u1()
            self.com4_pget_txltuhdrudfl1 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_txltuhdrhailing = self._io.read_bits_int_be(1) != 0
            self.com4_pget_txltuhdrrqbch = self._io.read_bits_int_be(1) != 0
            self.com4_pget_txltuhdrpdutypeid = self._io.read_bits_int_be(1) != 0
            self.com4_pget_txltuhdrarq = self._io.read_bits_int_be(1) != 0
            self.com4_pget_txltuhdrcaller = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_rxltuhdrdstid = self._io.read_u1()
            self.com4_pget_rxltuhdrsrcid = self._io.read_u1()
            self.com4_pget_rxltuhdrfrcnttx = self._io.read_u1()
            self.com4_pget_rxltuhdrfrcntrx = self._io.read_u1()
            self.com4_pget_rxltuhdrsnr = self._io.read_u1()
            self.com4_pget_rxltuhdraitypesrc = self._io.read_u1()
            self.com4_pget_rxltuhdraitypedst = self._io.read_u1()
            self.com4_pget_rxltuhdrdfcid = self._io.read_u1()
            self.com4_pget_rxltuhdrfrlength = self._io.read_u2le()
            self.com4_pget_rxltuhdrcrc13 = self._io.read_u2le()
            self.com4_pget_rxltuhdrcrc5 = self._io.read_u1()
            self.com4_pget_rxltuhdrudfl1 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxltuhdrhailing = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxltuhdrrqbch = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxltuhdrpdutypeid = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxltuhdrarq = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxltuhdrcaller = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_ltudecerrnum = self._io.read_u2le()
            self.com4_pget_sdutxfifonum = self._io.read_u1()
            self.com4_pget_sessiontime = self._io.read_u2le()
            self.com4_pget_fsmcomstate = self._io.read_u1()
            self.com4_pget_ltuhdrdec = self._io.read_bits_int_be(1) != 0
            self.com4_pget_pdufirstblockdec = self._io.read_bits_int_be(1) != 0
            self.com4_pget_sduhdrdec = self._io.read_bits_int_be(1) != 0
            self.com4_pget_lturxcomplete = self._io.read_bits_int_be(1) != 0
            self.com4_pget_ltuhdrdecerr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_ltuhdrrxerr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_ltuhdrdeclock = self._io.read_bits_int_be(1) != 0
            self.com4_pget_pdudecerr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_burst = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rangevalid = self._io.read_bits_int_be(1) != 0
            self.com4_pget_sdutxfifooverrun = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxpducrcerr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxsducrcerr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_collectbcherr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_chmon = self._io.read_bits_int_be(1) != 0
            self.com4_pget_ltuerr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_tddmode = self._io.read_bits_int_be(1) != 0
            self.com4_pget_generaltxlock = self._io.read_bits_int_be(1) != 0
            self.com4_pget_spktmodetxlock = self._io.read_bits_int_be(1) != 0
            self.com4_pget_ack = self._io.read_bits_int_be(1) != 0
            self.com4_pget_pktloss = self._io.read_bits_int_be(1) != 0
            self.com4_pget_sessionest = self._io.read_bits_int_be(1) != 0
            self.com4_pget_sessionopened = self._io.read_bits_int_be(1) != 0
            self.com4_pget_syncnewburst = self._io.read_bits_int_be(1) != 0
            self.com4_pget_syncerrnumvalid = self._io.read_bits_int_be(1) != 0
            self.com4_pget_syncburstnumvalid = self._io.read_bits_int_be(1) != 0
            self.com4_pget_syncchainnumvalid = self._io.read_bits_int_be(1) != 0
            self.com4_pget_extsrcid = self._io.read_bits_int_be(1) != 0
            self.com4_pget_answpending = self._io.read_bits_int_be(1) != 0
            self.com4_pget_arqsyncloss = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_range = self._io.read_u4le()
            self.com4_pget_rssirx = self._io.read_u2le()
            self.com4_pget_cd = self._io.read_u2le()


    class AdcsEnvSgp4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_sgp4latxpef = self._io.read_s2le()
            self.adcs_pget_sgp4longypef = self._io.read_s2le()
            self.adcs_pget_sgp4altpef = self._io.read_u1()
            self.adcs_pget_sgp4posxpef = self._io.read_s2le()
            self.adcs_pget_sgp4posypef = self._io.read_s2le()
            self.adcs_pget_sgp4poszpef = self._io.read_s2le()
            self.adcs_pget_sgp4velxpef = self._io.read_s2le()
            self.adcs_pget_sgp4velypef = self._io.read_s2le()
            self.adcs_pget_sgp4velzpef = self._io.read_s2le()
            self.adcs_pget_sgp4posxteme = self._io.read_s2le()
            self.adcs_pget_sgp4posyteme = self._io.read_s2le()
            self.adcs_pget_sgp4poszteme = self._io.read_s2le()
            self.adcs_pget_sgp4velxteme = self._io.read_s2le()
            self.adcs_pget_sgp4velyteme = self._io.read_s2le()
            self.adcs_pget_sgp4velzteme = self._io.read_s2le()


    class Rw2TmSram(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_cntrlmode = self._io.read_u1()
            self.rw2_pget_kpnumsram = self._io.read_u2le()
            self.rw2_pget_kpdensram = self._io.read_u2le()
            self.rw2_pget_kinumsram = self._io.read_u2le()
            self.rw2_pget_kidensram = self._io.read_u2le()
            self.rw2_pget_kdnumsram = self._io.read_u2le()
            self.rw2_pget_kddensram = self._io.read_u2le()
            self.rw2_pget_svlimitsram = self._io.read_u4le()
            self.rw2_pget_mvlimitsrampwm = self._io.read_u2le()
            self.rw2_pget_gyro0offsetsram = self._io.read_u2le()
            self.rw2_pget_gyro1offsetsram = self._io.read_u2le()
            self.rw2_pget_gyro1activesram = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0


    class FdirThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_buffertime = self._io.read_u1()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_periodcounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class PdhTmLaysesStd0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_sesfsmstate = self._io.read_u1()
            self.slkpdh_pget_sesbasetrmsesest = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmseslost = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmseschngsttmoutact = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmwaitforaiandtrmt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmberrunning = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmsetrxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmsettxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmcaller = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmcallersendbcst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmresponder = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmpayloaddir = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmsettxgain = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmfddon = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_sesbasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_sesbasercvsesest = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvseslost = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvseschngsttmoutact = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvwaitforaiandtrmt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvberrunning = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvsetrxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvsettxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvcaller = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvcallersendbcst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvresponder = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvpayloaddir = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvsettxgain = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvfddon = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_sesbasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_sesspectrmmactypemain = self._io.read_u1()
            self.slkpdh_pget_sesspectrmmactypesub = self._io.read_u1()
            self.slkpdh_pget_sesspectrmpara0 = self._io.read_u1()
            self.slkpdh_pget_sesspectrmpara1 = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvmactypemain = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvmactypesub = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvpara0 = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvpara1 = self._io.read_u1()


    class LinkgsTmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.linkgs_pget_time = self._io.read_u8le()
            self.linkgs_com_ant_fsm = self._io.read_u1()
            self.linkgs_com_ant_satazimuth = self._io.read_f4le()
            self.linkgs_com_ant_satelevation = self._io.read_f4le()
            self.linkgs_com_ant_antazimuth = self._io.read_f4le()
            self.linkgs_com_ant_antelevation = self._io.read_f4le()
            self.linkgs_com_ant_downlink = self._io.read_u4le()
            self.linkgs_com_ant_uplink = self._io.read_u4le()
            self.linkgs_com_ant_scn = self._io.read_u4le()
            self.linkgs_slk_ant_fsm = self._io.read_u1()
            self.linkgs_slk_ant_satazimuth = self._io.read_f4le()
            self.linkgs_slk_ant_satelevation = self._io.read_f4le()
            self.linkgs_slk_ant_antazimuth = self._io.read_f4le()
            self.linkgs_slk_ant_antelevation = self._io.read_f4le()
            self.linkgs_slk_ant_uplink = self._io.read_u4le()
            self.linkgs_slk_ant_downlink = self._io.read_u4le()
            self.linkgs_slk_ant_scn = self._io.read_u4le()
            self.linkgs_clientid = self._io.read_u1()
            self.linkgs_clientip = self._io.read_u4le()
            self.linkgs_latestframe_servertime = self._io.read_u8le()
            self.linkgs_latestframe_origin = self._io.read_bits_int_be(1) != 0


    class SalsaTmReadMissingFrames(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_pmu_content = self._io.read_u1()


    class SalsaFwUpdateTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_fw_updater_state = self._io.read_u1()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_fw_updater_tmpimgaddr = self._io.read_u4le()
            self.sat_pget_selectedslotnum = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundererase = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundercrc = self._io.read_u1()
            self.sat_pget_fw_updater_activeimagelength = self._io.read_u4le()
            self.sat_pget_fw_updater_numwrittensequences = self._io.read_u2le()
            self.sat_pget_fw_updater_nextexpectedsequence = self._io.read_u2le()
            self.sat_pget_fw_updater_totalmissingsequences = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceswriteidx = self._io.read_u1()
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0


    class SalsaTmRqMaxVThreshold(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_max_v_stm = self._io.read_u2le()
            self.salsa_pget_max_v_fpga1v2 = self._io.read_u2le()
            self.salsa_pget_max_v_fpga3v3 = self._io.read_u2le()
            self.salsa_pget_max_v_lms = self._io.read_u2le()
            self.salsa_pget_max_v_ddr = self._io.read_u2le()
            self.salsa_pget_max_v_pmu = self._io.read_u2le()
            self.salsa_pget_max_v_flash = self._io.read_u2le()


    class Com4TmSram(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_frsyncsram = self._io.read_u4le()
            self.com4_pget_frsynchamsram = self._io.read_u4le()
            self.com4_pget_bitsyncnumsram = self._io.read_u1()
            self.com4_pget_srcidsram = self._io.read_u1()
            self.com4_pget_bcstidsram = self._io.read_u1()
            self.com4_pget_syncbiterrnumsram = self._io.read_u1()
            self.com4_pget_syncburstnumsram = self._io.read_u1()
            self.com4_pget_syncchainnumsram = self._io.read_u1()
            self.com4_pget_hamcallsignsram = self._io.read_u1()


    class AdcsActMatzInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_matz_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matz_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matz_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matz_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matz_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matz_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactstatematz = self._io.read_u1()


    class AdcsSenseSuse3D(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxsuse3_sat = self._io.read_s2le()
            self.adcs_pget_dysuse3_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse3_sat = self._io.read_s2le()
            self.thm_pget_tempsuse3 = self._io.read_u2le()
            self.adcs_pget_cursumsuse3_sat = self._io.read_s2le()
            self.adcs_pget_curx1suse3_sat = self._io.read_s2le()
            self.adcs_pget_curx2suse3_sat = self._io.read_s2le()
            self.adcs_pget_cury1suse3_sat = self._io.read_s2le()
            self.adcs_pget_cury2suse3_sat = self._io.read_s2le()
            self.adcs_pget_suse3_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates3 = self._io.read_u1()
            self.adcs_pget_isensorstatuss3 = self._io.read_u1()


    class PdhTmLaynetCost(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_networkdijkstracost = self._io.read_u2le()


    class AdcsCalTcompG1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g1tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g1tbiaspol0coefzaxis = self._io.read_s4le()


    class AdcsCalDcmMfrtosatSuse1To3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse1mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_suse1mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_suse2mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_suse3mfrtosatdcmw3 = self._io.read_s2le()


    class SalsaTmRqMaxIThreshold(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_max_i_stm = self._io.read_u2le()
            self.salsa_pget_max_i_fpga1v2 = self._io.read_u2le()
            self.salsa_pget_max_i_fpga3v3 = self._io.read_u2le()
            self.salsa_pget_max_i_lms = self._io.read_u2le()
            self.salsa_pget_max_i_ddr = self._io.read_u2le()
            self.salsa_pget_max_i_pmu = self._io.read_u2le()
            self.salsa_pget_max_i_flash = self._io.read_u2le()


    class AdcsCalTcompG5(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g5tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g5tbiaspol0coefzaxis = self._io.read_s4le()


    class PdhTmLayappStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_appfsmstate = self._io.read_u1()
            self.slkpdh_pget_appbasetrmpktloss = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasetrmcrcerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasetrmpkthdrerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_appbasetrmtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_appbasetrmrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_appbasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_appbasercvpktloss = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasercvcrcerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasercvpkthdrerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu22 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu23 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu24 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu25 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_appbasercvtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_appbasercvrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_appbasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_appspectrmpkttypemain = self._io.read_u1()
            self.slkpdh_pget_appspectrmpkttypesub = self._io.read_u1()
            self.slkpdh_pget_appspectrmpktlength = self._io.read_u2le()
            self.slkpdh_pget_appspectrmpktnum = self._io.read_u2le()
            self.slkpdh_pget_appspecrcvpkttypemain = self._io.read_u1()
            self.slkpdh_pget_appspecrcvpkttypesub = self._io.read_u1()
            self.slkpdh_pget_appspecrcvpktlength = self._io.read_u2le()
            self.slkpdh_pget_appspecrcvpktnum = self._io.read_u2le()


    class PdhTmSapEepromSat(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_satctrfrequencytxeeprom = self._io.read_u4le()
            self.slkpdh_pget_satctrfrequencyrxeeprom = self._io.read_u4le()
            self.slkpdh_pget_satctratttxgaineeprom = self._io.read_u1()
            self.slkpdh_pget_satctrchanneleeprom = self._io.read_u1()
            self.slkpdh_pget_satctrmaxaitypeeeprom = self._io.read_u1()
            self.slkpdh_pget_satctrantmodeeeprom = self._io.read_u1()
            self.slkpdh_pget_satctrrfrangeeeprom = self._io.read_u1()
            self.slkpdh_pget_satctrcallereeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrcallersendbroadcasteeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrrespondereeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrpayloaddireeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrfddoneeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0


    class AdcsRwcmdfifoinfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_rwcmdfifofilllevel = self._io.read_u1()
            self.adcs_pget_rwcmdfifoisrewritable = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_rwcmdfifomaxobservedfilllevel = self._io.read_u1()
            self.adcs_pget_rwcmdfifooverflowcount = self._io.read_u2le()
            self.adcs_pget_rwcmdfifomsgcount = self._io.read_u2le()
            self.adcs_pget_rwcmdfifomaxobservedbytecount = self._io.read_u4le()


    class EpsExtTmA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_s18_a_trx0 = self._io.read_s2le()
            self.eps_pget_s40_a_trx1 = self._io.read_s2le()
            self.eps_pget_s34_a_tnc0 = self._io.read_s2le()
            self.eps_pget_s35_a_tnc1 = self._io.read_s2le()
            self.eps_pget_s47_a_sun0 = self._io.read_s2le()
            self.eps_pget_s39_a_sun1 = self._io.read_s2le()
            self.eps_pget_s27_a_sens0 = self._io.read_s2le()
            self.eps_pget_s36_a_sens1 = self._io.read_s2le()
            self.thm_pget_s28_th_charger0 = self._io.read_s2le()
            self.thm_pget_s21_th_charger1 = self._io.read_s2le()
            self.eps_pget_main_3v3_0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_main_3v3_1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_trx0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_trx1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sun0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sun1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_iso_mult0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_iso_mult1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_pdh0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_pdh1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_tnc0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_tnc1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sens0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sens1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw0_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw1_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw2_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_main_unreg0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_main_unreg1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_a = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_b = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw0_wde = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw1_wde = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw2_wde = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mc_main = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mcx = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mcy = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mcz = self._io.read_bits_int_be(1) != 0
            self.eps_pget_reserve = self._io.read_bits_int_be(1) != 0
            self.eps_pget_tempsens = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_a_err = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.eps_pget_s46_v_in_dcdc_a = self._io.read_s2le()
            self.eps_pget_s43_v_in_dcdc_b = self._io.read_s2le()
            self.eps_pget_s42_a_tempsens = self._io.read_s2le()
            self.eps_pget_realalgotime = self._io.read_u1()


    class Rw1TmStdB(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_fsmmainstate = self._io.read_u1()
            self.rw1_pget_anomalycurmtrfine = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycurmtrcoarse = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v2minus = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt10v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalygyro = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw1_pget_curmtrfine = self._io.read_u2le()
            self.rw1_pget_vlt3v2 = self._io.read_u2le()
            self.rw1_pget_vlt3v2minus = self._io.read_u2le()
            self.rw1_pget_vlt10v = self._io.read_u2le()
            self.thm_rw1_pget_tmpgyro1 = self._io.read_s2le()
            self.rw1_pget_rategyro1x = self._io.read_s2le()
            self.rw1_pget_rategyro1y = self._io.read_s2le()
            self.rw1_pget_rategyro1z = self._io.read_s2le()


    class PdhTmMemextser8(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_memextserialrdaddr = self._io.read_u4le()
            self.pdh_pget_memextserialdata8 = self._io.read_u1()


    class PdhTmFifo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_fifonumspcmaintxsf = self._io.read_u1()
            self.pdh_pget_fifonumspcmaintxsf64 = self._io.read_u1()
            self.pdh_pget_fifonumspcmaintxmf = self._io.read_u1()
            self.pdh_pget_fifonumspcrxsf = self._io.read_u1()
            self.pdh_pget_fifonumspcrxsf16 = self._io.read_u1()
            self.pdh_pget_fifonumspcrxsf32 = self._io.read_u1()
            self.pdh_pget_fifonumspcrxmf = self._io.read_u1()
            self.pdh_pget_fifonumexprxsf16 = self._io.read_u1()
            self.pdh_pget_fifonumexprxsf32 = self._io.read_u1()
            self.pdh_pget_fifonumsdutxsf = self._io.read_u1()
            self.pdh_pget_fifonumsdutxsf64 = self._io.read_u1()
            self.pdh_pget_fifonumsdurxsf = self._io.read_u1()
            self.pdh_pget_fifonumsdurxsf64 = self._io.read_u1()
            self.pdh_pget_fifonumexprxsf = self._io.read_u1()
            self.pdh_pget_fifonumspcdbgtxsf = self._io.read_u1()
            self.pdh_pget_fifonumspcdbgtxsf64 = self._io.read_u1()
            self.pdh_pget_fifonumspcdbgtxmf = self._io.read_u1()
            self.pdh_pget_fifonumsbandtxsf = self._io.read_u1()
            self.pdh_pget_fifonumsbandtxsf64 = self._io.read_u1()
            self.pdh_pget_fifonumsbandtxmf = self._io.read_u1()
            self.pdh_pget_fifonummemtxsf = self._io.read_u1()
            self.pdh_pget_fifonummemtxsf64 = self._io.read_u1()
            self.pdh_pget_fifonumspcrxsf64 = self._io.read_u1()


    class AdcsActMatyInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_maty_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_maty_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_maty_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_maty_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_maty_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_maty_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactstatematy = self._io.read_u1()


    class AdcsCalMappingSuse3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse3mappingpol0coefx = self._io.read_s4le()
            self.adcs_pget_suse3mappingpol1coefx = self._io.read_s4le()
            self.adcs_pget_suse3mappingpol2coefx = self._io.read_s4le()
            self.adcs_pget_suse3mappingpol3coefx = self._io.read_s4le()
            self.adcs_pget_suse3mappingpol0coefy = self._io.read_s4le()
            self.adcs_pget_suse3mappingpol1coefy = self._io.read_s4le()
            self.adcs_pget_suse3mappingpol2coefy = self._io.read_s4le()
            self.adcs_pget_suse3mappingpol3coefy = self._io.read_s4le()


    class PdhTmSapEepromSat2sat(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_sat2satctrfrequencytxeeprom = self._io.read_u4le()
            self.slkpdh_pget_sat2satctrfrequencyrxeeprom = self._io.read_u4le()
            self.slkpdh_pget_sat2satctratttxgaineeprom = self._io.read_u1()
            self.slkpdh_pget_sat2satctrchanneleeprom = self._io.read_u1()
            self.slkpdh_pget_sat2satctrmaxaitypeeeprom = self._io.read_u1()
            self.slkpdh_pget_sat2satctrantmodeeeprom = self._io.read_u1()
            self.slkpdh_pget_sat2satctrrfrangeeeprom = self._io.read_u1()
            self.slkpdh_pget_sat2satctrcallereeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sat2satctrcallersendbroadcasteeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sat2satctrrespondereeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sat2satctrpayloaddireeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0


    class Rw0TmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_resetcnt = self._io.read_u2le()
            self.rw0_pget_fsmmainstate = self._io.read_u1()
            self.rw0_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtroff = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mvlimit = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrovercur = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_faultgyro0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_faultgyro1 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycurmtr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v3mcu = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalygyro0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalygyro1 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw0_pget_curmtr = self._io.read_u2le()
            self.rw0_pget_curwde = self._io.read_u2le()
            self.rw0_pget_cur3v3 = self._io.read_u2le()
            self.rw0_pget_cur5v = self._io.read_u2le()
            self.rw0_pget_vltmtr = self._io.read_u2le()
            self.rw0_pget_vlt3v2 = self._io.read_u2le()
            self.rw0_pget_vlt5v = self._io.read_u2le()
            self.rw0_pget_vlt3v3 = self._io.read_u2le()
            self.rw0_pget_vlt3v3mcu = self._io.read_u2le()
            self.thm_rw0_pget_tmppwr = self._io.read_u2le()
            self.thm_rw0_pget_tmppresssens = self._io.read_u4le()
            self.thm_rw0_pget_tmpgyro1 = self._io.read_s2le()
            self.rw0_pget_vltgyro0zref = self._io.read_u2le()
            self.rw0_pget_vltgyro0z = self._io.read_u2le()
            self.rw0_pget_rategyro1x = self._io.read_s2le()
            self.rw0_pget_rategyro1y = self._io.read_s2le()
            self.rw0_pget_rategyro1z = self._io.read_s2le()
            self.rw0_pget_press = self._io.read_u4le()


    class Com0TmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_resetcnt = self._io.read_u2le()
            self.com0_pget_rxsducnt = self._io.read_u2le()
            self.com0_pget_rxspducnt = self._io.read_u2le()
            self.com0_pget_fsmmainstate = self._io.read_u1()
            self.com0_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.com0_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_pdurxfifofull = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxmode = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxrxovercur = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxtxovercur = self._io.read_bits_int_be(1) != 0
            self.com0_pget_initeepromparcompl = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyrssi = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyrssirx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycd = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycurtrxrx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycurtrxtx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyvlttrxrx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyvlttrxtx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytmptnc = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_rssi_a = self._io.read_u2le()
            self.com0_pget_rssirx_a = self._io.read_u2le()
            self.com0_pget_cd_a = self._io.read_u2le()
            self.com0_pget_curtrx_a = self._io.read_u2le()
            self.com0_pget_curtrxtx_a = self._io.read_u2le()
            self.com0_pget_cur3v3_a = self._io.read_u2le()
            self.com0_pget_vlttrx_a = self._io.read_u2le()
            self.com0_pget_vlttrxtx_a = self._io.read_u2le()
            self.com0_pget_vlt3v3_a = self._io.read_u2le()
            self.thm_com0_pget_tmptnc_a = self._io.read_u2le()
            self.thm_com0_pget_trxtmyreg = self._io.read_u2le()
            self.com0_pget_timetoautorecoveryreset = self._io.read_u4le()


    class FdaTmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_mode = self._io.read_u1()
            self.fda_pget_power_mode = self._io.read_bits_int_be(1) != 0
            self.fda_pget_rot_dir = self._io.read_bits_int_be(1) != 0
            self.fda_pget_flag_fu = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.fda_pget_sys_time = self._io.read_u2le()
            self.fda_pget_turn_on_counter = self._io.read_u2le()
            self.fda_pget_temp_fda_x = self._io.read_s1()
            self.fda_pget_temp_fda_y = self._io.read_s1()
            self.fda_pget_temp_fda_z = self._io.read_s1()
            self.fda_pget_temp_gyro = self._io.read_s1()
            self.fda_pget_dac_x = self._io.read_u2le()
            self.fda_pget_dac_y = self._io.read_u2le()
            self.fda_pget_dac_z = self._io.read_u2le()
            self.fda_pget_int_gyr_omega_x = self._io.read_f4le()
            self.fda_pget_int_gyr_omega_y = self._io.read_f4le()
            self.fda_pget_int_gyr_omega_z = self._io.read_f4le()
            self.fda_pget_int_gyr_omega_abs = self._io.read_f4le()
            self.fda_pget_int_gyr_phi_x = self._io.read_f4le()
            self.fda_pget_int_gyr_phi_y = self._io.read_f4le()
            self.fda_pget_int_gyr_phi_z = self._io.read_f4le()
            self.fda_pget_sat_mag_x = self._io.read_s2le()
            self.fda_pget_sat_mag_y = self._io.read_s2le()
            self.fda_pget_sat_mag_z = self._io.read_s2le()
            self.fda_pget_u_bx = self._io.read_u1()
            self.fda_pget_u_by = self._io.read_u1()
            self.fda_pget_u_bz = self._io.read_u1()
            self.fda_pget_k_p = self._io.read_u1()
            self.fda_pget_k_d = self._io.read_u1()
            self.fda_pget_k_i = self._io.read_u1()
            self.fda_pget_gyro_def = self._io.read_u1()
            self.fda_pget_int_gyro_val = self._io.read_u1()


    class AdcsCalDcmMfrtosatSuse4To6(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse4mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_suse4mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_suse5mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_suse6mfrtosatdcmw3 = self._io.read_s2le()


    class AdcsSenseG4Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg4_sat = self._io.read_s2le()
            self.adcs_pget_omegayg4_sat = self._io.read_s2le()
            self.adcs_pget_omegazg4_sat = self._io.read_s2le()
            self.thm_pget_tempg4 = self._io.read_s2le()
            self.adcs_pget_g4_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg4 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg4 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg4 = self._io.read_u1()


    class AdcsSenseMfs4B(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxmfs4_sat = self._io.read_s2le()
            self.adcs_pget_dymfs4_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs4_sat = self._io.read_s2le()
            self.adcs_pget_mfs4_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs4 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs4 = self._io.read_u1()


    class SalsaTmGetInaDdrStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class SalsaTmRqMinVThreshold(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_min_v_stm = self._io.read_u2le()
            self.salsa_pget_min_v_fpga1v2 = self._io.read_u2le()
            self.salsa_pget_min_v_fpga3v3 = self._io.read_u2le()
            self.salsa_pget_min_v_lms = self._io.read_u2le()
            self.salsa_pget_min_v_ddr = self._io.read_u2le()
            self.salsa_pget_min_v_pmu = self._io.read_u2le()
            self.salsa_pget_min_v_flash = self._io.read_u2le()


    class Com4TmTrx(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_freqsetting = self._io.read_bits_int_be(1) != 0
            self.com4_pget_trxcomtimeout = self._io.read_bits_int_be(1) != 0
            self.com4_pget_trxtype = self._io.read_bits_int_be(1) != 0
            self.com4_pget_trxwaitbeforefreqset = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_txfreqicom_10_1 = self._io.read_u1()
            self.com4_pget_txfreqicom_100_10 = self._io.read_u1()
            self.com4_pget_txfreqicom_1k_100 = self._io.read_u1()
            self.com4_pget_txfreqicom_10k_1k = self._io.read_u1()
            self.com4_pget_txfreqicom_100k_10k = self._io.read_u1()
            self.com4_pget_txfreqicom_1m_100k = self._io.read_u1()
            self.com4_pget_txfreqicom_10m_1m = self._io.read_u1()
            self.com4_pget_txfreqicom_100m_10m = self._io.read_u1()
            self.com4_pget_txfreqicom_1g_100m = self._io.read_u1()
            self.com4_pget_txfreqicom_10g_1g = self._io.read_u1()
            self.com4_pget_rxfreqicom_10_1 = self._io.read_u1()
            self.com4_pget_rxfreqicom_100_10 = self._io.read_u1()
            self.com4_pget_rxfreqicom_1k_100 = self._io.read_u1()
            self.com4_pget_rxfreqicom_10k_1k = self._io.read_u1()
            self.com4_pget_rxfreqicom_100k_10k = self._io.read_u1()
            self.com4_pget_rxfreqicom_1m_100k = self._io.read_u1()
            self.com4_pget_rxfreqicom_10m_1m = self._io.read_u1()
            self.com4_pget_rxfreqicom_100m_10m = self._io.read_u1()
            self.com4_pget_rxfreqicom_1g_100m = self._io.read_u1()
            self.com4_pget_rxfreqicom_10g_1g = self._io.read_u1()


    class PdhPlepsHkThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class PdhTmSapSramSat2sat(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_sat2satctrfrequencytxsram = self._io.read_u4le()
            self.slkpdh_pget_sat2satctrfrequencyrxsram = self._io.read_u4le()
            self.slkpdh_pget_sat2satctratttxgainsram = self._io.read_u1()
            self.slkpdh_pget_sat2satctrchannelsram = self._io.read_u1()
            self.slkpdh_pget_sat2satctrmaxaitypesram = self._io.read_u1()
            self.slkpdh_pget_sat2satctrantmodesram = self._io.read_u1()
            self.slkpdh_pget_sat2satctrrfrangesram = self._io.read_u1()
            self.slkpdh_pget_sat2satctrcallersram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sat2satctrcallersendbroadcastsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sat2satctrrespondersram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sat2satctrpayloaddirsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0


    class PdhPlepsIpuCtrlStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_ipu_ctrl_state = self._io.read_u1()
            self.pdh_pleps_pget_ipu_status_check_interval = self._io.read_u2le()


    class AdcsAttTargetInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_targetdata_latitude = self._io.read_u2le()
            self.adcs_pget_targetdata_longitude = self._io.read_u2le()
            self.adcs_pget_targetdata_altitude = self._io.read_s2le()
            self.adcs_pget_targetdata_controlmindistance = self._io.read_u2le()
            self.adcs_pget_targetdata_distance = self._io.read_u2le()
            self.adcs_pget_targetdata_targetpanel = self._io.read_u1()
            self.adcs_pget_targetdata_offsetanglex = self._io.read_s2le()
            self.adcs_pget_targetdata_offsetangley = self._io.read_s2le()
            self.adcs_pget_targetdata_offsetanglez = self._io.read_s2le()
            self.adcs_pget_targetdata_controlisactive = self._io.read_bits_int_be(1) != 0


    class SalsaTmGetInaPmuStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class SalsaTmPmuStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_pmua1_status = self._io.read_u1()
            self.salsa_pget_pmub1_status = self._io.read_u1()
            self.salsa_pget_pmua2_status = self._io.read_u1()
            self.salsa_pget_pmub2_status = self._io.read_u1()
            self.salsa_pget_pmua_be_in_progress = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_pmub_be_in_progress = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_pmua_se_in_progress = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_pmub_se_in_progress = self._io.read_bits_int_be(1) != 0


    class SalsaLinkThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class FdaTmImuPhi(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_imu_phi_x = self._io.read_f4le()
            self.fda_pget_imu_phi_y = self._io.read_f4le()
            self.fda_pget_imu_phi_z = self._io.read_f4le()


    class AdcsSenseSuse6D(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxsuse6_sat = self._io.read_s2le()
            self.adcs_pget_dysuse6_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse6_sat = self._io.read_s2le()
            self.thm_pget_tempsuse6 = self._io.read_u2le()
            self.adcs_pget_cursumsuse6_sat = self._io.read_s2le()
            self.adcs_pget_curx1suse6_sat = self._io.read_s2le()
            self.adcs_pget_curx2suse6_sat = self._io.read_s2le()
            self.adcs_pget_cury1suse6_sat = self._io.read_s2le()
            self.adcs_pget_cury2suse6_sat = self._io.read_s2le()
            self.adcs_pget_suse6_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates6 = self._io.read_u1()
            self.adcs_pget_isensorstatuss6 = self._io.read_u1()


    class ObcInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_obc_red_num = self._io.read_s1()
            self.fdir_pget_rodoserrorcounter = self._io.read_u4le()
            self.fdir_pget_gitversion = self._io.read_u8le()
            self.fdir_pget_compiletimeinsec = self._io.read_u8le()
            self.fdir_pget_ismodifiedversion = self._io.read_bits_int_be(1) != 0


    class Com1TmRtc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_rtcinitcomplete = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcinvreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcspiactive = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcspirelease = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcconfcomplete = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcwrtime = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcttavailable = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_rtcsec01 = self._io.read_u1()
            self.com1_pget_rtcsec001 = self._io.read_u1()
            self.com1_pget_rtcsec10 = self._io.read_u1()
            self.com1_pget_rtcsec1 = self._io.read_u1()
            self.com1_pget_rtcsec01alarm = self._io.read_u1()
            self.com1_pget_rtcsec001alarm = self._io.read_u1()
            self.com1_pget_rtcsec10alarm = self._io.read_u1()
            self.com1_pget_rtcsec1alarm = self._io.read_u1()
            self.com1_pget_rtcmin10 = self._io.read_u1()
            self.com1_pget_rtcmin1 = self._io.read_u1()
            self.com1_pget_rtcmin10alarm = self._io.read_u1()
            self.com1_pget_rtcmin1alarm = self._io.read_u1()
            self.com1_pget_rtchour10 = self._io.read_u1()
            self.com1_pget_rtchour1 = self._io.read_u1()
            self.com1_pget_rtchour10alarm = self._io.read_u1()
            self.com1_pget_rtchour1alarm = self._io.read_u1()
            self.com1_pget_rtcday = self._io.read_u1()
            self.com1_pget_rtcdayalarm = self._io.read_u1()
            self.com1_pget_rtcdate10 = self._io.read_u1()
            self.com1_pget_rtcdate1 = self._io.read_u1()
            self.com1_pget_rtcdate10alarm = self._io.read_u1()
            self.com1_pget_rtcdate1alarm = self._io.read_u1()
            self.com1_pget_rtcmonth10 = self._io.read_u1()
            self.com1_pget_rtcmonth1 = self._io.read_u1()
            self.com1_pget_rtcyear10 = self._io.read_u1()
            self.com1_pget_rtcyear1 = self._io.read_u1()
            self.com1_pget_rtcregcontrol = self._io.read_u1()
            self.com1_pget_rtcregstatus = self._io.read_u1()
            self.com1_pget_rtcregtricklecharger = self._io.read_u1()
            self.com1_pget_rtc12 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcpm = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtccentury = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtc12alarm = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcpmalarm = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcdyalarm = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcam1 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcam2 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcam3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rtcam4 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_rtcyear = self._io.read_u2le()
            self.com1_pget_rtcmonth = self._io.read_u1()
            self.com1_pget_rtcmin = self._io.read_u1()
            self.com1_pget_rtcminalarm = self._io.read_u1()
            self.com1_pget_rtchour = self._io.read_u1()
            self.com1_pget_rtchouralarm = self._io.read_u1()
            self.com1_pget_rtcdate = self._io.read_u1()
            self.com1_pget_rtcdatealarm = self._io.read_u1()
            self.com1_pget_rtcsec = self._io.read_u2le()
            self.com1_pget_rtcsecalarm = self._io.read_u2le()


    class PdhPlepsSatStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obc_act = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_selectedslotnum = self._io.read_u1()
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_realalgotime = self._io.read_u1()


    class AdcsCtrlParameterInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_pdkfactor = self._io.read_s2le()
            self.adcs_pget_pdkdfactor = self._io.read_s2le()
            self.adcs_pget_pdcontrollawselector = self._io.read_u1()
            self.adcs_pget_pdomegakfactor = self._io.read_s2le()
            self.adcs_pget_pdomegakdfactor = self._io.read_s2le()
            self.adcs_pget_pdomegacontrollawselector = self._io.read_u1()
            self.adcs_pget_bdotcfactor = self._io.read_u1()
            self.adcs_pget_bdotmfsafilterrotationthreshold = self._io.read_u1()
            self.adcs_pget_ibdotfilterdepth = self._io.read_u1()


    class Com0TmCom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_txltuhdrdstid = self._io.read_u1()
            self.com0_pget_txltuhdrsrcid = self._io.read_u1()
            self.com0_pget_txltuhdrfrcnttx = self._io.read_u1()
            self.com0_pget_txltuhdrfrcntrx = self._io.read_u1()
            self.com0_pget_txltuhdrsnr = self._io.read_u1()
            self.com0_pget_txltuhdraitypesrc = self._io.read_u1()
            self.com0_pget_txltuhdraitypedst = self._io.read_u1()
            self.com0_pget_txltuhdrdfcid = self._io.read_u1()
            self.com0_pget_txltuhdrfrlength = self._io.read_u2le()
            self.com0_pget_txltuhdrcrc13 = self._io.read_u2le()
            self.com0_pget_txltuhdrcrc5 = self._io.read_u1()
            self.com0_pget_txltuhdrudfl1 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_txltuhdrhailing = self._io.read_bits_int_be(1) != 0
            self.com0_pget_txltuhdrrqbch = self._io.read_bits_int_be(1) != 0
            self.com0_pget_txltuhdrpdutypeid = self._io.read_bits_int_be(1) != 0
            self.com0_pget_txltuhdrarq = self._io.read_bits_int_be(1) != 0
            self.com0_pget_txltuhdrcaller = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_rxltuhdrdstid = self._io.read_u1()
            self.com0_pget_rxltuhdrsrcid = self._io.read_u1()
            self.com0_pget_rxltuhdrfrcnttx = self._io.read_u1()
            self.com0_pget_rxltuhdrfrcntrx = self._io.read_u1()
            self.com0_pget_rxltuhdrsnr = self._io.read_u1()
            self.com0_pget_rxltuhdraitypesrc = self._io.read_u1()
            self.com0_pget_rxltuhdraitypedst = self._io.read_u1()
            self.com0_pget_rxltuhdrdfcid = self._io.read_u1()
            self.com0_pget_rxltuhdrfrlength = self._io.read_u2le()
            self.com0_pget_rxltuhdrcrc13 = self._io.read_u2le()
            self.com0_pget_rxltuhdrcrc5 = self._io.read_u1()
            self.com0_pget_rxltuhdrudfl1 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxltuhdrhailing = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxltuhdrrqbch = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxltuhdrpdutypeid = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxltuhdrarq = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxltuhdrcaller = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_ltudecerrnum = self._io.read_u2le()
            self.com0_pget_sdutxfifonum = self._io.read_u1()
            self.com0_pget_sessiontime = self._io.read_u2le()
            self.com0_pget_fsmcomstate = self._io.read_u1()
            self.com0_pget_ltuhdrdec = self._io.read_bits_int_be(1) != 0
            self.com0_pget_pdufirstblockdec = self._io.read_bits_int_be(1) != 0
            self.com0_pget_sduhdrdec = self._io.read_bits_int_be(1) != 0
            self.com0_pget_lturxcomplete = self._io.read_bits_int_be(1) != 0
            self.com0_pget_ltuhdrdecerr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_ltuhdrrxerr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_ltuhdrdeclock = self._io.read_bits_int_be(1) != 0
            self.com0_pget_pdudecerr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_burst = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rangevalid = self._io.read_bits_int_be(1) != 0
            self.com0_pget_sdutxfifooverrun = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxpducrcerr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxsducrcerr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_collectbcherr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_chmon = self._io.read_bits_int_be(1) != 0
            self.com0_pget_ltuerr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_tddmode = self._io.read_bits_int_be(1) != 0
            self.com0_pget_generaltxlock = self._io.read_bits_int_be(1) != 0
            self.com0_pget_spktmodetxlock = self._io.read_bits_int_be(1) != 0
            self.com0_pget_ack = self._io.read_bits_int_be(1) != 0
            self.com0_pget_pktloss = self._io.read_bits_int_be(1) != 0
            self.com0_pget_sessionest = self._io.read_bits_int_be(1) != 0
            self.com0_pget_sessionopened = self._io.read_bits_int_be(1) != 0
            self.com0_pget_syncnewburst = self._io.read_bits_int_be(1) != 0
            self.com0_pget_syncerrnumvalid = self._io.read_bits_int_be(1) != 0
            self.com0_pget_syncburstnumvalid = self._io.read_bits_int_be(1) != 0
            self.com0_pget_syncchainnumvalid = self._io.read_bits_int_be(1) != 0
            self.com0_pget_extsrcid = self._io.read_bits_int_be(1) != 0
            self.com0_pget_answpending = self._io.read_bits_int_be(1) != 0
            self.com0_pget_arqsyncloss = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_range = self._io.read_u4le()
            self.com0_pget_rssirx = self._io.read_u2le()
            self.com0_pget_cd = self._io.read_u2le()


    class PdhPlepsSatThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class SalsaTmGetLmsRegister(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_lms_reg_address = self._io.read_u2le()
            self.salsa_pget_lms_reg_value = self._io.read_u2le()


    class EpsSwitchState(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_main_3v3_0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_main_3v3_1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_heat_1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_heat_0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_reserve = self._io.read_bits_int_be(1) != 0
            self.eps_pget_trx1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_trx0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sun0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sun1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_iso_mult1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_iso_mult0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_tnc1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_tnc0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_pdh1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_tempsens = self._io.read_bits_int_be(1) != 0
            self.eps_pget_pdh0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw2_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw1_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw0_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sens0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sens1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mcx = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mcy = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mcz = self._io.read_bits_int_be(1) != 0
            self.eps_pget_mc_main = self._io.read_bits_int_be(1) != 0
            self.eps_pget_main_unreg0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_main_unreg1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_a = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_b = self._io.read_bits_int_be(1) != 0
            self.eps_pget_lb_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw0_wde = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw1_wde = self._io.read_bits_int_be(1) != 0
            self.eps_pget_rw2_wde = self._io.read_bits_int_be(1) != 0
            self.eps_pget_sw35_unused = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_a_err = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_b_err = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger0_err = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger1_err = self._io.read_bits_int_be(1) != 0


    class Com1TmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_resetcnt = self._io.read_u2le()
            self.com1_pget_rxsducnt = self._io.read_u2le()
            self.com1_pget_rxspducnt = self._io.read_u2le()
            self.com1_pget_fsmmainstate = self._io.read_u1()
            self.com1_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.com1_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_pdurxfifofull = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxmode = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxrxovercur = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxtxovercur = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyrssi = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyrssirx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycd = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycurtrxrx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycurtrxtx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyvlttrxrx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyvlttrxtx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytmptnc = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_rssi = self._io.read_u2le()
            self.com1_pget_rssirx = self._io.read_u2le()
            self.com1_pget_cd = self._io.read_u2le()
            self.com1_pget_curtrx = self._io.read_u2le()
            self.com1_pget_curtrxtx = self._io.read_u2le()
            self.com1_pget_cur3v3 = self._io.read_u2le()
            self.com1_pget_vlttrx = self._io.read_u2le()
            self.com1_pget_vlttrxtx = self._io.read_u2le()
            self.com1_pget_vlt3v3 = self._io.read_u2le()
            self.thm_com1_pget_tmptnc = self._io.read_u2le()
            self.com1_pget_timetoautorecoveryreset = self._io.read_u4le()


    class AdcsSenseSuse5D(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxsuse5_sat = self._io.read_s2le()
            self.adcs_pget_dysuse5_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse5_sat = self._io.read_s2le()
            self.thm_pget_tempsuse5 = self._io.read_u2le()
            self.adcs_pget_cursumsuse5_sat = self._io.read_s2le()
            self.adcs_pget_curx1suse5_sat = self._io.read_s2le()
            self.adcs_pget_curx2suse5_sat = self._io.read_s2le()
            self.adcs_pget_cury1suse5_sat = self._io.read_s2le()
            self.adcs_pget_cury2suse5_sat = self._io.read_s2le()
            self.adcs_pget_suse5_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates5 = self._io.read_u1()
            self.adcs_pget_isensorstatuss5 = self._io.read_u1()


    class Rw2TmStdB(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_fsmmainstate = self._io.read_u1()
            self.rw2_pget_anomalycurmtrfine = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycurmtrcoarse = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v2minus = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt10v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalygyro = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw2_pget_curmtrfine = self._io.read_u2le()
            self.rw2_pget_vlt3v2 = self._io.read_u2le()
            self.rw2_pget_vlt3v2minus = self._io.read_u2le()
            self.rw2_pget_vlt10v = self._io.read_u2le()
            self.thm_rw2_pget_tmpgyro1 = self._io.read_s2le()
            self.rw2_pget_rategyro1x = self._io.read_s2le()
            self.rw2_pget_rategyro1y = self._io.read_s2le()
            self.rw2_pget_rategyro1z = self._io.read_s2le()


    class AdcsSuseAllInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse1_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates1 = self._io.read_u1()
            self.adcs_pget_isensorstatuss1 = self._io.read_u1()
            self.adcs_pget_suse2_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates2 = self._io.read_u1()
            self.adcs_pget_isensorstatuss2 = self._io.read_u1()
            self.adcs_pget_suse3_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates3 = self._io.read_u1()
            self.adcs_pget_isensorstatuss3 = self._io.read_u1()
            self.adcs_pget_suse4_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates4 = self._io.read_u1()
            self.adcs_pget_isensorstatuss4 = self._io.read_u1()
            self.adcs_pget_suse5_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates5 = self._io.read_u1()
            self.adcs_pget_isensorstatuss5 = self._io.read_u1()
            self.adcs_pget_suse6_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates6 = self._io.read_u1()
            self.adcs_pget_isensorstatuss6 = self._io.read_u1()


    class SalsaTmGetInaLmsStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class PdhPlepsFdaCtrlThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class AdcsActMatxInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_matx_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matx_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matx_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matx_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matx_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_matx_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactstatematx = self._io.read_u1()


    class PdhTmMemextser32(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_memextserialrdaddr = self._io.read_u4le()
            self.pdh_pget_memextserialdata32 = self._io.read_u1()


    class EpsRawthm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.thm_pget_s15_th_bat1_raw = self._io.read_s2le()
            self.thm_pget_s21_th_charger1_raw = self._io.read_s2le()
            self.thm_pget_s28_th_charger0_raw = self._io.read_s2le()
            self.thm_pget_s31_th_bat0_raw = self._io.read_s2le()
            self.thm_pget_th_stm_raw = self._io.read_s2le()


    class SalsaTmGetInaFpga3v3Status(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class PdhTmMemextser512(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_memextserialrdaddr = self._io.read_u4le()
            self.pdh_pget_memextserialdata512 = self._io.read_u1()


    class PdhTmLaynetStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_netfsmstate = self._io.read_u1()
            self.slkpdh_pget_netbasetrmsgperr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasetrmdijkstraerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasetrmjdayconfig = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_netbasetrmtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_netbasetrmrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_netbasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_netbasercvsgperr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasercvdijkstraerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasercvjdayconfig = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu22 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu23 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu24 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu25 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_netbasercvtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_netbasercvrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_netbasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_netspectrmsrcscid = self._io.read_u2le()
            self.slkpdh_pget_netspectrmdstscid = self._io.read_u2le()
            self.slkpdh_pget_netspectrmantmode = self._io.read_u1()
            self.slkpdh_pget_netspectrmrfrange = self._io.read_u1()
            self.slkpdh_pget_netspectrmzerosystime = self._io.read_u4le()
            self.slkpdh_pget_netspectrmzerojdfld = self._io.read_s8le()
            self.slkpdh_pget_netspectrmzerojdexp = self._io.read_s1()
            self.slkpdh_pget_netspecrcvsrcscid = self._io.read_u2le()
            self.slkpdh_pget_netspecrcvdstscid = self._io.read_u2le()
            self.slkpdh_pget_netspecrcvantmode = self._io.read_u1()
            self.slkpdh_pget_netspecrcvrfrange = self._io.read_u1()
            self.slkpdh_pget_netspecrcvzerosystime = self._io.read_u4le()
            self.slkpdh_pget_netspecrcvzerojdfld = self._io.read_s8le()
            self.slkpdh_pget_netspecrcvzerojdexp = self._io.read_s1()


    class Rw1TmSwvers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_swversmajor = self._io.read_u1()
            self.rw1_pget_swversminor = self._io.read_u1()
            self.rw1_pget_swbuildyear = self._io.read_u1()
            self.rw1_pget_swbuildmonth = self._io.read_u1()
            self.rw1_pget_swbuildday = self._io.read_u1()
            self.rw1_pget_swbuildhour = self._io.read_u1()
            self.rw1_pget_swbuildmin = self._io.read_u1()
            self.rw1_pget_swbuildsec = self._io.read_u1()
            self.rw1_pget_serialnum = self._io.read_u2le()
            self.rw1_pget_devid = self._io.read_u1()


    class Rw2TmCstm3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()


    class PdhPlepsFwUpdateTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_fw_updater_state = self._io.read_u1()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_fw_updater_tmpimgaddr = self._io.read_u4le()
            self.sat_pget_selectedslotnum = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundererase = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundercrc = self._io.read_u1()
            self.sat_pget_fw_updater_activeimagelength = self._io.read_u4le()
            self.sat_pget_fw_updater_numwrittensequences = self._io.read_u2le()
            self.sat_pget_fw_updater_nextexpectedsequence = self._io.read_u2le()
            self.sat_pget_fw_updater_totalmissingsequences = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceswriteidx = self._io.read_u1()
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0


    class AdcsMfsAllInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_mfs1_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs1 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs1 = self._io.read_u1()
            self.adcs_pget_mfs2_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs2 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs2 = self._io.read_u1()
            self.adcs_pget_mfs3_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs3 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs3 = self._io.read_u1()
            self.adcs_pget_mfs4_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs4 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs4 = self._io.read_u1()


    class SalsaTmRqMinIThreshold(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_min_i_stm = self._io.read_u2le()
            self.salsa_pget_min_i_fpga1v2 = self._io.read_u2le()
            self.salsa_pget_min_i_fpga3v3 = self._io.read_u2le()
            self.salsa_pget_min_i_lms = self._io.read_u2le()
            self.salsa_pget_min_i_ddr = self._io.read_u2le()
            self.salsa_pget_min_i_pmu = self._io.read_u2le()
            self.salsa_pget_min_i_flash = self._io.read_u2le()


    class AdcsCalGOffsetInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_debug_pget_icalimodegbias = self._io.read_u1()
            self.adcs_debug_pget_icalistategbias = self._io.read_u1()
            self.adcs_debug_pget_icalilastcalelapsedtimegbias = self._io.read_u2le()
            self.adcs_debug_pget_icalicalibintervallgbias = self._io.read_u2le()
            self.adcs_debug_pget_icalicalibstepgbias = self._io.read_u2le()


    class AdcsActaMataLoopVec(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dcmdmagmomentmatax_sat = self._io.read_s2le()
            self.adcs_pget_dcmdmagmomentmatay_sat = self._io.read_s2le()
            self.adcs_pget_dcmdmagmomentmataz_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentmatax_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentmatay_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentmataz_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentnamatax_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentnamatay_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentnamataz_sat = self._io.read_s2le()
            self.adcs_pget_dctrlcurrentmatax_mfr = self._io.read_s2le()
            self.adcs_pget_dctrlcurrentmatay_mfr = self._io.read_s2le()
            self.adcs_pget_dctrlcurrentmataz_mfr = self._io.read_s2le()
            self.adcs_pget_dcmdtorquematax_sat = self._io.read_s2le()
            self.adcs_pget_dcmdtorquematay_sat = self._io.read_s2le()
            self.adcs_pget_dcmdtorquemataz_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquematax_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquematay_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquemataz_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquenamatax_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquenamatay_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquenamataz_sat = self._io.read_s2le()


    class SalsaUpdatesStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obc_act = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_selectedslotnum = self._io.read_u1()
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_realalgotime = self._io.read_u1()


    class Com0TmTrx(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_anomalytrxtreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxrreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxyreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxsreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxureg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxvreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxnreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxqreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxpreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytrxdreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_txorrxfreqnotdefault = self._io.read_bits_int_be(1) != 0
            self.com0_pget_invtrxtmtxrx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxcomtimeout = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxtmrxmode = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxtmbaudlow = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxsetfreqboth = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_trxtmsreg = self._io.read_u4le()
            self.com0_pget_trxtmrreg = self._io.read_u4le()
            self.com0_pget_trxtmtreg = self._io.read_u4le()
            self.thm_com0_pget_trxtmyreg = self._io.read_u2le()
            self.com0_pget_trxtmqreg = self._io.read_u2le()
            self.com0_pget_trxtmnreg = self._io.read_u2le()
            self.com0_pget_trxtmdreg = self._io.read_u2le()
            self.com0_pget_trxtmpreg = self._io.read_u2le()
            self.com0_pget_trxtmvreg = self._io.read_u2le()
            self.com0_pget_trxtmureg = self._io.read_u2le()
            self.com0_pget_systimetrxtm = self._io.read_u4le()
            self.com0_pget_periodrdtrxtmeeprom = self._io.read_u2le()
            self.com0_pget_periodrdtrxtmsram = self._io.read_u2le()


    class Rw2TmCstm2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()


    class Rw1TmCstm1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_fsmcntrlstate = self._io.read_u1()
            self.rw1_pget_mtrnegdirsense = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrrotdirchange = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrrotzero = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_softstholdmtroff = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_newhalledge = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_hallirqguard = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_hallirqcollision = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryext = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw1_pget_rategyroz = self._io.read_s4le()
            self.rw1_pget_satrate = self._io.read_s4le()
            self.rw1_pget_vltgyro0zref = self._io.read_u2le()
            self.rw1_pget_vltgyro0z = self._io.read_u2le()
            self.rw1_pget_rategyro1x = self._io.read_s2le()
            self.rw1_pget_rategyro1y = self._io.read_s2le()
            self.rw1_pget_rategyro1z = self._io.read_s2le()


    class LinkTnc1Info(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_tnc1_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_validflag = self._io.read_bits_int_be(1) != 0


    class PdhTmLayappStd0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_appfsmstate = self._io.read_u1()
            self.slkpdh_pget_appbasetrmpktloss = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasetrmcrcerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasetrmpkthdrerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_appbasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_appbasercvpktloss = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasercvcrcerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasercvpkthdrerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu22 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu23 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu24 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu25 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_appbasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_appspectrmpkttypemain = self._io.read_u1()
            self.slkpdh_pget_appspectrmpkttypesub = self._io.read_u1()
            self.slkpdh_pget_appspectrmpktnum = self._io.read_u2le()
            self.slkpdh_pget_appspectrmtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_appspectrmrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_appspecrcvpkttypemain = self._io.read_u1()
            self.slkpdh_pget_appspecrcvpkttypesub = self._io.read_u1()
            self.slkpdh_pget_appspecrcvpktnum = self._io.read_u2le()
            self.slkpdh_pget_appspecrcvtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_appspecrcvrxseqnum = self._io.read_u2le()


    class AdcsGAllInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g1_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg1 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg1 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg1 = self._io.read_u1()
            self.adcs_pget_g2_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg2 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg2 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg2 = self._io.read_u1()
            self.adcs_pget_g3_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg3 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg3 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg3 = self._io.read_u1()
            self.adcs_pget_g4_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg4 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg4 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg4 = self._io.read_u1()
            self.adcs_pget_g5_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg5 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg5 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg5 = self._io.read_u1()
            self.adcs_pget_g6_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg6 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg6 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg6 = self._io.read_u1()
            self.adcs_pget_g7_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg7 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg7 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg7 = self._io.read_u1()
            self.adcs_pget_g8_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg8 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg8 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg8 = self._io.read_u1()


    class AdcsSenseG7Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg7_sat = self._io.read_s2le()
            self.adcs_pget_omegayg7_sat = self._io.read_s2le()
            self.adcs_pget_omegazg7_sat = self._io.read_s2le()
            self.thm_pget_tempg7 = self._io.read_s2le()
            self.adcs_pget_g7_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg7 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg7 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg7 = self._io.read_u1()


    class PdhPlepsSatObtUtcNs(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obt_utc_ns = self._io.read_s8le()


    class PdhTmExtd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_tmoutl1sync = self._io.read_u4le()
            self.pdh_pget_tmoutl2sync = self._io.read_u4le()
            self.pdh_pget_tmoutl2connect = self._io.read_u4le()
            self.slkpdh_pget_sesbasetrmcaller = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmcallersendbcst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmresponder = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmsesest = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmseslost = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmwaitforaiandtrmt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvsesest = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvseslost = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvwaitforaiandtrmt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_traitrnrcvcpt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmnak = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmcpt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvnak = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvcpt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appitrnallpktgen = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasetrmpktloss = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasetrmcrcerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasetrmpkthdrerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasercvpktloss = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasercvcrcerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_appbasercvpkthdrerr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_sesspec0trmtxallbytenum = self._io.read_u4le()
            self.slkpdh_pget_sesspec0trmrxallbytenum = self._io.read_u4le()
            self.slkpdh_pget_sesspec0trmtxdatabytenum = self._io.read_u4le()
            self.slkpdh_pget_sesspec0trmrxdatabytenum = self._io.read_u4le()
            self.pdh_pget_arrayrfu0 = self._io.read_u1()


    class LinkTnc0Info(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_tnc0_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_validflag = self._io.read_bits_int_be(1) != 0


    class AdcsActRwxInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_rwx_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwx_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwx_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwx_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwx_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwx_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactstaterwx = self._io.read_u1()


    class AdcsActaRwaStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dctrltorquerwaz_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquerwax_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquerway_sat = self._io.read_s2le()
            self.adcs_pget_rwa_useflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactarrayavailstatusrwa = self._io.read_u1()
            self.adcs_pget_iactstaterwx = self._io.read_u1()
            self.adcs_pget_iactstaterwy = self._io.read_u1()
            self.adcs_pget_iactstaterwz = self._io.read_u1()
            self.adcs_pget_rwxruntime = self._io.read_u2le()
            self.adcs_pget_rwyruntime = self._io.read_u2le()
            self.adcs_pget_rwzruntime = self._io.read_u2le()
            self.adcs_pget_rwxruntimethreshold = self._io.read_u2le()
            self.adcs_pget_rwyruntimethreshold = self._io.read_u2le()
            self.adcs_pget_rwzruntimethreshold = self._io.read_u2le()


    class SalsaTmLmsRegister(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_lms_reg_address = self._io.read_u2le()
            self.salsa_pget_lms_reg_value = self._io.read_u2le()


    class AdcsEnvSun(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_sunmodelrxeci = self._io.read_s2le()
            self.adcs_pget_sunmodelryeci = self._io.read_s2le()
            self.adcs_pget_sunmodelrzeci = self._io.read_s2le()


    class Rw1TmEeprom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_cntrlmode = self._io.read_u1()
            self.rw1_pget_kpnumeeprom = self._io.read_u2le()
            self.rw1_pget_kpdeneeprom = self._io.read_u2le()
            self.rw1_pget_kinumeeprom = self._io.read_u2le()
            self.rw1_pget_kideneeprom = self._io.read_u2le()
            self.rw1_pget_kdnumeeprom = self._io.read_u2le()
            self.rw1_pget_kddeneeprom = self._io.read_u2le()
            self.rw1_pget_svlimiteeprom = self._io.read_u4le()
            self.rw1_pget_mvlimiteeprompwm = self._io.read_u2le()
            self.rw1_pget_gyro0offseteeprom = self._io.read_u2le()
            self.rw1_pget_gyro1offseteeprom = self._io.read_u2le()
            self.rw1_pget_gyro1activeeeprom = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0


    class PdhPlepsFwUpdateSlotTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_ishealthy = self._io.read_bits_int_be(1) != 0


    class SatHeater1Info(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_heater1_useflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater1_powerflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater1_healthflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_heater1_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_heater1_togglecounter = self._io.read_u1()
            self.sat_pget_heater1_totalglowtime = self._io.read_u1()


    class PdhTmCom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_fsmmainstate = self._io.read_u1()
            self.pdh_pget_fsmsapstate = self._io.read_u1()
            self.pdh_pget_fsmslkstate = self._io.read_u1()
            self.pdh_pget_sapmuxstate = self._io.read_u1()
            self.pdh_pget_ipumode = self._io.read_u1()
            self.pdh_pget_cammode = self._io.read_u1()
            self.pdh_pget_fifonumfreesdutxa = self._io.read_u1()
            self.pdh_pget_fifonumfreesdutxb = self._io.read_u1()
            self.pdh_pget_fifonumfreesbandtxa = self._io.read_u1()
            self.pdh_pget_fifonumfreesbandtxb = self._io.read_u1()
            self.pdh_pget_fifonumfreesbandtxc = self._io.read_u1()
            self.pdh_pget_satxmtmode = self._io.read_u1()
            self.pdh_pget_satctrmaxaitype = self._io.read_u1()
            self.pdh_pget_satrcvstate = self._io.read_u1()
            self.pdh_pget_satfrc = self._io.read_u1()
            self.pdh_pget_satmaxsir = self._io.read_u1()
            self.pdh_pget_satminsir = self._io.read_u1()
            self.pdh_pget_satdopplerfreq = self._io.read_s1()
            self.pdh_pget_satdistance = self._io.read_s4le()
            self.pdh_pget_arqonuplink = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_arqondownlink = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sessionest = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sessionopened = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comtxon = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comrxon = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_arquplinkack = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comautotm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_stdautotm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_sataitype = self._io.read_u1()
            self.pdh_pget_txrepeatmode = self._io.read_u1()
            self.pdh_pget_thresholdacktm = self._io.read_u1()
            self.pdh_pget_thresholdcomtm = self._io.read_u2le()
            self.pdh_pget_thresholdstdtm = self._io.read_u2le()
            self.pdh_pget_stdtmautogenmode = self._io.read_u1()
            self.pdh_pget_arrayrfucomtm = self._io.read_u1()


    class FdaTmLongtermPhiZ(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_longterm_phi_z = self._io.read_s2le()


    class Com0TmRndpkt(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_rndpktcnt = self._io.read_u1()
            self.com0_pget_rndpkttype = self._io.read_u1()
            self.com0_pget_rnddata = self._io.read_u1()


    class AdcsAttDcmEcitotgt(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_ecitotgtdcmu1 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmu2 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmu3 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmv1 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmv2 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmv3 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmw1 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmw2 = self._io.read_s2le()
            self.adcs_pget_ecitotgtdcmw3 = self._io.read_s2le()


    class PdhPlepsLinkThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class PdhTmStdAdd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_resetcnt = self._io.read_u2le()
            self.pdh_pget_fsmmainstate = self._io.read_u1()
            self.pdh_pget_fsmanalogstate = self._io.read_u1()
            self.pdh_pget_fsmspcdbgstate = self._io.read_u1()
            self.pdh_pget_fsmspcmainstate = self._io.read_u1()
            self.pdh_pget_fsmsapstate = self._io.read_u1()
            self.pdh_pget_fsmslkstate = self._io.read_u1()
            self.pdh_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_initeepromparcompl = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_swspccmdtosband = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_unsecured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycur3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycur3v3int = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycurtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlt3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlt3v3int = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlttrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalytmpext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalytmpint = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwrtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgcomtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgtxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgrxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu28 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmaincomtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmainspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmainwait = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmaincierrfrsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmaincierrfrlength = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmainfdirrdy = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu26 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu27 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapadcconfigured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvstartsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspinotready = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvfrom = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvendsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvlength = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspimissedendhdr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvportid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuversno = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuscid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltucrc32 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvasm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvfrmlen = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiopactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesat2satmain = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesat2satredund = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatmain = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatredund = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatwopa = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodeboot = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu29 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu30 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu31 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu32 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu33 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu34 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu35 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_cur3v3ext = self._io.read_u2le()
            self.pdh_pget_cur3v3int = self._io.read_u2le()
            self.pdh_pget_curtrx = self._io.read_u2le()
            self.pdh_pget_vlt3v3ext = self._io.read_u2le()
            self.pdh_pget_vlt3v3int = self._io.read_u2le()
            self.pdh_pget_vlttrx = self._io.read_u2le()
            self.thm_pdh_pget_tmpext = self._io.read_u2le()
            self.thm_pdh_pget_tmpint = self._io.read_u2le()


    class PdhPlepsIpuFrameCounter(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_ipu_frames_received = self._io.read_u4le()
            self.pdh_pget_pleps_ipu_frames_sent = self._io.read_u4le()


    class AdcsCalDcmMfrtosatMfs1To4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_mfs1mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_mfs1mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_mfs2mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_mfs3mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_mfs4mfrtosatdcmw3 = self._io.read_s2le()


    class PdhTmSlkStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_fsmsapstate = self._io.read_u1()
            self.slkpdh_pget_fsmslkstate = self._io.read_u1()
            self.slkpdh_pget_sapspiactive = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapadcconfigured = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvstartsync = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspinotready = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvfrom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvendsync = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvlength = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspimissedendhdr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvportid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvversno = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvscid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvcrc32 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvasm = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvfrmlen = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiopactive = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodesat2satmain = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodesat2satredund = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodesatmain = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodesatredund = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodesatwopa = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodefree0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodefree1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_progrmodeboot = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapactive = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_curtrx = self._io.read_u2le()
            self.slkpdh_pget_vlttrx = self._io.read_u2le()


    class LinkPdhctrlExtTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pdhctrl_pget_configuredbaudrate = self._io.read_s4le()
            self.link_pdhctrl_pget_pdhswitchcounter = self._io.read_u4le()
            self.link_pdhctrl_pget_parsererrorcounter = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedframes = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedpdhhkframes = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedpdhfdirframes = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedsciframes = self._io.read_u4le()
            self.link_pdhctrl_pget_parsedbytecount = self._io.read_u4le()
            self.link_pget_pdh0fwdflag = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_syncreceived = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvtcupstream = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_fwdtmdownstream = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvpdhtm = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvscitm = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvpdhfdir = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_activepdh = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_useflaglocked = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_powerflaglocked = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_healthflag = self._io.read_bits_int_be(1) != 0


    class SalsaUpdatesTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_fw_updater_state = self._io.read_u1()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_fw_updater_tmpimgaddr = self._io.read_u4le()
            self.salsa_pget_updating_device = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundererase = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundercrc = self._io.read_u1()
            self.sat_pget_fw_updater_activeimagelength = self._io.read_u4le()
            self.sat_pget_fw_updater_numwrittensequences = self._io.read_u2le()
            self.sat_pget_fw_updater_nextexpectedsequence = self._io.read_u2le()
            self.sat_pget_fw_updater_totalmissingsequences = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceswriteidx = self._io.read_u1()
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0


    class Com0TmArq(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_txltuhdrfrcnttx = self._io.read_u1()
            self.com0_pget_txltuhdrfrcntrx = self._io.read_u1()
            self.com0_pget_rxltuhdrfrcnttx = self._io.read_u1()
            self.com0_pget_rxltuhdrfrcntrx = self._io.read_u1()
            self.com0_pget_frcnttx = self._io.read_u1()
            self.com0_pget_frcntrx = self._io.read_u1()
            self.com0_pget_senderrn = self._io.read_u2le()
            self.com0_pget_sendersb = self._io.read_u2le()
            self.com0_pget_receiverrn = self._io.read_u2le()
            self.com0_pget_receiversb = self._io.read_u2le()
            self.com0_pget_sdutxfifonum = self._io.read_u1()
            self.com0_pget_sdutxfifonumtdd = self._io.read_u1()
            self.com0_pget_sdutxfifoputpos = self._io.read_u1()
            self.com0_pget_sdutxfifogetpos = self._io.read_u1()


    class PdhTmLaypreStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_prefsmstate = self._io.read_u1()
            self.slkpdh_pget_prebasetrmformatchangerqst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_prebasetrmtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_prebasetrmrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_prebasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_prebasercvformatchangerqst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_prebasercvtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_prebasercvrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_prebasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_prespectrmpkttypemain = self._io.read_u1()
            self.slkpdh_pget_prespectrmpkttypesub = self._io.read_u1()
            self.slkpdh_pget_prespecrcvpkttypemain = self._io.read_u1()
            self.slkpdh_pget_prespecrcvpkttypesub = self._io.read_u1()


    class Com4TmEeprom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_frsynceeprom = self._io.read_u4le()
            self.com4_pget_frsynchameeprom = self._io.read_u4le()
            self.com4_pget_bitsyncnumeeprom = self._io.read_u1()
            self.com4_pget_srcideeprom = self._io.read_u1()
            self.com4_pget_bcstideeprom = self._io.read_u1()
            self.com4_pget_syncbiterrnumeeprom = self._io.read_u1()
            self.com4_pget_syncburstnumeeprom = self._io.read_u1()
            self.com4_pget_syncchainnumeeprom = self._io.read_u1()
            self.com4_pget_hamcallsigneeprom = self._io.read_u1()
            self.com4_pget_resetcnt = self._io.read_u2le()
            self.com4_pget_periodrdtrxtmeeprom = self._io.read_u2le()
            self.com4_pget_rxsducnt = self._io.read_u2le()
            self.com4_pget_rxspducnt = self._io.read_u2le()
            self.com4_pget_periodautorecoveryreset = self._io.read_u4le()


    class SatRtcTime(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_rtc_cddayofmonth = self._io.read_u1()
            self.sat_pget_rtc_cdmonth = self._io.read_u1()
            self.sat_pget_rtc_cdyear = self._io.read_u2le()
            self.sat_pget_rtc_cdhour = self._io.read_u1()
            self.sat_pget_rtc_cdminute = self._io.read_u1()
            self.sat_pget_rtc_cdsecond = self._io.read_u2le()


    class SalsaTmPmuRegsValid(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_lms_calib_valid_a1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_lms_calib_valid_b1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_lms_regs_valid_a1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_lms_regs_valid_b1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_clk_regs_valid_a1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_clk_regs_valid_b1 = self._io.read_bits_int_be(1) != 0


    class Rw2TmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_resetcnt = self._io.read_u2le()
            self.rw2_pget_fsmmainstate = self._io.read_u1()
            self.rw2_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtroff = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mvlimit = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrovercur = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_faultgyro0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_faultgyro1 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycurmtr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v3mcu = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalygyro0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalygyro1 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw2_pget_curmtr = self._io.read_u2le()
            self.rw2_pget_curwde = self._io.read_u2le()
            self.rw2_pget_cur3v3 = self._io.read_u2le()
            self.rw2_pget_cur5v = self._io.read_u2le()
            self.rw2_pget_vltmtr = self._io.read_u2le()
            self.rw2_pget_vlt3v2 = self._io.read_u2le()
            self.rw2_pget_vlt5v = self._io.read_u2le()
            self.rw2_pget_vlt3v3 = self._io.read_u2le()
            self.rw2_pget_vlt3v3mcu = self._io.read_u2le()
            self.thm_rw2_pget_tmppwr = self._io.read_u2le()
            self.thm_rw2_pget_tmppresssens = self._io.read_u4le()
            self.thm_rw2_pget_tmpgyro1 = self._io.read_s2le()
            self.rw2_pget_vltgyro0zref = self._io.read_u2le()
            self.rw2_pget_vltgyro0z = self._io.read_u2le()
            self.rw2_pget_rategyro1x = self._io.read_s2le()
            self.rw2_pget_rategyro1y = self._io.read_s2le()
            self.rw2_pget_rategyro1z = self._io.read_s2le()
            self.rw2_pget_press = self._io.read_u4le()


    class AdcsSenseG1Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg1_sat = self._io.read_s2le()
            self.adcs_pget_omegayg1_sat = self._io.read_s2le()
            self.adcs_pget_omegazg1_sat = self._io.read_s2le()
            self.thm_pget_tempg1 = self._io.read_s2le()
            self.adcs_pget_g1_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg1 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg1 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg1 = self._io.read_u1()


    class PdhPlepsIpuCtrlThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class Rw0TmSwvers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_swversmajor = self._io.read_u1()
            self.rw0_pget_swversminor = self._io.read_u1()
            self.rw0_pget_swbuildyear = self._io.read_u1()
            self.rw0_pget_swbuildmonth = self._io.read_u1()
            self.rw0_pget_swbuildday = self._io.read_u1()
            self.rw0_pget_swbuildhour = self._io.read_u1()
            self.rw0_pget_swbuildmin = self._io.read_u1()
            self.rw0_pget_swbuildsec = self._io.read_u1()
            self.rw0_pget_serialnum = self._io.read_u2le()
            self.rw0_pget_devid = self._io.read_u1()


    class SalsaTmGetFftFrameDataLength(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_fft_frame_data_length = self._io.read_u1()


    class PdhTmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_resetcnt = self._io.read_u2le()
            self.pdh_pget_fsmmainstate = self._io.read_u1()
            self.pdh_pget_fsmspcdbgstate = self._io.read_u1()
            self.pdh_pget_fsmsapstate = self._io.read_u1()
            self.pdh_pget_fsmslkstate = self._io.read_u1()
            self.pdh_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_initeepromparcompl = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_swspccmdtosband = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_unsecured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycur3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycurtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlt3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlttrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalytmpext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwrtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycuripu = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycurcam = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgcomtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgtxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgrxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spctxlock = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu22 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapadcconfigured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvstartsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspinotready = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvfrom = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvendsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvlength = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspimissedendhdr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvportid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuversno = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuscid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltucrc32 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvasm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvfrmlen = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiopactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu23 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu24 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatmain = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatredund = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu25 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodeboot = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatmain1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatredund1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodeboot1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu26 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu27 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu28 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu29 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_cur3v3ext = self._io.read_u2le()
            self.pdh_pget_curipu = self._io.read_u2le()
            self.pdh_pget_curtrxa = self._io.read_u2le()
            self.pdh_pget_vlt3v3ext = self._io.read_u2le()
            self.pdh_pget_curcam = self._io.read_u2le()
            self.pdh_pget_vlttrx = self._io.read_u2le()
            self.thm_pdh_pget_tmpext = self._io.read_u2le()


    class SalsaSatThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class AdcsCalMappingSuse6(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse6mappingpol0coefx = self._io.read_s4le()
            self.adcs_pget_suse6mappingpol1coefx = self._io.read_s4le()
            self.adcs_pget_suse6mappingpol2coefx = self._io.read_s4le()
            self.adcs_pget_suse6mappingpol3coefx = self._io.read_s4le()
            self.adcs_pget_suse6mappingpol0coefy = self._io.read_s4le()
            self.adcs_pget_suse6mappingpol1coefy = self._io.read_s4le()
            self.adcs_pget_suse6mappingpol2coefy = self._io.read_s4le()
            self.adcs_pget_suse6mappingpol3coefy = self._io.read_s4le()


    class SatStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obc_act = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_selectedslotnum = self._io.read_u1()
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_leop_doleop = self._io.read_bits_int_be(1) != 0
            self.sat_pget_leop_isstarted = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_realalgotime = self._io.read_u1()


    class Com1TmFec(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_ltudecerrnum = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw13 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw12 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw11 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw10 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw9 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw8 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw7 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw6 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw5 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw4 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw3 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw2 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw1 = self._io.read_u2le()
            self.com1_pget_ltuhdrbchrootcw0 = self._io.read_u2le()
            self.com1_pget_rssirx = self._io.read_u2le()


    class PdhTmLaytraStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_trafsmstate = self._io.read_u1()
            self.slkpdh_pget_trabasetrmtxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmrxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmnak = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactivetxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactivetxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactivetxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactiverxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactiverxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactiverxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmcpt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullsvc = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullsdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullsduqos = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullspdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_trabasetrmtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_trabasetrmrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_trabasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_trabasercvtxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvrxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvnak = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactivetxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactivetxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactivetxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactiverxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactiverxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactiverxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvcpt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullsvc = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullsdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullsduqos = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullspdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_trabasercvtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_trabasercvrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_trabasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_traspectrmfifonum = self._io.read_u1()
            self.slkpdh_pget_traspectrmtxacknum = self._io.read_u1()
            self.slkpdh_pget_traspectrmrxacknum = self._io.read_u1()
            self.slkpdh_pget_traspectrml2packetcountsdu = self._io.read_u1()
            self.slkpdh_pget_traspectrml2packetcountsduqos = self._io.read_u1()
            self.slkpdh_pget_traspectrml2packetcountspdu = self._io.read_u1()
            self.slkpdh_pget_traspectrml2packetcountsvc = self._io.read_u1()
            self.slkpdh_pget_traspecrcvfifonum = self._io.read_u1()
            self.slkpdh_pget_traspecrcvtxacknum = self._io.read_u1()
            self.slkpdh_pget_traspecrcvrxacknum = self._io.read_u1()
            self.slkpdh_pget_traspecrcvl2packetcountsdu = self._io.read_u1()
            self.slkpdh_pget_traspecrcvl2packetcountsduqos = self._io.read_u1()
            self.slkpdh_pget_traspecrcvl2packetcountspdu = self._io.read_u1()
            self.slkpdh_pget_traspecrcvl2packetcountsvc = self._io.read_u1()


    class AdcsSenseG8Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg8_sat = self._io.read_s2le()
            self.adcs_pget_omegayg8_sat = self._io.read_s2le()
            self.adcs_pget_omegazg8_sat = self._io.read_s2le()
            self.thm_pget_tempg8 = self._io.read_s2le()
            self.adcs_pget_g8_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg8 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg8 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg8 = self._io.read_u1()


    class PdhPlepsSwitchState(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_ctrl_pwr_salsa = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_salsa = self._io.read_u2le()
            self.pdh_pget_pleps_ctrl_pwr_fu = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_fu = self._io.read_u2le()
            self.pdh_pget_pleps_ctrl_pwr_fda_3v3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_fda_3v3 = self._io.read_u2le()
            self.pdh_pget_pleps_ctrl_pwr_fda_unreg = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_fda_unreg = self._io.read_u2le()
            self.pdh_pget_pleps_ctrl_pwr_gyro_3v3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_gyro_3v3 = self._io.read_u2le()
            self.pdh_pget_pleps_ctrl_pwr_gyro_unreg = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_gyro_unreg = self._io.read_u2le()
            self.pdh_pget_pleps_ctrl_pwr_pdh0 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_pdh0_3v3 = self._io.read_u2le()
            self.pdh_pget_pleps_ctrl_pwr_pdh1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pleps_pget_i_pdh1_3v3 = self._io.read_u2le()


    class AdcsSenseMfs3B(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxmfs3_sat = self._io.read_s2le()
            self.adcs_pget_dymfs3_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs3_sat = self._io.read_s2le()
            self.adcs_pget_mfs3_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs3 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs3 = self._io.read_u1()


    class AdcsCalDcmMfrtosatMata(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_matamfrtosatdcmu1 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmu2 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmu3 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmv1 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmv2 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmv3 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmw1 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmw2 = self._io.read_s1()
            self.adcs_pget_matamfrtosatdcmw3 = self._io.read_s1()


    class SalsaLinkStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_link_frames_received = self._io.read_u4le()
            self.pdh_pget_pleps_link_frames_sent = self._io.read_u4le()


    class Com0TmSwvers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_swversmajor = self._io.read_u1()
            self.com0_pget_swversminor = self._io.read_u1()
            self.com0_pget_swbuildyear = self._io.read_u1()
            self.com0_pget_swbuildmonth = self._io.read_u1()
            self.com0_pget_swbuildday = self._io.read_u1()
            self.com0_pget_swbuildhour = self._io.read_u1()
            self.com0_pget_swbuildmin = self._io.read_u1()
            self.com0_pget_swbuildsec = self._io.read_u1()
            self.com0_pget_serialnum = self._io.read_u2le()
            self.com0_pget_devid = self._io.read_u1()


    class AdcsCtrlBdotOutput(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dbdotcmdmagmomentx_sat = self._io.read_s2le()
            self.adcs_pget_dbdotcmdmagmomenty_sat = self._io.read_s2le()
            self.adcs_pget_dbdotcmdmagmomentz_sat = self._io.read_s2le()


    class AdcsCalOffsetMfs1To4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_mfs1offsetx = self._io.read_s2le()
            self.adcs_pget_mfs1offsety = self._io.read_s2le()
            self.adcs_pget_mfs1offsetz = self._io.read_s2le()
            self.adcs_pget_mfs2offsetx = self._io.read_s2le()
            self.adcs_pget_mfs2offsety = self._io.read_s2le()
            self.adcs_pget_mfs2offsetz = self._io.read_s2le()
            self.adcs_pget_mfs3offsetx = self._io.read_s2le()
            self.adcs_pget_mfs3offsety = self._io.read_s2le()
            self.adcs_pget_mfs3offsetz = self._io.read_s2le()
            self.adcs_pget_mfs4offsetx = self._io.read_s2le()
            self.adcs_pget_mfs4offsety = self._io.read_s2le()
            self.adcs_pget_mfs4offsetz = self._io.read_s2le()


    class SalsaTmGetInaFlashStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class PdhPlepsRqFdaPwr(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_ctrl_pwr_fda = self._io.read_u1()


    class AdcsCalTcompG2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g2tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g2tbiaspol0coefzaxis = self._io.read_s4le()


    class SatLeopInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_leop_doleop = self._io.read_bits_int_be(1) != 0
            self.sat_pget_leop_isstarted = self._io.read_bits_int_be(1) != 0
            self.sat_pget_leop_isfinished = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_leop_substate = self._io.read_u1()
            self.sat_pget_leop_runtime = self._io.read_u2le()


    class AdcsEnvTle(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_tleepocheyear = self._io.read_u2le()
            self.adcs_pget_tleepochedecimalday = self._io.read_f8le()
            self.adcs_pget_tlebstar = self._io.read_f8le()
            self.adcs_pget_tleeccentricity = self._io.read_f8le()
            self.adcs_pget_tleargperigee = self._io.read_f8le()
            self.adcs_pget_tleinclination = self._io.read_f8le()
            self.adcs_pget_tlemeananomaly = self._io.read_f8le()
            self.adcs_pget_tlemeanmotion = self._io.read_f8le()
            self.adcs_pget_tleraan = self._io.read_f8le()
            self.adcs_pget_tlesatelliteid = self._io.read_u1()


    class AdcsSenseG2Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg2_sat = self._io.read_s2le()
            self.adcs_pget_omegayg2_sat = self._io.read_s2le()
            self.adcs_pget_omegazg2_sat = self._io.read_s2le()
            self.thm_pget_tempg2 = self._io.read_s2le()
            self.adcs_pget_g2_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg2 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg2 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg2 = self._io.read_u1()


    class SalsaInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_rodoserrorcounter = self._io.read_u4le()
            self.fdir_pget_gitversion = self._io.read_u8le()
            self.fdir_pget_compiletimeinsec = self._io.read_u8le()
            self.shared_reset_counter = self._io.read_u8le()
            self.fdir_pget_ismodifiedversion = self._io.read_bits_int_be(1) != 0


    class Rw0TmPress(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_presscoeff0 = self._io.read_u2le()
            self.rw0_pget_presscoeff1 = self._io.read_u2le()
            self.rw0_pget_presscoeff2 = self._io.read_u2le()
            self.rw0_pget_presscoeff3 = self._io.read_u2le()
            self.rw0_pget_presscoeff4 = self._io.read_u2le()
            self.rw0_pget_presscoeff5 = self._io.read_u2le()
            self.rw0_pget_presscoeff6 = self._io.read_u2le()
            self.rw0_pget_presscrc = self._io.read_u2le()
            self.thm_rw0_pget_tmppresssens = self._io.read_u4le()
            self.rw0_pget_press = self._io.read_u4le()


    class PdhTmSapStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_fsmsapstate = self._io.read_u1()
            self.slkpdh_pget_sapspiactive = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapadcconfigured = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvstartsync = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspinotready = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvfrom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvendsync = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvlength = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspiinvid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sapspimissedendhdr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvportid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvversno = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvscid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvcrc32 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvasm = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sappltuinvfrmlen = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_saprxslktmcnt = self._io.read_u2le()
            self.slkpdh_pget_saptxslktmcnt = self._io.read_u2le()


    class PdhPlepsSctrlRqStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_ctrl_pwr_salsa = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_pleps_ctrl_pwr_state = self._io.read_u1()
            self.pdh_pleps_pget_rf_switch = self._io.read_bits_int_be(1) != 0
            self.pdh_pleps_pget_rf_block_utrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pleps_pget_utrx0_ptt = self._io.read_bits_int_be(1) != 0
            self.pdh_pleps_pget_utrx1_ptt = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pset_pget_rf_switch_time = self._io.read_u2le()
            self.pdh_pleps_pget_salsa_ctrl_reset_counter = self._io.read_u4le()


    class Rw0TmCstm2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()


    class Rw2TmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_resetcnt = self._io.read_u2le()
            self.rw2_pget_fsmmainstate = self._io.read_u1()
            self.rw2_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtroff = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mvlimit = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrovercur = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_extadcconfigured = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_faultgyro = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycurmtrfine = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycurmtrcoarse = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt3v2minus = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalyvlt10v = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalygyro = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw2_pget_curmtr = self._io.read_u2le()
            self.rw2_pget_cur3v3 = self._io.read_u2le()
            self.rw2_pget_cur5v = self._io.read_u2le()
            self.rw2_pget_curwde = self._io.read_u2le()
            self.rw2_pget_vltmtr = self._io.read_u2le()
            self.rw2_pget_vlt3v3 = self._io.read_u2le()
            self.rw2_pget_vlt5va = self._io.read_u2le()
            self.thm_rw2_pget_tmppwra = self._io.read_u2le()
            self.thm_rw2_pget_tmppresssens = self._io.read_u4le()
            self.rw2_pget_press = self._io.read_u4le()


    class LinkStncctrlExtTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pdhctrl_pget_configuredbaudrate = self._io.read_s4le()
            self.link_pdhctrl_pget_parsererrorcounter = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedframes = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedpdhhkframes = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedpdhfdirframes = self._io.read_u4le()
            self.link_pdhctrl_pget_receivedsciframes = self._io.read_u4le()
            self.link_pdhctrl_pget_parsedbytecount = self._io.read_u4le()
            self.link_pdhctrl_pget_syncreceived = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvtcupstream = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_fwdtmdownstream = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvpdhtm = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvscitm = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvpdhfdir = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_useflaglocked = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_powerflaglocked = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pdhx_pget_healthflag = self._io.read_bits_int_be(1) != 0


    class AdcsSenseaMfsaStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxmfsa_sat = self._io.read_s2le()
            self.adcs_pget_dymfsa_sat = self._io.read_s2le()
            self.adcs_pget_dzmfsa_sat = self._io.read_s2le()
            self.adcs_pget_mfsa_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs3_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs4_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_attdetmfsdistcorrmode = self._io.read_u1()
            self.adcs_pget_iinusecountmfsa = self._io.read_u1()
            self.adcs_pget_isensorstatemfs1 = self._io.read_u1()
            self.adcs_pget_isensorstatemfs2 = self._io.read_u1()
            self.adcs_pget_isensorstatemfs3 = self._io.read_u1()
            self.adcs_pget_isensorstatemfs4 = self._io.read_u1()


    class SalsaTmGetFftRecordingStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_fft_record_in_progress = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.salsa_pget_fft_count = self._io.read_u2le()
            self.salsa_pget_fft_count_last = self._io.read_u2le()


    class AdcsCalMappingSuse1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse1mappingpol0coefx = self._io.read_s4le()
            self.adcs_pget_suse1mappingpol1coefx = self._io.read_s4le()
            self.adcs_pget_suse1mappingpol2coefx = self._io.read_s4le()
            self.adcs_pget_suse1mappingpol3coefx = self._io.read_s4le()
            self.adcs_pget_suse1mappingpol0coefy = self._io.read_s4le()
            self.adcs_pget_suse1mappingpol1coefy = self._io.read_s4le()
            self.adcs_pget_suse1mappingpol2coefy = self._io.read_s4le()
            self.adcs_pget_suse1mappingpol3coefy = self._io.read_s4le()


    class Rw0TmCstm3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()


    class SalsaTmBootStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_clk_conf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_fpga_conf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_fpga_init_done = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_lms_conf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_lms_calibrated = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.salsa_pget_fft_size = self._io.read_u2le()
            self.salsa_pget_fft_window = self._io.read_u1()
            self.salsa_pget_fft_decim = self._io.read_u1()


    class PdhTmSapSramSat(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_satctrfrequencytxsram = self._io.read_u4le()
            self.slkpdh_pget_satctrfrequencyrxsram = self._io.read_u4le()
            self.slkpdh_pget_satctratttxgainsram = self._io.read_u1()
            self.slkpdh_pget_satctrchannelsram = self._io.read_u1()
            self.slkpdh_pget_satctrmaxaitypesram = self._io.read_u1()
            self.slkpdh_pget_satctrantmodesram = self._io.read_u1()
            self.slkpdh_pget_satctrrfrangesram = self._io.read_u1()
            self.slkpdh_pget_satctrcallersram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrcallersendbroadcastsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrrespondersram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrpayloaddirsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrfddonsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0


    class PdhTmRtc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_rtcinitcomplete = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcinvreg = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcspirelease = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcconfcomplete = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcwrtime = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcttavailable = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_rtcsec01 = self._io.read_u1()
            self.pdh_pget_rtcsec001 = self._io.read_u1()
            self.pdh_pget_rtcsec10 = self._io.read_u1()
            self.pdh_pget_rtcsec1 = self._io.read_u1()
            self.pdh_pget_rtcsec01alarm = self._io.read_u1()
            self.pdh_pget_rtcsec001alarm = self._io.read_u1()
            self.pdh_pget_rtcsec10alarm = self._io.read_u1()
            self.pdh_pget_rtcsec1alarm = self._io.read_u1()
            self.pdh_pget_rtcmin10 = self._io.read_u1()
            self.pdh_pget_rtcmin1 = self._io.read_u1()
            self.pdh_pget_rtcmin10alarm = self._io.read_u1()
            self.pdh_pget_rtcmin1alarm = self._io.read_u1()
            self.pdh_pget_rtchour10 = self._io.read_u1()
            self.pdh_pget_rtchour1 = self._io.read_u1()
            self.pdh_pget_rtchour10alarm = self._io.read_u1()
            self.pdh_pget_rtchour1alarm = self._io.read_u1()
            self.pdh_pget_rtcday = self._io.read_u1()
            self.pdh_pget_rtcdayalarm = self._io.read_u1()
            self.pdh_pget_rtcdate10 = self._io.read_u1()
            self.pdh_pget_rtcdate1 = self._io.read_u1()
            self.pdh_pget_rtcdate10alarm = self._io.read_u1()
            self.pdh_pget_rtcdate1alarm = self._io.read_u1()
            self.pdh_pget_rtcmonth10 = self._io.read_u1()
            self.pdh_pget_rtcmonth1 = self._io.read_u1()
            self.pdh_pget_rtcyear10 = self._io.read_u1()
            self.pdh_pget_rtcyear1 = self._io.read_u1()
            self.pdh_pget_rtcregcontrol = self._io.read_u1()
            self.pdh_pget_rtcregstatus = self._io.read_u1()
            self.pdh_pget_rtcregtricklecharger = self._io.read_u1()
            self.pdh_pget_rtc12 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcpm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtccentury = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtc12alarm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcpmalarm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcdyalarm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcam1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcam2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcam3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_rtcam4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_rtcyear = self._io.read_u2le()
            self.pdh_pget_rtcmonth = self._io.read_u1()
            self.pdh_pget_rtcmin = self._io.read_u1()
            self.pdh_pget_rtcminalarm = self._io.read_u1()
            self.pdh_pget_rtchour = self._io.read_u1()
            self.pdh_pget_rtchouralarm = self._io.read_u1()
            self.pdh_pget_rtcdate = self._io.read_u1()
            self.pdh_pget_rtcdatealarm = self._io.read_u1()
            self.pdh_pget_rtcsec = self._io.read_u2le()
            self.pdh_pget_rtcsecalarm = self._io.read_u2le()


    class PdhTmMemextserStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_fsmmemextserialstate = self._io.read_u1()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_fsmmemextserialeepromstate = self._io.read_u1()
            self.pdh_pget_memextserialeepromconfigured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeeprompdhparloaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromdataloaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeeprompdhparsaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromsapsatparsaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromsapsat2satparsaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromdatasaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeeprominvsr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromexploaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromnetworktleparsaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromsapparloaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromnetworktleparloaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromnetworkparsaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialeepromnetworkparloaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_fsmmemextserialflashstate = self._io.read_u1()
            self.pdh_pget_memextserialflash0configured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0dataloaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0datasaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0dataerased = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invidcfi = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invsr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invcr1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invbar = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invaspr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invppbl = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invppbar = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invdybar = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0inveccsr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invvdlr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invabr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash0invpasswd = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1configured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1dataloaded = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1datasaved = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1dataerased = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invidcfi = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invsr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invcr1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invbar = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invaspr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invppbl = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invppbar = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invdybar = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1inveccsr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invvdlr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invabr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialflash1invpasswd = self._io.read_bits_int_be(1) != 0


    class SalsaTmReadPmuPage(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_pmu_config_id = self._io.read_u2le()
            self.salsa_pget_max_frames = self._io.read_u2le()
            self.salsa_pget_pmu_content = self._io.read_u1()


    class Com4TmComExtd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_frsyncsram = self._io.read_u4le()
            self.com4_pget_frsynchamsram = self._io.read_u4le()
            self.com4_pget_bitsyncnumsram = self._io.read_u1()
            self.com4_pget_syncbiterrnumsram = self._io.read_u1()
            self.com4_pget_syncburstnumsram = self._io.read_u1()
            self.com4_pget_syncchainnumsram = self._io.read_u1()
            self.com4_pget_frsyncbitmaskrx = self._io.read_u4le()
            self.com4_pget_syncbiterrnumrx = self._io.read_u1()
            self.com4_pget_syncburstnumrx = self._io.read_u1()
            self.com4_pget_syncchainnumrx = self._io.read_u1()
            self.com4_pget_tmcomextdrfu = self._io.read_u1()


    class AdcsCalTcompG6(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g6tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g6tbiaspol0coefzaxis = self._io.read_s4le()


    class SalsaHkThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class AdcsSenseaSuseaStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxsusea_sat = self._io.read_s2le()
            self.adcs_pget_dysusea_sat = self._io.read_s2le()
            self.adcs_pget_dzsusea_sat = self._io.read_s2le()
            self.adcs_pget_susea_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6albedoflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_attdetsusedistcorrmode = self._io.read_u1()
            self.adcs_pget_iinusecountsusea = self._io.read_u1()
            self.adcs_pget_isensorstates1 = self._io.read_u1()
            self.adcs_pget_isensorstates2 = self._io.read_u1()
            self.adcs_pget_isensorstates3 = self._io.read_u1()
            self.adcs_pget_isensorstates4 = self._io.read_u1()
            self.adcs_pget_isensorstates5 = self._io.read_u1()
            self.adcs_pget_isensorstates6 = self._io.read_u1()
            self.adcs_pget_cursumsuse1_sat = self._io.read_s2le()
            self.adcs_pget_cursumsuse2_sat = self._io.read_s2le()
            self.adcs_pget_cursumsuse3_sat = self._io.read_s2le()
            self.adcs_pget_cursumsuse4_sat = self._io.read_s2le()
            self.adcs_pget_cursumsuse5_sat = self._io.read_s2le()
            self.adcs_pget_cursumsuse6_sat = self._io.read_s2le()


    class Rw1TmCstm0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_fsmmainstate = self._io.read_u1()
            self.rw1_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw1_pget_mtrrate = self._io.read_s4le()
            self.rw1_pget_mtrratedot = self._io.read_s4le()
            self.rw1_pget_satrate = self._io.read_s4le()
            self.rw1_pget_satangle = self._io.read_s4le()


    class SalsaFwUpdateSlotTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_ishealthy = self._io.read_bits_int_be(1) != 0


    class EpsStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_s00_cur_solx_pos = self._io.read_s2le()
            self.eps_pget_s01_cur_solx_neg = self._io.read_s2le()
            self.eps_pget_s02_cur_soly_pos = self._io.read_s2le()
            self.eps_pget_s03_cur_soly_neg = self._io.read_s2le()
            self.eps_pget_s04_cur_solz_pos = self._io.read_s2le()
            self.eps_pget_s05_cur_solz_neg = self._io.read_s2le()
            self.eps_pget_s06_v_sol = self._io.read_s2le()
            self.eps_pget_s24_v_bat0 = self._io.read_s2le()
            self.eps_pget_s26_a_in_charger0 = self._io.read_s2le()
            self.eps_pget_s25_a_out_charger0 = self._io.read_s2le()
            self.eps_pget_s13_v_bat1 = self._io.read_s2le()
            self.eps_pget_s23_a_in_charger1 = self._io.read_s2le()
            self.eps_pget_s14_a_out_charger1 = self._io.read_s2le()
            self.eps_pget_s22_v_sum = self._io.read_s2le()
            self.eps_pget_s44_v_3v3 = self._io.read_s2le()
            self.eps_pget_s45_v_5v = self._io.read_s2le()
            self.thm_pget_s31_th_bat0 = self._io.read_s2le()
            self.thm_pget_s15_th_bat1 = self._io.read_s2le()
            self.thm_pget_th_obc = self._io.read_s2le()
            self.eps_pget_a_obc = self._io.read_u2le()
            self.eps_pget_v_obc = self._io.read_u2le()
            self.eps_pget_s30_a_in_bat0 = self._io.read_s2le()
            self.eps_pget_s29_a_out_bat0 = self._io.read_s2le()
            self.eps_pget_s12_a_in_bat1 = self._io.read_s2le()
            self.eps_pget_s20_a_out_bat1 = self._io.read_s2le()


    class AdcsCalDarkcurrentSuse1To6(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse1darkcurrentx1 = self._io.read_u2le()
            self.adcs_pget_suse1darkcurrentx2 = self._io.read_u2le()
            self.adcs_pget_suse1darkcurrenty1 = self._io.read_u2le()
            self.adcs_pget_suse1darkcurrenty2 = self._io.read_u2le()
            self.adcs_pget_suse2darkcurrentx1 = self._io.read_u2le()
            self.adcs_pget_suse2darkcurrentx2 = self._io.read_u2le()
            self.adcs_pget_suse2darkcurrenty1 = self._io.read_u2le()
            self.adcs_pget_suse2darkcurrenty2 = self._io.read_u2le()
            self.adcs_pget_suse3darkcurrentx1 = self._io.read_u2le()
            self.adcs_pget_suse3darkcurrentx2 = self._io.read_u2le()
            self.adcs_pget_suse3darkcurrenty1 = self._io.read_u2le()
            self.adcs_pget_suse3darkcurrenty2 = self._io.read_u2le()
            self.adcs_pget_suse4darkcurrentx1 = self._io.read_u2le()
            self.adcs_pget_suse4darkcurrentx2 = self._io.read_u2le()
            self.adcs_pget_suse4darkcurrenty1 = self._io.read_u2le()
            self.adcs_pget_suse4darkcurrenty2 = self._io.read_u2le()
            self.adcs_pget_suse5darkcurrentx1 = self._io.read_u2le()
            self.adcs_pget_suse5darkcurrentx2 = self._io.read_u2le()
            self.adcs_pget_suse5darkcurrenty1 = self._io.read_u2le()
            self.adcs_pget_suse5darkcurrenty2 = self._io.read_u2le()
            self.adcs_pget_suse6darkcurrentx1 = self._io.read_u2le()
            self.adcs_pget_suse6darkcurrentx2 = self._io.read_u2le()
            self.adcs_pget_suse6darkcurrenty1 = self._io.read_u2le()
            self.adcs_pget_suse6darkcurrenty2 = self._io.read_u2le()


    class PdhTmSapSramSatA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_satctrfrequencytxsram = self._io.read_u4le()
            self.slkpdh_pget_satctrfrequencyrxsram = self._io.read_u4le()
            self.slkpdh_pget_satctrpwrampoffsram = self._io.read_u2le()
            self.slkpdh_pget_satctrrxoffvalsram = self._io.read_u2le()
            self.slkpdh_pget_satctrtestmodevalsram = self._io.read_u2le()
            self.slkpdh_pget_satctrxmtmodesram = self._io.read_u1()
            self.slkpdh_pget_satctratttxgainsram = self._io.read_u1()
            self.slkpdh_pget_satctrmaxaitypesrama = self._io.read_u1()
            self.slkpdh_pget_satctrtestmodesram = self._io.read_u1()
            self.slkpdh_pget_satctri2creadtemppowsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrtxonsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrrxonsram = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0


    class Rw1TmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_resetcnt = self._io.read_u2le()
            self.rw1_pget_fsmmainstate = self._io.read_u1()
            self.rw1_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtroff = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mvlimit = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrovercur = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_extadcconfigured = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_faultgyro = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycurmtrfine = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycurmtrcoarse = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v2minus = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt10v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalygyro = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw1_pget_curmtr = self._io.read_u2le()
            self.rw1_pget_cur3v3 = self._io.read_u2le()
            self.rw1_pget_cur5v = self._io.read_u2le()
            self.rw1_pget_curwde = self._io.read_u2le()
            self.rw1_pget_vltmtr = self._io.read_u2le()
            self.rw1_pget_vlt3v3 = self._io.read_u2le()
            self.rw1_pget_vlt5va = self._io.read_u2le()
            self.thm_rw1_pget_tmppwra = self._io.read_u2le()
            self.thm_rw1_pget_tmppresssens = self._io.read_u4le()
            self.rw1_pget_press = self._io.read_u4le()


    class LinkPdh1Info(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_pdh1_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_validflag = self._io.read_bits_int_be(1) != 0


    class PdhTmLaynetSgp(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_networksatnum = self._io.read_u1()
            self.slkpdh_pget_networksgprangex = self._io.read_s4le()
            self.slkpdh_pget_networksgprangey = self._io.read_s4le()
            self.slkpdh_pget_networksgprangez = self._io.read_s4le()
            self.slkpdh_pget_networksgpvelx = self._io.read_s4le()
            self.slkpdh_pget_networksgpvely = self._io.read_s4le()
            self.slkpdh_pget_networksgpvelz = self._io.read_s4le()


    class PdhPlepsInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_rodoserrorcounter = self._io.read_u4le()
            self.fdir_pget_gitversion = self._io.read_u8le()
            self.fdir_pget_compiletimeinsec = self._io.read_u8le()
            self.shared_reset_counter = self._io.read_u8le()
            self.fdir_pget_ismodifiedversion = self._io.read_bits_int_be(1) != 0


    class FdaTmLongtermMagX(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_longterm_mag_x = self._io.read_s2le()


    class PdhPlepsSramCheckRes(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pget_memt_type = self._io.read_u1()
            self.pget_memt_int_min = self._io.read_u2le()
            self.pget_memt_dur_min = self._io.read_u2le()
            self.pget_memt_res = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pget_memt_state = self._io.read_u1()
            self.pget_memt_err_cnt = self._io.read_u4le()


    class SalsaTmReadClkRegs(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_pmu_config_id = self._io.read_u2le()
            self.salsa_pget_max_frames = self._io.read_u2le()
            self.salsa_pget_pmu_content = self._io.read_u1()


    class LinkgsTmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.linkgs_pget_time = self._io.read_u8le()
            self.linkgs_com_ant_fsm = self._io.read_u1()
            self.linkgs_com_ant_satazimuth = self._io.read_f4le()
            self.linkgs_com_ant_satelevation = self._io.read_f4le()
            self.linkgs_com_ant_antazimuth = self._io.read_f4le()
            self.linkgs_com_ant_antelevation = self._io.read_f4le()
            self.linkgs_com_ant_downlink = self._io.read_u4le()
            self.linkgs_com_ant_uplink = self._io.read_u4le()
            self.linkgs_com_ant_scn = self._io.read_u4le()
            self.linkgs_slk_ant_fsm = self._io.read_u1()
            self.linkgs_slk_ant_satazimuth = self._io.read_f4le()
            self.linkgs_slk_ant_satelevation = self._io.read_f4le()
            self.linkgs_slk_ant_antazimuth = self._io.read_f4le()
            self.linkgs_slk_ant_antelevation = self._io.read_f4le()
            self.linkgs_slk_ant_uplink = self._io.read_u4le()
            self.linkgs_slk_ant_downlink = self._io.read_u4le()
            self.linkgs_slk_ant_scn = self._io.read_u4le()
            self.linkgs_clientid = self._io.read_u1()
            self.linkgs_clientip = self._io.read_u4le()
            self.linkgs_latestframe_servertime = self._io.read_u8le()
            self.linkgs_latestframe_origin = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.linkgs_txchannela = self._io.read_u1()
            self.linkgs_pget_slkarq = self._io.read_u1()
            self.linkgs_pget_arrayrfustdtma = self._io.read_u1()


    class Com1TmTrx(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_anomalytrxtreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxrreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxyreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxsreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxureg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxvreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxnreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxqreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxpreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytrxdreg = self._io.read_bits_int_be(1) != 0
            self.com1_pget_txorrxfreqnotdefault = self._io.read_bits_int_be(1) != 0
            self.com1_pget_invtrxtmtxrx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxcomtimeout = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxtmrxmode = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxtmbaudlow = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxsetfreqboth = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_trxtmsreg = self._io.read_u4le()
            self.com1_pget_trxtmrreg = self._io.read_u4le()
            self.com1_pget_trxtmtreg = self._io.read_u4le()
            self.thm_com1_pget_trxtmyreg = self._io.read_u2le()
            self.com1_pget_trxtmqreg = self._io.read_u2le()
            self.com1_pget_trxtmnreg = self._io.read_u2le()
            self.com1_pget_trxtmdreg = self._io.read_u2le()
            self.com1_pget_trxtmpreg = self._io.read_u2le()
            self.com1_pget_trxtmvreg = self._io.read_u2le()
            self.com1_pget_trxtmureg = self._io.read_u2le()
            self.com1_pget_systimetrxtm = self._io.read_u4le()
            self.com1_pget_periodrdtrxtmeeprom = self._io.read_u2le()
            self.com1_pget_periodrdtrxtmsram = self._io.read_u2le()


    class Rw1TmCstm4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()


    class SalsaTmGetInaStmStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class Rw1TmCstm3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()


    class SalsaTmGetRecordInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_sector_count = self._io.read_u2le()
            self.salsa_pget_max_frames = self._io.read_u2le()
            self.salsa_pget_rx1l_vhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2l_vhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx1w_uhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2w_srd_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx1h_sband_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2h_sband_used = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.salsa_pget_rx1l_vhf_freq = self._io.read_u2le()
            self.salsa_pget_rx2l_vhf_freq = self._io.read_u2le()
            self.salsa_pget_rx1w_uhf_freq = self._io.read_u2le()
            self.salsa_pget_rx2w_srd_freq = self._io.read_u2le()
            self.salsa_pget_rx1h_sband_freq = self._io.read_u2le()
            self.salsa_pget_rx2h_sband_freq = self._io.read_u2le()
            self.salsa_pget_lna = self._io.read_u1()
            self.salsa_pget_lna_gain_rx2 = self._io.read_u1()
            self.salsa_pget_tia = self._io.read_u1()
            self.salsa_pget_tia_gain_rx2 = self._io.read_u1()
            self.salsa_pget_pga = self._io.read_s1()
            self.salsa_pget_pga_gain_rx2 = self._io.read_s1()
            self.salsa_pget_bw = self._io.read_u1()
            self.salsa_pget_fft_record_rate = self._io.read_u1()
            self.salsa_pget_record_hours = self._io.read_u1()
            self.salsa_pget_record_minutes = self._io.read_u1()


    class Rw2TmCntrl(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_fsmcntrlstate = self._io.read_u1()
            self.rw2_pget_mtrnegdirsense = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrrotdirchange = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrrotzero = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_softstholdmtroff = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_newhalledge = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_hallirqguard = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_hallirqcollision = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryext = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw2_pget_mvpwm = self._io.read_u2le()
            self.rw2_pget_mtrrate = self._io.read_s4le()
            self.rw2_pget_mtrratedot = self._io.read_s4le()
            self.rw2_pget_satrate = self._io.read_s4le()
            self.rw2_pget_satangle = self._io.read_s4le()
            self.rw2_pget_curmtr = self._io.read_u2le()


    class PdhTmStdAddA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_resetcnt = self._io.read_u2le()
            self.pdh_pget_fsmmainstate = self._io.read_u1()
            self.pdh_pget_fsmspcdbgstate = self._io.read_u1()
            self.pdh_pget_fsmsapstate = self._io.read_u1()
            self.pdh_pget_fsmslkstate = self._io.read_u1()
            self.pdh_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_initeepromparcompl = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_swspccmdtosband = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_unsecured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycur3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycurtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlt3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlttrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalytmpext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwrtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycuripu = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycurcam = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgcomtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgtxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgrxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spctxlock = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu22 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapadcconfigured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvstartsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspinotready = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvfrom = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvendsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvlength = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspimissedendhdr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvportid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuversno = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuscid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltucrc32 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvasm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvfrmlen = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiopactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu23 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu24 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatmain = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatredund = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu25 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodeboot = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatmain1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatredund1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodeboot1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu26 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu27 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu28 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu29 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_cur3v3ext = self._io.read_u2le()
            self.pdh_pget_curipu = self._io.read_u2le()
            self.pdh_pget_curtrxa = self._io.read_u2le()
            self.pdh_pget_vlt3v3ext = self._io.read_u2le()
            self.pdh_pget_curcam = self._io.read_u2le()
            self.pdh_pget_vlttrx = self._io.read_u2le()
            self.thm_pdh_pget_tmpext = self._io.read_u2le()


    class Com4TmArq(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_txltuhdrfrcnttx = self._io.read_u1()
            self.com4_pget_txltuhdrfrcntrx = self._io.read_u1()
            self.com4_pget_rxltuhdrfrcnttx = self._io.read_u1()
            self.com4_pget_rxltuhdrfrcntrx = self._io.read_u1()
            self.com4_pget_frcnttx = self._io.read_u1()
            self.com4_pget_frcntrx = self._io.read_u1()
            self.com4_pget_senderrn = self._io.read_u2le()
            self.com4_pget_sendersb = self._io.read_u2le()
            self.com4_pget_receiverrn = self._io.read_u2le()
            self.com4_pget_receiversb = self._io.read_u2le()
            self.com4_pget_sdutxfifonum = self._io.read_u1()
            self.com4_pget_sdutxfifonumtdd = self._io.read_u1()
            self.com4_pget_sdutxfifoputpos = self._io.read_u1()
            self.com4_pget_sdutxfifogetpos = self._io.read_u1()


    class LinkPdh0Info(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_pdh0_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_validflag = self._io.read_bits_int_be(1) != 0


    class PdhTmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_resetcnt = self._io.read_u2le()
            self.pdh_pget_fsmmainstate = self._io.read_u1()
            self.pdh_pget_fsmanalogstate = self._io.read_u1()
            self.pdh_pget_fsmspcdbgstate = self._io.read_u1()
            self.pdh_pget_fsmspcmainstate = self._io.read_u1()
            self.pdh_pget_fsmsapstate = self._io.read_u1()
            self.pdh_pget_fsmslkstate = self._io.read_u1()
            self.pdh_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_initeepromparcompl = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_swspccmdtosband = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_unsecured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycur3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycur3v3int = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalycurtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlt3v3ext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlt3v3int = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalyvlttrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalytmpext = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalytmpint = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_anomalypwrtrx = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgcomtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgtxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcdbgrxactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu28 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmaincomtimeout = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmainspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmainwait = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmaincierrfrsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmaincierrfrlength = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_spcmainfdirrdy = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu26 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu27 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapadcconfigured = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvstartsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspinotready = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvfrom = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvendsync = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvlength = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiinvid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspimissedendhdr = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvportid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuversno = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltuscid = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapinvpltucrc32 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvasm = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sappltuinvfrmlen = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapspiopactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesat2satmain = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesat2satredund = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatmain = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatredund = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodesatwopa = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodefree1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_progrmodeboot = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sapactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu29 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu30 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu31 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu32 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu33 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu34 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu35 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_cur3v3ext = self._io.read_u2le()
            self.pdh_pget_cur3v3int = self._io.read_u2le()
            self.pdh_pget_curtrx = self._io.read_u2le()
            self.pdh_pget_vlt3v3ext = self._io.read_u2le()
            self.pdh_pget_vlt3v3int = self._io.read_u2le()
            self.pdh_pget_vlttrx = self._io.read_u2le()
            self.thm_pdh_pget_tmpext = self._io.read_u2le()
            self.thm_pdh_pget_tmpint = self._io.read_u2le()


    class PdhPlepsSctrlConfigStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pleps_pget_scrtl_status_check_interval = self._io.read_u2le()
            self.pdh_pleps_pget_scrtl_auto_tm_interval = self._io.read_u2le()
            self.pdh_pleps_pget_scrtl_auto_tm_flag = self._io.read_bits_int_be(1) != 0
            self.pdh_pleps_pget_salsa_auto_reset_flag = self._io.read_bits_int_be(1) != 0


    class LinkgsTmClientdisconnected(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.linkgs_clientid = self._io.read_u1()
            self.linkgs_clientip = self._io.read_u4le()


    class FdaTmDebug(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()


    class EpsIntAdc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.thm_pget_th_obc = self._io.read_s2le()
            self.eps_pget_a_obc = self._io.read_u2le()
            self.eps_pget_v_obc = self._io.read_u2le()
            self.thm_pget_th_stm = self._io.read_s2le()


    class PdhTmMemextser256(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_memextserialrdaddr = self._io.read_u4le()
            self.pdh_pget_memextserialdata256 = self._io.read_u1()


    class Rw0TmEeprom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_cntrlmode = self._io.read_u1()
            self.rw0_pget_kpnumeeprom = self._io.read_u2le()
            self.rw0_pget_kpdeneeprom = self._io.read_u2le()
            self.rw0_pget_kinumeeprom = self._io.read_u2le()
            self.rw0_pget_kideneeprom = self._io.read_u2le()
            self.rw0_pget_kdnumeeprom = self._io.read_u2le()
            self.rw0_pget_kddeneeprom = self._io.read_u2le()
            self.rw0_pget_svlimiteeprom = self._io.read_u4le()
            self.rw0_pget_mvlimiteeprompwm = self._io.read_u2le()
            self.rw0_pget_gyro0offseteeprom = self._io.read_u2le()
            self.rw0_pget_gyro1offseteeprom = self._io.read_u2le()
            self.rw0_pget_gyro1activeeeprom = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0


    class SalsaTmInaStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class AdcsSenseG3Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg3_sat = self._io.read_s2le()
            self.adcs_pget_omegayg3_sat = self._io.read_s2le()
            self.adcs_pget_omegazg3_sat = self._io.read_s2le()
            self.thm_pget_tempg3 = self._io.read_s2le()
            self.adcs_pget_g3_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg3 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg3 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg3 = self._io.read_u1()


    class PdhTmLaytraStd0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_trafsmstate = self._io.read_u1()
            self.slkpdh_pget_trabasetrmtxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmrxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmnak = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactivetxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactivetxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactivetxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactiverxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactiverxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmactiverxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrmcpt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullsvc = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullsdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullsduqos = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasetrml2fifofullspdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_trabasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_trabasercvtxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvrxfifofull = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvnak = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactivetxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactivetxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactivetxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactiverxfifo0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactiverxfifo1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvactiverxfifo2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvcpt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullsvc = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullsdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullsduqos = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_trabasercvl2fifofullspdu = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_trabasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_traspectrmfifonum = self._io.read_u1()
            self.slkpdh_pget_traspectrmtxacknum = self._io.read_u1()
            self.slkpdh_pget_traspectrmrxacknum = self._io.read_u1()
            self.slkpdh_pget_traspecrcvfifonum = self._io.read_u1()
            self.slkpdh_pget_traspecrcvtxacknum = self._io.read_u1()
            self.slkpdh_pget_traspecrcvrxacknum = self._io.read_u1()


    class Com4TmMem32(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_memdatatype = self._io.read_u1()
            self.com0_pget_memdata32 = self._io.read_u1()


    class Rw2TmPress(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_presscoeff0 = self._io.read_u2le()
            self.rw2_pget_presscoeff1 = self._io.read_u2le()
            self.rw2_pget_presscoeff2 = self._io.read_u2le()
            self.rw2_pget_presscoeff3 = self._io.read_u2le()
            self.rw2_pget_presscoeff4 = self._io.read_u2le()
            self.rw2_pget_presscoeff5 = self._io.read_u2le()
            self.rw2_pget_presscoeff6 = self._io.read_u2le()
            self.rw2_pget_presscrc = self._io.read_u2le()
            self.thm_rw2_pget_tmppresssens = self._io.read_u4le()
            self.rw2_pget_press = self._io.read_u4le()


    class Com4TmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_resetcnt = self._io.read_u2le()
            self.com4_pget_rxsducnt = self._io.read_u2le()
            self.com4_pget_rxspducnt = self._io.read_u2le()
            self.com4_pget_fsmmainstate = self._io.read_u1()
            self.com4_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.com4_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.com4_pget_pdurxfifofull = self._io.read_bits_int_be(1) != 0
            self.com4_pget_rxmode = self._io.read_bits_int_be(1) != 0
            self.com4_pget_trxrxovercur = self._io.read_bits_int_be(1) != 0
            self.com4_pget_trxtxovercur = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyrssi = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyrssirx = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalycd = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalycurtrxrx = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalycurtrxtx = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyvlttrxrx = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyvlttrxtx = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_anomalytmptnc = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.com4_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com4_pget_rssi = self._io.read_u2le()
            self.com4_pget_rssirx = self._io.read_u2le()
            self.com4_pget_cd = self._io.read_u2le()
            self.com4_pget_curtrx = self._io.read_u2le()
            self.com4_pget_curtrxtx = self._io.read_u2le()
            self.com4_pget_cur3v3 = self._io.read_u2le()
            self.com4_pget_vlttrx = self._io.read_u2le()
            self.com4_pget_vlttrxtx = self._io.read_u2le()
            self.com4_pget_vlt3v3 = self._io.read_u2le()
            self.thm_com4_pget_tmptnc = self._io.read_u2le()
            self.com4_pget_timetoautorecoveryreset = self._io.read_u4le()


    class Rw2TmEeprom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_cntrlmode = self._io.read_u1()
            self.rw2_pget_kpnumeeprom = self._io.read_u2le()
            self.rw2_pget_kpdeneeprom = self._io.read_u2le()
            self.rw2_pget_kinumeeprom = self._io.read_u2le()
            self.rw2_pget_kideneeprom = self._io.read_u2le()
            self.rw2_pget_kdnumeeprom = self._io.read_u2le()
            self.rw2_pget_kddeneeprom = self._io.read_u2le()
            self.rw2_pget_svlimiteeprom = self._io.read_u4le()
            self.rw2_pget_mvlimiteeprompwm = self._io.read_u2le()
            self.rw2_pget_gyro0offseteeprom = self._io.read_u2le()
            self.rw2_pget_gyro1offseteeprom = self._io.read_u2le()
            self.rw2_pget_gyro1activeeeprom = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0


    class SatRtcInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_rtc_useflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_useflaglock = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_powerflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_healthflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_validflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_alarminterruptflag = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_rtcwassetatwakeup = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_oscstopflagatwakeup = self._io.read_bits_int_be(1) != 0
            self.sat_pget_rtc_alarmflagatwakeup = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_rtc_state = self._io.read_u1()
            self.sat_pget_rtc_errorcounter = self._io.read_u2le()
            self.sat_pget_rtc_configuredbaudrate = self._io.read_s4le()


    class Com1TmEeprom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_frsynceeprom = self._io.read_u4le()
            self.com1_pget_frsynchameeprom = self._io.read_u4le()
            self.com1_pget_bitsyncnumeeprom = self._io.read_u1()
            self.com1_pget_srcideeprom = self._io.read_u1()
            self.com1_pget_bcstideeprom = self._io.read_u1()
            self.com1_pget_syncbiterrnumeeprom = self._io.read_u1()
            self.com1_pget_syncburstnumeeprom = self._io.read_u1()
            self.com1_pget_syncchainnumeeprom = self._io.read_u1()
            self.com1_pget_hamcallsigneeprom = self._io.read_u1()
            self.com1_pget_resetcnt = self._io.read_u2le()
            self.com1_pget_periodrdtrxtmeeprom = self._io.read_u2le()
            self.com1_pget_rxsducnt = self._io.read_u2le()
            self.com1_pget_rxspducnt = self._io.read_u2le()
            self.com1_pget_periodautorecoveryreset = self._io.read_u4le()


    class AdcsThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_runtime = self._io.read_s8le()
            self.adcs_pget_imalivecounter = self._io.read_u4le()
            self.adcs_pget_periodcounter = self._io.read_u4le()
            self.adcs_pget_unfinishedcounter = self._io.read_u4le()
            self.adcs_pget_buffertime = self._io.read_u1()
            self.adcs_pget_realalgotime = self._io.read_u1()


    class PdhTmLaynetEepromTle(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_networksatnum = self._io.read_u1()
            self.slkpdh_pget_networktlesatnumeeprom = self._io.read_u4le()
            self.slkpdh_pget_networktleepochyreeprom = self._io.read_u1()
            self.slkpdh_pget_networktleepochdaysfldeeprom = self._io.read_u8le()
            self.slkpdh_pget_networktleepochdaysexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktlendotfldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktlendotexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktlenddotfldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktlenddotexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktlebstarfldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktlebstarexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktleinclofldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktleincloexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktlenodeofldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktlenodeoexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktleeccofldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktleeccoexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktleargpofldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktleargpoexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktlemofldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktlemoexpeeprom = self._io.read_s1()
            self.slkpdh_pget_networktlenofldeeprom = self._io.read_s4le()
            self.slkpdh_pget_networktlenoexpeeprom = self._io.read_s1()


    class AdcsAttPointingInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_attdet_pointingxsat = self._io.read_s2le()
            self.adcs_pget_attdet_pointingysat = self._io.read_s2le()
            self.adcs_pget_attdet_pointingzsat = self._io.read_s2le()
            self.adcs_pget_attdet_pointingxpef = self._io.read_s2le()
            self.adcs_pget_attdet_pointingypef = self._io.read_s2le()
            self.adcs_pget_attdet_pointingzpef = self._io.read_s2le()
            self.adcs_pget_attdet_pointingxtemed = self._io.read_s2le()
            self.adcs_pget_attdet_pointingytemed = self._io.read_s2le()
            self.adcs_pget_attdet_pointingztemed = self._io.read_s2le()


    class SatRtcRegisterraw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_rtc_centiseconds = self._io.read_u1()
            self.sat_pget_rtc_seconds = self._io.read_u1()
            self.sat_pget_rtc_minutes = self._io.read_u1()
            self.sat_pget_rtc_hours = self._io.read_u1()
            self.sat_pget_rtc_dayofweek = self._io.read_u1()
            self.sat_pget_rtc_dayofmonth = self._io.read_u1()
            self.sat_pget_rtc_monthandcentury = self._io.read_u1()
            self.sat_pget_rtc_year = self._io.read_u1()
            self.sat_pget_rtc_alarmcentiseconds = self._io.read_u1()
            self.sat_pget_rtc_alarmseconds = self._io.read_u1()
            self.sat_pget_rtc_alarmminutes = self._io.read_u1()
            self.sat_pget_rtc_alarmhours = self._io.read_u1()
            self.sat_pget_rtc_alarmdayordate = self._io.read_u1()
            self.sat_pget_rtc_controlreg = self._io.read_u1()
            self.sat_pget_rtc_statusreg = self._io.read_u1()
            self.sat_pget_rtc_tricklecharger = self._io.read_u1()


    class AdcsSenseaGaStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxga_sat = self._io.read_s2le()
            self.adcs_pget_omegayga_sat = self._io.read_s2le()
            self.adcs_pget_omegazga_sat = self._io.read_s2le()
            self.adcs_pget_ga_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g1_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g2_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g3_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g4_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g5_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g7_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g8_validflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetgahighprecmodeflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iinusecountga = self._io.read_u1()
            self.adcs_pget_isensorstateg1 = self._io.read_u1()
            self.adcs_pget_isensorstateg2 = self._io.read_u1()
            self.adcs_pget_isensorstateg3 = self._io.read_u1()
            self.adcs_pget_isensorstateg4 = self._io.read_u1()
            self.adcs_pget_isensorstateg5 = self._io.read_u1()
            self.adcs_pget_isensorstateg6 = self._io.read_u1()
            self.adcs_pget_isensorstateg7 = self._io.read_u1()
            self.adcs_pget_isensorstateg8 = self._io.read_u1()


    class Rw0TmCstm4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()


    class PdhTmSlkSat2sat(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slk_pget_sat2satctrfrequencytx = self._io.read_u4le()
            self.slk_pget_sat2satctrfrequencyrx = self._io.read_u4le()
            self.slk_pget_sat2satl2fifofullsvc = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satberrunning = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satsetrxchannel = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satsettxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satctrcaller = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satctrcallersendbroadcast = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satctrresponder = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satctrpayloaddir = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satsettxgain = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satl2fifofullsdu = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satl2fifofullsduqos = self._io.read_bits_int_be(1) != 0
            self.slk_pget_sat2satl2fifofullspdu = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slk_pget_sat2satctrsrcscid = self._io.read_u2le()
            self.slk_pget_sat2satctrdstscid = self._io.read_u2le()
            self.slk_pget_sat2satctratttxgain = self._io.read_u1()
            self.slk_pget_sat2satctrchannel = self._io.read_u1()
            self.slk_pget_sat2satctrmaxaitype = self._io.read_u1()
            self.slk_pget_sat2sataistate = self._io.read_u1()
            self.slk_pget_sat2satl2state = self._io.read_u1()
            self.slk_pget_sat2sataitype = self._io.read_u1()
            self.slk_pget_sat2satfrc = self._io.read_u1()
            self.slk_pget_sat2satchangechannelfrc = self._io.read_u1()
            self.slk_pget_sat2sataierr = self._io.read_u1()
            self.slk_pget_sat2satl2packetcountsdu = self._io.read_u1()
            self.slk_pget_sat2satl2packetcountsduqos = self._io.read_u1()
            self.slk_pget_sat2satl2packetcountspdu = self._io.read_u1()
            self.slk_pget_sat2satl2packetcountsvc = self._io.read_u1()
            self.thm_slk_pget_sat2satboardtemperature = self._io.read_s2le()
            self.slk_pget_sat2sattestmode = self._io.read_u1()
            self.slk_pget_sat2satvoltage = self._io.read_u1()
            self.slk_pget_sat2satcurrent = self._io.read_u1()
            self.slk_pget_sat2satpower = self._io.read_u2le()
            self.slk_pget_sat2satrcvdsir = self._io.read_u1()
            self.slk_pget_sat2satrxsir = self._io.read_u1()
            self.slk_pget_sat2satmaxsir = self._io.read_u1()
            self.slk_pget_sat2satminsir = self._io.read_u1()
            self.slk_pget_sat2satdistance = self._io.read_s4le()
            self.slk_pget_sat2satctrantmode = self._io.read_u1()
            self.slk_pget_sat2satctrrfrange = self._io.read_u1()
            self.slk_pget_sat2satusedl2bytes = self._io.read_u4le()
            self.slkpdh_pget_saprxslktmcnt = self._io.read_u2le()


    class AdcsCalTcompG3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g3tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g3tbiaspol0coefzaxis = self._io.read_s4le()


    class FdaTmLongtermPhiY(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_longterm_phi_y = self._io.read_s2le()


    class SalsaTmStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_rxfreq = self._io.read_u2le()
            self.salsa_pget_lms_temp = self._io.read_u4le()
            self.salsa_pget_bw = self._io.read_u1()
            self.salsa_pget_lna = self._io.read_u1()
            self.salsa_pget_rxport = self._io.read_u1()
            self.salsa_pget_tia = self._io.read_u1()
            self.salsa_pget_lnaport = self._io.read_u1()
            self.salsa_pget_pga = self._io.read_s1()
            self.salsa_pget_mario = self._io.read_u1()
            self.salsa_pget_fpga_alive = self._io.read_u1()
            self.salsa_pget_v_ic43 = self._io.read_u2le()
            self.salsa_pget_i_ic43 = self._io.read_s2le()
            self.salsa_pget_v_ic40 = self._io.read_u2le()
            self.salsa_pget_i_ic40 = self._io.read_s2le()
            self.salsa_pget_v_ic39 = self._io.read_u2le()
            self.salsa_pget_i_ic39 = self._io.read_s2le()
            self.salsa_pget_v_ic25 = self._io.read_u2le()
            self.salsa_pget_i_ic25 = self._io.read_s2le()
            self.salsa_pget_v_ic21 = self._io.read_u2le()
            self.salsa_pget_i_ic21 = self._io.read_s2le()
            self.salsa_pget_v_ic19 = self._io.read_u2le()
            self.salsa_pget_i_ic19 = self._io.read_s2le()
            self.salsa_pget_v_ic17 = self._io.read_u2le()
            self.salsa_pget_i_ic17 = self._io.read_s2le()
            self.salsa_pget_t_t1 = self._io.read_s4le()
            self.salsa_pget_t_t2 = self._io.read_s4le()
            self.salsa_pget_t_t3 = self._io.read_s4le()
            self.salsa_pget_t_t4 = self._io.read_s4le()
            self.salsa_pget_stm_boot_slot = self._io.read_u1()
            self.salsa_pget_fpga_boot_slot = self._io.read_u1()
            self.salsa_pget_flash_sw_master = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_flash_sw_device = self._io.read_bits_int_be(1) != 0


    class AdcsCalDcmMfrtosatG1To4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g1mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g1mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g2mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g3mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g4mfrtosatdcmw3 = self._io.read_s2le()


    class AdcsSenseSuse4D(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxsuse4_sat = self._io.read_s2le()
            self.adcs_pget_dysuse4_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse4_sat = self._io.read_s2le()
            self.thm_pget_tempsuse4 = self._io.read_u2le()
            self.adcs_pget_cursumsuse4_sat = self._io.read_s2le()
            self.adcs_pget_curx1suse4_sat = self._io.read_s2le()
            self.adcs_pget_curx2suse4_sat = self._io.read_s2le()
            self.adcs_pget_cury1suse4_sat = self._io.read_s2le()
            self.adcs_pget_cury2suse4_sat = self._io.read_s2le()
            self.adcs_pget_suse4_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates4 = self._io.read_u1()
            self.adcs_pget_isensorstatuss4 = self._io.read_u1()


    class SatFwUpdateSlotTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_ishealthy = self._io.read_bits_int_be(1) != 0


    class AdcsCtrlPdOutput(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dpdcmdtorquex_sat = self._io.read_s2le()
            self.adcs_pget_dpdcmdtorquey_sat = self._io.read_s2le()
            self.adcs_pget_dpdcmdtorquez_sat = self._io.read_s2le()


    class Rw0TmStdB(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_fsmmainstate = self._io.read_u1()
            self.rw0_pget_anomalycurmtrfine = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycurmtrcoarse = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v2minus = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt10v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalygyro = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw0_pget_curmtrfine = self._io.read_u2le()
            self.rw0_pget_vlt3v2 = self._io.read_u2le()
            self.rw0_pget_vlt3v2minus = self._io.read_u2le()
            self.rw0_pget_vlt10v = self._io.read_u2le()
            self.thm_rw0_pget_tmpgyro1 = self._io.read_s2le()
            self.rw0_pget_rategyro1x = self._io.read_s2le()
            self.rw0_pget_rategyro1y = self._io.read_s2le()
            self.rw0_pget_rategyro1z = self._io.read_s2le()


    class Com0TmSram(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_frsyncsram = self._io.read_u4le()
            self.com0_pget_frsynchamsram = self._io.read_u4le()
            self.com0_pget_bitsyncnumsram = self._io.read_u1()
            self.com0_pget_srcidsram = self._io.read_u1()
            self.com0_pget_bcstidsram = self._io.read_u1()
            self.com0_pget_syncbiterrnumsram = self._io.read_u1()
            self.com0_pget_syncburstnumsram = self._io.read_u1()
            self.com0_pget_syncchainnumsram = self._io.read_u1()
            self.com0_pget_hamcallsignsram = self._io.read_u1()


    class SalsaTmReadFlashPage(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_read_flash = self._io.read_u1()
            self.salsa_pget_mem_page = self._io.read_u1()
            self.salsa_pget_mem_sector = self._io.read_u1()
            self.salsa_pget_pmu_config_id = self._io.read_u2le()
            self.salsa_pget_pmu_content = self._io.read_u1()


    class PdhTmSlkSat(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slk_pget_satctrfrequencytx = self._io.read_u4le()
            self.slk_pget_satctrfrequencyrx = self._io.read_u4le()
            self.slk_pget_satl2fifofullsvc = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satberrunning = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satsetrxchannel = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satsettxchannel = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satctrfddon = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satctrcaller = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satctrcallersendbroadcast = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satctrresponder = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satctrpayloaddir = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satsettxgain = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satl2fifofullsdu = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satl2fifofullsduqos = self._io.read_bits_int_be(1) != 0
            self.slk_pget_satl2fifofullspdu = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slk_pget_satctrsrcscid = self._io.read_u2le()
            self.slk_pget_satctrdstscid = self._io.read_u2le()
            self.slk_pget_satctratttxgain = self._io.read_u1()
            self.slk_pget_satctrchannel = self._io.read_u1()
            self.slk_pget_satctrmaxaitype = self._io.read_u1()
            self.slk_pget_sataistate = self._io.read_u1()
            self.slk_pget_satl2state = self._io.read_u1()
            self.slk_pget_sataitype = self._io.read_u1()
            self.slk_pget_satfrc = self._io.read_u1()
            self.slk_pget_satchangechannelfrc = self._io.read_u1()
            self.slk_pget_sataierr = self._io.read_u1()
            self.slk_pget_satl2packetcountsdu = self._io.read_u1()
            self.slk_pget_satl2packetcountsduqos = self._io.read_u1()
            self.slk_pget_satl2packetcountspdu = self._io.read_u1()
            self.slk_pget_satl2packetcountsvc = self._io.read_u1()
            self.thm_slk_pget_satboardtemperature = self._io.read_s2le()
            self.slk_pget_sattestmode = self._io.read_u1()
            self.slk_pget_satvoltage = self._io.read_u1()
            self.slk_pget_satcurrent = self._io.read_u1()
            self.slk_pget_satpower = self._io.read_u2le()
            self.slk_pget_satrcvdsir = self._io.read_u1()
            self.slk_pget_satrxsir = self._io.read_u1()
            self.slk_pget_satmaxsir = self._io.read_u1()
            self.slk_pget_satminsir = self._io.read_u1()
            self.slk_pget_satdistance = self._io.read_s4le()
            self.slk_pget_satctrantmode = self._io.read_u1()
            self.slk_pget_satctrrfrange = self._io.read_u1()
            self.slk_pget_satusedl2bytes = self._io.read_u4le()
            self.slkpdh_pget_saprxslktmcnt = self._io.read_u2le()


    class AdcsCalMappingSuse5(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse5mappingpol0coefx = self._io.read_s4le()
            self.adcs_pget_suse5mappingpol1coefx = self._io.read_s4le()
            self.adcs_pget_suse5mappingpol2coefx = self._io.read_s4le()
            self.adcs_pget_suse5mappingpol3coefx = self._io.read_s4le()
            self.adcs_pget_suse5mappingpol0coefy = self._io.read_s4le()
            self.adcs_pget_suse5mappingpol1coefy = self._io.read_s4le()
            self.adcs_pget_suse5mappingpol2coefy = self._io.read_s4le()
            self.adcs_pget_suse5mappingpol3coefy = self._io.read_s4le()


    class Com0TmEeprom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_frsynceeprom = self._io.read_u4le()
            self.com0_pget_frsynchameeprom = self._io.read_u4le()
            self.com0_pget_bitsyncnumeeprom = self._io.read_u1()
            self.com0_pget_srcideeprom = self._io.read_u1()
            self.com0_pget_bcstideeprom = self._io.read_u1()
            self.com0_pget_syncbiterrnumeeprom = self._io.read_u1()
            self.com0_pget_syncburstnumeeprom = self._io.read_u1()
            self.com0_pget_syncchainnumeeprom = self._io.read_u1()
            self.com0_pget_hamcallsigneeprom = self._io.read_u1()
            self.com0_pget_resetcnt = self._io.read_u2le()
            self.com0_pget_periodrdtrxtmeeprom = self._io.read_u2le()
            self.com0_pget_rxsducnt = self._io.read_u2le()
            self.com0_pget_rxspducnt = self._io.read_u2le()
            self.com0_pget_periodautorecoveryreset = self._io.read_u4le()


    class EpsRawadc2values(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_s32_a_pdh0_raw = self._io.read_s2le()
            self.eps_pget_s33_a_pdh1_raw = self._io.read_s2le()
            self.eps_pget_s34_a_tnc0_raw = self._io.read_s2le()
            self.eps_pget_s35_a_tnc1_raw = self._io.read_s2le()
            self.eps_pget_s36_a_sens1_raw = self._io.read_s2le()
            self.eps_pget_s37_a_iso_mult0_raw = self._io.read_s2le()
            self.eps_pget_s38_a_iso_mult1_raw = self._io.read_s2le()
            self.eps_pget_s39_a_sun1_raw = self._io.read_s2le()
            self.eps_pget_s40_a_trx1_raw = self._io.read_s2le()
            self.eps_pget_s41_a_res_raw = self._io.read_s2le()
            self.eps_pget_s42_a_tempsens_raw = self._io.read_s2le()
            self.eps_pget_s43_v_in_dcdc_b_raw = self._io.read_s2le()
            self.eps_pget_s44_v_3v3_raw = self._io.read_s2le()
            self.eps_pget_s45_v_5v_raw = self._io.read_s2le()
            self.eps_pget_s46_v_dcdc_a_raw = self._io.read_s2le()
            self.eps_pget_s47_a_sun0_raw = self._io.read_s2le()


    class AdcsCalDcmMfrtosatG5To8(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g5mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g5mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g6mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g7mfrtosatdcmw3 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmu1 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmu2 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmu3 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmv1 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmv2 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmv3 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmw1 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmw2 = self._io.read_s2le()
            self.adcs_pget_g8mfrtosatdcmw3 = self._io.read_s2le()


    class Com0TmFec(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_ltudecerrnum = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw13 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw12 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw11 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw10 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw9 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw8 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw7 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw6 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw5 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw4 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw3 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw2 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw1 = self._io.read_u2le()
            self.com0_pget_ltuhdrbchrootcw0 = self._io.read_u2le()
            self.com0_pget_rssirx = self._io.read_u2le()


    class Rw2TmCstm0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_fsmmainstate = self._io.read_u1()
            self.rw2_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw2_pget_mtrrate = self._io.read_s4le()
            self.rw2_pget_mtrratedot = self._io.read_s4le()
            self.rw2_pget_satrate = self._io.read_s4le()
            self.rw2_pget_satangle = self._io.read_s4le()


    class PdhPlepsHkRqStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pleps_pget_v_salsa = self._io.read_u2le()
            self.pdh_pleps_pget_i_salsa = self._io.read_u2le()
            self.pdh_pleps_pget_v_fu = self._io.read_u2le()
            self.pdh_pleps_pget_i_fu = self._io.read_u2le()
            self.pdh_pleps_pget_v_fda_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_i_fda_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_v_fda_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_i_fda_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_v_gyro_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_i_gyro_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_v_gyro_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_i_gyro_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_v_pdh0_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_i_pdh0_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_v_pdh1_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_i_pdh1_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_t_myc_int = self._io.read_f4le()


    class LinkStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_link_mode = self._io.read_u1()
            self.link_pget_link_mode_last_error = self._io.read_u1()
            self.link_pdhctrl_pget_state = self._io.read_u1()
            self.link_stncctrl_pget_state = self._io.read_u1()
            self.link_pget_tnc0recvframecnt = self._io.read_u2le()
            self.link_pget_tnc1recvframecnt = self._io.read_u2le()
            self.link_pget_activetnc = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_activepdh = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc0_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_tnc1_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh_payloads_pwr_flag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh1_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_stncctrl_stnc0_pget_useflag = self._io.read_bits_int_be(1) != 0
            self.link_stncctrl_stnc0_pget_useflaglocked = self._io.read_bits_int_be(1) != 0
            self.link_stncctrl_stnc0_pget_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_stncctrl_stnc0_pget_powerflaglocked = self._io.read_bits_int_be(1) != 0
            self.link_stncctrl_stnc0_pget_healthflag = self._io.read_bits_int_be(1) != 0


    class SalsaTmGetFftCrcValue(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_sci_crc16_value = self._io.read_u2le()


    class Com1TmArq(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_txltuhdrfrcnttx = self._io.read_u1()
            self.com1_pget_txltuhdrfrcntrx = self._io.read_u1()
            self.com1_pget_rxltuhdrfrcnttx = self._io.read_u1()
            self.com1_pget_rxltuhdrfrcntrx = self._io.read_u1()
            self.com1_pget_frcnttx = self._io.read_u1()
            self.com1_pget_frcntrx = self._io.read_u1()
            self.com1_pget_senderrn = self._io.read_u2le()
            self.com1_pget_sendersb = self._io.read_u2le()
            self.com1_pget_receiverrn = self._io.read_u2le()
            self.com1_pget_receiversb = self._io.read_u2le()
            self.com1_pget_sdutxfifonum = self._io.read_u1()
            self.com1_pget_sdutxfifonumtdd = self._io.read_u1()
            self.com1_pget_sdutxfifoputpos = self._io.read_u1()
            self.com1_pget_sdutxfifogetpos = self._io.read_u1()


    class PdhPlepsSctrlFrameCounter(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_sctrl_frames_received = self._io.read_u4le()
            self.pdh_pget_pleps_sctrl_frames_sent = self._io.read_u4le()


    class Com1TmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_resetcnt = self._io.read_u2le()
            self.com1_pget_rxsducnt = self._io.read_u2le()
            self.com1_pget_rxspducnt = self._io.read_u2le()
            self.com1_pget_fsmmainstate = self._io.read_u1()
            self.com1_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.com1_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_pdurxfifofull = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxmode = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxrxovercur = self._io.read_bits_int_be(1) != 0
            self.com1_pget_trxtxovercur = self._io.read_bits_int_be(1) != 0
            self.com1_pget_initeepromparcompl = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyrssi = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyrssirx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycd = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycurtrxrx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycurtrxtx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyvlttrxrx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyvlttrxtx = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_anomalytmptnc = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_rssi_a = self._io.read_u2le()
            self.com1_pget_rssirx_a = self._io.read_u2le()
            self.com1_pget_cd_a = self._io.read_u2le()
            self.com1_pget_curtrx_a = self._io.read_u2le()
            self.com1_pget_curtrxtx_a = self._io.read_u2le()
            self.com1_pget_cur3v3_a = self._io.read_u2le()
            self.com1_pget_vlttrx_a = self._io.read_u2le()
            self.com1_pget_vlttrxtx_a = self._io.read_u2le()
            self.com1_pget_vlt3v3_a = self._io.read_u2le()
            self.thm_com1_pget_tmptnc_a = self._io.read_u2le()
            self.thm_com1_pget_trxtmyreg = self._io.read_u2le()
            self.com1_pget_timetoautorecoveryreset = self._io.read_u4le()


    class AdcsSenseMfs1B(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxmfs1_sat = self._io.read_s2le()
            self.adcs_pget_dymfs1_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs1_sat = self._io.read_s2le()
            self.adcs_pget_mfs1_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs1_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs1 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs1 = self._io.read_u1()


    class SalsaTmGetInaFpga1v2Status(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_ina_wov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wuv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_wsm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olov = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_oluv = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_olp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critp = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_critm = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_cnvr = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_smba = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_ovf = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d2 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d1 = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_ina_d0 = self._io.read_bits_int_be(1) != 0


    class PdhTmLaypreStd0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_prefsmstate = self._io.read_u1()
            self.slkpdh_pget_prebasetrmformatchangerqst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasetrmerrformatchange9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_prebasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_prebasercvformatchangerqst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_prebasercverrformatchange9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_prebasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_prespectrmpkttypemain = self._io.read_u1()
            self.slkpdh_pget_prespectrmpkttypesub = self._io.read_u1()
            self.slkpdh_pget_prespecrcvpkttypemain = self._io.read_u1()
            self.slkpdh_pget_prespecrcvpkttypesub = self._io.read_u1()


    class PdhPlepsSatObtUtc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obt_utc_cddayofmonth = self._io.read_u1()
            self.sat_pget_obt_utc_cdmonth = self._io.read_u1()
            self.sat_pget_obt_utc_cdyear = self._io.read_u2le()
            self.sat_pget_obt_utc_cdhour = self._io.read_u1()
            self.sat_pget_obt_utc_cdminute = self._io.read_u1()
            self.sat_pget_obt_utc_second = self._io.read_u2le()


    class EpsExtTmB(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_heat_0 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_heat_1 = self._io.read_bits_int_be(1) != 0
            self.eps_pget_lb_pwr = self._io.read_bits_int_be(1) != 0
            self.eps_pget_ant0rel = self._io.read_bits_int_be(1) != 0
            self.eps_pget_ant1rel = self._io.read_bits_int_be(1) != 0
            self.eps_pget_dcdc_b_err = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger0_err = self._io.read_bits_int_be(1) != 0
            self.eps_pget_charger1_err = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.eps_pget_s07_a_mc = self._io.read_s2le()
            self.eps_pget_s10_a_mcx = self._io.read_s2le()
            self.eps_pget_s09_a_mcy = self._io.read_s2le()
            self.eps_pget_s08_a_mcz = self._io.read_s2le()
            self.eps_pget_s11_a_rw0 = self._io.read_s2le()
            self.eps_pget_s16_a_rw1 = self._io.read_s2le()
            self.eps_pget_s17_a_rw2 = self._io.read_s2le()
            self.eps_pget_s19_a_slink = self._io.read_s2le()
            self.eps_pget_s32_a_pdh0 = self._io.read_s2le()
            self.eps_pget_s33_a_pdh1 = self._io.read_s2le()
            self.eps_pget_s37_a_iso_mult0 = self._io.read_s2le()
            self.eps_pget_s38_a_iso_mult1 = self._io.read_s2le()
            self.eps_pget_adcuseflag = self._io.read_bits_int_be(1) != 0
            self.eps_pget_analyzereactepsirqs = self._io.read_bits_int_be(1) != 0
            self.eps_irq_pget_subsysirqonoff = self._io.read_bits_int_be(1) != 0
            self.eps_irq_pget_dcdcairqonoff = self._io.read_bits_int_be(1) != 0
            self.eps_irq_pget_dcdcbirqonoff = self._io.read_bits_int_be(1) != 0
            self.eps_irq_pget_charger0irqonoff = self._io.read_bits_int_be(1) != 0
            self.eps_irq_pget_charger1irqonoff = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.eps_irq_pget_subsysovercurrcounter = self._io.read_u1()
            self.eps_irq_pget_dcdcaerrorcounter = self._io.read_u1()
            self.eps_irq_pget_dcdcberrorcounter = self._io.read_u1()
            self.eps_irq_pget_charger0errorcounter = self._io.read_u1()
            self.eps_irq_pget_charger1errorcounter = self._io.read_u1()
            self.eps_irq_pget_solarundervoltagecounter = self._io.read_u2le()


    class Rw0TmCstm1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_fsmcntrlstate = self._io.read_u1()
            self.rw0_pget_mtrnegdirsense = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrrotdirchange = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrrotzero = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_softstholdmtroff = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_newhalledge = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_hallirqguard = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_hallirqcollision = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryext = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw0_pget_rategyroz = self._io.read_s4le()
            self.rw0_pget_satrate = self._io.read_s4le()
            self.rw0_pget_vltgyro0zref = self._io.read_u2le()
            self.rw0_pget_vltgyro0z = self._io.read_u2le()
            self.rw0_pget_rategyro1x = self._io.read_s2le()
            self.rw0_pget_rategyro1y = self._io.read_s2le()
            self.rw0_pget_rategyro1z = self._io.read_s2le()


    class LinkStncInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_pdh0_useflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_useflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_powerflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_healthflag = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0_validflag = self._io.read_bits_int_be(1) != 0


    class EpsAllAdc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_s00_cur_solx_pos = self._io.read_s2le()
            self.eps_pget_s01_cur_solx_neg = self._io.read_s2le()
            self.eps_pget_s02_cur_soly_pos = self._io.read_s2le()
            self.eps_pget_s03_cur_soly_neg = self._io.read_s2le()
            self.eps_pget_s04_cur_solz_pos = self._io.read_s2le()
            self.eps_pget_s05_cur_solz_neg = self._io.read_s2le()
            self.eps_pget_s06_v_sol = self._io.read_s2le()
            self.eps_pget_s07_a_mc = self._io.read_s2le()
            self.eps_pget_s08_a_mcz = self._io.read_s2le()
            self.eps_pget_s09_a_mcy = self._io.read_s2le()
            self.eps_pget_s10_a_mcx = self._io.read_s2le()
            self.eps_pget_s11_a_rw0 = self._io.read_s2le()
            self.eps_pget_s12_a_in_bat1 = self._io.read_s2le()
            self.eps_pget_s13_v_bat1 = self._io.read_s2le()
            self.eps_pget_s14_a_out_charger1 = self._io.read_s2le()
            self.thm_pget_s15_th_bat1 = self._io.read_s2le()
            self.eps_pget_s16_a_rw1 = self._io.read_s2le()
            self.eps_pget_s17_a_rw2 = self._io.read_s2le()
            self.eps_pget_s18_a_trx0 = self._io.read_s2le()
            self.eps_pget_s19_a_slink = self._io.read_s2le()
            self.eps_pget_s20_a_out_bat1 = self._io.read_s2le()
            self.thm_pget_s21_th_charger1 = self._io.read_s2le()
            self.eps_pget_s22_v_sum = self._io.read_s2le()
            self.eps_pget_s23_a_in_charger1 = self._io.read_s2le()
            self.eps_pget_s24_v_bat0 = self._io.read_s2le()
            self.eps_pget_s25_a_out_charger0 = self._io.read_s2le()
            self.eps_pget_s26_a_in_charger0 = self._io.read_s2le()
            self.eps_pget_s27_a_sens0 = self._io.read_s2le()
            self.thm_pget_s28_th_charger0 = self._io.read_s2le()
            self.eps_pget_s29_a_out_bat0 = self._io.read_s2le()
            self.eps_pget_s30_a_in_bat0 = self._io.read_s2le()
            self.thm_pget_s31_th_bat0 = self._io.read_s2le()
            self.eps_pget_s32_a_pdh0 = self._io.read_s2le()
            self.eps_pget_s33_a_pdh1 = self._io.read_s2le()
            self.eps_pget_s34_a_tnc0 = self._io.read_s2le()
            self.eps_pget_s35_a_tnc1 = self._io.read_s2le()
            self.eps_pget_s36_a_sens1 = self._io.read_s2le()
            self.eps_pget_s37_a_iso_mult0 = self._io.read_s2le()
            self.eps_pget_s38_a_iso_mult1 = self._io.read_s2le()
            self.eps_pget_s39_a_sun1 = self._io.read_s2le()
            self.eps_pget_s40_a_trx1 = self._io.read_s2le()
            self.eps_pget_s41_a_res = self._io.read_s2le()
            self.eps_pget_s42_a_tempsens = self._io.read_s2le()
            self.eps_pget_s43_v_in_dcdc_b = self._io.read_s2le()
            self.eps_pget_s44_v_3v3 = self._io.read_s2le()
            self.eps_pget_s45_v_5v = self._io.read_s2le()
            self.eps_pget_s46_v_in_dcdc_a = self._io.read_s2le()
            self.eps_pget_s47_a_sun0 = self._io.read_s2le()
            self.thm_pget_adc0_temperature = self._io.read_s2le()
            self.thm_pget_adc1_temperature = self._io.read_s2le()
            self.thm_pget_adc2_temperature = self._io.read_s2le()


    class AdcsCalDcmMfrtosatRwa(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_rwamfrtosatdcmu1 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmu2 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmu3 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmv1 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmv2 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmv3 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmw1 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmw2 = self._io.read_s1()
            self.adcs_pget_rwamfrtosatdcmw3 = self._io.read_s1()


    class PdhTmSapEepromSatA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_satctrfrequencytxeeprom = self._io.read_u4le()
            self.slkpdh_pget_satctrfrequencyrxeeprom = self._io.read_u4le()
            self.slkpdh_pget_satctrpwrampoffeeprom = self._io.read_u2le()
            self.slkpdh_pget_satctrrxoffvaleeprom = self._io.read_u2le()
            self.slkpdh_pget_satctrtestmodevaleeprom = self._io.read_u2le()
            self.slkpdh_pget_satctrxmtmodeeeprom = self._io.read_u1()
            self.slkpdh_pget_satctratttxgaineeprom = self._io.read_u1()
            self.slkpdh_pget_satctrmaxaitypeeeproma = self._io.read_u1()
            self.slkpdh_pget_satctrtestmodeeeprom = self._io.read_u1()
            self.slkpdh_pget_satctri2creadtemppoweeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrtxoneeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_satctrrxoneeprom = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0


    class AdcsActaRwaLoopVec(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dcmdtorquerwax_sat = self._io.read_s2le()
            self.adcs_pget_dcmdtorquerway_sat = self._io.read_s2le()
            self.adcs_pget_dcmdtorquerwaz_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquerwax_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquerway_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquerwaz_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquenarwax_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquenarway_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquenarwaz_sat = self._io.read_s2le()


    class Com4TmSwvers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_swversmajor = self._io.read_u1()
            self.com4_pget_swversminor = self._io.read_u1()
            self.com4_pget_swbuildyear = self._io.read_u1()
            self.com4_pget_swbuildmonth = self._io.read_u1()
            self.com4_pget_swbuildday = self._io.read_u1()
            self.com4_pget_swbuildhour = self._io.read_u1()
            self.com4_pget_swbuildmin = self._io.read_u1()
            self.com4_pget_swbuildsec = self._io.read_u1()
            self.com4_pget_serialnum = self._io.read_u2le()
            self.com4_pget_devid = self._io.read_u1()


    class AdcsActRwzInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_rwz_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwz_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwz_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwz_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwz_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwz_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactstaterwz = self._io.read_u1()


    class AdcsAttdetDeterminationInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_attdetnarrowvectors = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetmismatchingvectors = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6albedoflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_attdetalbedoanglesuse1 = self._io.read_u1()
            self.adcs_pget_attdetalbedoanglesuse2 = self._io.read_u1()
            self.adcs_pget_attdetalbedoanglesuse3 = self._io.read_u1()
            self.adcs_pget_attdetalbedoanglesuse4 = self._io.read_u1()
            self.adcs_pget_attdetalbedoanglesuse5 = self._io.read_u1()
            self.adcs_pget_attdetalbedoanglesuse6 = self._io.read_u1()
            self.adcs_pget_attdetvectorsangle_sensor = self._io.read_u2le()
            self.adcs_pget_attdetvectorsangle_model = self._io.read_u2le()
            self.adcs_pget_attdetmfsdistcorrmode = self._io.read_u1()
            self.adcs_pget_attdetsusedistcorrmode = self._io.read_u1()
            self.adcs_pget_attdetgahighprecmodeflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdettrackigrfdeltab = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetsusealbedotracking = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetautovirtualizemfsa = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetautovirtualizesusea = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_attdetnarrowvectorsanglethreshold = self._io.read_u1()
            self.adcs_pget_attdetmissmatchingvectorsthreshold = self._io.read_u1()
            self.adcs_pget_attdetsusealbedoanglethreshold = self._io.read_u1()
            self.adcs_pget_attdetmfsadiscompensationthreshold = self._io.read_u2le()
            self.adcs_pget_attdetsuseadiscompensationthreshold = self._io.read_u2le()
            self.adcs_pget_attdetmfsameasurementpause = self._io.read_u1()
            self.adcs_pget_matadischargepause = self._io.read_u1()


    class SalsaUpdatesMissingintervalls(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_missingsequencestartarray = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceendarray = self._io.read_u2le()


    class PdhPlepsRqPwrMinVThresholdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pleps_pget_min_v_salsa = self._io.read_u2le()
            self.pdh_pleps_pget_min_v_fu = self._io.read_u2le()
            self.pdh_pleps_pget_min_v_fda_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_min_v_fda_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_min_v_gyro_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_min_v_gyro_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_min_v_pdh0_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_min_v_pdh1_3v3 = self._io.read_u2le()


    class Rw0TmCntrl(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_fsmcntrlstate = self._io.read_u1()
            self.rw0_pget_mtrnegdirsense = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrrotdirchange = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrrotzero = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_softstholdmtroff = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_newhalledge = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_hallirqguard = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_hallirqcollision = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryext = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw0_pget_mvpwm = self._io.read_u2le()
            self.rw0_pget_mtrrate = self._io.read_s4le()
            self.rw0_pget_mtrratedot = self._io.read_s4le()
            self.rw0_pget_satrate = self._io.read_s4le()
            self.rw0_pget_satangle = self._io.read_s4le()
            self.rw0_pget_curmtr = self._io.read_u2le()


    class Com1TmSwvers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_swversmajor = self._io.read_u1()
            self.com1_pget_swversminor = self._io.read_u1()
            self.com1_pget_swbuildyear = self._io.read_u1()
            self.com1_pget_swbuildmonth = self._io.read_u1()
            self.com1_pget_swbuildday = self._io.read_u1()
            self.com1_pget_swbuildhour = self._io.read_u1()
            self.com1_pget_swbuildmin = self._io.read_u1()
            self.com1_pget_swbuildsec = self._io.read_u1()
            self.com1_pget_serialnum = self._io.read_u2le()
            self.com1_pget_devid = self._io.read_u1()


    class PdhPlepsSalsaCtrlThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class SalsaTmRqLmsTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_rxfreq = self._io.read_u2le()
            self.salsa_pget_lms_temp = self._io.read_u4le()
            self.salsa_pget_bw = self._io.read_u1()
            self.salsa_pget_lna = self._io.read_u1()
            self.salsa_pget_rxport = self._io.read_u1()
            self.salsa_pget_tia = self._io.read_u1()
            self.salsa_pget_lnaport = self._io.read_u1()
            self.salsa_pget_pga = self._io.read_s1()


    class AdcsExtTmA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_ecitosatdcmoptimalu1_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalu2_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalu3_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalv1_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalv2_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalv3_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalw1_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalw2_lr = self._io.read_s1()
            self.adcs_pget_ecitosatdcmoptimalw3_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmu1_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmu2_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmu3_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmv1_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmv2_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmv3_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmw1_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmw2_lr = self._io.read_s1()
            self.adcs_pget_ecitotgtdcmw3_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerroru1_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerroru2_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerroru3_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerrorv1_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerrorv2_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerrorv3_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerrorw1_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerrorw2_lr = self._io.read_s1()
            self.adcs_pget_sattotgtdcmerrorw3_lr = self._io.read_s1()
            self.adcs_pget_igrfbmagxeci = self._io.read_s2le()
            self.adcs_pget_igrfbmagyeci = self._io.read_s2le()
            self.adcs_pget_igrfbmagzeci = self._io.read_s2le()
            self.adcs_pget_sunmodelrxeci = self._io.read_s2le()
            self.adcs_pget_sunmodelryeci = self._io.read_s2le()
            self.adcs_pget_sunmodelrzeci = self._io.read_s2le()


    class PdhPlepsLinkRqStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_link_frames_received = self._io.read_u4le()
            self.pdh_pget_pleps_link_frames_sent = self._io.read_u4le()


    class PdhPlepsFdaCtrlRqStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_pleps_ctrl_fda_state = self._io.read_u1()
            self.pdh_pget_pleps_ctrl_gyro_state = self._io.read_u1()
            self.pdh_pget_pleps_ctrl_pwr_3v3_fda = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_pleps_ctrl_pwr_3v3_gyro = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_pleps_ctrl_pwr_unreg_fda = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_pleps_ctrl_pwr_unreg_gyro = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_pleps_ctrl_fda_uart_switch_enable = self._io.read_bits_int_be(1) != 0


    class LinkStncSlinkComInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_linksessionopened = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_sessionopened = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_arquplinkack = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comtxon = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comrxon = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comautotm = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_txrepeatmode = self._io.read_u1()
            self.pdh_pget_fifonumfreesdutxa = self._io.read_u1()
            self.pdh_pget_fifonumfreesdutxb = self._io.read_u1()


    class PdhPlepsNorfCheckRes(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pget_memt_type = self._io.read_u1()
            self.pget_memt_int_min = self._io.read_u2le()
            self.pget_memt_dur_min = self._io.read_u2le()
            self.pget_memt_res = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pget_memt_state = self._io.read_u1()
            self.pget_memt_err_cnt = self._io.read_u4le()


    class PdhTmMemextser64(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_memextserialrdaddr = self._io.read_u4le()
            self.pdh_pget_memextserialdata64 = self._io.read_u1()


    class AdcsCalMappingSuse2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse2mappingpol0coefx = self._io.read_s4le()
            self.adcs_pget_suse2mappingpol1coefx = self._io.read_s4le()
            self.adcs_pget_suse2mappingpol2coefx = self._io.read_s4le()
            self.adcs_pget_suse2mappingpol3coefx = self._io.read_s4le()
            self.adcs_pget_suse2mappingpol0coefy = self._io.read_s4le()
            self.adcs_pget_suse2mappingpol1coefy = self._io.read_s4le()
            self.adcs_pget_suse2mappingpol2coefy = self._io.read_s4le()
            self.adcs_pget_suse2mappingpol3coefy = self._io.read_s4le()


    class AdcsCtrlBdotInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_bdotdeltabx = self._io.read_s1()
            self.adcs_pget_bdotdeltaby = self._io.read_s1()
            self.adcs_pget_bdotdeltabz = self._io.read_s1()
            self.adcs_pget_bdotdeltab_omega = self._io.read_u1()


    class FdaTmLongtermMagY(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_longterm_mag_y = self._io.read_s2le()


    class PdhTmLaynetRouting(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_networkdijkstraroutingfrom = self._io.read_u1()
            self.slkpdh_pget_networkdijkstraroutingdistance = self._io.read_u2le()


    class PdhTmSwvers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_swversmajor = self._io.read_u1()
            self.pdh_pget_swversminor = self._io.read_u1()
            self.pdh_pget_swbuildyear = self._io.read_u1()
            self.pdh_pget_swbuildmonth = self._io.read_u1()
            self.pdh_pget_swbuildday = self._io.read_u1()
            self.pdh_pget_swbuildhour = self._io.read_u1()
            self.pdh_pget_swbuildmin = self._io.read_u1()
            self.pdh_pget_swbuildsec = self._io.read_u1()
            self.pdh_pget_serialnum = self._io.read_u2le()
            self.pdh_pget_devid = self._io.read_u1()


    class FdaTmImuIncrPhi(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_imu_incr_phi_x = self._io.read_f4le()
            self.fda_pget_imu_incr_phi_y = self._io.read_f4le()
            self.fda_pget_imu_incr_phi_z = self._io.read_f4le()


    class PdhTmLaysesStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_sesfsmstate = self._io.read_u1()
            self.slkpdh_pget_sesbasetrmsesest = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmseslost = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmseschngsttmoutact = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmwaitforaiandtrmt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmberrunning = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmsetrxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmsettxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmcaller = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmcallersendbcst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmresponder = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmpayloaddir = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmsettxgain = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasetrmfddon = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_sesbasetrmtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_sesbasetrmrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_sesbasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_sesbasercvsesest = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvseslost = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvseschngsttmoutact = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvwaitforaiandtrmt = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvberrunning = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvsetrxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvsettxchannel = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvcaller = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvcallersendbcst = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvresponder = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvpayloaddir = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvsettxgain = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_sesbasercvfddon = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_sesbasercvtxseqnum = self._io.read_u2le()
            self.slkpdh_pget_sesbasercvrxseqnum = self._io.read_u2le()
            self.slkpdh_pget_sesbasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_sesspectrmmactypemain = self._io.read_u1()
            self.slkpdh_pget_sesspectrmmactypesub = self._io.read_u1()
            self.slkpdh_pget_sesspectrmpara0 = self._io.read_u1()
            self.slkpdh_pget_sesspectrmpara1 = self._io.read_u1()
            self.slkpdh_pget_sesspectrmrestartattempts = self._io.read_u1()
            self.slkpdh_pget_sesspectrmtxchangestatefrc = self._io.read_u1()
            self.slkpdh_pget_sesspectrmrxchangestatefrc = self._io.read_u1()
            self.slkpdh_pget_sesspectrmrcvdsir = self._io.read_u1()
            self.slkpdh_pget_sesspectrmrxsir = self._io.read_u1()
            self.slkpdh_pget_sesspectrmmaxsir = self._io.read_u1()
            self.slkpdh_pget_sesspectrmminsir = self._io.read_u1()
            self.slkpdh_pget_sesspectrmaistate = self._io.read_u1()
            self.slkpdh_pget_sesspectrml2state = self._io.read_u1()
            self.slkpdh_pget_sesspectrmaitype = self._io.read_u1()
            self.slkpdh_pget_sesspectrmaierr = self._io.read_u1()
            self.slkpdh_pget_sesspectrmfrc = self._io.read_u1()
            self.slkpdh_pget_sesspectrmchangechannelfrc = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvmactypemain = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvmactypesub = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvpara0 = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvpara1 = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvrestartattempts = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvtxchangestatefrc = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvrxchangestatefrc = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvrcvdsir = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvrxsir = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvmaxsir = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvminsir = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvaistate = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvl2state = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvaitype = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvaierr = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvfrc = self._io.read_u1()
            self.slkpdh_pget_sesspecrcvchangechannelfrc = self._io.read_u1()


    class AdcsThm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.thm_pget_tempg1 = self._io.read_s2le()
            self.thm_pget_tempg2 = self._io.read_s2le()
            self.thm_pget_tempg3 = self._io.read_s2le()
            self.thm_pget_tempg4 = self._io.read_s2le()
            self.thm_pget_tempg5 = self._io.read_s2le()
            self.thm_pget_tempg6 = self._io.read_s2le()
            self.thm_pget_tempg7 = self._io.read_s2le()
            self.thm_pget_tempg8 = self._io.read_s2le()
            self.thm_pget_tempsuse1 = self._io.read_u2le()
            self.thm_pget_tempsuse2 = self._io.read_u2le()
            self.thm_pget_tempsuse3 = self._io.read_u2le()
            self.thm_pget_tempsuse4 = self._io.read_u2le()
            self.thm_pget_tempsuse5 = self._io.read_u2le()
            self.thm_pget_tempsuse6 = self._io.read_u2le()


    class SatObtUtcNs(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obt_utc_ns = self._io.read_s8le()


    class AdcsCalMappingSuse4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse4mappingpol0coefx = self._io.read_s4le()
            self.adcs_pget_suse4mappingpol1coefx = self._io.read_s4le()
            self.adcs_pget_suse4mappingpol2coefx = self._io.read_s4le()
            self.adcs_pget_suse4mappingpol3coefx = self._io.read_s4le()
            self.adcs_pget_suse4mappingpol0coefy = self._io.read_s4le()
            self.adcs_pget_suse4mappingpol1coefy = self._io.read_s4le()
            self.adcs_pget_suse4mappingpol2coefy = self._io.read_s4le()
            self.adcs_pget_suse4mappingpol3coefy = self._io.read_s4le()


    class EpsRawadc0values(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_s00_cur_solx_pos_raw = self._io.read_s2le()
            self.eps_pget_s01_cur_solx_neg_raw = self._io.read_s2le()
            self.eps_pget_s02_cur_soly_pos_raw = self._io.read_s2le()
            self.eps_pget_s03_cur_soly_neg_raw = self._io.read_s2le()
            self.eps_pget_s04_cur_solz_pos_raw = self._io.read_s2le()
            self.eps_pget_s05_cur_solz_neg_raw = self._io.read_s2le()
            self.eps_pget_s06_v_sol_raw = self._io.read_s2le()
            self.eps_pget_s07_a_mc_raw = self._io.read_s2le()
            self.eps_pget_s08_a_mcz_raw = self._io.read_s2le()
            self.eps_pget_s09_a_mcy_raw = self._io.read_s2le()
            self.eps_pget_s10_a_mcx_raw = self._io.read_s2le()
            self.eps_pget_s11_a_rw0_raw = self._io.read_s2le()
            self.eps_pget_s12_a_in_bat1_raw = self._io.read_s2le()
            self.eps_pget_s13_v_bat1_raw = self._io.read_s2le()
            self.eps_pget_s14_a_out_charger1_raw = self._io.read_s2le()
            self.thm_pget_s15_th_bat1_raw = self._io.read_s2le()


    class Rw0TmSram(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_cntrlmode = self._io.read_u1()
            self.rw0_pget_kpnumsram = self._io.read_u2le()
            self.rw0_pget_kpdensram = self._io.read_u2le()
            self.rw0_pget_kinumsram = self._io.read_u2le()
            self.rw0_pget_kidensram = self._io.read_u2le()
            self.rw0_pget_kdnumsram = self._io.read_u2le()
            self.rw0_pget_kddensram = self._io.read_u2le()
            self.rw0_pget_svlimitsram = self._io.read_u4le()
            self.rw0_pget_mvlimitsrampwm = self._io.read_u2le()
            self.rw0_pget_gyro0offsetsram = self._io.read_u2le()
            self.rw0_pget_gyro1offsetsram = self._io.read_u2le()
            self.rw0_pget_gyro1activesram = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0


    class AdcsAttDcmEcitosatOptimal(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_ecitosatdcmoptimalu1 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalu2 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalu3 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalv1 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalv2 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalv3 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalw1 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalw2 = self._io.read_s2le()
            self.adcs_pget_ecitosatdcmoptimalw3 = self._io.read_s2le()


    class SalsaLmsThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class AdcsSenseG6Omega(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_omegaxg6_sat = self._io.read_s2le()
            self.adcs_pget_omegayg6_sat = self._io.read_s2le()
            self.adcs_pget_omegazg6_sat = self._io.read_s2le()
            self.thm_pget_tempg6 = self._io.read_s2le()
            self.adcs_pget_g6_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_g6_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstateg6 = self._io.read_u1()
            self.adcs_pget_ififofilllevelg6 = self._io.read_u2le()
            self.adcs_pget_isensorstatusg6 = self._io.read_u1()


    class AdcsSenseSuse1D(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxsuse1_sat = self._io.read_s2le()
            self.adcs_pget_dysuse1_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse1_sat = self._io.read_s2le()
            self.thm_pget_tempsuse1 = self._io.read_u2le()
            self.adcs_pget_cursumsuse1_sat = self._io.read_s2le()
            self.adcs_pget_curx1suse1_sat = self._io.read_s2le()
            self.adcs_pget_curx2suse1_sat = self._io.read_s2le()
            self.adcs_pget_cury1suse1_sat = self._io.read_s2le()
            self.adcs_pget_cury2suse1_sat = self._io.read_s2le()
            self.adcs_pget_suse1_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates1 = self._io.read_u1()
            self.adcs_pget_isensorstatuss1 = self._io.read_u1()


    class Rw1TmSram(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_cntrlmode = self._io.read_u1()
            self.rw1_pget_kpnumsram = self._io.read_u2le()
            self.rw1_pget_kpdensram = self._io.read_u2le()
            self.rw1_pget_kinumsram = self._io.read_u2le()
            self.rw1_pget_kidensram = self._io.read_u2le()
            self.rw1_pget_kdnumsram = self._io.read_u2le()
            self.rw1_pget_kddensram = self._io.read_u2le()
            self.rw1_pget_svlimitsram = self._io.read_u4le()
            self.rw1_pget_mvlimitsrampwm = self._io.read_u2le()
            self.rw1_pget_gyro0offsetsram = self._io.read_u2le()
            self.rw1_pget_gyro1offsetsram = self._io.read_u2le()
            self.rw1_pget_gyro1activesram = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0


    class SalsaFwUpdateMissingintervalls(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_missingsequencestartarray = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceendarray = self._io.read_u2le()


    class AdcsCalTcompG7(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g7tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g7tbiaspol0coefzaxis = self._io.read_s4le()


    class PdhPlepsRqPwrMaxVThresholdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pleps_pget_max_v_salsa = self._io.read_u2le()
            self.pdh_pleps_pget_max_v_fu = self._io.read_u2le()
            self.pdh_pleps_pget_max_v_fda_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_max_v_fda_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_max_v_gyro_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_max_v_gyro_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_max_v_pdh0_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_max_v_pdh1_3v3 = self._io.read_u2le()


    class Com1TmRndpkt(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_rndpktcnt = self._io.read_u1()
            self.com1_pget_rndpkttype = self._io.read_u1()
            self.com1_pget_rnddata = self._io.read_u1()


    class AdcsCalTcompG4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g4tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g4tbiaspol0coefzaxis = self._io.read_s4le()


    class PdhPlepsRqPwrMaxIThresholdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pleps_pget_max_i_salsa = self._io.read_u2le()
            self.pdh_pleps_pget_max_i_fu = self._io.read_u2le()
            self.pdh_pleps_pget_max_i_fda_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_max_i_fda_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_max_i_gyro_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_max_i_gyro_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_max_i_pdh0_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_max_i_pdh1_3v3 = self._io.read_u2le()


    class EpsThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_runtime = self._io.read_s8le()
            self.eps_pget_imalivecounter = self._io.read_u4le()
            self.eps_pget_periodcounter = self._io.read_u4le()
            self.eps_pget_unfinishedcounter = self._io.read_u4le()
            self.eps_pget_buffertime = self._io.read_u1()
            self.eps_pget_realalgotime = self._io.read_u1()


    class SalsaFpgaThreadInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fdir_pget_runtime = self._io.read_s8le()
            self.fdir_pget_imalivecounter = self._io.read_u4le()
            self.fdir_pget_realalgotime = self._io.read_u1()


    class Rw0TmCstm0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_fsmmainstate = self._io.read_u1()
            self.rw0_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw0_pget_mtrrate = self._io.read_s4le()
            self.rw0_pget_mtrratedot = self._io.read_s4le()
            self.rw0_pget_satrate = self._io.read_s4le()
            self.rw0_pget_satangle = self._io.read_s4le()


    class SatObtUtc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obt_utc_cddayofmonth = self._io.read_u1()
            self.sat_pget_obt_utc_cdmonth = self._io.read_u1()
            self.sat_pget_obt_utc_cdyear = self._io.read_u2le()
            self.sat_pget_obt_utc_cdhour = self._io.read_u1()
            self.sat_pget_obt_utc_cdminute = self._io.read_u1()
            self.sat_pget_obt_utc_second = self._io.read_u2le()


    class LinkgsTmClientconnected(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.linkgs_clientid = self._io.read_u1()
            self.linkgs_clientip = self._io.read_u4le()


    class Com4TmFec(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_ltudecerrnum = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw13 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw12 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw11 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw10 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw9 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw8 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw7 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw6 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw5 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw4 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw3 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw2 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw1 = self._io.read_u2le()
            self.com4_pget_ltuhdrbchrootcw0 = self._io.read_u2le()
            self.com4_pget_rssirx = self._io.read_u2le()


    class Com1TmSram(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_frsyncsram = self._io.read_u4le()
            self.com1_pget_frsynchamsram = self._io.read_u4le()
            self.com1_pget_bitsyncnumsram = self._io.read_u1()
            self.com1_pget_srcidsram = self._io.read_u1()
            self.com1_pget_bcstidsram = self._io.read_u1()
            self.com1_pget_syncbiterrnumsram = self._io.read_u1()
            self.com1_pget_syncburstnumsram = self._io.read_u1()
            self.com1_pget_syncchainnumsram = self._io.read_u1()
            self.com1_pget_hamcallsignsram = self._io.read_u1()


    class SalsaFwStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_obc_act = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_selectedslotnum = self._io.read_u1()
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_realalgotime = self._io.read_u1()


    class AdcsActRwTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_ireadstaterwx_mfr = self._io.read_u1()
            self.adcs_pget_ireadstaterwy_mfr = self._io.read_u1()
            self.adcs_pget_ireadstaterwz_mfr = self._io.read_u1()
            self.adcs_pget_ireadtorquerwx_mfr = self._io.read_s2le()
            self.adcs_pget_ireadtorquerwy_mfr = self._io.read_s2le()
            self.adcs_pget_ireadtorquerwz_mfr = self._io.read_s2le()
            self.adcs_pget_ireadrotspeedrwx_mfr = self._io.read_s2le()
            self.adcs_pget_ireadrotspeedrwy_mfr = self._io.read_s2le()
            self.adcs_pget_ireadrotspeedrwz_mfr = self._io.read_s2le()
            self.adcs_pget_ireadangularraterwx_mfr = self._io.read_s1()
            self.adcs_pget_ireadangularraterwy_mfr = self._io.read_s1()
            self.adcs_pget_ireadangularraterwz_mfr = self._io.read_s1()
            self.adcs_pget_ireadanglerwx_mfr = self._io.read_s1()
            self.adcs_pget_ireadanglerwy_mfr = self._io.read_s1()
            self.adcs_pget_ireadanglerwz_mfr = self._io.read_s1()


    class FdaTmImuRotRate(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_imu_omega_x = self._io.read_f4le()
            self.fda_pget_imu_omega_y = self._io.read_f4le()
            self.fda_pget_imu_omega_z = self._io.read_f4le()
            self.fda_pget_int_imu_omega_abs = self._io.read_f4le()


    class LinkPdhctrlStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pdhctrl_pget_configuredbaudrate = self._io.read_s4le()
            self.link_pdhctrl_pget_receivedframes = self._io.read_u4le()
            self.link_pdhctrl_pget_parsedbytecount = self._io.read_u4le()
            self.link_pdhctrl_pget_activepdh = self._io.read_bits_int_be(1) != 0
            self.link_pget_pdh0fwdflag = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_syncreceived = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvtcupstream = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_fwdtmdownstream = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.link_pget_pdh0runtime = self._io.read_u2le()
            self.link_pget_pdh1runtime = self._io.read_u2le()
            self.link_pget_pdh0runtimethreshold = self._io.read_u2le()
            self.link_pget_pdh1runtimethreshold = self._io.read_u2le()


    class Com0TmMem32(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_memdatatype = self._io.read_u1()
            self.com0_pget_memdata32 = self._io.read_u1()


    class Rw0TmStdA(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw0_pget_systime = self._io.read_u4le()
            self.rw0_pget_resetcnt = self._io.read_u2le()
            self.rw0_pget_fsmmainstate = self._io.read_u1()
            self.rw0_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtroff = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mvlimit = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_mtrovercur = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_extadcconfigured = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_faultgyro = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycurmtrfine = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycurmtrcoarse = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt3v2minus = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalyvlt10v = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalygyro = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw0_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw0_pget_curmtr = self._io.read_u2le()
            self.rw0_pget_cur3v3 = self._io.read_u2le()
            self.rw0_pget_cur5v = self._io.read_u2le()
            self.rw0_pget_curwde = self._io.read_u2le()
            self.rw0_pget_vltmtr = self._io.read_u2le()
            self.rw0_pget_vlt3v3 = self._io.read_u2le()
            self.rw0_pget_vlt5va = self._io.read_u2le()
            self.thm_rw0_pget_tmppwra = self._io.read_u2le()
            self.thm_rw0_pget_tmppresssens = self._io.read_u4le()
            self.rw0_pget_press = self._io.read_u4le()


    class SatFwUpdateTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_currentlyrunningsoftwareslot = self._io.read_u1()
            self.sat_pget_fw_updater_state = self._io.read_u1()
            self.sat_pget_fw_updater_activeslotnum = self._io.read_u1()
            self.sat_pget_fw_updater_tmpimgaddr = self._io.read_u4le()
            self.sat_pget_selectedslotnum = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundererase = self._io.read_u1()
            self.sat_pget_fw_updater_slotnumundercrc = self._io.read_u1()
            self.sat_pget_fw_updater_activeimagelength = self._io.read_u4le()
            self.sat_pget_fw_updater_numwrittensequences = self._io.read_u2le()
            self.sat_pget_fw_updater_nextexpectedsequence = self._io.read_u2le()
            self.sat_pget_fw_updater_totalmissingsequences = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceswriteidx = self._io.read_u1()
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0


    class SalsaTmGetRecordingDatetime(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_sector_count = self._io.read_u2le()
            self.salsa_pget_max_frames = self._io.read_u2le()
            self.salsa_pget_rx1l_vhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2l_vhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx1w_uhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2w_srd_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx1h_sband_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2h_sband_used = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.salsa_pget_start_year = self._io.read_u1()
            self.salsa_pget_end_year = self._io.read_u1()
            self.salsa_pget_start_month = self._io.read_u1()
            self.salsa_pget_end_month = self._io.read_u1()
            self.salsa_pget_start_day = self._io.read_u1()
            self.salsa_pget_end_day = self._io.read_u1()
            self.salsa_pget_start_hours = self._io.read_u1()
            self.salsa_pget_end_hours = self._io.read_u1()
            self.salsa_pget_start_minutes = self._io.read_u1()
            self.salsa_pget_end_minutes = self._io.read_u1()
            self.salsa_pget_start_seconds = self._io.read_f4le()
            self.salsa_pget_end_seconds = self._io.read_f4le()
            self.salsa_pget_start_centiseconds = self._io.read_u1()
            self.salsa_pget_end_centiseconds = self._io.read_u1()
            self.salsa_pget_fft_record_rate = self._io.read_u1()
            self.salsa_pget_record_hours = self._io.read_u1()
            self.salsa_pget_record_minutes = self._io.read_u1()


    class PdhTmLaynetSramPar(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_networksatnum = self._io.read_u1()
            self.slkpdh_pget_networksatsrcsram = self._io.read_u2le()
            self.slkpdh_pget_networksatdstsram = self._io.read_u2le()
            self.slkpdh_pget_networksat2satsrcsram = self._io.read_u2le()
            self.slkpdh_pget_networksat2satdstsram = self._io.read_u2le()
            self.slkpdh_pget_networkcostmaxsram = self._io.read_u2le()


    class AdcsSenseMfs2B(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxmfs2_sat = self._io.read_s2le()
            self.adcs_pget_dymfs2_sat = self._io.read_s2le()
            self.adcs_pget_dzmfs2_sat = self._io.read_s2le()
            self.adcs_pget_mfs2_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_mfs2_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstatemfs2 = self._io.read_u1()
            self.adcs_pget_isensorstatusmfs2 = self._io.read_u1()


    class Rw1TmCntrl(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_fsmcntrlstate = self._io.read_u1()
            self.rw1_pget_mtrnegdirsense = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrrotdirchange = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrrotzero = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_softstholdmtroff = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_newhalledge = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_hallirqguard = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_hallirqcollision = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryext = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw1_pget_mvpwm = self._io.read_u2le()
            self.rw1_pget_mtrrate = self._io.read_s4le()
            self.rw1_pget_mtrratedot = self._io.read_s4le()
            self.rw1_pget_satrate = self._io.read_s4le()
            self.rw1_pget_satangle = self._io.read_s4le()
            self.rw1_pget_curmtr = self._io.read_u2le()


    class Com0TmRtc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_rtcinitcomplete = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcinvreg = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcspiactive = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcspirelease = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcconfcomplete = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcwrtime = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcttavailable = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_rtcsec01 = self._io.read_u1()
            self.com0_pget_rtcsec001 = self._io.read_u1()
            self.com0_pget_rtcsec10 = self._io.read_u1()
            self.com0_pget_rtcsec1 = self._io.read_u1()
            self.com0_pget_rtcsec01alarm = self._io.read_u1()
            self.com0_pget_rtcsec001alarm = self._io.read_u1()
            self.com0_pget_rtcsec10alarm = self._io.read_u1()
            self.com0_pget_rtcsec1alarm = self._io.read_u1()
            self.com0_pget_rtcmin10 = self._io.read_u1()
            self.com0_pget_rtcmin1 = self._io.read_u1()
            self.com0_pget_rtcmin10alarm = self._io.read_u1()
            self.com0_pget_rtcmin1alarm = self._io.read_u1()
            self.com0_pget_rtchour10 = self._io.read_u1()
            self.com0_pget_rtchour1 = self._io.read_u1()
            self.com0_pget_rtchour10alarm = self._io.read_u1()
            self.com0_pget_rtchour1alarm = self._io.read_u1()
            self.com0_pget_rtcday = self._io.read_u1()
            self.com0_pget_rtcdayalarm = self._io.read_u1()
            self.com0_pget_rtcdate10 = self._io.read_u1()
            self.com0_pget_rtcdate1 = self._io.read_u1()
            self.com0_pget_rtcdate10alarm = self._io.read_u1()
            self.com0_pget_rtcdate1alarm = self._io.read_u1()
            self.com0_pget_rtcmonth10 = self._io.read_u1()
            self.com0_pget_rtcmonth1 = self._io.read_u1()
            self.com0_pget_rtcyear10 = self._io.read_u1()
            self.com0_pget_rtcyear1 = self._io.read_u1()
            self.com0_pget_rtcregcontrol = self._io.read_u1()
            self.com0_pget_rtcregstatus = self._io.read_u1()
            self.com0_pget_rtcregtricklecharger = self._io.read_u1()
            self.com0_pget_rtc12 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcpm = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtccentury = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtc12alarm = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcpmalarm = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcdyalarm = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcam1 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcam2 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcam3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rtcam4 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_rtcyear = self._io.read_u2le()
            self.com0_pget_rtcmonth = self._io.read_u1()
            self.com0_pget_rtcmin = self._io.read_u1()
            self.com0_pget_rtcminalarm = self._io.read_u1()
            self.com0_pget_rtchour = self._io.read_u1()
            self.com0_pget_rtchouralarm = self._io.read_u1()
            self.com0_pget_rtcdate = self._io.read_u1()
            self.com0_pget_rtcdatealarm = self._io.read_u1()
            self.com0_pget_rtcsec = self._io.read_u2le()
            self.com0_pget_rtcsecalarm = self._io.read_u2le()


    class SalsaTmInterfaceUsage(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_lms_pmua_user = self._io.read_u1()
            self.salsa_pget_lms_pmua_mode = self._io.read_u1()
            self.salsa_pget_pmub_user = self._io.read_u1()
            self.salsa_pget_pmub_mode = self._io.read_u1()
            self.salsa_pget_fpga_user = self._io.read_u1()
            self.salsa_pget_fpga_mode = self._io.read_u1()
            self.salsa_pget_flash_user = self._io.read_u1()
            self.salsa_pget_flash_mode = self._io.read_u1()


    class SalsaTmReadLmsCalib(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_pmu_config_id = self._io.read_u2le()
            self.salsa_pget_max_frames = self._io.read_u2le()
            self.salsa_pget_pmu_content = self._io.read_u1()


    class LinkStncctrlStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pdhctrl_pget_configuredbaudrate = self._io.read_s4le()
            self.link_pdhctrl_pget_receivedframes = self._io.read_u4le()
            self.link_pdhctrl_pget_parsedbytecount = self._io.read_u4le()
            self.link_pdhctrl_pget_syncreceived = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_recvtcupstream = self._io.read_bits_int_be(1) != 0
            self.link_pdhctrl_pget_fwdtmdownstream = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.link_pget_pdh0runtime = self._io.read_u2le()
            self.link_pget_pdh0runtimethreshold = self._io.read_u2le()
            self.link_pget_predictedfifosize256 = self._io.read_u1()
            self.link_pget_predictedfifosize64 = self._io.read_u1()


    class AdcsCalOffsetG1To8(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g1offsetx = self._io.read_s2le()
            self.adcs_pget_g1offsety = self._io.read_s2le()
            self.adcs_pget_g1offsetz = self._io.read_s2le()
            self.adcs_pget_g2offsetx = self._io.read_s2le()
            self.adcs_pget_g2offsety = self._io.read_s2le()
            self.adcs_pget_g2offsetz = self._io.read_s2le()
            self.adcs_pget_g3offsetx = self._io.read_s2le()
            self.adcs_pget_g3offsety = self._io.read_s2le()
            self.adcs_pget_g3offsetz = self._io.read_s2le()
            self.adcs_pget_g4offsetx = self._io.read_s2le()
            self.adcs_pget_g4offsety = self._io.read_s2le()
            self.adcs_pget_g4offsetz = self._io.read_s2le()
            self.adcs_pget_g5offsetx = self._io.read_s2le()
            self.adcs_pget_g5offsety = self._io.read_s2le()
            self.adcs_pget_g5offsetz = self._io.read_s2le()
            self.adcs_pget_g6offsetx = self._io.read_s2le()
            self.adcs_pget_g6offsety = self._io.read_s2le()
            self.adcs_pget_g6offsetz = self._io.read_s2le()
            self.adcs_pget_g7offsetx = self._io.read_s2le()
            self.adcs_pget_g7offsety = self._io.read_s2le()
            self.adcs_pget_g7offsetz = self._io.read_s2le()
            self.adcs_pget_g8offsetx = self._io.read_s2le()
            self.adcs_pget_g8offsety = self._io.read_s2le()
            self.adcs_pget_g8offsetz = self._io.read_s2le()


    class FdaTmLongtermPhiX(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_longterm_phi_x = self._io.read_s2le()


    class SalsaTmGetBootConfigs(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_lms_calib_boot_slot = self._io.read_u1()
            self.salsa_pget_lms_regs_boot_slot = self._io.read_u1()
            self.salsa_pget_clk_regs_boot_slot = self._io.read_u1()
            self.salsa_pget_fpga_boot_slot = self._io.read_u1()
            self.salsa_pget_ina_boot_slot = self._io.read_u1()


    class SalsatFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fsync = self._io.read_bits_int_be(18)
            self.crc = self._io.read_bits_int_be(14)
            self.fcid_major = self._io.read_bits_int_be(6)
            self.fcid_sub = self._io.read_bits_int_be(10)
            self.urgent_flag = self._io.read_bits_int_be(1) != 0
            self.future_use = self._io.read_bits_int_be(1) != 0
            self.crc_check = self._io.read_bits_int_be(1) != 0
            self.multiframe = self._io.read_bits_int_be(1) != 0
            self.time_tagged_setting = self._io.read_bits_int_be(1) != 0
            self.time_tagged = self._io.read_bits_int_be(1) != 0
            self.data_length = self._io.read_bits_int_be(10)
            self._io.align_to_byte()
            if self.time_tagged == True:
                self.time_tag = self._io.read_u4le()

            if  ((self.fcid_major == 32) and (self.fcid_sub == 10)) :
                self.user_data_obc_info = Salsat.ObcInfo(self._io, self, self._root)

            if  ((self.fcid_major == 32) and (self.fcid_sub == 11)) :
                self.user_data_fdir_thread_info = Salsat.FdirThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 0)) :
                self.user_data_link_std_tm = Salsat.LinkStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 10)) :
                self.user_data_link_pdhctrl_std_tm = Salsat.LinkPdhctrlStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 11)) :
                self.user_data_link_pdhctrl_ext_tm = Salsat.LinkPdhctrlExtTm(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 12)) :
                self.user_data_link_tnc0_info = Salsat.LinkTnc0Info(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 13)) :
                self.user_data_link_tnc1_info = Salsat.LinkTnc1Info(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 14)) :
                self.user_data_link_pdh0_info = Salsat.LinkPdh0Info(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 15)) :
                self.user_data_link_pdh1_info = Salsat.LinkPdh1Info(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 16)) :
                self.user_data_link_stncctrl_std_tm = Salsat.LinkStncctrlStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 17)) :
                self.user_data_link_stncctrl_ext_tm = Salsat.LinkStncctrlExtTm(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 18)) :
                self.user_data_link_stnc_info = Salsat.LinkStncInfo(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 19)) :
                self.user_data_link_stnc_slink_com_info = Salsat.LinkStncSlinkComInfo(self._io, self, self._root)

            if  ((self.fcid_major == 40) and (self.fcid_sub == 40)) :
                self.user_data_link_com_mode = Salsat.LinkComMode(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 0)) :
                self.user_data_pdh_pleps_link_rq_std_tm = Salsat.PdhPlepsLinkRqStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 20)) :
                self.user_data_pdh_pleps_rq_fda_pwr = Salsat.PdhPlepsRqFdaPwr(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 24)) :
                self.user_data_pdh_pleps_link_thread_info = Salsat.PdhPlepsLinkThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 25)) :
                self.user_data_pdh_pleps_sat_std_tm = Salsat.PdhPlepsSatStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 27)) :
                self.user_data_pdh_pleps_sat_obt_utc = Salsat.PdhPlepsSatObtUtc(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 28)) :
                self.user_data_pdh_pleps_sat_obt_utc_ns = Salsat.PdhPlepsSatObtUtcNs(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 30)) :
                self.user_data_pdh_pleps_fw_update_tm = Salsat.PdhPlepsFwUpdateTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 31)) :
                self.user_data_pdh_pleps_fw_update_slot_tm = Salsat.PdhPlepsFwUpdateSlotTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 32)) :
                self.user_data_pdh_pleps_fw_update_missingintervalls = Salsat.PdhPlepsFwUpdateMissingintervalls(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 35)) :
                self.user_data_pdh_pleps_info = Salsat.PdhPlepsInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 36)) :
                self.user_data_pdh_pleps_sat_thread_info = Salsat.PdhPlepsSatThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 50)) :
                self.user_data_pdh_pleps_hk_rq_std_tm = Salsat.PdhPlepsHkRqStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 51)) :
                self.user_data_pdh_pleps_rq_pwr_max_v_threshold_tm = Salsat.PdhPlepsRqPwrMaxVThresholdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 52)) :
                self.user_data_pdh_pleps_rq_pwr_max_i_threshold_tm = Salsat.PdhPlepsRqPwrMaxIThresholdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 53)) :
                self.user_data_pdh_pleps_rq_pwr_min_v_threshold_tm = Salsat.PdhPlepsRqPwrMinVThresholdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 54)) :
                self.user_data_pdh_pleps_rq_pwr_min_i_threshold_tm = Salsat.PdhPlepsRqPwrMinIThresholdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 55)) :
                self.user_data_pdh_pleps_switch_state = Salsat.PdhPlepsSwitchState(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 60)) :
                self.user_data_pdh_pleps_sram_check_res = Salsat.PdhPlepsSramCheckRes(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 62)) :
                self.user_data_pdh_pleps_norf_check_res = Salsat.PdhPlepsNorfCheckRes(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 74)) :
                self.user_data_pdh_pleps_hk_thread_info = Salsat.PdhPlepsHkThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 125)) :
                self.user_data_pdh_pleps_sctrl_rq_std_tm = Salsat.PdhPlepsSctrlRqStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 127)) :
                self.user_data_pdh_pleps_sctrl_config_status = Salsat.PdhPlepsSctrlConfigStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 128)) :
                self.user_data_pdh_pleps_sctrl_frame_counter = Salsat.PdhPlepsSctrlFrameCounter(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 145)) :
                self.user_data_pdh_pleps_sctrl_get_fwd_mode = Salsat.PdhPlepsSctrlGetFwdMode(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 149)) :
                self.user_data_pdh_pleps_salsa_ctrl_thread_info = Salsat.PdhPlepsSalsaCtrlThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 150)) :
                self.user_data_pdh_pleps_fda_ctrl_rq_std_tm = Salsat.PdhPlepsFdaCtrlRqStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 174)) :
                self.user_data_pdh_pleps_fda_ctrl_thread_info = Salsat.PdhPlepsFdaCtrlThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 176)) :
                self.user_data_pdh_pleps_ipu_ctrl_status = Salsat.PdhPlepsIpuCtrlStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 177)) :
                self.user_data_pdh_pleps_ipu_frame_counter = Salsat.PdhPlepsIpuFrameCounter(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 199)) :
                self.user_data_pdh_pleps_ipu_ctrl_thread_info = Salsat.PdhPlepsIpuCtrlThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 14)) :
                self.user_data_sat_rtc_registerraw = Salsat.SatRtcRegisterraw(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 13)) :
                self.user_data_sat_rtc_info = Salsat.SatRtcInfo(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 0)) :
                self.user_data_sat_std_tm = Salsat.SatStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 51)) :
                self.user_data_sat_fw_update_slot_tm = Salsat.SatFwUpdateSlotTm(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 10)) :
                self.user_data_sat_obt_utc = Salsat.SatObtUtc(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 12)) :
                self.user_data_sat_rtc_time = Salsat.SatRtcTime(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 11)) :
                self.user_data_sat_obt_utc_ns = Salsat.SatObtUtcNs(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 15)) :
                self.user_data_sat_heater0_info = Salsat.SatHeater0Info(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 16)) :
                self.user_data_sat_heater1_info = Salsat.SatHeater1Info(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 17)) :
                self.user_data_sat_leop_info = Salsat.SatLeopInfo(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 52)) :
                self.user_data_sat_fw_update_missingintervalls = Salsat.SatFwUpdateMissingintervalls(self._io, self, self._root)

            if  ((self.fcid_major == 17) and (self.fcid_sub == 50)) :
                self.user_data_sat_fw_update_tm = Salsat.SatFwUpdateTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 401)) :
                self.user_data_fda_tm_std = Salsat.FdaTmStd(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 400)) :
                self.user_data_fda_tm_imu_rot_rate = Salsat.FdaTmImuRotRate(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 404)) :
                self.user_data_fda_tm_imu_incr_phi = Salsat.FdaTmImuIncrPhi(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 402)) :
                self.user_data_fda_tm_imu_phi = Salsat.FdaTmImuPhi(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 403)) :
                self.user_data_fda_tm_debug = Salsat.FdaTmDebug(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 405)) :
                self.user_data_fda_tm_longterm_mag_x = Salsat.FdaTmLongtermMagX(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 406)) :
                self.user_data_fda_tm_longterm_mag_y = Salsat.FdaTmLongtermMagY(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 407)) :
                self.user_data_fda_tm_longterm_mag_z = Salsat.FdaTmLongtermMagZ(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 408)) :
                self.user_data_fda_tm_longterm_phi_x = Salsat.FdaTmLongtermPhiX(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 409)) :
                self.user_data_fda_tm_longterm_phi_y = Salsat.FdaTmLongtermPhiY(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 410)) :
                self.user_data_fda_tm_longterm_phi_z = Salsat.FdaTmLongtermPhiZ(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 411)) :
                self.user_data_fda_tm_longterm_temps = Salsat.FdaTmLongtermTemps(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 0)) :
                self.user_data_pdh_tm_std = Salsat.PdhTmStd(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 12)) :
                self.user_data_pdh_tm_memextser_8 = Salsat.PdhTmMemextser8(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 13)) :
                self.user_data_pdh_tm_memextser_16 = Salsat.PdhTmMemextser16(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 14)) :
                self.user_data_pdh_tm_memextser_32 = Salsat.PdhTmMemextser32(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 15)) :
                self.user_data_pdh_tm_memextser_64 = Salsat.PdhTmMemextser64(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 16)) :
                self.user_data_pdh_tm_memextser_128 = Salsat.PdhTmMemextser128(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 17)) :
                self.user_data_pdh_tm_memextser_256 = Salsat.PdhTmMemextser256(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 18)) :
                self.user_data_pdh_tm_memextser_512 = Salsat.PdhTmMemextser512(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 19)) :
                self.user_data_pdh_tm_swvers = Salsat.PdhTmSwvers(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 11)) :
                self.user_data_pdh_tm_memextser_std = Salsat.PdhTmMemextserStd(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 20)) :
                self.user_data_pdh_tm_fifo = Salsat.PdhTmFifo(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 21)) :
                self.user_data_pdh_tm_std_add = Salsat.PdhTmStdAdd(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 23)) :
                self.user_data_pdh_tm_extd = Salsat.PdhTmExtd(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 1)) :
                self.user_data_pdh_tm_std_a = Salsat.PdhTmStdA(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 25)) :
                self.user_data_pdh_tm_std_add_a = Salsat.PdhTmStdAddA(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 24)) :
                self.user_data_pdh_tm_rtc = Salsat.PdhTmRtc(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 26)) :
                self.user_data_pdh_tm_com = Salsat.PdhTmCom(self._io, self, self._root)

            if  ((self.fcid_major == 47) and (self.fcid_sub == 27)) :
                self.user_data_pdh_tm_ack = Salsat.PdhTmAck(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 0)) :
                self.user_data_rw0_tm_std = Salsat.Rw0TmStd(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 1)) :
                self.user_data_rw0_tm_cntrl = Salsat.Rw0TmCntrl(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 100)) :
                self.user_data_rw1_tm_std = Salsat.Rw1TmStd(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 200)) :
                self.user_data_rw2_tm_std = Salsat.Rw2TmStd(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 210)) :
                self.user_data_rw2_tm_eeprom = Salsat.Rw2TmEeprom(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 12)) :
                self.user_data_rw0_tm_press = Salsat.Rw0TmPress(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 112)) :
                self.user_data_rw1_tm_press = Salsat.Rw1TmPress(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 212)) :
                self.user_data_rw2_tm_press = Salsat.Rw2TmPress(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 14)) :
                self.user_data_rw0_tm_cstm_0 = Salsat.Rw0TmCstm0(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 114)) :
                self.user_data_rw1_tm_cstm_0 = Salsat.Rw1TmCstm0(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 214)) :
                self.user_data_rw2_tm_cstm_0 = Salsat.Rw2TmCstm0(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 13)) :
                self.user_data_rw0_tm_swvers = Salsat.Rw0TmSwvers(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 113)) :
                self.user_data_rw1_tm_swvers = Salsat.Rw1TmSwvers(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 213)) :
                self.user_data_rw2_tm_swvers = Salsat.Rw2TmSwvers(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 11)) :
                self.user_data_rw0_tm_sram = Salsat.Rw0TmSram(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 110)) :
                self.user_data_rw1_tm_eeprom = Salsat.Rw1TmEeprom(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 10)) :
                self.user_data_rw0_tm_eeprom = Salsat.Rw0TmEeprom(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 111)) :
                self.user_data_rw1_tm_sram = Salsat.Rw1TmSram(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 211)) :
                self.user_data_rw2_tm_sram = Salsat.Rw2TmSram(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 101)) :
                self.user_data_rw1_tm_cntrl = Salsat.Rw1TmCntrl(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 201)) :
                self.user_data_rw2_tm_cntrl = Salsat.Rw2TmCntrl(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 16)) :
                self.user_data_rw0_tm_cstm_2 = Salsat.Rw0TmCstm2(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 116)) :
                self.user_data_rw1_tm_cstm_2 = Salsat.Rw1TmCstm2(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 216)) :
                self.user_data_rw2_tm_cstm_2 = Salsat.Rw2TmCstm2(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 17)) :
                self.user_data_rw0_tm_cstm_3 = Salsat.Rw0TmCstm3(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 218)) :
                self.user_data_rw2_tm_cstm_4 = Salsat.Rw2TmCstm4(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 117)) :
                self.user_data_rw1_tm_cstm_3 = Salsat.Rw1TmCstm3(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 217)) :
                self.user_data_rw2_tm_cstm_3 = Salsat.Rw2TmCstm3(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 18)) :
                self.user_data_rw0_tm_cstm_4 = Salsat.Rw0TmCstm4(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 118)) :
                self.user_data_rw1_tm_cstm_4 = Salsat.Rw1TmCstm4(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 15)) :
                self.user_data_rw0_tm_cstm_1 = Salsat.Rw0TmCstm1(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 115)) :
                self.user_data_rw1_tm_cstm_1 = Salsat.Rw1TmCstm1(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 215)) :
                self.user_data_rw2_tm_cstm_1 = Salsat.Rw2TmCstm1(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 2)) :
                self.user_data_rw0_tm_std_a = Salsat.Rw0TmStdA(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 219)) :
                self.user_data_rw2_tm_std_b = Salsat.Rw2TmStdB(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 119)) :
                self.user_data_rw1_tm_std_b = Salsat.Rw1TmStdB(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 19)) :
                self.user_data_rw0_tm_std_b = Salsat.Rw0TmStdB(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 202)) :
                self.user_data_rw2_tm_std_a = Salsat.Rw2TmStdA(self._io, self, self._root)

            if  ((self.fcid_major == 51) and (self.fcid_sub == 102)) :
                self.user_data_rw1_tm_std_a = Salsat.Rw1TmStdA(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 0)) :
                self.user_data_pdh_tm_slk_sat = Salsat.PdhTmSlkSat(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 1)) :
                self.user_data_pdh_tm_slk_sat2sat = Salsat.PdhTmSlkSat2sat(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 2)) :
                self.user_data_pdh_tm_slk_std = Salsat.PdhTmSlkStd(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 20)) :
                self.user_data_pdh_tm_sap_std = Salsat.PdhTmSapStd(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 24)) :
                self.user_data_pdh_tm_sap_eeprom_sat2sat = Salsat.PdhTmSapEepromSat2sat(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 21)) :
                self.user_data_pdh_tm_sap_sram_sat = Salsat.PdhTmSapSramSat(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 22)) :
                self.user_data_pdh_tm_sap_eeprom_sat = Salsat.PdhTmSapEepromSat(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 23)) :
                self.user_data_pdh_tm_sap_sram_sat2sat = Salsat.PdhTmSapSramSat2sat(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 25)) :
                self.user_data_pdh_tm_sap_pltu = Salsat.PdhTmSapPltu(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 40)) :
                self.user_data_pdh_tm_laynet_sram_tle = Salsat.PdhTmLaynetSramTle(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 41)) :
                self.user_data_pdh_tm_laynet_eeprom_tle = Salsat.PdhTmLaynetEepromTle(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 45)) :
                self.user_data_pdh_tm_laynet_sram_par = Salsat.PdhTmLaynetSramPar(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 47)) :
                self.user_data_pdh_tm_laynet_std = Salsat.PdhTmLaynetStd(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 42)) :
                self.user_data_pdh_tm_laynet_sgp = Salsat.PdhTmLaynetSgp(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 43)) :
                self.user_data_pdh_tm_laynet_cost = Salsat.PdhTmLaynetCost(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 44)) :
                self.user_data_pdh_tm_laynet_routing = Salsat.PdhTmLaynetRouting(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 46)) :
                self.user_data_pdh_tm_laynet_eeprom_par = Salsat.PdhTmLaynetEepromPar(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 60)) :
                self.user_data_pdh_tm_laytra_std = Salsat.PdhTmLaytraStd(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 70)) :
                self.user_data_pdh_tm_layses_std = Salsat.PdhTmLaysesStd(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 80)) :
                self.user_data_pdh_tm_laypre_std = Salsat.PdhTmLaypreStd(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 90)) :
                self.user_data_pdh_tm_layapp_std = Salsat.PdhTmLayappStd(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 48)) :
                self.user_data_pdh_tm_laynet_std_0 = Salsat.PdhTmLaynetStd0(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 98)) :
                self.user_data_pdh_tm_layapp_std_0 = Salsat.PdhTmLayappStd0(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 61)) :
                self.user_data_pdh_tm_laytra_std_0 = Salsat.PdhTmLaytraStd0(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 81)) :
                self.user_data_pdh_tm_laypre_std_0 = Salsat.PdhTmLaypreStd0(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 71)) :
                self.user_data_pdh_tm_layses_std_0 = Salsat.PdhTmLaysesStd0(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 26)) :
                self.user_data_pdh_tm_sap_sram_sat_a = Salsat.PdhTmSapSramSatA(self._io, self, self._root)

            if  ((self.fcid_major == 48) and (self.fcid_sub == 27)) :
                self.user_data_pdh_tm_sap_eeprom_sat_a = Salsat.PdhTmSapEepromSatA(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 11)) :
                self.user_data_com0_tm_eeprom = Salsat.Com0TmEeprom(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 12)) :
                self.user_data_com0_tm_sram = Salsat.Com0TmSram(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 100)) :
                self.user_data_com1_tm_std = Salsat.Com1TmStd(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 413)) :
                self.user_data_com4_tm_fec = Salsat.Com4TmFec(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 110)) :
                self.user_data_com1_tm_com = Salsat.Com1TmCom(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 411)) :
                self.user_data_com4_tm_eeprom = Salsat.Com4TmEeprom(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 412)) :
                self.user_data_com4_tm_sram = Salsat.Com4TmSram(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 101)) :
                self.user_data_com1_tm_trx = Salsat.Com1TmTrx(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 15)) :
                self.user_data_com0_tm_arq = Salsat.Com0TmArq(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 415)) :
                self.user_data_com4_tm_arq = Salsat.Com4TmArq(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 115)) :
                self.user_data_com1_tm_arq = Salsat.Com1TmArq(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 10)) :
                self.user_data_com0_tm_com = Salsat.Com0TmCom(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 410)) :
                self.user_data_com4_tm_com = Salsat.Com4TmCom(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 111)) :
                self.user_data_com1_tm_eeprom = Salsat.Com1TmEeprom(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 13)) :
                self.user_data_com0_tm_fec = Salsat.Com0TmFec(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 113)) :
                self.user_data_com1_tm_fec = Salsat.Com1TmFec(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 14)) :
                self.user_data_com0_tm_swvers = Salsat.Com0TmSwvers(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 114)) :
                self.user_data_com1_tm_swvers = Salsat.Com1TmSwvers(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 414)) :
                self.user_data_com4_tm_swvers = Salsat.Com4TmSwvers(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 112)) :
                self.user_data_com1_tm_sram = Salsat.Com1TmSram(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 0)) :
                self.user_data_com0_tm_std = Salsat.Com0TmStd(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 400)) :
                self.user_data_com4_tm_std = Salsat.Com4TmStd(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 401)) :
                self.user_data_com4_tm_trx = Salsat.Com4TmTrx(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 1)) :
                self.user_data_com0_tm_trx = Salsat.Com0TmTrx(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 16)) :
                self.user_data_com0_tm_rndpkt = Salsat.Com0TmRndpkt(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 116)) :
                self.user_data_com1_tm_rndpkt = Salsat.Com1TmRndpkt(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 416)) :
                self.user_data_com4_tm_rndpkt = Salsat.Com4TmRndpkt(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 17)) :
                self.user_data_com0_tm_mem_32 = Salsat.Com0TmMem32(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 117)) :
                self.user_data_com1_tm_mem_32 = Salsat.Com1TmMem32(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 417)) :
                self.user_data_com4_tm_mem_32 = Salsat.Com4TmMem32(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 420)) :
                self.user_data_com4_tm_com_extd = Salsat.Com4TmComExtd(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 2)) :
                self.user_data_com0_tm_std_a = Salsat.Com0TmStdA(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 102)) :
                self.user_data_com1_tm_std_a = Salsat.Com1TmStdA(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 402)) :
                self.user_data_com4_tm_std_a = Salsat.Com4TmStdA(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 21)) :
                self.user_data_com0_tm_rtc = Salsat.Com0TmRtc(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 121)) :
                self.user_data_com1_tm_rtc = Salsat.Com1TmRtc(self._io, self, self._root)

            if  ((self.fcid_major == 54) and (self.fcid_sub == 421)) :
                self.user_data_com4_tm_rtc = Salsat.Com4TmRtc(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 10)) :
                self.user_data_eps_all_adc = Salsat.EpsAllAdc(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 11)) :
                self.user_data_eps_int_adc = Salsat.EpsIntAdc(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 12)) :
                self.user_data_eps_switch_state = Salsat.EpsSwitchState(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 250)) :
                self.user_data_eps_thread_info = Salsat.EpsThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 0)) :
                self.user_data_eps_std_tm = Salsat.EpsStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 1)) :
                self.user_data_eps_ext_tm_a = Salsat.EpsExtTmA(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 2)) :
                self.user_data_eps_ext_tm_b = Salsat.EpsExtTmB(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 13)) :
                self.user_data_eps_rawadc0values = Salsat.EpsRawadc0values(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 14)) :
                self.user_data_eps_rawadc1values = Salsat.EpsRawadc1values(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 15)) :
                self.user_data_eps_rawadc2values = Salsat.EpsRawadc2values(self._io, self, self._root)

            if  ((self.fcid_major == 9) and (self.fcid_sub == 16)) :
                self.user_data_eps_rawthm = Salsat.EpsRawthm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 284)) :
                self.user_data_salsa_fw_std_tm = Salsat.SalsaFwStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 285)) :
                self.user_data_salsa_fw_update_tm = Salsat.SalsaFwUpdateTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 286)) :
                self.user_data_salsa_fw_update_slot_tm = Salsat.SalsaFwUpdateSlotTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 287)) :
                self.user_data_salsa_fw_update_missingintervalls = Salsat.SalsaFwUpdateMissingintervalls(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 311)) :
                self.user_data_salsa_tm_flash_status = Salsat.SalsaTmFlashStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 277)) :
                self.user_data_salsa_tm_pmu_regs_valid = Salsat.SalsaTmPmuRegsValid(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 265)) :
                self.user_data_salsa_tm_boot_status = Salsat.SalsaTmBootStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 310)) :
                self.user_data_salsa_tm_pmu_status = Salsat.SalsaTmPmuStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 264)) :
                self.user_data_salsa_tm_interface_usage = Salsat.SalsaTmInterfaceUsage(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 366)) :
                self.user_data_salsa_tm_rq_lms_tm = Salsat.SalsaTmRqLmsTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 347)) :
                self.user_data_salsa_tm_get_lms_register = Salsat.SalsaTmGetLmsRegister(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 281)) :
                self.user_data_salsa_tm_std_tm = Salsat.SalsaTmStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 318)) :
                self.user_data_salsa_tm_get_record_info = Salsat.SalsaTmGetRecordInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 350)) :
                self.user_data_salsa_tm_lms_register = Salsat.SalsaTmLmsRegister(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 266)) :
                self.user_data_salsa_tm_rq_max_v_threshold = Salsat.SalsaTmRqMaxVThreshold(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 267)) :
                self.user_data_salsa_tm_rq_max_i_threshold = Salsat.SalsaTmRqMaxIThreshold(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 268)) :
                self.user_data_salsa_tm_rq_min_v_threshold = Salsat.SalsaTmRqMinVThreshold(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 269)) :
                self.user_data_salsa_tm_rq_min_i_threshold = Salsat.SalsaTmRqMinIThreshold(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 271)) :
                self.user_data_salsa_tm_read_lms_regs = Salsat.SalsaTmReadLmsRegs(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 272)) :
                self.user_data_salsa_tm_read_lms_calib = Salsat.SalsaTmReadLmsCalib(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 273)) :
                self.user_data_salsa_tm_read_clk_regs = Salsat.SalsaTmReadClkRegs(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 302)) :
                self.user_data_salsa_tm_read_missing_frames = Salsat.SalsaTmReadMissingFrames(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 308)) :
                self.user_data_salsa_tm_upload_status = Salsat.SalsaTmUploadStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 303)) :
                self.user_data_salsa_updates_std_tm = Salsat.SalsaUpdatesStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 304)) :
                self.user_data_salsa_updates_tm = Salsat.SalsaUpdatesTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 305)) :
                self.user_data_salsa_updates_slot_tm = Salsat.SalsaUpdatesSlotTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 306)) :
                self.user_data_salsa_updates_missingintervalls = Salsat.SalsaUpdatesMissingintervalls(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 299)) :
                self.user_data_salsa_info = Salsat.SalsaInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 300)) :
                self.user_data_salsa_sat_thread_info = Salsat.SalsaSatThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 200)) :
                self.user_data_salsa_link_std_tm = Salsat.SalsaLinkStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 225)) :
                self.user_data_salsa_link_thread_info = Salsat.SalsaLinkThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 283)) :
                self.user_data_salsa_hk_thread_info = Salsat.SalsaHkThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 339)) :
                self.user_data_salsa_fpga_thread_info = Salsat.SalsaFpgaThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 360)) :
                self.user_data_salsa_lms_thread_info = Salsat.SalsaLmsThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 321)) :
                self.user_data_salsa_tm_get_fft_recording_status = Salsat.SalsaTmGetFftRecordingStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 280)) :
                self.user_data_salsa_tm_get_boot_configs = Salsat.SalsaTmGetBootConfigs(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 279)) :
                self.user_data_salsa_tm_read_pmu_page = Salsat.SalsaTmReadPmuPage(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 278)) :
                self.user_data_salsa_tm_read_flash_page = Salsat.SalsaTmReadFlashPage(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 322)) :
                self.user_data_salsa_tm_get_fft_crc_value = Salsat.SalsaTmGetFftCrcValue(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 263)) :
                self.user_data_salsa_tm_ina_status = Salsat.SalsaTmInaStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 256)) :
                self.user_data_salsa_tm_get_ina_stm_status = Salsat.SalsaTmGetInaStmStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 257)) :
                self.user_data_salsa_tm_get_ina_fpga1v2_status = Salsat.SalsaTmGetInaFpga1v2Status(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 258)) :
                self.user_data_salsa_tm_get_ina_fpga3v3_status = Salsat.SalsaTmGetInaFpga3v3Status(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 259)) :
                self.user_data_salsa_tm_get_ina_lms_status = Salsat.SalsaTmGetInaLmsStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 260)) :
                self.user_data_salsa_tm_get_ina_ddr_status = Salsat.SalsaTmGetInaDdrStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 261)) :
                self.user_data_salsa_tm_get_ina_pmu_status = Salsat.SalsaTmGetInaPmuStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 262)) :
                self.user_data_salsa_tm_get_ina_flash_status = Salsat.SalsaTmGetInaFlashStatus(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 323)) :
                self.user_data_salsa_tm_get_recording_timestamps = Salsat.SalsaTmGetRecordingTimestamps(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 324)) :
                self.user_data_salsa_tm_get_recording_datetime = Salsat.SalsaTmGetRecordingDatetime(self._io, self, self._root)

            if  ((self.fcid_major == 3) and (self.fcid_sub == 325)) :
                self.user_data_salsa_tm_get_fft_frame_data_length = Salsat.SalsaTmGetFftFrameDataLength(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 0)) :
                self.user_data_adcs_std_tm = Salsat.AdcsStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 1)) :
                self.user_data_adcs_ext_tm_a = Salsat.AdcsExtTmA(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 300)) :
                self.user_data_adcs_cal_dcm_mfrtosat_g1_to_4 = Salsat.AdcsCalDcmMfrtosatG1To4(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 304)) :
                self.user_data_adcs_cal_dcm_mfrtosat_g5_to_8 = Salsat.AdcsCalDcmMfrtosatG5To8(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 308)) :
                self.user_data_adcs_cal_dcm_mfrtosat_mfs1_to_4 = Salsat.AdcsCalDcmMfrtosatMfs1To4(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 312)) :
                self.user_data_adcs_cal_dcm_mfrtosat_suse1_to_3 = Salsat.AdcsCalDcmMfrtosatSuse1To3(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 315)) :
                self.user_data_adcs_cal_dcm_mfrtosat_suse4_to_6 = Salsat.AdcsCalDcmMfrtosatSuse4To6(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 318)) :
                self.user_data_adcs_cal_dcm_mfrtosat_rwa = Salsat.AdcsCalDcmMfrtosatRwa(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 319)) :
                self.user_data_adcs_cal_dcm_mfrtosat_mata = Salsat.AdcsCalDcmMfrtosatMata(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 320)) :
                self.user_data_adcs_cal_offset_g1_to_8 = Salsat.AdcsCalOffsetG1To8(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 328)) :
                self.user_data_adcs_cal_offset_mfs1_to_4 = Salsat.AdcsCalOffsetMfs1To4(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 332)) :
                self.user_data_adcs_cal_threshold_suse1_to_6 = Salsat.AdcsCalThresholdSuse1To6(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 338)) :
                self.user_data_adcs_cal_darkcurrent_suse1_to_6 = Salsat.AdcsCalDarkcurrentSuse1To6(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 344)) :
                self.user_data_adcs_cal_tcomp_g1 = Salsat.AdcsCalTcompG1(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 345)) :
                self.user_data_adcs_cal_tcomp_g2 = Salsat.AdcsCalTcompG2(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 346)) :
                self.user_data_adcs_cal_tcomp_g3 = Salsat.AdcsCalTcompG3(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 347)) :
                self.user_data_adcs_cal_tcomp_g4 = Salsat.AdcsCalTcompG4(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 348)) :
                self.user_data_adcs_cal_tcomp_g5 = Salsat.AdcsCalTcompG5(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 349)) :
                self.user_data_adcs_cal_tcomp_g6 = Salsat.AdcsCalTcompG6(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 350)) :
                self.user_data_adcs_cal_tcomp_g7 = Salsat.AdcsCalTcompG7(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 351)) :
                self.user_data_adcs_cal_tcomp_g8 = Salsat.AdcsCalTcompG8(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 352)) :
                self.user_data_adcs_cal_mapping_suse1 = Salsat.AdcsCalMappingSuse1(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 353)) :
                self.user_data_adcs_cal_mapping_suse2 = Salsat.AdcsCalMappingSuse2(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 354)) :
                self.user_data_adcs_cal_mapping_suse3 = Salsat.AdcsCalMappingSuse3(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 355)) :
                self.user_data_adcs_cal_mapping_suse4 = Salsat.AdcsCalMappingSuse4(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 356)) :
                self.user_data_adcs_cal_mapping_suse5 = Salsat.AdcsCalMappingSuse5(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 357)) :
                self.user_data_adcs_cal_mapping_suse6 = Salsat.AdcsCalMappingSuse6(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 10)) :
                self.user_data_adcs_att_dcm_ecitosat_optimal = Salsat.AdcsAttDcmEcitosatOptimal(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 11)) :
                self.user_data_adcs_att_dcm_ecitotgt = Salsat.AdcsAttDcmEcitotgt(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 31)) :
                self.user_data_adcs_sensea_ga_std_tm = Salsat.AdcsSenseaGaStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 32)) :
                self.user_data_adcs_sensea_mfsa_std_tm = Salsat.AdcsSenseaMfsaStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 33)) :
                self.user_data_adcs_sensea_susea_std_tm = Salsat.AdcsSenseaSuseaStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 34)) :
                self.user_data_adcs_acta_rwa_std_tm = Salsat.AdcsActaRwaStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 35)) :
                self.user_data_adcs_acta_mata_std_tm = Salsat.AdcsActaMataStdTm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 50)) :
                self.user_data_adcs_sense_g1_omega = Salsat.AdcsSenseG1Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 51)) :
                self.user_data_adcs_sense_g2_omega = Salsat.AdcsSenseG2Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 52)) :
                self.user_data_adcs_sense_g3_omega = Salsat.AdcsSenseG3Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 53)) :
                self.user_data_adcs_sense_g4_omega = Salsat.AdcsSenseG4Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 54)) :
                self.user_data_adcs_sense_g5_omega = Salsat.AdcsSenseG5Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 55)) :
                self.user_data_adcs_sense_g6_omega = Salsat.AdcsSenseG6Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 56)) :
                self.user_data_adcs_sense_g7_omega = Salsat.AdcsSenseG7Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 57)) :
                self.user_data_adcs_sense_g8_omega = Salsat.AdcsSenseG8Omega(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 58)) :
                self.user_data_adcs_sense_mfs1_b = Salsat.AdcsSenseMfs1B(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 59)) :
                self.user_data_adcs_sense_mfs2_b = Salsat.AdcsSenseMfs2B(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 60)) :
                self.user_data_adcs_sense_mfs3_b = Salsat.AdcsSenseMfs3B(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 61)) :
                self.user_data_adcs_sense_mfs4_b = Salsat.AdcsSenseMfs4B(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 62)) :
                self.user_data_adcs_sense_suse1_d = Salsat.AdcsSenseSuse1D(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 63)) :
                self.user_data_adcs_sense_suse2_d = Salsat.AdcsSenseSuse2D(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 64)) :
                self.user_data_adcs_sense_suse3_d = Salsat.AdcsSenseSuse3D(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 65)) :
                self.user_data_adcs_sense_suse4_d = Salsat.AdcsSenseSuse4D(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 66)) :
                self.user_data_adcs_sense_suse5_d = Salsat.AdcsSenseSuse5D(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 67)) :
                self.user_data_adcs_sense_suse6_d = Salsat.AdcsSenseSuse6D(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 87)) :
                self.user_data_adcs_acta_mata_loop_vec = Salsat.AdcsActaMataLoopVec(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 86)) :
                self.user_data_adcs_acta_rwa_loop_vec = Salsat.AdcsActaRwaLoopVec(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 88)) :
                self.user_data_adcs_act_rwx_info = Salsat.AdcsActRwxInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 89)) :
                self.user_data_adcs_act_rwy_info = Salsat.AdcsActRwyInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 90)) :
                self.user_data_adcs_act_rwz_info = Salsat.AdcsActRwzInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 91)) :
                self.user_data_adcs_act_matx_info = Salsat.AdcsActMatxInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 92)) :
                self.user_data_adcs_act_maty_info = Salsat.AdcsActMatyInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 93)) :
                self.user_data_adcs_act_matz_info = Salsat.AdcsActMatzInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 37)) :
                self.user_data_adcs_sense_all_vec = Salsat.AdcsSenseAllVec(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 38)) :
                self.user_data_adcs_g_all_info = Salsat.AdcsGAllInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 30)) :
                self.user_data_adcs_thm = Salsat.AdcsThm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 39)) :
                self.user_data_adcs_mfs_all_info = Salsat.AdcsMfsAllInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 40)) :
                self.user_data_adcs_suse_all_info = Salsat.AdcsSuseAllInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 100)) :
                self.user_data_adcs_env_sgp4 = Salsat.AdcsEnvSgp4(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 101)) :
                self.user_data_adcs_env_igrf = Salsat.AdcsEnvIgrf(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 102)) :
                self.user_data_adcs_env_sun = Salsat.AdcsEnvSun(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 12)) :
                self.user_data_adcs_att_dcm_sattotgt = Salsat.AdcsAttDcmSattotgt(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 36)) :
                self.user_data_adcs_act_rw_tm = Salsat.AdcsActRwTm(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 17)) :
                self.user_data_adcs_ctrl_parameter_info = Salsat.AdcsCtrlParameterInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 25)) :
                self.user_data_adcs_cal_g_offset_info = Salsat.AdcsCalGOffsetInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 13)) :
                self.user_data_adcs_att_target_info = Salsat.AdcsAttTargetInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 14)) :
                self.user_data_adcs_att_pointing_info = Salsat.AdcsAttPointingInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 18)) :
                self.user_data_adcs_ctrl_bdot_info = Salsat.AdcsCtrlBdotInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 19)) :
                self.user_data_adcs_ctrl_bdot_output = Salsat.AdcsCtrlBdotOutput(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 21)) :
                self.user_data_adcs_ctrl_pd_output = Salsat.AdcsCtrlPdOutput(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 401)) :
                self.user_data_adcs_cmdfifoinfo = Salsat.AdcsCmdfifoinfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 402)) :
                self.user_data_adcs_rwcmdfifoinfo = Salsat.AdcsRwcmdfifoinfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 400)) :
                self.user_data_adcs_thread_info = Salsat.AdcsThreadInfo(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 103)) :
                self.user_data_adcs_env_tle = Salsat.AdcsEnvTle(self._io, self, self._root)

            if  ((self.fcid_major == 0) and (self.fcid_sub == 15)) :
                self.user_data_adcs_attdet_determination_info = Salsat.AdcsAttdetDeterminationInfo(self._io, self, self._root)

            if  ((self.fcid_major == 58) and (self.fcid_sub == 1)) :
                self.user_data_linkgs_tm_std = Salsat.LinkgsTmStd(self._io, self, self._root)

            if  ((self.fcid_major == 58) and (self.fcid_sub == 2)) :
                self.user_data_linkgs_tm_clientconnected = Salsat.LinkgsTmClientconnected(self._io, self, self._root)

            if  ((self.fcid_major == 58) and (self.fcid_sub == 3)) :
                self.user_data_linkgs_tm_clientdisconnected = Salsat.LinkgsTmClientdisconnected(self._io, self, self._root)

            if  ((self.fcid_major == 58) and (self.fcid_sub == 4)) :
                self.user_data_linkgs_tm_state = Salsat.LinkgsTmState(self._io, self, self._root)

            if  ((self.fcid_major == 58) and (self.fcid_sub == 5)) :
                self.user_data_linkgs_tm_std_a = Salsat.LinkgsTmStdA(self._io, self, self._root)



    class Rw1TmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()
            self.rw1_pget_resetcnt = self._io.read_u2le()
            self.rw1_pget_fsmmainstate = self._io.read_u1()
            self.rw1_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtroff = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mvlimit = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_mtrovercur = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_faultgyro0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_faultgyro1 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycurmtr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycurwde = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalycur5v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvltmtr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v2 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt5v = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalyvlt3v3mcu = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalytmppwr = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalygyro0 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalygyro1 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_anomalypress = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.rw1_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw1_pget_curmtr = self._io.read_u2le()
            self.rw1_pget_curwde = self._io.read_u2le()
            self.rw1_pget_cur3v3 = self._io.read_u2le()
            self.rw1_pget_cur5v = self._io.read_u2le()
            self.rw1_pget_vltmtr = self._io.read_u2le()
            self.rw1_pget_vlt3v2 = self._io.read_u2le()
            self.rw1_pget_vlt5v = self._io.read_u2le()
            self.rw1_pget_vlt3v3 = self._io.read_u2le()
            self.rw1_pget_vlt3v3mcu = self._io.read_u2le()
            self.thm_rw1_pget_tmppwr = self._io.read_u2le()
            self.thm_rw1_pget_tmppresssens = self._io.read_u4le()
            self.thm_rw1_pget_tmpgyro1 = self._io.read_s2le()
            self.rw1_pget_vltgyro0zref = self._io.read_u2le()
            self.rw1_pget_vltgyro0z = self._io.read_u2le()
            self.rw1_pget_rategyro1x = self._io.read_s2le()
            self.rw1_pget_rategyro1y = self._io.read_s2le()
            self.rw1_pget_rategyro1z = self._io.read_s2le()
            self.rw1_pget_press = self._io.read_u4le()


    class PdhPlepsSctrlGetFwdMode(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_sctrl_fwd_mode = self._io.read_u1()


    class FdaTmLongtermTemps(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.fda_pget_device = self._io.read_u1()
            self.fda_pget_longterm_temp_x = self._io.read_s1()
            self.fda_pget_longterm_temp_y = self._io.read_s1()
            self.fda_pget_longterm_temp_z = self._io.read_s1()
            self.fda_pget_longterm_temp_imu = self._io.read_s1()


    class SalsaTmFlashStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_flash1_status = self._io.read_u1()
            self.salsa_pget_flash2_status = self._io.read_u1()
            self.salsa_pget_flash1_be_in_progress = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_flash2_be_in_progress = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_flash1_se_in_progress = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_flash2_se_in_progress = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.salsa_pget_fpga_boot_slot = self._io.read_u1()


    class AdcsActRwyInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_rwy_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwy_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwy_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwy_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwy_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_rwy_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactstaterwy = self._io.read_u1()


    class Com1TmCom(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com1_pget_systime = self._io.read_u4le()
            self.com1_pget_txltuhdrdstid = self._io.read_u1()
            self.com1_pget_txltuhdrsrcid = self._io.read_u1()
            self.com1_pget_txltuhdrfrcnttx = self._io.read_u1()
            self.com1_pget_txltuhdrfrcntrx = self._io.read_u1()
            self.com1_pget_txltuhdrsnr = self._io.read_u1()
            self.com1_pget_txltuhdraitypesrc = self._io.read_u1()
            self.com1_pget_txltuhdraitypedst = self._io.read_u1()
            self.com1_pget_txltuhdrdfcid = self._io.read_u1()
            self.com1_pget_txltuhdrfrlength = self._io.read_u2le()
            self.com1_pget_txltuhdrcrc13 = self._io.read_u2le()
            self.com1_pget_txltuhdrcrc5 = self._io.read_u1()
            self.com1_pget_txltuhdrudfl1 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_txltuhdrhailing = self._io.read_bits_int_be(1) != 0
            self.com1_pget_txltuhdrrqbch = self._io.read_bits_int_be(1) != 0
            self.com1_pget_txltuhdrpdutypeid = self._io.read_bits_int_be(1) != 0
            self.com1_pget_txltuhdrarq = self._io.read_bits_int_be(1) != 0
            self.com1_pget_txltuhdrcaller = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_rxltuhdrdstid = self._io.read_u1()
            self.com1_pget_rxltuhdrsrcid = self._io.read_u1()
            self.com1_pget_rxltuhdrfrcnttx = self._io.read_u1()
            self.com1_pget_rxltuhdrfrcntrx = self._io.read_u1()
            self.com1_pget_rxltuhdrsnr = self._io.read_u1()
            self.com1_pget_rxltuhdraitypesrc = self._io.read_u1()
            self.com1_pget_rxltuhdraitypedst = self._io.read_u1()
            self.com1_pget_rxltuhdrdfcid = self._io.read_u1()
            self.com1_pget_rxltuhdrfrlength = self._io.read_u2le()
            self.com1_pget_rxltuhdrcrc13 = self._io.read_u2le()
            self.com1_pget_rxltuhdrcrc5 = self._io.read_u1()
            self.com1_pget_rxltuhdrudfl1 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxltuhdrhailing = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxltuhdrrqbch = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxltuhdrpdutypeid = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxltuhdrarq = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxltuhdrcaller = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_ltudecerrnum = self._io.read_u2le()
            self.com1_pget_sdutxfifonum = self._io.read_u1()
            self.com1_pget_sessiontime = self._io.read_u2le()
            self.com1_pget_fsmcomstate = self._io.read_u1()
            self.com1_pget_ltuhdrdec = self._io.read_bits_int_be(1) != 0
            self.com1_pget_pdufirstblockdec = self._io.read_bits_int_be(1) != 0
            self.com1_pget_sduhdrdec = self._io.read_bits_int_be(1) != 0
            self.com1_pget_lturxcomplete = self._io.read_bits_int_be(1) != 0
            self.com1_pget_ltuhdrdecerr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_ltuhdrrxerr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_ltuhdrdeclock = self._io.read_bits_int_be(1) != 0
            self.com1_pget_pdudecerr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_burst = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rangevalid = self._io.read_bits_int_be(1) != 0
            self.com1_pget_sdutxfifooverrun = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxpducrcerr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_rxsducrcerr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_collectbcherr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_chmon = self._io.read_bits_int_be(1) != 0
            self.com1_pget_ltuerr = self._io.read_bits_int_be(1) != 0
            self.com1_pget_tddmode = self._io.read_bits_int_be(1) != 0
            self.com1_pget_generaltxlock = self._io.read_bits_int_be(1) != 0
            self.com1_pget_spktmodetxlock = self._io.read_bits_int_be(1) != 0
            self.com1_pget_ack = self._io.read_bits_int_be(1) != 0
            self.com1_pget_pktloss = self._io.read_bits_int_be(1) != 0
            self.com1_pget_sessionest = self._io.read_bits_int_be(1) != 0
            self.com1_pget_sessionopened = self._io.read_bits_int_be(1) != 0
            self.com1_pget_syncnewburst = self._io.read_bits_int_be(1) != 0
            self.com1_pget_syncerrnumvalid = self._io.read_bits_int_be(1) != 0
            self.com1_pget_syncburstnumvalid = self._io.read_bits_int_be(1) != 0
            self.com1_pget_syncchainnumvalid = self._io.read_bits_int_be(1) != 0
            self.com1_pget_extsrcid = self._io.read_bits_int_be(1) != 0
            self.com1_pget_answpending = self._io.read_bits_int_be(1) != 0
            self.com1_pget_arqsyncloss = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com1_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com1_pget_range = self._io.read_u4le()
            self.com1_pget_rssirx = self._io.read_u2le()
            self.com1_pget_cd = self._io.read_u2le()


    class AdcsCalThresholdSuse1To6(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_suse1currentthreshold = self._io.read_u2le()
            self.adcs_pget_suse1psdmaxxthreshold = self._io.read_u2le()
            self.adcs_pget_suse1psdmaxythreshold = self._io.read_u2le()
            self.adcs_pget_suse2currentthreshold = self._io.read_u2le()
            self.adcs_pget_suse2psdmaxxthreshold = self._io.read_u2le()
            self.adcs_pget_suse2psdmaxythreshold = self._io.read_u2le()
            self.adcs_pget_suse3currentthreshold = self._io.read_u2le()
            self.adcs_pget_suse3psdmaxxthreshold = self._io.read_u2le()
            self.adcs_pget_suse3psdmaxythreshold = self._io.read_u2le()
            self.adcs_pget_suse4currentthreshold = self._io.read_u2le()
            self.adcs_pget_suse4psdmaxxthreshold = self._io.read_u2le()
            self.adcs_pget_suse4psdmaxythreshold = self._io.read_u2le()
            self.adcs_pget_suse5currentthreshold = self._io.read_u2le()
            self.adcs_pget_suse5psdmaxxthreshold = self._io.read_u2le()
            self.adcs_pget_suse5psdmaxythreshold = self._io.read_u2le()
            self.adcs_pget_suse6currentthreshold = self._io.read_u2le()
            self.adcs_pget_suse6psdmaxxthreshold = self._io.read_u2le()
            self.adcs_pget_suse6psdmaxythreshold = self._io.read_u2le()


    class PdhTmLaynetSramTle(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_networksatnum = self._io.read_u1()
            self.slkpdh_pget_networktlesatnumsram = self._io.read_u4le()
            self.slkpdh_pget_networktleepochyrsram = self._io.read_u1()
            self.slkpdh_pget_networktleepochdaysfldsram = self._io.read_u8le()
            self.slkpdh_pget_networktleepochdaysexpsram = self._io.read_s1()
            self.slkpdh_pget_networktlendotfldsram = self._io.read_s4le()
            self.slkpdh_pget_networktlendotexpsram = self._io.read_s1()
            self.slkpdh_pget_networktlenddotfldsram = self._io.read_s4le()
            self.slkpdh_pget_networktlenddotexpsram = self._io.read_s1()
            self.slkpdh_pget_networktlebstarfldsram = self._io.read_s4le()
            self.slkpdh_pget_networktlebstarexpsram = self._io.read_s1()
            self.slkpdh_pget_networktleinclofldsram = self._io.read_s4le()
            self.slkpdh_pget_networktleincloexpsram = self._io.read_s1()
            self.slkpdh_pget_networktlenodeofldsram = self._io.read_s4le()
            self.slkpdh_pget_networktlenodeoexpsram = self._io.read_s1()
            self.slkpdh_pget_networktleeccofldsram = self._io.read_s4le()
            self.slkpdh_pget_networktleeccoexpsram = self._io.read_s1()
            self.slkpdh_pget_networktleargpofldsram = self._io.read_s4le()
            self.slkpdh_pget_networktleargpoexpsram = self._io.read_s1()
            self.slkpdh_pget_networktlemofldsram = self._io.read_s4le()
            self.slkpdh_pget_networktlemoexpsram = self._io.read_s1()
            self.slkpdh_pget_networktlenofldsram = self._io.read_s4le()
            self.slkpdh_pget_networktlenoexpsram = self._io.read_s1()


    class LinkComMode(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.link_pget_link_mode = self._io.read_u1()
            self.link_pget_link_mode_last_error = self._io.read_u1()
            self.link_pget_max_mode_time = self._io.read_u1()
            self.link_pget_max_transition_time = self._io.read_u1()
            self.link_pget_max_stnchktmwaittime = self._io.read_u1()
            self.link_pget_max_stnccomtmwaittime = self._io.read_u1()
            self.pdh_pget_slkprognum = self._io.read_u1()
            self.pdh_pget_txrepeatmode = self._io.read_u1()
            self.pdh_pget_arqonuplink = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comtxon = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comrxon = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_comautotm = self._io.read_bits_int_be(1) != 0
            self.link_pget_uhfmode_allow_slink_on = self._io.read_bits_int_be(1) != 0


    class PdhPlepsRqPwrMinIThresholdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pleps_pget_min_i_salsa = self._io.read_u2le()
            self.pdh_pleps_pget_min_i_fu = self._io.read_u2le()
            self.pdh_pleps_pget_min_i_fda_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_min_i_fda_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_min_i_gyro_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_min_i_gyro_unreg = self._io.read_u2le()
            self.pdh_pleps_pget_min_i_pdh0_3v3 = self._io.read_u2le()
            self.pdh_pleps_pget_min_i_pdh1_3v3 = self._io.read_u2le()


    class LinkgsTmState(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.linkgs_aistate = self._io.read_u1()
            self.linkgs_rxfrequency = self._io.read_u4le()
            self.linkgs_txfrequency = self._io.read_u4le()
            self.linkgs_rcvfecmod = self._io.read_u1()
            self.linkgs_xmtfecmod = self._io.read_u1()
            self.linkgs_servicetype = self._io.read_u1()
            self.linkgs_minsir = self._io.read_u1()
            self.linkgs_maxsir = self._io.read_u1()
            self.linkgs_tempgnd = self._io.read_s1()
            self.linkgs_tempsat = self._io.read_s1()
            self.linkgs_fading = self._io.read_u2le()
            self.linkgs_contacttime = self._io.read_u2le()
            self.linkgs_systime = self._io.read_u4le()


    class PdhTmSapPltu(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_pltuscid = self._io.read_u2le()
            self.slkpdh_pget_pltudfcid = self._io.read_u1()
            self.slkpdh_pget_pltuversno = self._io.read_u1()
            self.slkpdh_pget_pltuportid = self._io.read_u1()
            self.slkpdh_pget_pltufrmseqno = self._io.read_u1()
            self.slkpdh_pget_pltufrmlen = self._io.read_u2le()
            self.slkpdh_pget_pltupdutypeid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_pltuqos = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_pltusrcdstid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_pltupcid = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_pltucrc32 = self._io.read_u4le()


    class AdcsSenseSuse2D(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dxsuse2_sat = self._io.read_s2le()
            self.adcs_pget_dysuse2_sat = self._io.read_s2le()
            self.adcs_pget_dzsuse2_sat = self._io.read_s2le()
            self.thm_pget_tempsuse2 = self._io.read_u2le()
            self.adcs_pget_cursumsuse2_sat = self._io.read_s2le()
            self.adcs_pget_curx1suse2_sat = self._io.read_s2le()
            self.adcs_pget_curx2suse2_sat = self._io.read_s2le()
            self.adcs_pget_cury1suse2_sat = self._io.read_s2le()
            self.adcs_pget_cury2suse2_sat = self._io.read_s2le()
            self.adcs_pget_suse2_useflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_useflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_powerflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_powerflaglock = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_healthflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2_validflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_isensorstates2 = self._io.read_u1()
            self.adcs_pget_isensorstatuss2 = self._io.read_u1()


    class Rw2TmCstm1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_fsmcntrlstate = self._io.read_u1()
            self.rw2_pget_mtrnegdirsense = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrrotdirchange = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrrotzero = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_softstholdmtroff = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_newhalledge = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_hallirqguard = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_hallirqcollision = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryext = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextmtrrate = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryexttorque = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextsatrate = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_entryextsatangle = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_mtrcuractive = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_gyro1active = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.rw2_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.rw2_pget_rategyroz = self._io.read_s4le()
            self.rw2_pget_satrate = self._io.read_s4le()
            self.rw2_pget_vltgyro0zref = self._io.read_u2le()
            self.rw2_pget_vltgyro0z = self._io.read_u2le()
            self.rw2_pget_rategyro1x = self._io.read_s2le()
            self.rw2_pget_rategyro1y = self._io.read_s2le()
            self.rw2_pget_rategyro1z = self._io.read_s2le()


    class PdhTmLaynetEepromPar(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_networksatnum = self._io.read_u1()
            self.slkpdh_pget_networksatsrceeprom = self._io.read_u2le()
            self.slkpdh_pget_networksatdsteeprom = self._io.read_u2le()
            self.slkpdh_pget_networksat2satsrceeprom = self._io.read_u2le()
            self.slkpdh_pget_networksat2satdsteeprom = self._io.read_u2le()
            self.slkpdh_pget_networkcostmaxeeprom = self._io.read_u2le()


    class Rw1TmCstm2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw1_pget_systime = self._io.read_u4le()


    class SalsaUpdatesSlotTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_slot0_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_hasvalidimage = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isfree = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_isundererase = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot0_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot1_ishealthy = self._io.read_bits_int_be(1) != 0
            self.sat_pget_fw_updater_slot2_ishealthy = self._io.read_bits_int_be(1) != 0


    class EpsRawadc1values(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_pget_s16_a_rw1_raw = self._io.read_s2le()
            self.eps_pget_s17_a_rw2_raw = self._io.read_s2le()
            self.eps_pget_s18_a_trx0_raw = self._io.read_s2le()
            self.eps_pget_s19_a_slink_raw = self._io.read_s2le()
            self.eps_pget_s20_a_out_bat1_raw = self._io.read_s2le()
            self.thm_pget_s21_th_charger1_raw = self._io.read_s2le()
            self.eps_pget_s22_v_sum_raw = self._io.read_s2le()
            self.eps_pget_s23_a_in_charger1_raw = self._io.read_s2le()
            self.eps_pget_s24_v_bat0_raw = self._io.read_s2le()
            self.eps_pget_s25_a_out_charger0_raw = self._io.read_s2le()
            self.eps_pget_s26_a_in_charger0_raw = self._io.read_s2le()
            self.eps_pget_s27_a_sens0_raw = self._io.read_s2le()
            self.thm_pget_s28_th_charger0_raw = self._io.read_s2le()
            self.eps_pget_s29_a_out_bat0_raw = self._io.read_s2le()
            self.eps_pget_s30_a_in_bat0_raw = self._io.read_s2le()
            self.thm_pget_s31_th_bat0_raw = self._io.read_s2le()


    class AdcsAttDcmSattotgt(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_sattotgtdcmerroru1 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerroru2 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerroru3 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerrorv1 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerrorv2 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerrorv3 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerrorw1 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerrorw2 = self._io.read_s2le()
            self.adcs_pget_sattotgtdcmerrorw3 = self._io.read_s2le()
            self.adcs_pget_attitudeerrorangle = self._io.read_u2le()


    class PdhPlepsFwUpdateMissingintervalls(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_missingsequencestartarray = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceendarray = self._io.read_u2le()


    class PdhTmLaynetStd0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.slkpdh_pget_systime = self._io.read_u4le()
            self.slkpdh_pget_netfsmstate = self._io.read_u1()
            self.slkpdh_pget_netbasetrmsgperr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasetrmdijkstraerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasetrmjdayconfig = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_netbasetrmfsmstate = self._io.read_u1()
            self.slkpdh_pget_netbasercvsgperr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasercvdijkstraerr = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_netbasercvjdayconfig = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu14 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu15 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu16 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu17 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu18 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu19 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu20 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu21 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu22 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu23 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu24 = self._io.read_bits_int_be(1) != 0
            self.slkpdh_pget_boolrfu25 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.slkpdh_pget_netbasercvfsmstate = self._io.read_u1()
            self.slkpdh_pget_netspectrmsrcscid = self._io.read_u2le()
            self.slkpdh_pget_netspectrmdstscid = self._io.read_u2le()
            self.slkpdh_pget_netspecrcvsrcscid = self._io.read_u2le()
            self.slkpdh_pget_netspecrcvdstscid = self._io.read_u2le()


    class PdhTmMemextser16(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_memextserialrdaddr = self._io.read_u4le()
            self.pdh_pget_memextserialdata16 = self._io.read_u1()


    class Com1TmMem32(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_memdatatype = self._io.read_u1()
            self.com0_pget_memdata32 = self._io.read_u1()


    class SalsaTmReadLmsRegs(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_pmu_config_id = self._io.read_u2le()
            self.salsa_pget_max_frames = self._io.read_u2le()
            self.salsa_pget_pmu_content = self._io.read_u1()


    class Com4TmRndpkt(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com4_pget_systime = self._io.read_u4le()
            self.com4_pget_rndpktcnt = self._io.read_u1()
            self.com4_pget_rndpkttype = self._io.read_u1()
            self.com4_pget_rnddata = self._io.read_u1()


    class SalsaTmUploadStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_failed_to_verify = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.salsa_pget_config_failed_page = self._io.read_u2le()


    class AdcsEnvIgrf(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_igrfbmagxned = self._io.read_s2le()
            self.adcs_pget_igrfbmagyned = self._io.read_s2le()
            self.adcs_pget_igrfbmagzned = self._io.read_s2le()
            self.adcs_pget_igrfbmagxecef = self._io.read_s2le()
            self.adcs_pget_igrfbmagyecef = self._io.read_s2le()
            self.adcs_pget_igrfbmagzecef = self._io.read_s2le()
            self.adcs_pget_igrfbmagxeci = self._io.read_s2le()
            self.adcs_pget_igrfbmagyeci = self._io.read_s2le()
            self.adcs_pget_igrfbmagzeci = self._io.read_s2le()


    class PdhTmMemextser128(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_systime = self._io.read_u4le()
            self.pdh_pget_memextserialspiactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdeepromactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash0active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialrdflash1active = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialwractive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialreleaseactive = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_memextserialspiaccesserror = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.pdh_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.pdh_pget_memextserialrdaddr = self._io.read_u4le()
            self.pdh_pget_memextserialdata128 = self._io.read_u1()


    class AdcsActaMataStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_dctrlmagmomentmatax_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentmatay_sat = self._io.read_s2le()
            self.adcs_pget_dctrlmagmomentmataz_sat = self._io.read_s2le()
            self.adcs_pget_mata_useflag = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_iactarrayavailstatusmata = self._io.read_u1()
            self.adcs_pget_iactstatematx = self._io.read_u1()
            self.adcs_pget_iactstatematy = self._io.read_u1()
            self.adcs_pget_iactstatematz = self._io.read_u1()
            self.adcs_pget_matxruntime = self._io.read_u2le()
            self.adcs_pget_matyruntime = self._io.read_u2le()
            self.adcs_pget_matzruntime = self._io.read_u2le()
            self.adcs_pget_matxruntimethreshold = self._io.read_u2le()
            self.adcs_pget_matyruntimethreshold = self._io.read_u2le()
            self.adcs_pget_matzruntimethreshold = self._io.read_u2le()


    class PdhTmAck(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdh_pget_arqseqnouplink = self._io.read_u2le()
            self.pdh_pget_arrayrfuacktm = self._io.read_u1()


    class AdcsCmdfifoinfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_cmdfifofilllevel = self._io.read_u1()
            self.adcs_pget_cmdfifoisrewritable = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_cmdfifomaxobservedfilllevel = self._io.read_u1()
            self.adcs_pget_cmdfifooverflowcount = self._io.read_u2le()
            self.adcs_pget_cmdfifomsgcount = self._io.read_u2le()
            self.adcs_pget_cmdfifomaxobservedbytecount = self._io.read_u4le()


    class AdcsStdTm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_imodechklistthisstepactive = self._io.read_s1()
            self.adcs_pget_iattdetfinalstate = self._io.read_u1()
            self.adcs_pget_isensorarrayavailstatusga = self._io.read_u1()
            self.adcs_pget_isensorarrayavailstatusmfsa = self._io.read_u1()
            self.adcs_pget_isensorarrayavailstatussusea = self._io.read_u1()
            self.adcs_pget_iactarrayavailstatusrwa = self._io.read_u1()
            self.adcs_pget_iactarrayavailstatusmata = self._io.read_u1()
            self.adcs_pget_attdetmfsdistcorrmode = self._io.read_u1()
            self.adcs_pget_attdetsusedistcorrmode = self._io.read_u1()
            self.adcs_pget_attdettrackigrfdeltab = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetsusealbedotracking = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse1albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse2albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse3albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse4albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse5albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_suse6albedoflag = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetautovirtualizemfsa = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetautovirtualizesusea = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetnarrowvectors = self._io.read_bits_int_be(1) != 0
            self.adcs_pget_attdetmismatchingvectors = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.adcs_pget_omegaxoptimal_sat = self._io.read_s2le()
            self.adcs_pget_omegayoptimal_sat = self._io.read_s2le()
            self.adcs_pget_omegazoptimal_sat = self._io.read_s2le()
            self.adcs_pget_magxoptimal_sat = self._io.read_s2le()
            self.adcs_pget_magyoptimal_sat = self._io.read_s2le()
            self.adcs_pget_magzoptimal_sat = self._io.read_s2le()
            self.adcs_pget_sunxoptimal_sat = self._io.read_s2le()
            self.adcs_pget_sunyoptimal_sat = self._io.read_s2le()
            self.adcs_pget_sunzoptimal_sat = self._io.read_s2le()
            self.adcs_pget_dctrltorquerwax_sat_lr = self._io.read_s1()
            self.adcs_pget_dctrltorquerway_sat_lr = self._io.read_s1()
            self.adcs_pget_dctrltorquerwaz_sat_lr = self._io.read_s1()
            self.adcs_pget_dctrlmagmomentmatax_sat_lr = self._io.read_s1()
            self.adcs_pget_dctrlmagmomentmatay_sat_lr = self._io.read_s1()
            self.adcs_pget_dctrlmagmomentmataz_sat_lr = self._io.read_s1()
            self.adcs_pget_ireadtorquerwx_mfr = self._io.read_s2le()
            self.adcs_pget_ireadtorquerwy_mfr = self._io.read_s2le()
            self.adcs_pget_ireadtorquerwz_mfr = self._io.read_s2le()
            self.adcs_pget_ireadrotspeedrwx_mfr = self._io.read_s2le()
            self.adcs_pget_ireadrotspeedrwy_mfr = self._io.read_s2le()
            self.adcs_pget_ireadrotspeedrwz_mfr = self._io.read_s2le()
            self.adcs_pget_sgp4latxpef = self._io.read_s2le()
            self.adcs_pget_sgp4longypef = self._io.read_s2le()
            self.adcs_pget_sgp4altpef = self._io.read_u1()
            self.adcs_pget_attitudeerrorangle = self._io.read_u2le()
            self.adcs_pget_targetdata_distance = self._io.read_u2le()
            self.adcs_pget_targetdata_controlisactive = self._io.read_bits_int_be(1) != 0


    class Rw2TmSwvers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()
            self.rw2_pget_swversmajor = self._io.read_u1()
            self.rw2_pget_swversminor = self._io.read_u1()
            self.rw2_pget_swbuildyear = self._io.read_u1()
            self.rw2_pget_swbuildmonth = self._io.read_u1()
            self.rw2_pget_swbuildday = self._io.read_u1()
            self.rw2_pget_swbuildhour = self._io.read_u1()
            self.rw2_pget_swbuildmin = self._io.read_u1()
            self.rw2_pget_swbuildsec = self._io.read_u1()
            self.rw2_pget_serialnum = self._io.read_u2le()
            self.rw2_pget_devid = self._io.read_u1()


    class SatFwUpdateMissingintervalls(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sat_pget_fw_updater_missingsequencestartarray = self._io.read_u2le()
            self.sat_pget_fw_updater_missingsequenceendarray = self._io.read_u2le()


    class SalsaTmGetRecordingTimestamps(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.salsa_pget_sector_count = self._io.read_u2le()
            self.salsa_pget_max_frames = self._io.read_u2le()
            self.salsa_pget_rx1l_vhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2l_vhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx1w_uhf_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2w_srd_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx1h_sband_used = self._io.read_bits_int_be(1) != 0
            self.salsa_pget_rx2h_sband_used = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.salsa_pget_record_start_time = self._io.read_s8le()
            self.salsa_pget_record_end_time = self._io.read_s8le()
            self.salsa_pget_fft_record_rate = self._io.read_u1()
            self.salsa_pget_record_hours = self._io.read_u1()
            self.salsa_pget_record_minutes = self._io.read_u1()


    class Com0TmStd(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.com0_pget_systime = self._io.read_u4le()
            self.com0_pget_resetcnt = self._io.read_u2le()
            self.com0_pget_rxsducnt = self._io.read_u2le()
            self.com0_pget_rxspducnt = self._io.read_u2le()
            self.com0_pget_fsmmainstate = self._io.read_u1()
            self.com0_pget_invrxframe = self._io.read_bits_int_be(1) != 0
            self.com0_pget_comtimeout = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyenvir = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalypwr = self._io.read_bits_int_be(1) != 0
            self.com0_pget_pdurxfifofull = self._io.read_bits_int_be(1) != 0
            self.com0_pget_rxmode = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxrxovercur = self._io.read_bits_int_be(1) != 0
            self.com0_pget_trxtxovercur = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu0 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu1 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu2 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu4 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu5 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu6 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu7 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyrssi = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyrssirx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycd = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycurtrxrx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycurtrxtx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalycur3v3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyvlttrxrx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyvlttrxtx = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalyvlt3v3 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_anomalytmptnc = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu8 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu9 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu10 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu11 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu12 = self._io.read_bits_int_be(1) != 0
            self.com0_pget_boolrfu13 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.com0_pget_rssi = self._io.read_u2le()
            self.com0_pget_rssirx = self._io.read_u2le()
            self.com0_pget_cd = self._io.read_u2le()
            self.com0_pget_curtrx = self._io.read_u2le()
            self.com0_pget_curtrxtx = self._io.read_u2le()
            self.com0_pget_cur3v3 = self._io.read_u2le()
            self.com0_pget_vlttrx = self._io.read_u2le()
            self.com0_pget_vlttrxtx = self._io.read_u2le()
            self.com0_pget_vlt3v3 = self._io.read_u2le()
            self.thm_com0_pget_tmptnc = self._io.read_u2le()
            self.com0_pget_timetoautorecoveryreset = self._io.read_u4le()


    class AdcsCalTcompG8(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adcs_pget_g8tbiaspol2coefxaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol1coefxaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol0coefxaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol2coefyaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol1coefyaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol0coefyaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol2coefzaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol1coefzaxis = self._io.read_s4le()
            self.adcs_pget_g8tbiaspol0coefzaxis = self._io.read_s4le()


    class Rw2TmCstm4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rw2_pget_systime = self._io.read_u4le()



